Module: Aws::EC2

Defined in:
lib/aws-sdk-ec2/endpoint_parameters.rb,
lib/aws-sdk-ec2/customizations/tag.rb,
lib/aws-sdk-ec2/vpc_peering_connection.rb,
lib/aws-sdk-ec2/customizations/instance.rb,
lib/aws-sdk-ec2/customizations/resource.rb,
lib/aws-sdk-ec2/route_table_association.rb,
lib/aws-sdk-ec2/plugins/region_validation.rb,
lib/aws-sdk-ec2/network_interface_association.rb,
lib/aws-sdk-ec2/plugins/copy_encrypted_snapshot.rb,
sig/tag.rbs,
sig/vpc.rbs,
sig/image.rbs,
sig/route.rbs,
sig/client.rbs,
sig/errors.rbs,
sig/params.rbs,
sig/subnet.rbs,
sig/volume.rbs,
sig/waiters.rbs,
sig/instance.rbs,
sig/key_pair.rbs,
sig/resource.rbs,
sig/snapshot.rbs,
sig/nat_gateway.rbs,
sig/network_acl.rbs,
sig/route_table.rbs,
sig/vpc_address.rbs,
sig/dhcp_options.rbs,
sig/key_pair_info.rbs,
sig/security_group.rbs,
sig/classic_address.rbs,
sig/placement_group.rbs,
sig/internet_gateway.rbs,
sig/network_interface.rbs,
sig/vpc_peering_connection.rbs,
sig/route_table_association.rbs,
sig/network_interface_association.rbs,
lib/aws-sdk-ec2/plugins/endpoints.rb,
lib/aws-sdk-ec2/network_interface.rb,
lib/aws-sdk-ec2/endpoint_provider.rb,
lib/aws-sdk-ec2/internet_gateway.rb,
lib/aws-sdk-ec2/placement_group.rb,
lib/aws-sdk-ec2/classic_address.rb,
lib/aws-sdk-ec2/security_group.rb,
lib/aws-sdk-ec2/key_pair_info.rb,
lib/aws-sdk-ec2/dhcp_options.rb,
lib/aws-sdk-ec2/vpc_address.rb,
lib/aws-sdk-ec2/route_table.rb,
lib/aws-sdk-ec2/network_acl.rb,
lib/aws-sdk-ec2/nat_gateway.rb,
lib/aws-sdk-ec2/client_api.rb,
lib/aws-sdk-ec2/endpoints.rb,
lib/aws-sdk-ec2/snapshot.rb,
lib/aws-sdk-ec2/resource.rb,
lib/aws-sdk-ec2/key_pair.rb,
lib/aws-sdk-ec2/instance.rb,
lib/aws-sdk-ec2/waiters.rb,
lib/aws-sdk-ec2/volume.rb,
lib/aws-sdk-ec2/subnet.rb,
lib/aws-sdk-ec2/errors.rb,
lib/aws-sdk-ec2/client.rb,
lib/aws-sdk-ec2/types.rb,
lib/aws-sdk-ec2/route.rb,
lib/aws-sdk-ec2/image.rb,
lib/aws-sdk-ec2/vpc.rb,
lib/aws-sdk-ec2/tag.rb,
lib/aws-sdk-ec2.rb

Overview

This module provides support for Amazon Elastic Compute Cloud. This module is available in the aws-sdk-ec2 gem.

Client

The Client class provides one method for each API operation. Operation methods each accept a hash of request parameters and return a response structure.

ec2 = Aws::EC2::Client.new
resp = ec2.accept_address_transfer(params)

See Client for more information.

Errors

Errors returned from Amazon Elastic Compute Cloud are defined in the Errors module and all extend Errors::ServiceError.

begin
  # do stuff
rescue Aws::EC2::Errors::ServiceError
  # rescues all Amazon Elastic Compute Cloud API errors
end

See Errors for more information.

Defined Under Namespace

Modules: ClientApi, Endpoints, Errors, Params, Plugins, ResourcePaginationFix, Types, Waiters Classes: ClassicAddress, Client, DhcpOptions, EndpointParameters, EndpointProvider, Image, Instance, InternetGateway, KeyPair, KeyPairInfo, NatGateway, NetworkAcl, NetworkInterface, NetworkInterfaceAssociation, PlacementGroup, Resource, Route, RouteTable, RouteTableAssociation, SecurityGroup, Snapshot, Subnet, Tag, Volume, Vpc, VpcAddress, VpcPeeringConnection

service collapse

GEM_VERSION =
'1.626.0'