Class: Aws::EC2::DhcpOptions
- Inherits:
-
Object
- Object
- Aws::EC2::DhcpOptions
- Extended by:
- Deprecations
- Defined in:
- sig/dhcp_options.rbs,
lib/aws-sdk-ec2/dhcp_options.rb
Overview
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
-
#dhcp_configurations ⇒ Array<Types::DhcpConfiguration>
The DHCP options in the set.
- #id ⇒ String (also: #dhcp_options_id)
-
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the DHCP options set.
-
#tags ⇒ Array<Types::Tag>
Any tags assigned to the DHCP options set.
Actions collapse
- #associate_with_vpc(options = {}) ⇒ EmptyStructure
- #create_tags(options = {}) ⇒ Tag::Collection
- #delete(options = {}) ⇒ EmptyStructure
- #delete_tags(options = {}) ⇒ Tag::Collection
- #identifiers ⇒ Object deprecated private Deprecated.
Instance Method Summary collapse
- #client ⇒ Client
-
#data ⇒ Types::DhcpOptions
Returns the data for this DhcpOptions.
-
#data_loaded? ⇒ Boolean
Returns
trueif this resource is loaded. -
#initialize(*args) ⇒ DhcpOptions
constructor
A new instance of DhcpOptions.
-
#load ⇒ self
(also: #reload)
Loads, or reloads #data for the current DhcpOptions.
-
#wait_until(options = {}) {|resource| ... } ⇒ Resource
deprecated
Deprecated.
Use [Aws::EC2::Client] #wait_until instead
Constructor Details
#initialize(id, options = {}) ⇒ DhcpOptions #initialize(options = {}) ⇒ DhcpOptions
Returns a new instance of DhcpOptions.
13 14 15 |
# File 'sig/dhcp_options.rbs', line 13
def initialize: (String id, Hash[Symbol, untyped] options) -> void
| (id: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void
|
Instance Method Details
#associate_with_vpc(options = {}) ⇒ EmptyStructure
44 |
# File 'sig/dhcp_options.rbs', line 44
def associate_with_vpc: (
|
#create_tags(options = {}) ⇒ Tag::Collection
51 |
# File 'sig/dhcp_options.rbs', line 51
def create_tags: (
|
#data ⇒ Types::DhcpOptions
Returns the data for this Aws::EC2::DhcpOptions. Calls
Client#describe_dhcp_options if #data_loaded? is false.
37 |
# File 'sig/dhcp_options.rbs', line 37
def data: () -> Types::DhcpOptions
|
#data_loaded? ⇒ Boolean
40 |
# File 'sig/dhcp_options.rbs', line 40
def data_loaded?: () -> bool
|
#delete(options = {}) ⇒ EmptyStructure
75 |
# File 'sig/dhcp_options.rbs', line 75
def delete: (
|
#delete_tags(options = {}) ⇒ Tag::Collection
63 |
# File 'sig/dhcp_options.rbs', line 63
def delete_tags: (
|
#dhcp_configurations ⇒ Array<Types::DhcpConfiguration>
The DHCP options in the set.
28 |
# File 'sig/dhcp_options.rbs', line 28
def dhcp_configurations: () -> ::Array[Types::DhcpConfiguration]
|
#id ⇒ String Also known as: dhcp_options_id
18 |
# File 'sig/dhcp_options.rbs', line 18
def id: () -> String
|
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
326 327 328 |
# File 'lib/aws-sdk-ec2/dhcp_options.rb', line 326 def identifiers { id: @id } end |
#load ⇒ self Also known as: reload
Loads, or reloads #data for the current Aws::EC2::DhcpOptions.
Returns self making it possible to chain methods.
.reload.data
33 |
# File 'sig/dhcp_options.rbs', line 33
def load: () -> self
|
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the DHCP options set.
22 |
# File 'sig/dhcp_options.rbs', line 22
def owner_id: () -> ::String
|
#tags ⇒ Array<Types::Tag>
Any tags assigned to the DHCP options set.
25 |
# File 'sig/dhcp_options.rbs', line 25
def tags: () -> ::Array[Types::Tag]
|
#wait_until(options = {}) {|resource| ... } ⇒ Resource
Use [Aws::EC2::Client] #wait_until instead
The waiting operation is performed on a copy. The original resource remains unchanged.
Waiter polls an API operation until a resource enters a desired state.
Basic Usage
Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.
# polls in a loop until condition is true
resource.wait_until() {|resource| condition}
Example
instance.wait_until(max_attempts:10, delay:5) do |instance|
instance.state.name == 'running'
end
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:
# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
throw :failure if Time.now - started_at > 3600
end
# disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}
Handling Errors
When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.
begin
resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
attempts attempt in seconds invoked before each attempt invoked before each wait
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/aws-sdk-ec2/dhcp_options.rb', line 174 def wait_until( = {}, &block) self_copy = self.dup attempts = 0 [:max_attempts] = 10 unless .key?(:max_attempts) [:delay] ||= 10 [:poller] = Proc.new do attempts += 1 if block.call(self_copy) [:success, self_copy] else self_copy.reload unless attempts == [:max_attempts] :retry end end Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do Aws::Waiters::Waiter.new().wait({}) end end |