Class: Aws::EC2::Instance::Collection

Inherits:
Resources::Collection
  • Object
show all
Extended by:
Deprecations
Defined in:
lib/aws-sdk-ec2/customizations/instance.rb,
sig/instance.rbs,
lib/aws-sdk-ec2/instance.rb

Batch Actions collapse

Instance Method Details

#batch_create_tags(options = {}) ⇒ void

This method returns an undefined value.

Examples:

Request syntax with placeholder values


instance.batch_create_tags({
  dry_run: false,
  tags: [ # required
    {
      key: "String",
      value: "String",
    },
  ],
})

Parameters:

  • options ({}) (defaults to: {})

Options Hash (options):

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

  • :tags (required, Array<Types::Tag>)

    The tags. The value parameter is required, but if you don't want the tag to have a value, specify the parameter with no value, and we set the value to an empty string.



2001
2002
2003
2004
2005
2006
2007
2008
2009
2010
2011
2012
2013
# File 'lib/aws-sdk-ec2/instance.rb', line 2001

def batch_create_tags(options = {})
  batch_enum.each do |batch|
    params = Aws::Util.copy_hash(options)
    params[:resources] ||= []
    batch.each do |item|
      params[:resources] << item.id
    end
    Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
      batch[0].client.create_tags(params)
    end
  end
  nil
end

#batch_delete_tags!(options = {}) ⇒ void

This method returns an undefined value.

Examples:

Request syntax with placeholder values


instance.batch_delete_tags!({
  dry_run: false,
  tags: [
    {
      key: "String",
      value: "String",
    },
  ],
})

Parameters:

  • options ({}) (defaults to: {})

Options Hash (options):

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

  • :tags (Array<Types::Tag>)

    The tags to delete. Specify a tag key and an optional tag value to delete specific tags. If you specify a tag key without a tag value, we delete any tag with this key regardless of its value. If you specify a tag key with an empty string as the tag value, we delete the tag only if its value is an empty string.

    If you omit this parameter, we delete all user-defined tags for the specified resources. We do not delete Amazon Web Services-generated tags (tags that have the aws: prefix).

    Constraints: Up to 1000 tags.



2045
2046
2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
2057
# File 'lib/aws-sdk-ec2/instance.rb', line 2045

def batch_delete_tags!(options = {})
  batch_enum.each do |batch|
    params = Aws::Util.copy_hash(options)
    params[:resources] ||= []
    batch.each do |item|
      params[:resources] << item.id
    end
    Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
      batch[0].client.delete_tags(params)
    end
  end
  nil
end

#batch_monitor(options = {}) ⇒ void

This method returns an undefined value.

Examples:

Request syntax with placeholder values


instance.batch_monitor({
  dry_run: false,
})

Parameters:

  • options ({}) (defaults to: {})

Options Hash (options):

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.



2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
# File 'lib/aws-sdk-ec2/instance.rb', line 2071

def batch_monitor(options = {})
  batch_enum.each do |batch|
    params = Aws::Util.copy_hash(options)
    params[:instance_ids] ||= []
    batch.each do |item|
      params[:instance_ids] << item.id
    end
    Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
      batch[0].client.monitor_instances(params)
    end
  end
  nil
end

#batch_reboot(options = {}) ⇒ void

This method returns an undefined value.

Examples:

Request syntax with placeholder values


instance.batch_reboot({
  dry_run: false,
})

Parameters:

  • options ({}) (defaults to: {})

Options Hash (options):

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.



2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
# File 'lib/aws-sdk-ec2/instance.rb', line 2097

def batch_reboot(options = {})
  batch_enum.each do |batch|
    params = Aws::Util.copy_hash(options)
    params[:instance_ids] ||= []
    batch.each do |item|
      params[:instance_ids] << item.id
    end
    Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
      batch[0].client.reboot_instances(params)
    end
  end
  nil
end

#batch_start(options = {}) ⇒ void

This method returns an undefined value.

Examples:

Request syntax with placeholder values


instance.batch_start({
  additional_info: "String",
  dry_run: false,
})

Parameters:

  • options ({}) (defaults to: {})

Options Hash (options):

  • :additional_info (String)

    Reserved.

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.



2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
# File 'lib/aws-sdk-ec2/instance.rb', line 2126

def batch_start(options = {})
  batch_enum.each do |batch|
    params = Aws::Util.copy_hash(options)
    params[:instance_ids] ||= []
    batch.each do |item|
      params[:instance_ids] << item.id
    end
    Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
      batch[0].client.start_instances(params)
    end
  end
  nil
end

#batch_stop(options = {}) ⇒ void

This method returns an undefined value.

Examples:

Request syntax with placeholder values


instance.batch_stop({
  hibernate: false,
  skip_os_shutdown: false,
  dry_run: false,
  force: false,
})

Parameters:

  • options ({}) (defaults to: {})

Options Hash (options):

  • :hibernate (Boolean)

    Hibernates the instance if the instance was enabled for hibernation at launch. If the instance cannot hibernate successfully, a normal shutdown occurs. For more information, see Hibernate your Amazon EC2 instance in the Amazon EC2 User Guide.

    Default: false

  • :skip_os_shutdown (Boolean)

    Specifies whether to bypass the graceful OS shutdown process when the instance is stopped.

    Bypassing the graceful OS shutdown might result in data loss or corruption (for example, memory contents not flushed to disk or loss of in-flight IOs) or skipped shutdown scripts.

    Default: false

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

  • :force (Boolean)

    Forces the instance to stop. The instance will first attempt a graceful shutdown, which includes flushing file system caches and metadata. If the graceful shutdown fails to complete within the timeout period, the instance shuts down forcibly without flushing the file system caches and metadata.

    After using this option, you must perform file system check and repair procedures. This option is not recommended for Windows instances. For more information, see Troubleshoot Amazon EC2 instance stop issues in the Amazon EC2 User Guide.

    Default: false



2192
2193
2194
2195
2196
2197
2198
2199
2200
2201
2202
2203
2204
# File 'lib/aws-sdk-ec2/instance.rb', line 2192

def batch_stop(options = {})
  batch_enum.each do |batch|
    params = Aws::Util.copy_hash(options)
    params[:instance_ids] ||= []
    batch.each do |item|
      params[:instance_ids] << item.id
    end
    Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
      batch[0].client.stop_instances(params)
    end
  end
  nil
end

#batch_terminate!(options = {}) ⇒ void

This method returns an undefined value.

Examples:

Request syntax with placeholder values


instance.batch_terminate!({
  force: false,
  skip_os_shutdown: false,
  dry_run: false,
})

Parameters:

  • options ({}) (defaults to: {})

Options Hash (options):

  • :force (Boolean)

    Forces the instances to terminate. The instance will first attempt a graceful shutdown, which includes flushing file system caches and metadata. If the graceful shutdown fails to complete within the timeout period, the instance shuts down forcibly without flushing the file system caches and metadata.

  • :skip_os_shutdown (Boolean)

    Specifies whether to bypass the graceful OS shutdown process when the instance is terminated.

    Default: false

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.



2231
2232
2233
2234
2235
2236
2237
2238
2239
2240
2241
2242
2243
# File 'lib/aws-sdk-ec2/instance.rb', line 2231

def batch_terminate!(options = {})
  batch_enum.each do |batch|
    params = Aws::Util.copy_hash(options)
    params[:instance_ids] ||= []
    batch.each do |item|
      params[:instance_ids] << item.id
    end
    Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
      batch[0].client.terminate_instances(params)
    end
  end
  nil
end

#batch_unmonitor(options = {}) ⇒ void

This method returns an undefined value.

Examples:

Request syntax with placeholder values


instance.batch_unmonitor({
  dry_run: false,
})

Parameters:

  • options ({}) (defaults to: {})

Options Hash (options):

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.



2257
2258
2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
2269
# File 'lib/aws-sdk-ec2/instance.rb', line 2257

def batch_unmonitor(options = {})
  batch_enum.each do |batch|
    params = Aws::Util.copy_hash(options)
    params[:instance_ids] ||= []
    batch.each do |item|
      params[:instance_ids] << item.id
    end
    Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
      batch[0].client.unmonitor_instances(params)
    end
  end
  nil
end