Class: Aws::EC2::InternetGateway

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/internet_gateway.rbs,
lib/aws-sdk-ec2/internet_gateway.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Instance Method Summary collapse

Constructor Details

#initialize(id, options = {}) ⇒ InternetGateway #initialize(options = {}) ⇒ InternetGateway

Returns a new instance of InternetGateway.

Overloads:

  • #initialize(id, options = {}) ⇒ InternetGateway

    Parameters:

    • id (String)

    Options Hash (options):

  • #initialize(options = {}) ⇒ InternetGateway

    Options Hash (options):

    • :id (required, String)
    • :client (Client)


13
14
15
# File 'sig/internet_gateway.rbs', line 13

def initialize: (String id, Hash[Symbol, untyped] options) -> void
| (id: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#attach_to_vpc(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


internet_gateway.attach_to_vpc({
  dry_run: false,
  vpc_id: "VpcId", # required
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

  • :vpc_id (required, String)

    The ID of the VPC.

Returns:

  • (EmptyStructure)


44
# File 'sig/internet_gateway.rbs', line 44

def attach_to_vpc: (

#attachmentsArray<Types::InternetGatewayAttachment>

Any VPCs attached to the internet gateway.



22
# File 'sig/internet_gateway.rbs', line 22

def attachments: () -> ::Array[Types::InternetGatewayAttachment]

#clientClient

Returns:



60
# File 'lib/aws-sdk-ec2/internet_gateway.rb', line 60

def client: () -> Client

#create_tags(options = {}) ⇒ Tag::Collection

Examples:

Request syntax with placeholder values


tag = internet_gateway.create_tags({
  dry_run: false,
  tags: [ # required
    {
      key: "String",
      value: "String",
    },
  ],
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

  • :tags (required, Array<Types::Tag>)

    The tags. The value parameter is required, but if you don't want the tag to have a value, specify the parameter with no value, and we set the value to an empty string.

Returns:



51
# File 'sig/internet_gateway.rbs', line 51

def create_tags: (

#dataTypes::InternetGateway

Returns the data for this Aws::EC2::InternetGateway. Calls Client#describe_internet_gateways if #data_loaded? is false.

Returns:



37
# File 'sig/internet_gateway.rbs', line 37

def data: () -> Types::InternetGateway

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



40
# File 'sig/internet_gateway.rbs', line 40

def data_loaded?: () -> bool

#delete(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


internet_gateway.delete({
  dry_run: false,
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (EmptyStructure)


75
# File 'sig/internet_gateway.rbs', line 75

def delete: (

#delete_tags(options = {}) ⇒ Tag::Collection

Examples:

Request syntax with placeholder values


tag = internet_gateway.delete_tags({
  dry_run: false,
  tags: [
    {
      key: "String",
      value: "String",
    },
  ],
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

  • :tags (Array<Types::Tag>)

    The tags to delete. Specify a tag key and an optional tag value to delete specific tags. If you specify a tag key without a tag value, we delete any tag with this key regardless of its value. If you specify a tag key with an empty string as the tag value, we delete the tag only if its value is an empty string.

    If you omit this parameter, we delete all user-defined tags for the specified resources. We do not delete Amazon Web Services-generated tags (tags that have the aws: prefix).

    Constraints: Up to 1000 tags.

Returns:



63
# File 'sig/internet_gateway.rbs', line 63

def delete_tags: (

#detach_from_vpc(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


internet_gateway.detach_from_vpc({
  dry_run: false,
  vpc_id: "VpcId", # required
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

  • :vpc_id (required, String)

    The ID of the VPC.

Returns:

  • (EmptyStructure)


81
# File 'sig/internet_gateway.rbs', line 81

def detach_from_vpc: (

#idString Also known as: internet_gateway_id

Returns:

  • (String)


18
# File 'sig/internet_gateway.rbs', line 18

def id: () -> String

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


349
350
351
# File 'lib/aws-sdk-ec2/internet_gateway.rb', line 349

def identifiers
  { id: @id }
end

#loadself Also known as: reload

Loads, or reloads #data for the current Aws::EC2::InternetGateway. Returns self making it possible to chain methods.

internet_gateway.reload.data

Returns:

  • (self)


33
# File 'sig/internet_gateway.rbs', line 33

def load: () -> self

#owner_idString

The ID of the Amazon Web Services account that owns the internet gateway.

Returns:

  • (String)


25
# File 'sig/internet_gateway.rbs', line 25

def owner_id: () -> ::String

#tagsArray<Types::Tag>

Any tags assigned to the internet gateway.

Returns:



28
# File 'sig/internet_gateway.rbs', line 28

def tags: () -> ::Array[Types::Tag]

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::EC2::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/aws-sdk-ec2/internet_gateway.rb', line 174

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end