Class: Aws::EC2::KeyPair
- Inherits:
-
Object
- Object
- Aws::EC2::KeyPair
- Extended by:
- Deprecations
- Defined in:
- sig/key_pair.rbs,
lib/aws-sdk-ec2/key_pair.rb
Overview
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
-
#key_fingerprint ⇒ String
- For RSA key pairs, the key fingerprint is the SHA-1 digest of the DER encoded private key.
-
#key_material ⇒ String
An unencrypted PEM encoded RSA or ED25519 private key.
-
#key_pair_id ⇒ String
The ID of the key pair.
- #name ⇒ String (also: #key_name)
-
#tags ⇒ Array<Types::Tag>
Any tags applied to the key pair.
Actions collapse
- #delete(options = {}) ⇒ Types::DeleteKeyPairResult
- #identifiers ⇒ Object deprecated private Deprecated.
Instance Method Summary collapse
- #client ⇒ Client
-
#data ⇒ Types::KeyPair
Returns the data for this KeyPair.
-
#data_loaded? ⇒ Boolean
Returns
trueif this resource is loaded. -
#initialize(*args) ⇒ KeyPair
constructor
A new instance of KeyPair.
- #load ⇒ Object (also: #reload) private
-
#wait_until(options = {}) {|resource| ... } ⇒ Resource
deprecated
Deprecated.
Use [Aws::EC2::Client] #wait_until instead
Constructor Details
#initialize(name, options = {}) ⇒ KeyPair #initialize(options = {}) ⇒ KeyPair
Returns a new instance of KeyPair.
13 14 15 |
# File 'sig/key_pair.rbs', line 13
def initialize: (String name, Hash[Symbol, untyped] options) -> void
| (name: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void
|
Instance Method Details
#data ⇒ Types::KeyPair
Returns the data for this Aws::EC2::KeyPair.
37 |
# File 'sig/key_pair.rbs', line 37
def data: () -> Types::KeyPair
|
#data_loaded? ⇒ Boolean
40 |
# File 'sig/key_pair.rbs', line 40
def data_loaded?: () -> bool
|
#delete(options = {}) ⇒ Types::DeleteKeyPairResult
44 |
# File 'sig/key_pair.rbs', line 44
def delete: (
|
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
223 224 225 |
# File 'lib/aws-sdk-ec2/key_pair.rb', line 223 def identifiers { name: @name } end |
#key_fingerprint ⇒ String
-
For RSA key pairs, the key fingerprint is the SHA-1 digest of the DER encoded private key.
-
For ED25519 key pairs, the key fingerprint is the base64-encoded SHA-256 digest, which is the default for OpenSSH, starting with OpenSSH 6.8.
28 |
# File 'sig/key_pair.rbs', line 28
def key_fingerprint: () -> ::String
|
#key_material ⇒ String
An unencrypted PEM encoded RSA or ED25519 private key.
31 |
# File 'sig/key_pair.rbs', line 31
def key_material: () -> ::String
|
#key_pair_id ⇒ String
The ID of the key pair.
22 |
# File 'sig/key_pair.rbs', line 22
def key_pair_id: () -> ::String
|
#load ⇒ Object Also known as: reload
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
76 77 78 79 |
# File 'lib/aws-sdk-ec2/key_pair.rb', line 76 def load msg = "#load is not implemented, data only available via enumeration" raise NotImplementedError, msg end |
#name ⇒ String Also known as: key_name
18 |
# File 'sig/key_pair.rbs', line 18
def name: () -> String
|
#tags ⇒ Array<Types::Tag>
Any tags applied to the key pair.
25 |
# File 'sig/key_pair.rbs', line 25
def tags: () -> ::Array[Types::Tag]
|
#wait_until(options = {}) {|resource| ... } ⇒ Resource
Use [Aws::EC2::Client] #wait_until instead
The waiting operation is performed on a copy. The original resource remains unchanged.
Waiter polls an API operation until a resource enters a desired state.
Basic Usage
Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.
# polls in a loop until condition is true
resource.wait_until() {|resource| condition}
Example
instance.wait_until(max_attempts:10, delay:5) do |instance|
instance.state.name == 'running'
end
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:
# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
throw :failure if Time.now - started_at > 3600
end
# disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}
Handling Errors
When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.
begin
resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
attempts attempt in seconds invoked before each attempt invoked before each wait
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/aws-sdk-ec2/key_pair.rb', line 177 def wait_until( = {}, &block) self_copy = self.dup attempts = 0 [:max_attempts] = 10 unless .key?(:max_attempts) [:delay] ||= 10 [:poller] = Proc.new do attempts += 1 if block.call(self_copy) [:success, self_copy] else self_copy.reload unless attempts == [:max_attempts] :retry end end Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do Aws::Waiters::Waiter.new().wait({}) end end |