Class: Aws::EC2::KeyPairInfo

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/key_pair_info.rbs,
lib/aws-sdk-ec2/key_pair_info.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Instance Method Summary collapse

Constructor Details

#initialize(name, options = {}) ⇒ KeyPairInfo #initialize(options = {}) ⇒ KeyPairInfo

Returns a new instance of KeyPairInfo.

Overloads:

  • #initialize(name, options = {}) ⇒ KeyPairInfo

    Parameters:

    • name (String)

    Options Hash (options):

  • #initialize(options = {}) ⇒ KeyPairInfo

    Options Hash (options):

    • :name (required, String)
    • :client (Client)


13
14
15
# File 'sig/key_pair_info.rbs', line 13

def initialize: (String name, Hash[Symbol, untyped] options) -> void
| (name: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#clientClient

Returns:



108
# File 'lib/aws-sdk-ec2/key_pair_info.rb', line 108

def client: () -> Client

#create_timeTime

If you used Amazon EC2 to create the key pair, this is the date and time when the key was created, in ISO 8601 date-time format, in the UTC time zone.

If you imported an existing key pair to Amazon EC2, this is the date and time the key was imported, in ISO 8601 date-time format, in the UTC time zone.

Returns:

  • (Time)


34
# File 'sig/key_pair_info.rbs', line 34

def create_time: () -> ::Time

#dataTypes::KeyPairInfo

Returns the data for this Aws::EC2::KeyPairInfo. Calls Client#describe_key_pairs if #data_loaded? is false.

Returns:



46
# File 'sig/key_pair_info.rbs', line 46

def data: () -> Types::KeyPairInfo

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



49
# File 'sig/key_pair_info.rbs', line 49

def data_loaded?: () -> bool

#delete(options = {}) ⇒ Types::DeleteKeyPairResult

Examples:

Request syntax with placeholder values


key_pair_info.delete({
  key_pair_id: "KeyPairId",
  dry_run: false,
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :key_pair_id (String)

    The ID of the key pair.

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:



53
# File 'sig/key_pair_info.rbs', line 53

def delete: (

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


268
269
270
# File 'lib/aws-sdk-ec2/key_pair_info.rb', line 268

def identifiers
  { name: @name }
end

#key_fingerprintString

If you used CreateKeyPair to create the key pair:

  • For RSA key pairs, the key fingerprint is the SHA-1 digest of the DER encoded private key.

  • For ED25519 key pairs, the key fingerprint is the base64-encoded SHA-256 digest, which is the default for OpenSSH, starting with OpenSSH 6.8.

If you used ImportKeyPair to provide Amazon Web Services the public key:

  • For RSA key pairs, the key fingerprint is the MD5 public key fingerprint as specified in section 4 of RFC4716.

  • For ED25519 key pairs, the key fingerprint is the base64-encoded SHA-256 digest, which is the default for OpenSSH, starting with OpenSSH 6.8.

Returns:

  • (String)


37
# File 'sig/key_pair_info.rbs', line 37

def key_fingerprint: () -> ::String

#key_pair_idString

The ID of the key pair.

Returns:

  • (String)


22
# File 'sig/key_pair_info.rbs', line 22

def key_pair_id: () -> ::String

#key_typeString

The type of key pair.

Returns:

  • (String)


25
# File 'sig/key_pair_info.rbs', line 25

def key_type: () -> ("rsa" | "ed25519")

#loadself Also known as: reload

Loads, or reloads #data for the current Aws::EC2::KeyPairInfo. Returns self making it possible to chain methods.

key_pair_info.reload.data

Returns:

  • (self)


42
# File 'sig/key_pair_info.rbs', line 42

def load: () -> self

#nameString Also known as: key_name

Returns:

  • (String)


18
# File 'sig/key_pair_info.rbs', line 18

def name: () -> String

#public_keyString

The public key material.

Returns:

  • (String)


31
# File 'sig/key_pair_info.rbs', line 31

def public_key: () -> ::String

#tagsArray<Types::Tag>

Any tags applied to the key pair.

Returns:



28
# File 'sig/key_pair_info.rbs', line 28

def tags: () -> ::Array[Types::Tag]

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::EC2::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/aws-sdk-ec2/key_pair_info.rb', line 222

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end