Class: Aws::EC2::NetworkAcl

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/network_acl.rbs,
lib/aws-sdk-ec2/network_acl.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Associations collapse

Instance Method Summary collapse

Constructor Details

#initialize(id, options = {}) ⇒ NetworkAcl #initialize(options = {}) ⇒ NetworkAcl

Returns a new instance of NetworkAcl.

Overloads:

  • #initialize(id, options = {}) ⇒ NetworkAcl

    Parameters:

    • id (String)

    Options Hash (options):

  • #initialize(options = {}) ⇒ NetworkAcl

    Options Hash (options):

    • :id (required, String)
    • :client (Client)


13
14
15
# File 'sig/network_acl.rbs', line 13

def initialize: (String id, Hash[Symbol, untyped] options) -> void
| (id: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#associationsArray<Types::NetworkAclAssociation>

Any associations between the network ACL and your subnets

Returns:



22
# File 'sig/network_acl.rbs', line 22

def associations: () -> ::Array[Types::NetworkAclAssociation]

#clientClient

Returns:



77
# File 'lib/aws-sdk-ec2/network_acl.rb', line 77

def client: () -> Client

#create_entry(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


network_acl.create_entry({
  dry_run: false,
  rule_number: 1, # required
  protocol: "String", # required
  rule_action: "allow", # required, accepts allow, deny
  egress: false, # required
  cidr_block: "String",
  ipv_6_cidr_block: "String",
  icmp_type_code: {
    code: 1,
    type: 1,
  },
  port_range: {
    from: 1,
    to: 1,
  },
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

  • :rule_number (required, Integer)

    The rule number for the entry (for example, 100). ACL entries are processed in ascending order by rule number.

    Constraints: Positive integer from 1 to 32766. The range 32767 to 65535 is reserved for internal use.

  • :protocol (required, String)

    The protocol number. A value of "-1" means all protocols. If you specify "-1" or a protocol number other than "6" (TCP), "17" (UDP), or "1" (ICMP), traffic on all ports is allowed, regardless of any ports or ICMP types or codes that you specify. If you specify protocol "58" (ICMPv6) and specify an IPv4 CIDR block, traffic for all ICMP types and codes allowed, regardless of any that you specify. If you specify protocol "58" (ICMPv6) and specify an IPv6 CIDR block, you must specify an ICMP type and code.

  • :rule_action (required, String)

    Indicates whether to allow or deny the traffic that matches the rule.

  • :egress (required, Boolean)

    Indicates whether this is an egress rule (rule is applied to traffic leaving the subnet).

  • :cidr_block (String)

    The IPv4 network range to allow or deny, in CIDR notation (for example 172.16.0.0/24). We modify the specified CIDR block to its canonical form; for example, if you specify 100.68.0.18/18, we modify it to 100.68.0.0/18.

  • :ipv_6_cidr_block (String)

    The IPv6 network range to allow or deny, in CIDR notation (for example 2001:db8:1234:1a00::/64).

  • :icmp_type_code (Types::IcmpTypeCode)

    ICMP protocol: The ICMP or ICMPv6 type and code. Required if specifying protocol 1 (ICMP) or protocol 58 (ICMPv6) with an IPv6 CIDR block.

  • :port_range (Types::PortRange)

    TCP or UDP protocols: The range of ports the rule applies to. Required if specifying protocol 6 (TCP) or 17 (UDP).

Returns:

  • (EmptyStructure)


53
# File 'sig/network_acl.rbs', line 53

def create_entry: (

#create_tags(options = {}) ⇒ Tag::Collection

Examples:

Request syntax with placeholder values


tag = network_acl.create_tags({
  dry_run: false,
  tags: [ # required
    {
      key: "String",
      value: "String",
    },
  ],
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

  • :tags (required, Array<Types::Tag>)

    The tags. The value parameter is required, but if you don't want the tag to have a value, specify the parameter with no value, and we set the value to an empty string.

Returns:



73
# File 'sig/network_acl.rbs', line 73

def create_tags: (

#dataTypes::NetworkAcl

Returns the data for this Aws::EC2::NetworkAcl. Calls Client#describe_network_acls if #data_loaded? is false.

Returns:



46
# File 'sig/network_acl.rbs', line 46

def data: () -> Types::NetworkAcl

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



49
# File 'sig/network_acl.rbs', line 49

def data_loaded?: () -> bool

#delete(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


network_acl.delete({
  dry_run: false,
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (EmptyStructure)


97
# File 'sig/network_acl.rbs', line 97

def delete: (

#delete_entry(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


network_acl.delete_entry({
  dry_run: false,
  rule_number: 1, # required
  egress: false, # required
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

  • :rule_number (required, Integer)

    The rule number of the entry to delete.

  • :egress (required, Boolean)

    Indicates whether the rule is an egress rule.

Returns:

  • (EmptyStructure)


103
# File 'sig/network_acl.rbs', line 103

def delete_entry: (

#delete_tags(options = {}) ⇒ Tag::Collection

Examples:

Request syntax with placeholder values


tag = network_acl.delete_tags({
  dry_run: false,
  tags: [
    {
      key: "String",
      value: "String",
    },
  ],
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

  • :tags (Array<Types::Tag>)

    The tags to delete. Specify a tag key and an optional tag value to delete specific tags. If you specify a tag key without a tag value, we delete any tag with this key regardless of its value. If you specify a tag key with an empty string as the tag value, we delete the tag only if its value is an empty string.

    If you omit this parameter, we delete all user-defined tags for the specified resources. We do not delete Amazon Web Services-generated tags (tags that have the aws: prefix).

    Constraints: Up to 1000 tags.

Returns:



85
# File 'sig/network_acl.rbs', line 85

def delete_tags: (

#entriesArray<Types::NetworkAclEntry>

The entries (rules) in the network ACL.

Returns:



25
# File 'sig/network_acl.rbs', line 25

def entries: () -> ::Array[Types::NetworkAclEntry]

#idString Also known as: network_acl_id

Returns:

  • (String)


18
# File 'sig/network_acl.rbs', line 18

def id: () -> String

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


517
518
519
# File 'lib/aws-sdk-ec2/network_acl.rb', line 517

def identifiers
  { id: @id }
end

#is_defaultBoolean

Indicates whether this is the default network ACL for the VPC.

Returns:

  • (Boolean)


28
# File 'sig/network_acl.rbs', line 28

def is_default: () -> bool

#loadself Also known as: reload

Loads, or reloads #data for the current Aws::EC2::NetworkAcl. Returns self making it possible to chain methods.

network_acl.reload.data

Returns:

  • (self)


42
# File 'sig/network_acl.rbs', line 42

def load: () -> self

#owner_idString

The ID of the Amazon Web Services account that owns the network ACL.

Returns:

  • (String)


37
# File 'sig/network_acl.rbs', line 37

def owner_id: () -> ::String

#replace_association(options = {}) ⇒ Types::ReplaceNetworkAclAssociationResult

Examples:

Request syntax with placeholder values


network_acl.replace_association({
  dry_run: false,
  association_id: "NetworkAclAssociationId", # required
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

  • :association_id (required, String)

    The ID of the current association between the original network ACL and the subnet.

Returns:



111
# File 'sig/network_acl.rbs', line 111

def replace_association: (

#replace_entry(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


network_acl.replace_entry({
  dry_run: false,
  rule_number: 1, # required
  protocol: "String", # required
  rule_action: "allow", # required, accepts allow, deny
  egress: false, # required
  cidr_block: "String",
  ipv_6_cidr_block: "String",
  icmp_type_code: {
    code: 1,
    type: 1,
  },
  port_range: {
    from: 1,
    to: 1,
  },
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

  • :rule_number (required, Integer)

    The rule number of the entry to replace.

  • :protocol (required, String)

    The protocol number. A value of "-1" means all protocols. If you specify "-1" or a protocol number other than "6" (TCP), "17" (UDP), or "1" (ICMP), traffic on all ports is allowed, regardless of any ports or ICMP types or codes that you specify. If you specify protocol "58" (ICMPv6) and specify an IPv4 CIDR block, traffic for all ICMP types and codes allowed, regardless of any that you specify. If you specify protocol "58" (ICMPv6) and specify an IPv6 CIDR block, you must specify an ICMP type and code.

  • :rule_action (required, String)

    Indicates whether to allow or deny the traffic that matches the rule.

  • :egress (required, Boolean)

    Indicates whether to replace the egress rule.

    Default: If no value is specified, we replace the ingress rule.

  • :cidr_block (String)

    The IPv4 network range to allow or deny, in CIDR notation (for example 172.16.0.0/24).

  • :ipv_6_cidr_block (String)

    The IPv6 network range to allow or deny, in CIDR notation (for example 2001:bd8:1234:1a00::/64).

  • :icmp_type_code (Types::IcmpTypeCode)

    ICMP protocol: The ICMP or ICMPv6 type and code. Required if specifying protocol 1 (ICMP) or protocol 58 (ICMPv6) with an IPv6 CIDR block.

  • :port_range (Types::PortRange)

    TCP or UDP protocols: The range of ports the rule applies to. Required if specifying protocol 6 (TCP) or 17 (UDP).

Returns:

  • (EmptyStructure)


118
# File 'sig/network_acl.rbs', line 118

def replace_entry: (

#tagsArray<Types::Tag>

Any tags assigned to the network ACL.

Returns:



31
# File 'sig/network_acl.rbs', line 31

def tags: () -> ::Array[Types::Tag]

#vpcVpc?

Returns:



138
# File 'sig/network_acl.rbs', line 138

def vpc: () -> Vpc?

#vpc_idString

The ID of the VPC for the network ACL.

Returns:

  • (String)


34
# File 'sig/network_acl.rbs', line 34

def vpc_id: () -> ::String

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::EC2::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/aws-sdk-ec2/network_acl.rb', line 191

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end