Class: Aws::EC2::NetworkInterfaceAssociation

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/network_interface_association.rbs,
lib/aws-sdk-ec2/network_interface_association.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Associations collapse

Instance Method Summary collapse

Constructor Details

#initialize(id, options) ⇒ void #initialize(id:, client:) ⇒ void #initialize(args) ⇒ void

Overloads:

  • #initialize(id, options) ⇒ void

    Parameters:

    • id (String)
    • options (Hash[Symbol, untyped])
  • #initialize(id:, client:) ⇒ void

    Parameters:

    • id: (String)
    • client: (Client)
  • #initialize(args) ⇒ void

    Parameters:

    • args (Hash[Symbol, untyped])


22
23
24
25
26
27
28
# File 'lib/aws-sdk-ec2/network_interface_association.rb', line 22

def initialize(*args)
  options = Hash === args.last ? args.pop.dup : {}
  @id = extract_id(args, options)
  @data = options.delete(:data)
  @client = options.delete(:client) || Client.new(options)
  @waiter_block_warned = false
end

Instance Method Details

#addressVpcAddress?

Returns:



235
236
237
238
239
240
241
242
243
244
# File 'lib/aws-sdk-ec2/network_interface_association.rb', line 235

def address
  if data[:allocation_id]
    VpcAddress.new(
      allocation_id: data[:allocation_id],
      client: @client
    )
  else
    nil
  end
end

#carrier_ip::String

Returns:

  • (::String)


39
40
41
# File 'lib/aws-sdk-ec2/network_interface_association.rb', line 39

def carrier_ip
  data[:carrier_ip]
end

#clientClient

Returns:



71
72
73
# File 'lib/aws-sdk-ec2/network_interface_association.rb', line 71

def client
  @client
end

#customer_owned_ip::String

Returns:

  • (::String)


45
46
47
# File 'lib/aws-sdk-ec2/network_interface_association.rb', line 45

def customer_owned_ip
  data[:customer_owned_ip]
end

#dataTypes::InstanceNetworkInterfaceAssociation



96
97
98
99
# File 'lib/aws-sdk-ec2/network_interface_association.rb', line 96

def data
  load unless @data
  @data
end

#data_loaded?Boolean

Returns:

  • (Boolean)


104
105
106
# File 'lib/aws-sdk-ec2/network_interface_association.rb', line 104

def data_loaded?
  !!@data
end

#delete(options = {}) ⇒ Object



224
225
226
227
228
229
230
# File 'lib/aws-sdk-ec2/network_interface_association.rb', line 224

def delete(options = {})
  options = options.merge(association_id: @id)
  resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    @client.disassociate_address(options)
  end
  resp.data
end

#idString

Returns:

  • (String)


33
34
35
# File 'lib/aws-sdk-ec2/network_interface_association.rb', line 33

def id
  @id
end

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


248
249
250
# File 'lib/aws-sdk-ec2/network_interface_association.rb', line 248

def identifiers
  { id: @id }
end

#ip_owner_id::String

Returns:

  • (::String)


51
52
53
# File 'lib/aws-sdk-ec2/network_interface_association.rb', line 51

def ip_owner_id
  data[:ip_owner_id]
end

#loadself Also known as: reload

Returns:

  • (self)


81
82
83
84
85
86
87
88
89
90
# File 'lib/aws-sdk-ec2/network_interface_association.rb', line 81

def load
  resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    @client.describe_network_interfaces(filters: [{
    name: "association.association-id",
    values: [@id]
  }])
  end
  @data = resp.network_interfaces[0].association
  self
end

#public_dns_name::String

Returns:

  • (::String)


57
58
59
# File 'lib/aws-sdk-ec2/network_interface_association.rb', line 57

def public_dns_name
  data[:public_dns_name]
end

#public_ip::String

Returns:

  • (::String)


64
65
66
# File 'lib/aws-sdk-ec2/network_interface_association.rb', line 64

def public_ip
  data[:public_ip]
end

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::EC2::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/aws-sdk-ec2/network_interface_association.rb', line 188

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end