Class: Aws::EC2::RouteTable

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/route_table.rbs,
lib/aws-sdk-ec2/route_table.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Associations collapse

Instance Method Summary collapse

Constructor Details

#initialize(id, options = {}) ⇒ RouteTable #initialize(options = {}) ⇒ RouteTable

Returns a new instance of RouteTable.

Overloads:

  • #initialize(id, options = {}) ⇒ RouteTable

    Parameters:

    • id (String)

    Options Hash (options):

  • #initialize(options = {}) ⇒ RouteTable

    Options Hash (options):

    • :id (required, String)
    • :client (Client)


13
14
15
# File 'sig/route_table.rbs', line 13

def initialize: (String id, Hash[Symbol, untyped] options) -> void
| (id: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#associate_with_subnet(options = {}) ⇒ RouteTableAssociation

Examples:

Request syntax with placeholder values


routetableassociation = route_table.associate_with_subnet({
  gateway_id: "RouteGatewayId",
  public_ipv_4_pool: "Ipv4PoolEc2Id",
  dry_run: false,
  subnet_id: "SubnetId",
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :gateway_id (String)

    The ID of the internet gateway or virtual private gateway.

  • :public_ipv_4_pool (String)

    The ID of a public IPv4 pool. A public IPv4 pool is a pool of IPv4 addresses that you've brought to Amazon Web Services with BYOIP.

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

  • :subnet_id (String)

    The ID of the subnet.

Returns:



47
# File 'sig/route_table.rbs', line 47

def associate_with_subnet: (

#associationsRouteTableAssociation::Collection



107
# File 'sig/route_table.rbs', line 107

def associations: () -> RouteTableAssociation::Collection

#clientClient

Returns:



65
# File 'lib/aws-sdk-ec2/route_table.rb', line 65

def client: () -> Client

#create_route(options = {}) ⇒ Route

Examples:

Request syntax with placeholder values


route = route_table.create_route({
  destination_prefix_list_id: "PrefixListResourceId",
  vpc_endpoint_id: "VpcEndpointId",
  transit_gateway_id: "TransitGatewayId",
  local_gateway_id: "LocalGatewayId",
  carrier_gateway_id: "CarrierGatewayId",
  core_network_arn: "CoreNetworkArn",
  odb_network_arn: "OdbNetworkArn",
  dry_run: false,
  destination_cidr_block: "String",
  gateway_id: "RouteGatewayId",
  destination_ipv_6_cidr_block: "String",
  egress_only_internet_gateway_id: "EgressOnlyInternetGatewayId",
  instance_id: "InstanceId",
  network_interface_id: "NetworkInterfaceId",
  vpc_peering_connection_id: "VpcPeeringConnectionId",
  nat_gateway_id: "NatGatewayId",
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :destination_prefix_list_id (String)

    The ID of a prefix list used for the destination match.

  • :vpc_endpoint_id (String)

    The ID of a VPC endpoint. Supported for Gateway Load Balancer endpoints only.

  • :transit_gateway_id (String)

    The ID of a transit gateway.

  • :local_gateway_id (String)

    The ID of the local gateway.

  • :carrier_gateway_id (String)

    The ID of the carrier gateway.

    You can only use this option when the VPC contains a subnet which is associated with a Wavelength Zone.

  • :core_network_arn (String)

    The Amazon Resource Name (ARN) of the core network.

  • :odb_network_arn (String)

    The Amazon Resource Name (ARN) of the ODB network.

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

  • :destination_cidr_block (String)

    The IPv4 CIDR address block used for the destination match. Routing decisions are based on the most specific match. We modify the specified CIDR block to its canonical form; for example, if you specify 100.68.0.18/18, we modify it to 100.68.0.0/18.

  • :gateway_id (String)

    The ID of an internet gateway or virtual private gateway attached to your VPC.

  • :destination_ipv_6_cidr_block (String)

    The IPv6 CIDR block used for the destination match. Routing decisions are based on the most specific match.

  • :egress_only_internet_gateway_id (String)

    [IPv6 traffic only] The ID of an egress-only internet gateway.

  • :instance_id (String)

    The ID of a NAT instance in your VPC. The operation fails if you specify an instance ID unless exactly one network interface is attached.

  • :network_interface_id (String)

    The ID of a network interface.

  • :vpc_peering_connection_id (String)

    The ID of a VPC peering connection.

  • :nat_gateway_id (String)

    [IPv4 traffic only] The ID of a NAT gateway.

Returns:



56
# File 'sig/route_table.rbs', line 56

def create_route: (

#create_tags(options = {}) ⇒ Tag::Collection

Examples:

Request syntax with placeholder values


tag = route_table.create_tags({
  dry_run: false,
  tags: [ # required
    {
      key: "String",
      value: "String",
    },
  ],
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

  • :tags (required, Array<Types::Tag>)

    The tags. The value parameter is required, but if you don't want the tag to have a value, specify the parameter with no value, and we set the value to an empty string.

Returns:



77
# File 'sig/route_table.rbs', line 77

def create_tags: (

#dataTypes::RouteTable

Returns the data for this Aws::EC2::RouteTable. Calls Client#describe_route_tables if #data_loaded? is false.

Returns:



40
# File 'sig/route_table.rbs', line 40

def data: () -> Types::RouteTable

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



43
# File 'sig/route_table.rbs', line 43

def data_loaded?: () -> bool

#delete(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


route_table.delete({
  dry_run: false,
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (EmptyStructure)


101
# File 'sig/route_table.rbs', line 101

def delete: (

#delete_tags(options = {}) ⇒ Tag::Collection

Examples:

Request syntax with placeholder values


tag = route_table.delete_tags({
  dry_run: false,
  tags: [
    {
      key: "String",
      value: "String",
    },
  ],
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

  • :tags (Array<Types::Tag>)

    The tags to delete. Specify a tag key and an optional tag value to delete specific tags. If you specify a tag key without a tag value, we delete any tag with this key regardless of its value. If you specify a tag key with an empty string as the tag value, we delete the tag only if its value is an empty string.

    If you omit this parameter, we delete all user-defined tags for the specified resources. We do not delete Amazon Web Services-generated tags (tags that have the aws: prefix).

    Constraints: Up to 1000 tags.

Returns:



89
# File 'sig/route_table.rbs', line 89

def delete_tags: (

#idString Also known as: route_table_id

Returns:

  • (String)


18
# File 'sig/route_table.rbs', line 18

def id: () -> String

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


462
463
464
# File 'lib/aws-sdk-ec2/route_table.rb', line 462

def identifiers
  { id: @id }
end

#loadself Also known as: reload

Loads, or reloads #data for the current Aws::EC2::RouteTable. Returns self making it possible to chain methods.

route_table.reload.data

Returns:

  • (self)


36
# File 'sig/route_table.rbs', line 36

def load: () -> self

#owner_idString

The ID of the Amazon Web Services account that owns the route table.

Returns:

  • (String)


31
# File 'sig/route_table.rbs', line 31

def owner_id: () -> ::String

#propagating_vgwsArray<Types::PropagatingVgw>

Any virtual private gateway (VGW) propagating routes.

Returns:



22
# File 'sig/route_table.rbs', line 22

def propagating_vgws: () -> ::Array[Types::PropagatingVgw]

#routesRoute::Collection

Returns:



110
# File 'sig/route_table.rbs', line 110

def routes: () -> Route::Collection

#tagsArray<Types::Tag>

Any tags assigned to the route table.

Returns:



25
# File 'sig/route_table.rbs', line 25

def tags: () -> ::Array[Types::Tag]

#vpcVpc?

Returns:



113
# File 'sig/route_table.rbs', line 113

def vpc: () -> Vpc?

#vpc_idString

The ID of the VPC.

Returns:

  • (String)


28
# File 'sig/route_table.rbs', line 28

def vpc_id: () -> ::String

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::EC2::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/aws-sdk-ec2/route_table.rb', line 179

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end