Class: Aws::EC2::Types::Address
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::Address
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes an Elastic IP address, or a carrier IP address.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allocation_id ⇒ String
The ID representing the allocation of the address.
-
#association_id ⇒ String
The ID representing the association of the address with an instance.
-
#carrier_ip ⇒ String
The carrier IP address associated.
-
#customer_owned_ip ⇒ String
The customer-owned IP address.
-
#customer_owned_ipv_4_pool ⇒ String
The ID of the customer-owned address pool.
-
#domain ⇒ String
The network (‘vpc`).
-
#instance_id ⇒ String
The ID of the instance that the address is associated with (if any).
-
#network_border_group ⇒ String
The name of the unique set of Availability Zones, Local Zones, or Wavelength Zones from which Amazon Web Services advertises IP addresses.
-
#network_interface_id ⇒ String
The ID of the network interface.
-
#network_interface_owner_id ⇒ String
The ID of the Amazon Web Services account that owns the network interface.
-
#private_ip_address ⇒ String
The private IP address associated with the Elastic IP address.
-
#public_ip ⇒ String
The Elastic IP address.
-
#public_ipv_4_pool ⇒ String
The ID of an address pool.
-
#service_managed ⇒ String
The service that manages the elastic IP address.
-
#subnet_id ⇒ String
The ID of the subnet where the IP address is allocated.
-
#tags ⇒ Array<Types::Tag>
Any tags assigned to the Elastic IP address.
Instance Attribute Details
#allocation_id ⇒ String
The ID representing the allocation of the address.
885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-ec2/types.rb', line 885 class Address < Struct.new( :allocation_id, :association_id, :domain, :network_interface_id, :network_interface_owner_id, :private_ip_address, :tags, :public_ipv_4_pool, :network_border_group, :customer_owned_ip, :customer_owned_ipv_4_pool, :carrier_ip, :subnet_id, :service_managed, :instance_id, :public_ip) SENSITIVE = [] include Aws::Structure end |
#association_id ⇒ String
The ID representing the association of the address with an instance.
885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-ec2/types.rb', line 885 class Address < Struct.new( :allocation_id, :association_id, :domain, :network_interface_id, :network_interface_owner_id, :private_ip_address, :tags, :public_ipv_4_pool, :network_border_group, :customer_owned_ip, :customer_owned_ipv_4_pool, :carrier_ip, :subnet_id, :service_managed, :instance_id, :public_ip) SENSITIVE = [] include Aws::Structure end |
#carrier_ip ⇒ String
The carrier IP address associated. This option is only available for network interfaces which reside in a subnet in a Wavelength Zone (for example an EC2 instance).
885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-ec2/types.rb', line 885 class Address < Struct.new( :allocation_id, :association_id, :domain, :network_interface_id, :network_interface_owner_id, :private_ip_address, :tags, :public_ipv_4_pool, :network_border_group, :customer_owned_ip, :customer_owned_ipv_4_pool, :carrier_ip, :subnet_id, :service_managed, :instance_id, :public_ip) SENSITIVE = [] include Aws::Structure end |
#customer_owned_ip ⇒ String
The customer-owned IP address.
885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-ec2/types.rb', line 885 class Address < Struct.new( :allocation_id, :association_id, :domain, :network_interface_id, :network_interface_owner_id, :private_ip_address, :tags, :public_ipv_4_pool, :network_border_group, :customer_owned_ip, :customer_owned_ipv_4_pool, :carrier_ip, :subnet_id, :service_managed, :instance_id, :public_ip) SENSITIVE = [] include Aws::Structure end |
#customer_owned_ipv_4_pool ⇒ String
The ID of the customer-owned address pool.
885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-ec2/types.rb', line 885 class Address < Struct.new( :allocation_id, :association_id, :domain, :network_interface_id, :network_interface_owner_id, :private_ip_address, :tags, :public_ipv_4_pool, :network_border_group, :customer_owned_ip, :customer_owned_ipv_4_pool, :carrier_ip, :subnet_id, :service_managed, :instance_id, :public_ip) SENSITIVE = [] include Aws::Structure end |
#domain ⇒ String
The network (‘vpc`).
885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-ec2/types.rb', line 885 class Address < Struct.new( :allocation_id, :association_id, :domain, :network_interface_id, :network_interface_owner_id, :private_ip_address, :tags, :public_ipv_4_pool, :network_border_group, :customer_owned_ip, :customer_owned_ipv_4_pool, :carrier_ip, :subnet_id, :service_managed, :instance_id, :public_ip) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the instance that the address is associated with (if any).
885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-ec2/types.rb', line 885 class Address < Struct.new( :allocation_id, :association_id, :domain, :network_interface_id, :network_interface_owner_id, :private_ip_address, :tags, :public_ipv_4_pool, :network_border_group, :customer_owned_ip, :customer_owned_ipv_4_pool, :carrier_ip, :subnet_id, :service_managed, :instance_id, :public_ip) SENSITIVE = [] include Aws::Structure end |
#network_border_group ⇒ String
The name of the unique set of Availability Zones, Local Zones, or Wavelength Zones from which Amazon Web Services advertises IP addresses.
885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-ec2/types.rb', line 885 class Address < Struct.new( :allocation_id, :association_id, :domain, :network_interface_id, :network_interface_owner_id, :private_ip_address, :tags, :public_ipv_4_pool, :network_border_group, :customer_owned_ip, :customer_owned_ipv_4_pool, :carrier_ip, :subnet_id, :service_managed, :instance_id, :public_ip) SENSITIVE = [] include Aws::Structure end |
#network_interface_id ⇒ String
The ID of the network interface.
885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-ec2/types.rb', line 885 class Address < Struct.new( :allocation_id, :association_id, :domain, :network_interface_id, :network_interface_owner_id, :private_ip_address, :tags, :public_ipv_4_pool, :network_border_group, :customer_owned_ip, :customer_owned_ipv_4_pool, :carrier_ip, :subnet_id, :service_managed, :instance_id, :public_ip) SENSITIVE = [] include Aws::Structure end |
#network_interface_owner_id ⇒ String
The ID of the Amazon Web Services account that owns the network interface.
885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-ec2/types.rb', line 885 class Address < Struct.new( :allocation_id, :association_id, :domain, :network_interface_id, :network_interface_owner_id, :private_ip_address, :tags, :public_ipv_4_pool, :network_border_group, :customer_owned_ip, :customer_owned_ipv_4_pool, :carrier_ip, :subnet_id, :service_managed, :instance_id, :public_ip) SENSITIVE = [] include Aws::Structure end |
#private_ip_address ⇒ String
The private IP address associated with the Elastic IP address.
885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-ec2/types.rb', line 885 class Address < Struct.new( :allocation_id, :association_id, :domain, :network_interface_id, :network_interface_owner_id, :private_ip_address, :tags, :public_ipv_4_pool, :network_border_group, :customer_owned_ip, :customer_owned_ipv_4_pool, :carrier_ip, :subnet_id, :service_managed, :instance_id, :public_ip) SENSITIVE = [] include Aws::Structure end |
#public_ip ⇒ String
The Elastic IP address.
885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-ec2/types.rb', line 885 class Address < Struct.new( :allocation_id, :association_id, :domain, :network_interface_id, :network_interface_owner_id, :private_ip_address, :tags, :public_ipv_4_pool, :network_border_group, :customer_owned_ip, :customer_owned_ipv_4_pool, :carrier_ip, :subnet_id, :service_managed, :instance_id, :public_ip) SENSITIVE = [] include Aws::Structure end |
#public_ipv_4_pool ⇒ String
The ID of an address pool.
885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-ec2/types.rb', line 885 class Address < Struct.new( :allocation_id, :association_id, :domain, :network_interface_id, :network_interface_owner_id, :private_ip_address, :tags, :public_ipv_4_pool, :network_border_group, :customer_owned_ip, :customer_owned_ipv_4_pool, :carrier_ip, :subnet_id, :service_managed, :instance_id, :public_ip) SENSITIVE = [] include Aws::Structure end |
#service_managed ⇒ String
The service that manages the elastic IP address.
<note markdown=“1”> The only option supported today is ‘alb`.
</note>
885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-ec2/types.rb', line 885 class Address < Struct.new( :allocation_id, :association_id, :domain, :network_interface_id, :network_interface_owner_id, :private_ip_address, :tags, :public_ipv_4_pool, :network_border_group, :customer_owned_ip, :customer_owned_ipv_4_pool, :carrier_ip, :subnet_id, :service_managed, :instance_id, :public_ip) SENSITIVE = [] include Aws::Structure end |
#subnet_id ⇒ String
The ID of the subnet where the IP address is allocated.
885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-ec2/types.rb', line 885 class Address < Struct.new( :allocation_id, :association_id, :domain, :network_interface_id, :network_interface_owner_id, :private_ip_address, :tags, :public_ipv_4_pool, :network_border_group, :customer_owned_ip, :customer_owned_ipv_4_pool, :carrier_ip, :subnet_id, :service_managed, :instance_id, :public_ip) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Any tags assigned to the Elastic IP address.
885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-ec2/types.rb', line 885 class Address < Struct.new( :allocation_id, :association_id, :domain, :network_interface_id, :network_interface_owner_id, :private_ip_address, :tags, :public_ipv_4_pool, :network_border_group, :customer_owned_ip, :customer_owned_ipv_4_pool, :carrier_ip, :subnet_id, :service_managed, :instance_id, :public_ip) SENSITIVE = [] include Aws::Structure end |