Class: Aws::EC2::Types::AddressTransfer
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::AddressTransfer
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Details on the Elastic IP address transfer. For more information, see
- Transfer Elastic IP addresses][1
-
in the *Amazon VPC User Guide*.
[1]: docs.aws.amazon.com/vpc/latest/userguide/vpc-eips.html#transfer-EIPs-intro
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#address_transfer_status ⇒ String
The Elastic IP address transfer status.
-
#allocation_id ⇒ String
The allocation ID of an Elastic IP address.
-
#public_ip ⇒ String
The Elastic IP address being transferred.
-
#transfer_account_id ⇒ String
The ID of the account that you want to transfer the Elastic IP address to.
-
#transfer_offer_accepted_timestamp ⇒ Time
The timestamp when the Elastic IP address transfer was accepted.
-
#transfer_offer_expiration_timestamp ⇒ Time
The timestamp when the Elastic IP address transfer expired.
Instance Attribute Details
#address_transfer_status ⇒ String
The Elastic IP address transfer status.
972 973 974 975 976 977 978 979 980 981 |
# File 'lib/aws-sdk-ec2/types.rb', line 972 class AddressTransfer < Struct.new( :public_ip, :allocation_id, :transfer_account_id, :transfer_offer_expiration_timestamp, :transfer_offer_accepted_timestamp, :address_transfer_status) SENSITIVE = [] include Aws::Structure end |
#allocation_id ⇒ String
The allocation ID of an Elastic IP address.
972 973 974 975 976 977 978 979 980 981 |
# File 'lib/aws-sdk-ec2/types.rb', line 972 class AddressTransfer < Struct.new( :public_ip, :allocation_id, :transfer_account_id, :transfer_offer_expiration_timestamp, :transfer_offer_accepted_timestamp, :address_transfer_status) SENSITIVE = [] include Aws::Structure end |
#public_ip ⇒ String
The Elastic IP address being transferred.
972 973 974 975 976 977 978 979 980 981 |
# File 'lib/aws-sdk-ec2/types.rb', line 972 class AddressTransfer < Struct.new( :public_ip, :allocation_id, :transfer_account_id, :transfer_offer_expiration_timestamp, :transfer_offer_accepted_timestamp, :address_transfer_status) SENSITIVE = [] include Aws::Structure end |
#transfer_account_id ⇒ String
The ID of the account that you want to transfer the Elastic IP address to.
972 973 974 975 976 977 978 979 980 981 |
# File 'lib/aws-sdk-ec2/types.rb', line 972 class AddressTransfer < Struct.new( :public_ip, :allocation_id, :transfer_account_id, :transfer_offer_expiration_timestamp, :transfer_offer_accepted_timestamp, :address_transfer_status) SENSITIVE = [] include Aws::Structure end |
#transfer_offer_accepted_timestamp ⇒ Time
The timestamp when the Elastic IP address transfer was accepted.
972 973 974 975 976 977 978 979 980 981 |
# File 'lib/aws-sdk-ec2/types.rb', line 972 class AddressTransfer < Struct.new( :public_ip, :allocation_id, :transfer_account_id, :transfer_offer_expiration_timestamp, :transfer_offer_accepted_timestamp, :address_transfer_status) SENSITIVE = [] include Aws::Structure end |
#transfer_offer_expiration_timestamp ⇒ Time
The timestamp when the Elastic IP address transfer expired. When the source account starts the transfer, the transfer account has seven hours to allocate the Elastic IP address to complete the transfer, or the Elastic IP address will return to its original owner.
972 973 974 975 976 977 978 979 980 981 |
# File 'lib/aws-sdk-ec2/types.rb', line 972 class AddressTransfer < Struct.new( :public_ip, :allocation_id, :transfer_account_id, :transfer_offer_expiration_timestamp, :transfer_offer_accepted_timestamp, :address_transfer_status) SENSITIVE = [] include Aws::Structure end |