Class: Aws::EC2::Types::AllocateAddressResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::AllocateAddressResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allocation_id ⇒ String
The ID that represents the allocation of the Elastic IP address.
-
#carrier_ip ⇒ String
The carrier IP address.
-
#customer_owned_ip ⇒ String
The customer-owned IP address.
-
#customer_owned_ipv_4_pool ⇒ String
The ID of the customer-owned address pool.
-
#domain ⇒ String
The network (‘vpc`).
-
#network_border_group ⇒ String
The set of Availability Zones, Local Zones, or Wavelength Zones from which Amazon Web Services advertises IP addresses.
-
#public_ip ⇒ String
The Amazon-owned IP address.
-
#public_ipv_4_pool ⇒ String
The ID of an address pool that you own.
Instance Attribute Details
#allocation_id ⇒ String
The ID that represents the allocation of the Elastic IP address.
1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 |
# File 'lib/aws-sdk-ec2/types.rb', line 1152 class AllocateAddressResult < Struct.new( :allocation_id, :public_ipv_4_pool, :network_border_group, :domain, :customer_owned_ip, :customer_owned_ipv_4_pool, :carrier_ip, :public_ip) SENSITIVE = [] include Aws::Structure end |
#carrier_ip ⇒ String
The carrier IP address. Available only for network interfaces that reside in a subnet in a Wavelength Zone.
1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 |
# File 'lib/aws-sdk-ec2/types.rb', line 1152 class AllocateAddressResult < Struct.new( :allocation_id, :public_ipv_4_pool, :network_border_group, :domain, :customer_owned_ip, :customer_owned_ipv_4_pool, :carrier_ip, :public_ip) SENSITIVE = [] include Aws::Structure end |
#customer_owned_ip ⇒ String
The customer-owned IP address.
1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 |
# File 'lib/aws-sdk-ec2/types.rb', line 1152 class AllocateAddressResult < Struct.new( :allocation_id, :public_ipv_4_pool, :network_border_group, :domain, :customer_owned_ip, :customer_owned_ipv_4_pool, :carrier_ip, :public_ip) SENSITIVE = [] include Aws::Structure end |
#customer_owned_ipv_4_pool ⇒ String
The ID of the customer-owned address pool.
1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 |
# File 'lib/aws-sdk-ec2/types.rb', line 1152 class AllocateAddressResult < Struct.new( :allocation_id, :public_ipv_4_pool, :network_border_group, :domain, :customer_owned_ip, :customer_owned_ipv_4_pool, :carrier_ip, :public_ip) SENSITIVE = [] include Aws::Structure end |
#domain ⇒ String
The network (‘vpc`).
1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 |
# File 'lib/aws-sdk-ec2/types.rb', line 1152 class AllocateAddressResult < Struct.new( :allocation_id, :public_ipv_4_pool, :network_border_group, :domain, :customer_owned_ip, :customer_owned_ipv_4_pool, :carrier_ip, :public_ip) SENSITIVE = [] include Aws::Structure end |
#network_border_group ⇒ String
The set of Availability Zones, Local Zones, or Wavelength Zones from which Amazon Web Services advertises IP addresses.
1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 |
# File 'lib/aws-sdk-ec2/types.rb', line 1152 class AllocateAddressResult < Struct.new( :allocation_id, :public_ipv_4_pool, :network_border_group, :domain, :customer_owned_ip, :customer_owned_ipv_4_pool, :carrier_ip, :public_ip) SENSITIVE = [] include Aws::Structure end |
#public_ip ⇒ String
The Amazon-owned IP address. Not available when using an address pool that you own.
1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 |
# File 'lib/aws-sdk-ec2/types.rb', line 1152 class AllocateAddressResult < Struct.new( :allocation_id, :public_ipv_4_pool, :network_border_group, :domain, :customer_owned_ip, :customer_owned_ipv_4_pool, :carrier_ip, :public_ip) SENSITIVE = [] include Aws::Structure end |
#public_ipv_4_pool ⇒ String
The ID of an address pool that you own.
1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 |
# File 'lib/aws-sdk-ec2/types.rb', line 1152 class AllocateAddressResult < Struct.new( :allocation_id, :public_ipv_4_pool, :network_border_group, :domain, :customer_owned_ip, :customer_owned_ipv_4_pool, :carrier_ip, :public_ip) SENSITIVE = [] include Aws::Structure end |