Class: Aws::EC2::Types::AnalysisRouteTableRoute
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::AnalysisRouteTableRoute
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a route table route.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#carrier_gateway_id ⇒ String
The ID of a carrier gateway.
-
#core_network_arn ⇒ String
The Amazon Resource Name (ARN) of a core network.
-
#destination_cidr ⇒ String
The destination IPv4 address, in CIDR notation.
-
#destination_prefix_list_id ⇒ String
The prefix of the Amazon Web Services service.
-
#egress_only_internet_gateway_id ⇒ String
The ID of an egress-only internet gateway.
-
#gateway_id ⇒ String
The ID of the gateway, such as an internet gateway or virtual private gateway.
-
#instance_id ⇒ String
The ID of the instance, such as a NAT instance.
-
#local_gateway_id ⇒ String
The ID of a local gateway.
-
#nat_gateway_id ⇒ String
The ID of a NAT gateway.
-
#network_interface_id ⇒ String
The ID of a network interface.
-
#origin ⇒ String
Describes how the route was created.
-
#state ⇒ String
The state.
-
#transit_gateway_id ⇒ String
The ID of a transit gateway.
-
#vpc_peering_connection_id ⇒ String
The ID of a VPC peering connection.
Instance Attribute Details
#carrier_gateway_id ⇒ String
The ID of a carrier gateway.
1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 |
# File 'lib/aws-sdk-ec2/types.rb', line 1695 class AnalysisRouteTableRoute < Struct.new( :destination_cidr, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :nat_gateway_id, :network_interface_id, :origin, :transit_gateway_id, :vpc_peering_connection_id, :state, :carrier_gateway_id, :core_network_arn, :local_gateway_id) SENSITIVE = [] include Aws::Structure end |
#core_network_arn ⇒ String
The Amazon Resource Name (ARN) of a core network.
1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 |
# File 'lib/aws-sdk-ec2/types.rb', line 1695 class AnalysisRouteTableRoute < Struct.new( :destination_cidr, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :nat_gateway_id, :network_interface_id, :origin, :transit_gateway_id, :vpc_peering_connection_id, :state, :carrier_gateway_id, :core_network_arn, :local_gateway_id) SENSITIVE = [] include Aws::Structure end |
#destination_cidr ⇒ String
The destination IPv4 address, in CIDR notation.
1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 |
# File 'lib/aws-sdk-ec2/types.rb', line 1695 class AnalysisRouteTableRoute < Struct.new( :destination_cidr, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :nat_gateway_id, :network_interface_id, :origin, :transit_gateway_id, :vpc_peering_connection_id, :state, :carrier_gateway_id, :core_network_arn, :local_gateway_id) SENSITIVE = [] include Aws::Structure end |
#destination_prefix_list_id ⇒ String
The prefix of the Amazon Web Services service.
1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 |
# File 'lib/aws-sdk-ec2/types.rb', line 1695 class AnalysisRouteTableRoute < Struct.new( :destination_cidr, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :nat_gateway_id, :network_interface_id, :origin, :transit_gateway_id, :vpc_peering_connection_id, :state, :carrier_gateway_id, :core_network_arn, :local_gateway_id) SENSITIVE = [] include Aws::Structure end |
#egress_only_internet_gateway_id ⇒ String
The ID of an egress-only internet gateway.
1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 |
# File 'lib/aws-sdk-ec2/types.rb', line 1695 class AnalysisRouteTableRoute < Struct.new( :destination_cidr, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :nat_gateway_id, :network_interface_id, :origin, :transit_gateway_id, :vpc_peering_connection_id, :state, :carrier_gateway_id, :core_network_arn, :local_gateway_id) SENSITIVE = [] include Aws::Structure end |
#gateway_id ⇒ String
The ID of the gateway, such as an internet gateway or virtual private gateway.
1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 |
# File 'lib/aws-sdk-ec2/types.rb', line 1695 class AnalysisRouteTableRoute < Struct.new( :destination_cidr, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :nat_gateway_id, :network_interface_id, :origin, :transit_gateway_id, :vpc_peering_connection_id, :state, :carrier_gateway_id, :core_network_arn, :local_gateway_id) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the instance, such as a NAT instance.
1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 |
# File 'lib/aws-sdk-ec2/types.rb', line 1695 class AnalysisRouteTableRoute < Struct.new( :destination_cidr, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :nat_gateway_id, :network_interface_id, :origin, :transit_gateway_id, :vpc_peering_connection_id, :state, :carrier_gateway_id, :core_network_arn, :local_gateway_id) SENSITIVE = [] include Aws::Structure end |
#local_gateway_id ⇒ String
The ID of a local gateway.
1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 |
# File 'lib/aws-sdk-ec2/types.rb', line 1695 class AnalysisRouteTableRoute < Struct.new( :destination_cidr, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :nat_gateway_id, :network_interface_id, :origin, :transit_gateway_id, :vpc_peering_connection_id, :state, :carrier_gateway_id, :core_network_arn, :local_gateway_id) SENSITIVE = [] include Aws::Structure end |
#nat_gateway_id ⇒ String
The ID of a NAT gateway.
1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 |
# File 'lib/aws-sdk-ec2/types.rb', line 1695 class AnalysisRouteTableRoute < Struct.new( :destination_cidr, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :nat_gateway_id, :network_interface_id, :origin, :transit_gateway_id, :vpc_peering_connection_id, :state, :carrier_gateway_id, :core_network_arn, :local_gateway_id) SENSITIVE = [] include Aws::Structure end |
#network_interface_id ⇒ String
The ID of a network interface.
1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 |
# File 'lib/aws-sdk-ec2/types.rb', line 1695 class AnalysisRouteTableRoute < Struct.new( :destination_cidr, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :nat_gateway_id, :network_interface_id, :origin, :transit_gateway_id, :vpc_peering_connection_id, :state, :carrier_gateway_id, :core_network_arn, :local_gateway_id) SENSITIVE = [] include Aws::Structure end |
#origin ⇒ String
Describes how the route was created. The following are the possible values:
-
CreateRouteTable - The route was automatically created when the route table was created.
-
CreateRoute - The route was manually added to the route table.
-
EnableVgwRoutePropagation - The route was propagated by route propagation.
1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 |
# File 'lib/aws-sdk-ec2/types.rb', line 1695 class AnalysisRouteTableRoute < Struct.new( :destination_cidr, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :nat_gateway_id, :network_interface_id, :origin, :transit_gateway_id, :vpc_peering_connection_id, :state, :carrier_gateway_id, :core_network_arn, :local_gateway_id) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state. The following are the possible values:
-
active
-
blackhole
1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 |
# File 'lib/aws-sdk-ec2/types.rb', line 1695 class AnalysisRouteTableRoute < Struct.new( :destination_cidr, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :nat_gateway_id, :network_interface_id, :origin, :transit_gateway_id, :vpc_peering_connection_id, :state, :carrier_gateway_id, :core_network_arn, :local_gateway_id) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_id ⇒ String
The ID of a transit gateway.
1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 |
# File 'lib/aws-sdk-ec2/types.rb', line 1695 class AnalysisRouteTableRoute < Struct.new( :destination_cidr, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :nat_gateway_id, :network_interface_id, :origin, :transit_gateway_id, :vpc_peering_connection_id, :state, :carrier_gateway_id, :core_network_arn, :local_gateway_id) SENSITIVE = [] include Aws::Structure end |
#vpc_peering_connection_id ⇒ String
The ID of a VPC peering connection.
1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 |
# File 'lib/aws-sdk-ec2/types.rb', line 1695 class AnalysisRouteTableRoute < Struct.new( :destination_cidr, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :nat_gateway_id, :network_interface_id, :origin, :transit_gateway_id, :vpc_peering_connection_id, :state, :carrier_gateway_id, :core_network_arn, :local_gateway_id) SENSITIVE = [] include Aws::Structure end |