Class: Aws::EC2::Types::ApplicationStatus

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes the application-level health status for an instance.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#detailsArray<Types::ApplicationStatusDetail>

Details about the application status checks for the instance.

Returns:



1925
1926
1927
1928
1929
1930
1931
1932
1933
# File 'lib/aws-sdk-ec2/types.rb', line 1925

class ApplicationStatus < Struct.new(
  :status,
  :status_time_stamp,
  :status_since,
  :resume_at,
  :details)
  SENSITIVE = []
  include Aws::Structure
end

#resume_atTime

The date and time when application status reporting resumes after suppression.

Returns:

  • (Time)


1925
1926
1927
1928
1929
1930
1931
1932
1933
# File 'lib/aws-sdk-ec2/types.rb', line 1925

class ApplicationStatus < Struct.new(
  :status,
  :status_time_stamp,
  :status_since,
  :resume_at,
  :details)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current instance-level application status. This status is derived from application status checks with Aggregation set to included. Possible values:

  • ok – All included checks passed.

  • impaired – At least one included check failed.

  • initializing – At least one included check is initializing, and no included check is impaired.

  • insufficient-data – At least one included check has insufficient data, and no included check is impaired or initializing.

  • not-applicable – No checks with Aggregation set to included apply to the instance.

  • suppressed – Application status reporting is suppressed for the instance.

Checks with Aggregation set to excluded do not affect this value.

Returns:

  • (String)


1925
1926
1927
1928
1929
1930
1931
1932
1933
# File 'lib/aws-sdk-ec2/types.rb', line 1925

class ApplicationStatus < Struct.new(
  :status,
  :status_time_stamp,
  :status_since,
  :resume_at,
  :details)
  SENSITIVE = []
  include Aws::Structure
end

#status_sinceTime

The date and time when the current status started.

Returns:

  • (Time)


1925
1926
1927
1928
1929
1930
1931
1932
1933
# File 'lib/aws-sdk-ec2/types.rb', line 1925

class ApplicationStatus < Struct.new(
  :status,
  :status_time_stamp,
  :status_since,
  :resume_at,
  :details)
  SENSITIVE = []
  include Aws::Structure
end

#status_time_stampTime

The date and time of the last status update.

Returns:

  • (Time)


1925
1926
1927
1928
1929
1930
1931
1932
1933
# File 'lib/aws-sdk-ec2/types.rb', line 1925

class ApplicationStatus < Struct.new(
  :status,
  :status_time_stamp,
  :status_since,
  :resume_at,
  :details)
  SENSITIVE = []
  include Aws::Structure
end