Class: Aws::EC2::Types::ApplicationStatusCheckResponseObject

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes an application status check.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aggregationString

The aggregation setting for the application status check. When set to included, the result of this check contributes to the instance-level application status. When set to excluded, the check runs independently and does not affect the instance-level status.

Returns:

  • (String)


2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
# File 'lib/aws-sdk-ec2/types.rb', line 2082

class ApplicationStatusCheckResponseObject < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :last_updated_at,
  :target_tag_associations,
  :tags,
  :creation_time,
  :modify_time,
  :deletion_time)
  SENSITIVE = []
  include Aws::Structure
end

#application_status_check_idString

The ID of the application status check.

Returns:

  • (String)


2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
# File 'lib/aws-sdk-ec2/types.rb', line 2082

class ApplicationStatusCheckResponseObject < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :last_updated_at,
  :target_tag_associations,
  :tags,
  :creation_time,
  :modify_time,
  :deletion_time)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The date and time when the application status check was created.

Returns:

  • (Time)


2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
# File 'lib/aws-sdk-ec2/types.rb', line 2082

class ApplicationStatusCheckResponseObject < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :last_updated_at,
  :target_tag_associations,
  :tags,
  :creation_time,
  :modify_time,
  :deletion_time)
  SENSITIVE = []
  include Aws::Structure
end

#deletion_timeTime

The date and time when the application status check was deleted.

Returns:

  • (Time)


2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
# File 'lib/aws-sdk-ec2/types.rb', line 2082

class ApplicationStatusCheckResponseObject < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :last_updated_at,
  :target_tag_associations,
  :tags,
  :creation_time,
  :modify_time,
  :deletion_time)
  SENSITIVE = []
  include Aws::Structure
end

#device_indexInteger

The index of the network device used for the health check. The value is greater than or equal to 0.

Returns:

  • (Integer)


2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
# File 'lib/aws-sdk-ec2/types.rb', line 2082

class ApplicationStatusCheckResponseObject < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :last_updated_at,
  :target_tag_associations,
  :tags,
  :creation_time,
  :modify_time,
  :deletion_time)
  SENSITIVE = []
  include Aws::Structure
end

#failure_thresholdInteger

The number of consecutive failed health checks before the application status is considered impaired. The value must be greater than 0.

Returns:

  • (Integer)


2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
# File 'lib/aws-sdk-ec2/types.rb', line 2082

class ApplicationStatusCheckResponseObject < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :last_updated_at,
  :target_tag_associations,
  :tags,
  :creation_time,
  :modify_time,
  :deletion_time)
  SENSITIVE = []
  include Aws::Structure
end

#health_check_pathsArray<Types::HealthCheckPathResponseObject>

The health check paths for the application status check.



2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
# File 'lib/aws-sdk-ec2/types.rb', line 2082

class ApplicationStatusCheckResponseObject < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :last_updated_at,
  :target_tag_associations,
  :tags,
  :creation_time,
  :modify_time,
  :deletion_time)
  SENSITIVE = []
  include Aws::Structure
end

#initialization_grace_period_secondsInteger

The number of seconds to wait before starting health checks after an instance is launched. Valid values: 1 to 600.

Returns:

  • (Integer)


2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
# File 'lib/aws-sdk-ec2/types.rb', line 2082

class ApplicationStatusCheckResponseObject < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :last_updated_at,
  :target_tag_associations,
  :tags,
  :creation_time,
  :modify_time,
  :deletion_time)
  SENSITIVE = []
  include Aws::Structure
end

#intervalInteger

The interval, in seconds, between health checks. Valid value: 60.

Returns:

  • (Integer)


2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
# File 'lib/aws-sdk-ec2/types.rb', line 2082

class ApplicationStatusCheckResponseObject < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :last_updated_at,
  :target_tag_associations,
  :tags,
  :creation_time,
  :modify_time,
  :deletion_time)
  SENSITIVE = []
  include Aws::Structure
end

#ip_scopeString

The IP scope used for the health check.

Returns:

  • (String)


2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
# File 'lib/aws-sdk-ec2/types.rb', line 2082

class ApplicationStatusCheckResponseObject < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :last_updated_at,
  :target_tag_associations,
  :tags,
  :creation_time,
  :modify_time,
  :deletion_time)
  SENSITIVE = []
  include Aws::Structure
end

#ip_versionString

The IP version used for the health check.

Returns:

  • (String)


2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
# File 'lib/aws-sdk-ec2/types.rb', line 2082

class ApplicationStatusCheckResponseObject < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :last_updated_at,
  :target_tag_associations,
  :tags,
  :creation_time,
  :modify_time,
  :deletion_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_atTime

The date and time when the application status check was last updated.

Returns:

  • (Time)


2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
# File 'lib/aws-sdk-ec2/types.rb', line 2082

class ApplicationStatusCheckResponseObject < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :last_updated_at,
  :target_tag_associations,
  :tags,
  :creation_time,
  :modify_time,
  :deletion_time)
  SENSITIVE = []
  include Aws::Structure
end

#modify_timeTime

The date and time when the application status check was last modified.

Returns:

  • (Time)


2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
# File 'lib/aws-sdk-ec2/types.rb', line 2082

class ApplicationStatusCheckResponseObject < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :last_updated_at,
  :target_tag_associations,
  :tags,
  :creation_time,
  :modify_time,
  :deletion_time)
  SENSITIVE = []
  include Aws::Structure
end

#pathString

The URL path used for the health check HTTP request.

Returns:

  • (String)


2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
# File 'lib/aws-sdk-ec2/types.rb', line 2082

class ApplicationStatusCheckResponseObject < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :last_updated_at,
  :target_tag_associations,
  :tags,
  :creation_time,
  :modify_time,
  :deletion_time)
  SENSITIVE = []
  include Aws::Structure
end

#portInteger

The port used for the health check.

Returns:

  • (Integer)


2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
# File 'lib/aws-sdk-ec2/types.rb', line 2082

class ApplicationStatusCheckResponseObject < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :last_updated_at,
  :target_tag_associations,
  :tags,
  :creation_time,
  :modify_time,
  :deletion_time)
  SENSITIVE = []
  include Aws::Structure
end

#protocolString

The protocol used for the health check.

Returns:

  • (String)


2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
# File 'lib/aws-sdk-ec2/types.rb', line 2082

class ApplicationStatusCheckResponseObject < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :last_updated_at,
  :target_tag_associations,
  :tags,
  :creation_time,
  :modify_time,
  :deletion_time)
  SENSITIVE = []
  include Aws::Structure
end

#status_code_matcherString

The comma-separated list of individual HTTP status codes or ranges that indicate a successful health check response.

Returns:

  • (String)


2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
# File 'lib/aws-sdk-ec2/types.rb', line 2082

class ApplicationStatusCheckResponseObject < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :last_updated_at,
  :target_tag_associations,
  :tags,
  :creation_time,
  :modify_time,
  :deletion_time)
  SENSITIVE = []
  include Aws::Structure
end

#success_thresholdInteger

The number of consecutive successful health checks before the application status is considered healthy. The value must be greater than 0.

Returns:

  • (Integer)


2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
# File 'lib/aws-sdk-ec2/types.rb', line 2082

class ApplicationStatusCheckResponseObject < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :last_updated_at,
  :target_tag_associations,
  :tags,
  :creation_time,
  :modify_time,
  :deletion_time)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The tags assigned to the application status check.

Returns:



2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
# File 'lib/aws-sdk-ec2/types.rb', line 2082

class ApplicationStatusCheckResponseObject < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :last_updated_at,
  :target_tag_associations,
  :tags,
  :creation_time,
  :modify_time,
  :deletion_time)
  SENSITIVE = []
  include Aws::Structure
end

#target_tag_associationsArray<Types::CustomTagKeyValueResponsePair>

The tags associated with the application status check. Instances with these tags are automatically monitored by this check.



2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
# File 'lib/aws-sdk-ec2/types.rb', line 2082

class ApplicationStatusCheckResponseObject < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :last_updated_at,
  :target_tag_associations,
  :tags,
  :creation_time,
  :modify_time,
  :deletion_time)
  SENSITIVE = []
  include Aws::Structure
end

#timeoutInteger

The amount of time, in seconds, to wait for a health check response. Valid values: 1 to 30.

Returns:

  • (Integer)


2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
# File 'lib/aws-sdk-ec2/types.rb', line 2082

class ApplicationStatusCheckResponseObject < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :last_updated_at,
  :target_tag_associations,
  :tags,
  :creation_time,
  :modify_time,
  :deletion_time)
  SENSITIVE = []
  include Aws::Structure
end