Class: Aws::EC2::Types::ApplicationStatusReason

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes the reason for an application status check result.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#codeString

The reason code for the application status check result. Possible values:

  • ResponseCodeMatched – The HTTP status code returned by the health check matched the configured StatusCodeMatcher.

  • ResponseCodeMismatch – The HTTP status code returned by the health check did not match the configured StatusCodeMatcher.

  • ConnectionTimeout – The connection to the target timed out.

  • ResponseTimeout – The health check timed out while waiting for a response from the target.

  • ConnectionRefused – The target refused the health check connection.

  • ConnectionReset – The target reset the health check connection before returning a response.

Current health check results use the values in the preceding list. Legacy results that do not contain structured reason metadata can instead contain a producer error type, such as Http Status Code or HttpConnectTimeoutException.

For ResponseCodeMatched and ResponseCodeMismatch, the statusCode field contains the returned HTTP status code. The protocol field contains the protocol used for the health check.

Returns:

  • (String)


2215
2216
2217
2218
2219
2220
2221
# File 'lib/aws-sdk-ec2/types.rb', line 2215

class ApplicationStatusReason < Struct.new(
  :code,
  :status_code,
  :protocol)
  SENSITIVE = []
  include Aws::Structure
end

#protocolString

The protocol used for the health check. Possible values: HTTP and HTTPS.

Returns:

  • (String)


2215
2216
2217
2218
2219
2220
2221
# File 'lib/aws-sdk-ec2/types.rb', line 2215

class ApplicationStatusReason < Struct.new(
  :code,
  :status_code,
  :protocol)
  SENSITIVE = []
  include Aws::Structure
end

#status_codeInteger

The HTTP status code returned by the health check.

Returns:

  • (Integer)


2215
2216
2217
2218
2219
2220
2221
# File 'lib/aws-sdk-ec2/types.rb', line 2215

class ApplicationStatusReason < Struct.new(
  :code,
  :status_code,
  :protocol)
  SENSITIVE = []
  include Aws::Structure
end