Class: Aws::EC2::Types::ApplySecurityGroupsToClientVpnTargetNetworkRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_vpn_endpoint_idString

The ID of the Client VPN endpoint.

Returns:

  • (String)


2280
2281
2282
2283
2284
2285
2286
2287
# File 'lib/aws-sdk-ec2/types.rb', line 2280

class ApplySecurityGroupsToClientVpnTargetNetworkRequest < Struct.new(
  :client_vpn_endpoint_id,
  :vpc_id,
  :security_group_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


2280
2281
2282
2283
2284
2285
2286
2287
# File 'lib/aws-sdk-ec2/types.rb', line 2280

class ApplySecurityGroupsToClientVpnTargetNetworkRequest < Struct.new(
  :client_vpn_endpoint_id,
  :vpc_id,
  :security_group_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#security_group_idsArray<String>

The IDs of the security groups to apply to the associated target network. Up to 5 security groups can be applied to an associated target network.

Returns:

  • (Array<String>)


2280
2281
2282
2283
2284
2285
2286
2287
# File 'lib/aws-sdk-ec2/types.rb', line 2280

class ApplySecurityGroupsToClientVpnTargetNetworkRequest < Struct.new(
  :client_vpn_endpoint_id,
  :vpc_id,
  :security_group_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC in which the associated target network is located.

Returns:

  • (String)


2280
2281
2282
2283
2284
2285
2286
2287
# File 'lib/aws-sdk-ec2/types.rb', line 2280

class ApplySecurityGroupsToClientVpnTargetNetworkRequest < Struct.new(
  :client_vpn_endpoint_id,
  :vpc_id,
  :security_group_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end