Class: Aws::EC2::Types::AssignIpv6AddressesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ipv_6_address_countInteger

The number of additional IPv6 addresses to assign to the network interface. The specified number of IPv6 addresses are assigned in addition to the existing IPv6 addresses that are already assigned to the network interface. Amazon EC2 automatically selects the IPv6 addresses from the subnet range. You can't use this option if specifying specific IPv6 addresses.

Returns:

  • (Integer)


2389
2390
2391
2392
2393
2394
2395
2396
2397
# File 'lib/aws-sdk-ec2/types.rb', line 2389

class AssignIpv6AddressesRequest < Struct.new(
  :ipv_6_prefix_count,
  :ipv_6_prefixes,
  :network_interface_id,
  :ipv_6_addresses,
  :ipv_6_address_count)
  SENSITIVE = []
  include Aws::Structure
end

#ipv_6_addressesArray<String>

The IPv6 addresses to be assigned to the network interface. You can't use this option if you're specifying a number of IPv6 addresses.

Returns:

  • (Array<String>)


2389
2390
2391
2392
2393
2394
2395
2396
2397
# File 'lib/aws-sdk-ec2/types.rb', line 2389

class AssignIpv6AddressesRequest < Struct.new(
  :ipv_6_prefix_count,
  :ipv_6_prefixes,
  :network_interface_id,
  :ipv_6_addresses,
  :ipv_6_address_count)
  SENSITIVE = []
  include Aws::Structure
end

#ipv_6_prefix_countInteger

The number of IPv6 prefixes that Amazon Web Services automatically assigns to the network interface. You cannot use this option if you use the Ipv6Prefixes option.

Returns:

  • (Integer)


2389
2390
2391
2392
2393
2394
2395
2396
2397
# File 'lib/aws-sdk-ec2/types.rb', line 2389

class AssignIpv6AddressesRequest < Struct.new(
  :ipv_6_prefix_count,
  :ipv_6_prefixes,
  :network_interface_id,
  :ipv_6_addresses,
  :ipv_6_address_count)
  SENSITIVE = []
  include Aws::Structure
end

#ipv_6_prefixesArray<String>

One or more IPv6 prefixes assigned to the network interface. You can't use this option if you use the Ipv6PrefixCount option.

Returns:

  • (Array<String>)


2389
2390
2391
2392
2393
2394
2395
2396
2397
# File 'lib/aws-sdk-ec2/types.rb', line 2389

class AssignIpv6AddressesRequest < Struct.new(
  :ipv_6_prefix_count,
  :ipv_6_prefixes,
  :network_interface_id,
  :ipv_6_addresses,
  :ipv_6_address_count)
  SENSITIVE = []
  include Aws::Structure
end

#network_interface_idString

The ID of the network interface.

Returns:

  • (String)


2389
2390
2391
2392
2393
2394
2395
2396
2397
# File 'lib/aws-sdk-ec2/types.rb', line 2389

class AssignIpv6AddressesRequest < Struct.new(
  :ipv_6_prefix_count,
  :ipv_6_prefixes,
  :network_interface_id,
  :ipv_6_addresses,
  :ipv_6_address_count)
  SENSITIVE = []
  include Aws::Structure
end