Class: Aws::EC2::Types::AssignPrivateIpAddressesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::AssignPrivateIpAddressesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for AssignPrivateIpAddresses.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allow_reassignment ⇒ Boolean
Indicates whether to allow an IP address that is already assigned to another network interface or instance to be reassigned to the specified network interface.
-
#ipv_4_prefix_count ⇒ Integer
The number of IPv4 prefixes that Amazon Web Services automatically assigns to the network interface.
-
#ipv_4_prefixes ⇒ Array<String>
One or more IPv4 prefixes assigned to the network interface.
-
#network_interface_id ⇒ String
The ID of the network interface.
-
#private_ip_addresses ⇒ Array<String>
The IP addresses to be assigned as a secondary private IP address to the network interface.
-
#secondary_private_ip_address_count ⇒ Integer
The number of secondary IP addresses to assign to the network interface.
Instance Attribute Details
#allow_reassignment ⇒ Boolean
Indicates whether to allow an IP address that is already assigned to another network interface or instance to be reassigned to the specified network interface.
2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 |
# File 'lib/aws-sdk-ec2/types.rb', line 2463 class AssignPrivateIpAddressesRequest < Struct.new( :ipv_4_prefixes, :ipv_4_prefix_count, :network_interface_id, :private_ip_addresses, :secondary_private_ip_address_count, :allow_reassignment) SENSITIVE = [] include Aws::Structure end |
#ipv_4_prefix_count ⇒ Integer
The number of IPv4 prefixes that Amazon Web Services automatically
assigns to the network interface. You can't use this option if you
use the Ipv4 Prefixes option.
2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 |
# File 'lib/aws-sdk-ec2/types.rb', line 2463 class AssignPrivateIpAddressesRequest < Struct.new( :ipv_4_prefixes, :ipv_4_prefix_count, :network_interface_id, :private_ip_addresses, :secondary_private_ip_address_count, :allow_reassignment) SENSITIVE = [] include Aws::Structure end |
#ipv_4_prefixes ⇒ Array<String>
One or more IPv4 prefixes assigned to the network interface. You
can't use this option if you use the Ipv4PrefixCount option.
2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 |
# File 'lib/aws-sdk-ec2/types.rb', line 2463 class AssignPrivateIpAddressesRequest < Struct.new( :ipv_4_prefixes, :ipv_4_prefix_count, :network_interface_id, :private_ip_addresses, :secondary_private_ip_address_count, :allow_reassignment) SENSITIVE = [] include Aws::Structure end |
#network_interface_id ⇒ String
The ID of the network interface.
2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 |
# File 'lib/aws-sdk-ec2/types.rb', line 2463 class AssignPrivateIpAddressesRequest < Struct.new( :ipv_4_prefixes, :ipv_4_prefix_count, :network_interface_id, :private_ip_addresses, :secondary_private_ip_address_count, :allow_reassignment) SENSITIVE = [] include Aws::Structure end |
#private_ip_addresses ⇒ Array<String>
The IP addresses to be assigned as a secondary private IP address to the network interface. You can't specify this parameter when also specifying a number of secondary IP addresses.
If you don't specify an IP address, Amazon EC2 automatically selects an IP address within the subnet range.
2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 |
# File 'lib/aws-sdk-ec2/types.rb', line 2463 class AssignPrivateIpAddressesRequest < Struct.new( :ipv_4_prefixes, :ipv_4_prefix_count, :network_interface_id, :private_ip_addresses, :secondary_private_ip_address_count, :allow_reassignment) SENSITIVE = [] include Aws::Structure end |
#secondary_private_ip_address_count ⇒ Integer
The number of secondary IP addresses to assign to the network interface. You can't specify this parameter when also specifying private IP addresses.
2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 |
# File 'lib/aws-sdk-ec2/types.rb', line 2463 class AssignPrivateIpAddressesRequest < Struct.new( :ipv_4_prefixes, :ipv_4_prefix_count, :network_interface_id, :private_ip_addresses, :secondary_private_ip_address_count, :allow_reassignment) SENSITIVE = [] include Aws::Structure end |