Class: Aws::EC2::Types::AssignPrivateNatGatewayAddressRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::AssignPrivateNatGatewayAddressRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#nat_gateway_id ⇒ String
The ID of the NAT gateway.
-
#private_ip_address_count ⇒ Integer
The number of private IP addresses to assign to the NAT gateway.
-
#private_ip_addresses ⇒ Array<String>
The private IPv4 addresses you want to assign to the private NAT gateway.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
2032 2033 2034 2035 2036 2037 2038 2039 |
# File 'lib/aws-sdk-ec2/types.rb', line 2032 class AssignPrivateNatGatewayAddressRequest < Struct.new( :nat_gateway_id, :private_ip_addresses, :private_ip_address_count, :dry_run) SENSITIVE = [] include Aws::Structure end |
#nat_gateway_id ⇒ String
The ID of the NAT gateway.
2032 2033 2034 2035 2036 2037 2038 2039 |
# File 'lib/aws-sdk-ec2/types.rb', line 2032 class AssignPrivateNatGatewayAddressRequest < Struct.new( :nat_gateway_id, :private_ip_addresses, :private_ip_address_count, :dry_run) SENSITIVE = [] include Aws::Structure end |
#private_ip_address_count ⇒ Integer
The number of private IP addresses to assign to the NAT gateway. You can’t specify this parameter when also specifying private IP addresses.
2032 2033 2034 2035 2036 2037 2038 2039 |
# File 'lib/aws-sdk-ec2/types.rb', line 2032 class AssignPrivateNatGatewayAddressRequest < Struct.new( :nat_gateway_id, :private_ip_addresses, :private_ip_address_count, :dry_run) SENSITIVE = [] include Aws::Structure end |
#private_ip_addresses ⇒ Array<String>
The private IPv4 addresses you want to assign to the private NAT gateway.
2032 2033 2034 2035 2036 2037 2038 2039 |
# File 'lib/aws-sdk-ec2/types.rb', line 2032 class AssignPrivateNatGatewayAddressRequest < Struct.new( :nat_gateway_id, :private_ip_addresses, :private_ip_address_count, :dry_run) SENSITIVE = [] include Aws::Structure end |