Class: Aws::EC2::Types::AssociateApplicationStatusCheckRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_status_check_idString

The ID of the application status check to associate.

Returns:

  • (String)


2673
2674
2675
2676
2677
2678
2679
2680
2681
# File 'lib/aws-sdk-ec2/types.rb', line 2673

class AssociateApplicationStatusCheckRequest < Struct.new(
  :application_status_check_id,
  :target_tag_associations,
  :instance_ids,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure that the operation completes no more than one time. If you retry a request with the same token, the service ignores the request but does not return an error. For more information, see Ensuring idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


2673
2674
2675
2676
2677
2678
2679
2680
2681
# File 'lib/aws-sdk-ec2/types.rb', line 2673

class AssociateApplicationStatusCheckRequest < Struct.new(
  :application_status_check_id,
  :target_tag_associations,
  :instance_ids,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


2673
2674
2675
2676
2677
2678
2679
2680
2681
# File 'lib/aws-sdk-ec2/types.rb', line 2673

class AssociateApplicationStatusCheckRequest < Struct.new(
  :application_status_check_id,
  :target_tag_associations,
  :instance_ids,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idsArray<String>

The IDs of the instances to associate with the application status check.

Returns:

  • (Array<String>)


2673
2674
2675
2676
2677
2678
2679
2680
2681
# File 'lib/aws-sdk-ec2/types.rb', line 2673

class AssociateApplicationStatusCheckRequest < Struct.new(
  :application_status_check_id,
  :target_tag_associations,
  :instance_ids,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#target_tag_associationsArray<Types::CustomTagKeyValueRequestPair>

The tags to associate the application status check with. Each tag is a key-value pair. When you associate tags, the application status check automatically monitors all instances that have the specified tags.



2673
2674
2675
2676
2677
2678
2679
2680
2681
# File 'lib/aws-sdk-ec2/types.rb', line 2673

class AssociateApplicationStatusCheckRequest < Struct.new(
  :application_status_check_id,
  :target_tag_associations,
  :instance_ids,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end