Class: Aws::EC2::Types::AssociateClientVpnTargetNetworkRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_zoneString

The Availability Zone name for the Transit Gateway association. Required if when associating an Availability Zone with a Client VPN endpoint that uses a Transit Gateway. You cannot specify both SubnetId and AvailabilityZone.

Returns:

  • (String)


2782
2783
2784
2785
2786
2787
2788
2789
2790
2791
# File 'lib/aws-sdk-ec2/types.rb', line 2782

class AssociateClientVpnTargetNetworkRequest < Struct.new(
  :client_vpn_endpoint_id,
  :subnet_id,
  :client_token,
  :dry_run,
  :availability_zone,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zone_idString

The Availability Zone ID for the Transit Gateway association. Required if when associating an Availability Zone with a Client VPN endpoint that uses a Transit Gateway. You cannot specify both AvailabilityZone and AvailabilityZoneId.

Returns:

  • (String)


2782
2783
2784
2785
2786
2787
2788
2789
2790
2791
# File 'lib/aws-sdk-ec2/types.rb', line 2782

class AssociateClientVpnTargetNetworkRequest < Struct.new(
  :client_vpn_endpoint_id,
  :subnet_id,
  :client_token,
  :dry_run,
  :availability_zone,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


2782
2783
2784
2785
2786
2787
2788
2789
2790
2791
# File 'lib/aws-sdk-ec2/types.rb', line 2782

class AssociateClientVpnTargetNetworkRequest < Struct.new(
  :client_vpn_endpoint_id,
  :subnet_id,
  :client_token,
  :dry_run,
  :availability_zone,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#client_vpn_endpoint_idString

The ID of the Client VPN endpoint.

Returns:

  • (String)


2782
2783
2784
2785
2786
2787
2788
2789
2790
2791
# File 'lib/aws-sdk-ec2/types.rb', line 2782

class AssociateClientVpnTargetNetworkRequest < Struct.new(
  :client_vpn_endpoint_id,
  :subnet_id,
  :client_token,
  :dry_run,
  :availability_zone,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


2782
2783
2784
2785
2786
2787
2788
2789
2790
2791
# File 'lib/aws-sdk-ec2/types.rb', line 2782

class AssociateClientVpnTargetNetworkRequest < Struct.new(
  :client_vpn_endpoint_id,
  :subnet_id,
  :client_token,
  :dry_run,
  :availability_zone,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idString

The ID of the subnet to associate with the Client VPN endpoint. Required for VPC-based endpoints. For Transit Gateway-based endpoints, use AvailabilityZone or AvailabilityZoneId instead.

Returns:

  • (String)


2782
2783
2784
2785
2786
2787
2788
2789
2790
2791
# File 'lib/aws-sdk-ec2/types.rb', line 2782

class AssociateClientVpnTargetNetworkRequest < Struct.new(
  :client_vpn_endpoint_id,
  :subnet_id,
  :client_token,
  :dry_run,
  :availability_zone,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end