Class: Aws::EC2::Types::AssociateDhcpOptionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::AssociateDhcpOptionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dhcp_options_id ⇒ String
The ID of the DHCP options set, or
defaultto associate no DHCP options with the VPC. -
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#vpc_id ⇒ String
The ID of the VPC.
Instance Attribute Details
#dhcp_options_id ⇒ String
The ID of the DHCP options set, or default to associate no DHCP
options with the VPC.
2828 2829 2830 2831 2832 2833 2834 |
# File 'lib/aws-sdk-ec2/types.rb', line 2828 class AssociateDhcpOptionsRequest < Struct.new( :dhcp_options_id, :vpc_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
2828 2829 2830 2831 2832 2833 2834 |
# File 'lib/aws-sdk-ec2/types.rb', line 2828 class AssociateDhcpOptionsRequest < Struct.new( :dhcp_options_id, :vpc_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC.
2828 2829 2830 2831 2832 2833 2834 |
# File 'lib/aws-sdk-ec2/types.rb', line 2828 class AssociateDhcpOptionsRequest < Struct.new( :dhcp_options_id, :vpc_id, :dry_run) SENSITIVE = [] include Aws::Structure end |