Class: Aws::EC2::Types::AssociateEnclaveCertificateIamRoleRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::AssociateEnclaveCertificateIamRoleRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_arn ⇒ String
The ARN of the ACM certificate with which to associate the IAM role.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#role_arn ⇒ String
The ARN of the IAM role to associate with the ACM certificate.
Instance Attribute Details
#certificate_arn ⇒ String
The ARN of the ACM certificate with which to associate the IAM role.
2854 2855 2856 2857 2858 2859 2860 |
# File 'lib/aws-sdk-ec2/types.rb', line 2854 class AssociateEnclaveCertificateIamRoleRequest < Struct.new( :certificate_arn, :role_arn, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
2854 2855 2856 2857 2858 2859 2860 |
# File 'lib/aws-sdk-ec2/types.rb', line 2854 class AssociateEnclaveCertificateIamRoleRequest < Struct.new( :certificate_arn, :role_arn, :dry_run) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The ARN of the IAM role to associate with the ACM certificate. You can associate up to 16 IAM roles with an ACM certificate.
2854 2855 2856 2857 2858 2859 2860 |
# File 'lib/aws-sdk-ec2/types.rb', line 2854 class AssociateEnclaveCertificateIamRoleRequest < Struct.new( :certificate_arn, :role_arn, :dry_run) SENSITIVE = [] include Aws::Structure end |