Class: Aws::EC2::Types::AssociateInstanceEventWindowRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::AssociateInstanceEventWindowRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#association_target ⇒ Types::InstanceEventWindowAssociationRequest
One or more targets associated with the specified event window.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#instance_event_window_id ⇒ String
The ID of the event window.
Instance Attribute Details
#association_target ⇒ Types::InstanceEventWindowAssociationRequest
One or more targets associated with the specified event window.
2365 2366 2367 2368 2369 2370 2371 |
# File 'lib/aws-sdk-ec2/types.rb', line 2365 class AssociateInstanceEventWindowRequest < Struct.new( :dry_run, :instance_event_window_id, :association_target) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
2365 2366 2367 2368 2369 2370 2371 |
# File 'lib/aws-sdk-ec2/types.rb', line 2365 class AssociateInstanceEventWindowRequest < Struct.new( :dry_run, :instance_event_window_id, :association_target) SENSITIVE = [] include Aws::Structure end |
#instance_event_window_id ⇒ String
The ID of the event window.
2365 2366 2367 2368 2369 2370 2371 |
# File 'lib/aws-sdk-ec2/types.rb', line 2365 class AssociateInstanceEventWindowRequest < Struct.new( :dry_run, :instance_event_window_id, :association_target) SENSITIVE = [] include Aws::Structure end |