Class: Aws::EC2::Types::AssociateIpamByoasnRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#asnString

A public 2-byte or 4-byte ASN.

Returns:

  • (String)


2973
2974
2975
2976
2977
2978
2979
# File 'lib/aws-sdk-ec2/types.rb', line 2973

class AssociateIpamByoasnRequest < Struct.new(
  :dry_run,
  :asn,
  :cidr)
  SENSITIVE = []
  include Aws::Structure
end

#cidrString

The BYOIP CIDR you want to associate with an ASN.

Returns:

  • (String)


2973
2974
2975
2976
2977
2978
2979
# File 'lib/aws-sdk-ec2/types.rb', line 2973

class AssociateIpamByoasnRequest < Struct.new(
  :dry_run,
  :asn,
  :cidr)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


2973
2974
2975
2976
2977
2978
2979
# File 'lib/aws-sdk-ec2/types.rb', line 2973

class AssociateIpamByoasnRequest < Struct.new(
  :dry_run,
  :asn,
  :cidr)
  SENSITIVE = []
  include Aws::Structure
end