Class: Aws::EC2::Types::AssociateNatGatewayAddressRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allocation_idsArray<String>

The allocation IDs of EIPs that you want to associate with your NAT gateway.

Returns:

  • (Array<String>)


3089
3090
3091
3092
3093
3094
3095
3096
3097
3098
# File 'lib/aws-sdk-ec2/types.rb', line 3089

class AssociateNatGatewayAddressRequest < Struct.new(
  :nat_gateway_id,
  :allocation_ids,
  :private_ip_addresses,
  :dry_run,
  :availability_zone,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zoneString

For regional NAT gateways only: The Availability Zone where you want to associate an Elastic IP address (EIP). The regional NAT gateway uses a separate EIP in each AZ to handle outbound NAT traffic from that AZ.

A regional NAT gateway is a single NAT Gateway that works across multiple availability zones (AZs) in your VPC, providing redundancy, scalability and availability across all the AZs in a Region.

Returns:

  • (String)


3089
3090
3091
3092
3093
3094
3095
3096
3097
3098
# File 'lib/aws-sdk-ec2/types.rb', line 3089

class AssociateNatGatewayAddressRequest < Struct.new(
  :nat_gateway_id,
  :allocation_ids,
  :private_ip_addresses,
  :dry_run,
  :availability_zone,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zone_idString

For regional NAT gateways only: The ID of the Availability Zone where you want to associate an Elastic IP address (EIP). The regional NAT gateway uses a separate EIP in each AZ to handle outbound NAT traffic from that AZ. Use this instead of AvailabilityZone for consistent identification of AZs across Amazon Web Services Regions.

A regional NAT gateway is a single NAT Gateway that works across multiple availability zones (AZs) in your VPC, providing redundancy, scalability and availability across all the AZs in a Region.

Returns:

  • (String)


3089
3090
3091
3092
3093
3094
3095
3096
3097
3098
# File 'lib/aws-sdk-ec2/types.rb', line 3089

class AssociateNatGatewayAddressRequest < Struct.new(
  :nat_gateway_id,
  :allocation_ids,
  :private_ip_addresses,
  :dry_run,
  :availability_zone,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


3089
3090
3091
3092
3093
3094
3095
3096
3097
3098
# File 'lib/aws-sdk-ec2/types.rb', line 3089

class AssociateNatGatewayAddressRequest < Struct.new(
  :nat_gateway_id,
  :allocation_ids,
  :private_ip_addresses,
  :dry_run,
  :availability_zone,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#nat_gateway_idString

The ID of the NAT gateway.

Returns:

  • (String)


3089
3090
3091
3092
3093
3094
3095
3096
3097
3098
# File 'lib/aws-sdk-ec2/types.rb', line 3089

class AssociateNatGatewayAddressRequest < Struct.new(
  :nat_gateway_id,
  :allocation_ids,
  :private_ip_addresses,
  :dry_run,
  :availability_zone,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#private_ip_addressesArray<String>

The private IPv4 addresses that you want to assign to the NAT gateway.

Returns:

  • (Array<String>)


3089
3090
3091
3092
3093
3094
3095
3096
3097
3098
# File 'lib/aws-sdk-ec2/types.rb', line 3089

class AssociateNatGatewayAddressRequest < Struct.new(
  :nat_gateway_id,
  :allocation_ids,
  :private_ip_addresses,
  :dry_run,
  :availability_zone,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end