Class: Aws::EC2::Types::AssociateRouteServerRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


3134
3135
3136
3137
3138
3139
3140
# File 'lib/aws-sdk-ec2/types.rb', line 3134

class AssociateRouteServerRequest < Struct.new(
  :route_server_id,
  :vpc_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#route_server_idString

The unique identifier for the route server to be associated.

Returns:

  • (String)


3134
3135
3136
3137
3138
3139
3140
# File 'lib/aws-sdk-ec2/types.rb', line 3134

class AssociateRouteServerRequest < Struct.new(
  :route_server_id,
  :vpc_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC to associate with the route server.

Returns:

  • (String)


3134
3135
3136
3137
3138
3139
3140
# File 'lib/aws-sdk-ec2/types.rb', line 3134

class AssociateRouteServerRequest < Struct.new(
  :route_server_id,
  :vpc_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end