Class: Aws::EC2::Types::AssociateSecurityGroupVpcRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::AssociateSecurityGroupVpcRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#group_id ⇒ String
A security group ID.
-
#vpc_id ⇒ String
A VPC ID.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
3226 3227 3228 3229 3230 3231 3232 |
# File 'lib/aws-sdk-ec2/types.rb', line 3226 class AssociateSecurityGroupVpcRequest < Struct.new( :group_id, :vpc_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#group_id ⇒ String
A security group ID.
3226 3227 3228 3229 3230 3231 3232 |
# File 'lib/aws-sdk-ec2/types.rb', line 3226 class AssociateSecurityGroupVpcRequest < Struct.new( :group_id, :vpc_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
A VPC ID.
3226 3227 3228 3229 3230 3231 3232 |
# File 'lib/aws-sdk-ec2/types.rb', line 3226 class AssociateSecurityGroupVpcRequest < Struct.new( :group_id, :vpc_id, :dry_run) SENSITIVE = [] include Aws::Structure end |