Class: Aws::EC2::Types::AssociateTransitGatewayPolicyTableRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::AssociateTransitGatewayPolicyTableRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#transit_gateway_attachment_id ⇒ String
The ID of the transit gateway attachment to associate with the policy table.
-
#transit_gateway_policy_table_id ⇒ String
The ID of the transit gateway policy table to associate with the transit gateway attachment.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
3353 3354 3355 3356 3357 3358 3359 |
# File 'lib/aws-sdk-ec2/types.rb', line 3353 class AssociateTransitGatewayPolicyTableRequest < Struct.new( :transit_gateway_policy_table_id, :transit_gateway_attachment_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_attachment_id ⇒ String
The ID of the transit gateway attachment to associate with the policy table.
3353 3354 3355 3356 3357 3358 3359 |
# File 'lib/aws-sdk-ec2/types.rb', line 3353 class AssociateTransitGatewayPolicyTableRequest < Struct.new( :transit_gateway_policy_table_id, :transit_gateway_attachment_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_policy_table_id ⇒ String
The ID of the transit gateway policy table to associate with the transit gateway attachment.
3353 3354 3355 3356 3357 3358 3359 |
# File 'lib/aws-sdk-ec2/types.rb', line 3353 class AssociateTransitGatewayPolicyTableRequest < Struct.new( :transit_gateway_policy_table_id, :transit_gateway_attachment_id, :dry_run) SENSITIVE = [] include Aws::Structure end |