Class: Aws::EC2::Types::AssociateTransitGatewayRouteTableRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::AssociateTransitGatewayRouteTableRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#transit_gateway_attachment_id ⇒ String
The ID of the attachment.
-
#transit_gateway_route_table_id ⇒ String
The ID of the transit gateway route table.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
3393 3394 3395 3396 3397 3398 3399 |
# File 'lib/aws-sdk-ec2/types.rb', line 3393 class AssociateTransitGatewayRouteTableRequest < Struct.new( :transit_gateway_route_table_id, :transit_gateway_attachment_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_attachment_id ⇒ String
The ID of the attachment.
3393 3394 3395 3396 3397 3398 3399 |
# File 'lib/aws-sdk-ec2/types.rb', line 3393 class AssociateTransitGatewayRouteTableRequest < Struct.new( :transit_gateway_route_table_id, :transit_gateway_attachment_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_route_table_id ⇒ String
The ID of the transit gateway route table.
3393 3394 3395 3396 3397 3398 3399 |
# File 'lib/aws-sdk-ec2/types.rb', line 3393 class AssociateTransitGatewayRouteTableRequest < Struct.new( :transit_gateway_route_table_id, :transit_gateway_attachment_id, :dry_run) SENSITIVE = [] include Aws::Structure end |