Class: Aws::EC2::Types::AttachVolumeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::AttachVolumeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#device ⇒ String
The device name (for example,
/dev/sdhorxvdh). -
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#ebs_card_index ⇒ Integer
The index of the EBS card.
-
#instance_id ⇒ String
The ID of the instance.
-
#volume_id ⇒ String
The ID of the EBS volume.
Instance Attribute Details
#device ⇒ String
The device name (for example, /dev/sdh or xvdh).
3969 3970 3971 3972 3973 3974 3975 3976 3977 |
# File 'lib/aws-sdk-ec2/types.rb', line 3969 class AttachVolumeRequest < Struct.new( :device, :instance_id, :volume_id, :ebs_card_index, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
3969 3970 3971 3972 3973 3974 3975 3976 3977 |
# File 'lib/aws-sdk-ec2/types.rb', line 3969 class AttachVolumeRequest < Struct.new( :device, :instance_id, :volume_id, :ebs_card_index, :dry_run) SENSITIVE = [] include Aws::Structure end |
#ebs_card_index ⇒ Integer
The index of the EBS card. Some instance types support multiple EBS cards. The default EBS card index is 0.
3969 3970 3971 3972 3973 3974 3975 3976 3977 |
# File 'lib/aws-sdk-ec2/types.rb', line 3969 class AttachVolumeRequest < Struct.new( :device, :instance_id, :volume_id, :ebs_card_index, :dry_run) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the instance.
3969 3970 3971 3972 3973 3974 3975 3976 3977 |
# File 'lib/aws-sdk-ec2/types.rb', line 3969 class AttachVolumeRequest < Struct.new( :device, :instance_id, :volume_id, :ebs_card_index, :dry_run) SENSITIVE = [] include Aws::Structure end |
#volume_id ⇒ String
The ID of the EBS volume. The volume and instance must be within the same Availability Zone.
3969 3970 3971 3972 3973 3974 3975 3976 3977 |
# File 'lib/aws-sdk-ec2/types.rb', line 3969 class AttachVolumeRequest < Struct.new( :device, :instance_id, :volume_id, :ebs_card_index, :dry_run) SENSITIVE = [] include Aws::Structure end |