Class: Aws::EC2::Types::AuthorizeClientVpnIngressRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::AuthorizeClientVpnIngressRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_group_id ⇒ String
The ID of the group to grant access to, for example, the Active Directory group or identity provider (IdP) group.
-
#authorize_all_groups ⇒ Boolean
Indicates whether to grant access to all clients.
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#client_vpn_endpoint_id ⇒ String
The ID of the Client VPN endpoint.
-
#description ⇒ String
A brief description of the authorization rule.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#target_network_cidr ⇒ String
The IPv4 address range, in CIDR notation, of the network for which access is being authorized.
Instance Attribute Details
#access_group_id ⇒ String
The ID of the group to grant access to, for example, the Active
Directory group or identity provider (IdP) group. Required if
AuthorizeAllGroups is false or not specified.
3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 |
# File 'lib/aws-sdk-ec2/types.rb', line 3781 class AuthorizeClientVpnIngressRequest < Struct.new( :client_vpn_endpoint_id, :target_network_cidr, :access_group_id, :authorize_all_groups, :description, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#authorize_all_groups ⇒ Boolean
Indicates whether to grant access to all clients. Specify true to
grant all clients who successfully establish a VPN connection access
to the network. Must be set to true if AccessGroupId is not
specified.
3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 |
# File 'lib/aws-sdk-ec2/types.rb', line 3781 class AuthorizeClientVpnIngressRequest < Struct.new( :client_vpn_endpoint_id, :target_network_cidr, :access_group_id, :authorize_all_groups, :description, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring idempotency.
A suitable default value is auto-generated. You should normally not need to pass this option.
3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 |
# File 'lib/aws-sdk-ec2/types.rb', line 3781 class AuthorizeClientVpnIngressRequest < Struct.new( :client_vpn_endpoint_id, :target_network_cidr, :access_group_id, :authorize_all_groups, :description, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#client_vpn_endpoint_id ⇒ String
The ID of the Client VPN endpoint.
3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 |
# File 'lib/aws-sdk-ec2/types.rb', line 3781 class AuthorizeClientVpnIngressRequest < Struct.new( :client_vpn_endpoint_id, :target_network_cidr, :access_group_id, :authorize_all_groups, :description, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A brief description of the authorization rule.
3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 |
# File 'lib/aws-sdk-ec2/types.rb', line 3781 class AuthorizeClientVpnIngressRequest < Struct.new( :client_vpn_endpoint_id, :target_network_cidr, :access_group_id, :authorize_all_groups, :description, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 |
# File 'lib/aws-sdk-ec2/types.rb', line 3781 class AuthorizeClientVpnIngressRequest < Struct.new( :client_vpn_endpoint_id, :target_network_cidr, :access_group_id, :authorize_all_groups, :description, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#target_network_cidr ⇒ String
The IPv4 address range, in CIDR notation, of the network for which access is being authorized.
3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 |
# File 'lib/aws-sdk-ec2/types.rb', line 3781 class AuthorizeClientVpnIngressRequest < Struct.new( :client_vpn_endpoint_id, :target_network_cidr, :access_group_id, :authorize_all_groups, :description, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |