Class: Aws::EC2::Types::AvailabilityZone
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::AvailabilityZone
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes Availability Zones, Local Zones, and Wavelength Zones.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#geography ⇒ Array<Types::AvailabilityZoneGeography>
The geography information for the Availability Zone or Local Zone.
-
#group_long_name ⇒ String
The long name of the Availability Zone group, Local Zone group, or Wavelength Zone group.
-
#group_name ⇒ String
The name of the zone group.
-
#messages ⇒ Array<Types::AvailabilityZoneMessage>
Any messages about the Availability Zone, Local Zone, or Wavelength Zone.
-
#network_border_group ⇒ String
The name of the network border group.
-
#opt_in_status ⇒ String
For Availability Zones, this parameter always has the value of
opt-in-not-required. -
#parent_zone_id ⇒ String
The ID of the zone that handles some of the Local Zone or Wavelength Zone control plane operations, such as API calls.
-
#parent_zone_name ⇒ String
The name of the zone that handles some of the Local Zone or Wavelength Zone control plane operations, such as API calls.
-
#region_name ⇒ String
The name of the Region.
-
#state ⇒ String
The state of the Availability Zone, Local Zone, or Wavelength Zone.
-
#sub_geography ⇒ Array<Types::AvailabilityZoneSubGeography>
The sub-geography information for the Availability Zone or Local Zone.
-
#zone_id ⇒ String
The ID of the Availability Zone, Local Zone, or Wavelength Zone.
-
#zone_name ⇒ String
The name of the Availability Zone, Local Zone, or Wavelength Zone.
-
#zone_type ⇒ String
The type of zone.
Instance Attribute Details
#geography ⇒ Array<Types::AvailabilityZoneGeography>
The geography information for the Availability Zone or Local Zone. The geography is returned as a list.
4551 4552 4553 4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 |
# File 'lib/aws-sdk-ec2/types.rb', line 4551 class AvailabilityZone < Struct.new( :opt_in_status, :messages, :region_name, :zone_name, :zone_id, :group_name, :network_border_group, :zone_type, :parent_zone_name, :parent_zone_id, :group_long_name, :geography, :sub_geography, :state) SENSITIVE = [] include Aws::Structure end |
#group_long_name ⇒ String
The long name of the Availability Zone group, Local Zone group, or Wavelength Zone group.
4551 4552 4553 4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 |
# File 'lib/aws-sdk-ec2/types.rb', line 4551 class AvailabilityZone < Struct.new( :opt_in_status, :messages, :region_name, :zone_name, :zone_id, :group_name, :network_border_group, :zone_type, :parent_zone_name, :parent_zone_id, :group_long_name, :geography, :sub_geography, :state) SENSITIVE = [] include Aws::Structure end |
#group_name ⇒ String
The name of the zone group. For example:
-
Availability Zones -
us-east-1-zg-1 -
Local Zones -
us-west-2-lax-1 -
Wavelength Zones -
us-east-1-wl1-bos-wlz-1
4551 4552 4553 4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 |
# File 'lib/aws-sdk-ec2/types.rb', line 4551 class AvailabilityZone < Struct.new( :opt_in_status, :messages, :region_name, :zone_name, :zone_id, :group_name, :network_border_group, :zone_type, :parent_zone_name, :parent_zone_id, :group_long_name, :geography, :sub_geography, :state) SENSITIVE = [] include Aws::Structure end |
#messages ⇒ Array<Types::AvailabilityZoneMessage>
Any messages about the Availability Zone, Local Zone, or Wavelength Zone.
4551 4552 4553 4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 |
# File 'lib/aws-sdk-ec2/types.rb', line 4551 class AvailabilityZone < Struct.new( :opt_in_status, :messages, :region_name, :zone_name, :zone_id, :group_name, :network_border_group, :zone_type, :parent_zone_name, :parent_zone_id, :group_long_name, :geography, :sub_geography, :state) SENSITIVE = [] include Aws::Structure end |
#network_border_group ⇒ String
The name of the network border group.
4551 4552 4553 4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 |
# File 'lib/aws-sdk-ec2/types.rb', line 4551 class AvailabilityZone < Struct.new( :opt_in_status, :messages, :region_name, :zone_name, :zone_id, :group_name, :network_border_group, :zone_type, :parent_zone_name, :parent_zone_id, :group_long_name, :geography, :sub_geography, :state) SENSITIVE = [] include Aws::Structure end |
#opt_in_status ⇒ String
For Availability Zones, this parameter always has the value of
opt-in-not-required.
For Local Zones and Wavelength Zones, this parameter is the opt-in
status. The possible values are opted-in and not-opted-in.
4551 4552 4553 4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 |
# File 'lib/aws-sdk-ec2/types.rb', line 4551 class AvailabilityZone < Struct.new( :opt_in_status, :messages, :region_name, :zone_name, :zone_id, :group_name, :network_border_group, :zone_type, :parent_zone_name, :parent_zone_id, :group_long_name, :geography, :sub_geography, :state) SENSITIVE = [] include Aws::Structure end |
#parent_zone_id ⇒ String
The ID of the zone that handles some of the Local Zone or Wavelength Zone control plane operations, such as API calls.
4551 4552 4553 4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 |
# File 'lib/aws-sdk-ec2/types.rb', line 4551 class AvailabilityZone < Struct.new( :opt_in_status, :messages, :region_name, :zone_name, :zone_id, :group_name, :network_border_group, :zone_type, :parent_zone_name, :parent_zone_id, :group_long_name, :geography, :sub_geography, :state) SENSITIVE = [] include Aws::Structure end |
#parent_zone_name ⇒ String
The name of the zone that handles some of the Local Zone or Wavelength Zone control plane operations, such as API calls.
4551 4552 4553 4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 |
# File 'lib/aws-sdk-ec2/types.rb', line 4551 class AvailabilityZone < Struct.new( :opt_in_status, :messages, :region_name, :zone_name, :zone_id, :group_name, :network_border_group, :zone_type, :parent_zone_name, :parent_zone_id, :group_long_name, :geography, :sub_geography, :state) SENSITIVE = [] include Aws::Structure end |
#region_name ⇒ String
The name of the Region.
4551 4552 4553 4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 |
# File 'lib/aws-sdk-ec2/types.rb', line 4551 class AvailabilityZone < Struct.new( :opt_in_status, :messages, :region_name, :zone_name, :zone_id, :group_name, :network_border_group, :zone_type, :parent_zone_name, :parent_zone_id, :group_long_name, :geography, :sub_geography, :state) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the Availability Zone, Local Zone, or Wavelength Zone.
The possible values are available, unavailable, and
constrained.
4551 4552 4553 4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 |
# File 'lib/aws-sdk-ec2/types.rb', line 4551 class AvailabilityZone < Struct.new( :opt_in_status, :messages, :region_name, :zone_name, :zone_id, :group_name, :network_border_group, :zone_type, :parent_zone_name, :parent_zone_id, :group_long_name, :geography, :sub_geography, :state) SENSITIVE = [] include Aws::Structure end |
#sub_geography ⇒ Array<Types::AvailabilityZoneSubGeography>
The sub-geography information for the Availability Zone or Local Zone. The sub-geography is returned as a list.
4551 4552 4553 4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 |
# File 'lib/aws-sdk-ec2/types.rb', line 4551 class AvailabilityZone < Struct.new( :opt_in_status, :messages, :region_name, :zone_name, :zone_id, :group_name, :network_border_group, :zone_type, :parent_zone_name, :parent_zone_id, :group_long_name, :geography, :sub_geography, :state) SENSITIVE = [] include Aws::Structure end |
#zone_id ⇒ String
The ID of the Availability Zone, Local Zone, or Wavelength Zone.
4551 4552 4553 4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 |
# File 'lib/aws-sdk-ec2/types.rb', line 4551 class AvailabilityZone < Struct.new( :opt_in_status, :messages, :region_name, :zone_name, :zone_id, :group_name, :network_border_group, :zone_type, :parent_zone_name, :parent_zone_id, :group_long_name, :geography, :sub_geography, :state) SENSITIVE = [] include Aws::Structure end |
#zone_name ⇒ String
The name of the Availability Zone, Local Zone, or Wavelength Zone.
4551 4552 4553 4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 |
# File 'lib/aws-sdk-ec2/types.rb', line 4551 class AvailabilityZone < Struct.new( :opt_in_status, :messages, :region_name, :zone_name, :zone_id, :group_name, :network_border_group, :zone_type, :parent_zone_name, :parent_zone_id, :group_long_name, :geography, :sub_geography, :state) SENSITIVE = [] include Aws::Structure end |
#zone_type ⇒ String
The type of zone.
Valid values: availability-zone | local-zone |
wavelength-zone
4551 4552 4553 4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 |
# File 'lib/aws-sdk-ec2/types.rb', line 4551 class AvailabilityZone < Struct.new( :opt_in_status, :messages, :region_name, :zone_name, :zone_id, :group_name, :network_border_group, :zone_type, :parent_zone_name, :parent_zone_id, :group_long_name, :geography, :sub_geography, :state) SENSITIVE = [] include Aws::Structure end |