Class: Aws::EC2::Types::AvailableCapacity
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::AvailableCapacity
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
The capacity information for instances that can be launched onto the Dedicated Host.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#available_instance_capacity ⇒ Array<Types::InstanceCapacity>
The number of instances that can be launched onto the Dedicated Host depending on the host's available capacity.
-
#available_v_cpus ⇒ Integer
The number of vCPUs available for launching instances onto the Dedicated Host.
Instance Attribute Details
#available_instance_capacity ⇒ Array<Types::InstanceCapacity>
The number of instances that can be launched onto the Dedicated Host depending on the host's available capacity. For Dedicated Hosts that support multiple instance types, this parameter represents the number of instances for each instance size that is supported on the host.
4241 4242 4243 4244 4245 4246 |
# File 'lib/aws-sdk-ec2/types.rb', line 4241 class AvailableCapacity < Struct.new( :available_instance_capacity, :available_v_cpus) SENSITIVE = [] include Aws::Structure end |
#available_v_cpus ⇒ Integer
The number of vCPUs available for launching instances onto the Dedicated Host.
4241 4242 4243 4244 4245 4246 |
# File 'lib/aws-sdk-ec2/types.rb', line 4241 class AvailableCapacity < Struct.new( :available_instance_capacity, :available_v_cpus) SENSITIVE = [] include Aws::Structure end |