Class: Aws::EC2::Types::BatchModifyIpamRoutingPolicyRegistrationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, the operation ignores the request, but does not return an error.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


4829
4830
4831
4832
4833
4834
4835
4836
4837
# File 'lib/aws-sdk-ec2/types.rb', line 4829

class BatchModifyIpamRoutingPolicyRegistrationsRequest < Struct.new(
  :dry_run,
  :ipam_internet_registry_association_id,
  :delta_json,
  :force,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#delta_jsonString

The batch modifications to apply, in JSON format.

Returns:

  • (String)


4829
4830
4831
4832
4833
4834
4835
4836
4837
# File 'lib/aws-sdk-ec2/types.rb', line 4829

class BatchModifyIpamRoutingPolicyRegistrationsRequest < Struct.new(
  :dry_run,
  :ipam_internet_registry_association_id,
  :delta_json,
  :force,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


4829
4830
4831
4832
4833
4834
4835
4836
4837
# File 'lib/aws-sdk-ec2/types.rb', line 4829

class BatchModifyIpamRoutingPolicyRegistrationsRequest < Struct.new(
  :dry_run,
  :ipam_internet_registry_association_id,
  :delta_json,
  :force,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#forceBoolean

Forces the batch modification even if individual changes conflict with announced routes. Default: false.

Returns:

  • (Boolean)


4829
4830
4831
4832
4833
4834
4835
4836
4837
# File 'lib/aws-sdk-ec2/types.rb', line 4829

class BatchModifyIpamRoutingPolicyRegistrationsRequest < Struct.new(
  :dry_run,
  :ipam_internet_registry_association_id,
  :delta_json,
  :force,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_internet_registry_association_idString

The ID of the IPAM internet registry association.

Returns:

  • (String)


4829
4830
4831
4832
4833
4834
4835
4836
4837
# File 'lib/aws-sdk-ec2/types.rb', line 4829

class BatchModifyIpamRoutingPolicyRegistrationsRequest < Struct.new(
  :dry_run,
  :ipam_internet_registry_association_id,
  :delta_json,
  :force,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end