Class: Aws::EC2::Types::BundleInstanceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for BundleInstance.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


4999
5000
5001
5002
5003
5004
5005
# File 'lib/aws-sdk-ec2/types.rb', line 4999

class BundleInstanceRequest < Struct.new(
  :instance_id,
  :storage,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The ID of the instance to bundle.

Default: None

Returns:

  • (String)


4999
5000
5001
5002
5003
5004
5005
# File 'lib/aws-sdk-ec2/types.rb', line 4999

class BundleInstanceRequest < Struct.new(
  :instance_id,
  :storage,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#storageTypes::Storage

The bucket in which to store the AMI. You can specify a bucket that you already own or a new bucket that Amazon EC2 creates on your behalf. If you specify a bucket that belongs to someone else, Amazon EC2 returns an error.

Returns:



4999
5000
5001
5002
5003
5004
5005
# File 'lib/aws-sdk-ec2/types.rb', line 4999

class BundleInstanceRequest < Struct.new(
  :instance_id,
  :storage,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end