Class: Aws::EC2::Types::CancelCapacityReservationFleetsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CancelCapacityReservationFleetsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_reservation_fleet_ids ⇒ Array<String>
The IDs of the Capacity Reservation Fleets to cancel.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#capacity_reservation_fleet_ids ⇒ Array<String>
The IDs of the Capacity Reservation Fleets to cancel.
5305 5306 5307 5308 5309 5310 |
# File 'lib/aws-sdk-ec2/types.rb', line 5305 class CancelCapacityReservationFleetsRequest < Struct.new( :dry_run, :capacity_reservation_fleet_ids) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
5305 5306 5307 5308 5309 5310 |
# File 'lib/aws-sdk-ec2/types.rb', line 5305 class CancelCapacityReservationFleetsRequest < Struct.new( :dry_run, :capacity_reservation_fleet_ids) SENSITIVE = [] include Aws::Structure end |