Class: Aws::EC2::Types::CancelCapacityReservationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CancelCapacityReservationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#apply_cancellation_charges ⇒ String
Specifies the cancellation charge type to apply when cancelling a future-dated Capacity Reservation during its commitment duration.
-
#capacity_reservation_id ⇒ String
The ID of the Capacity Reservation to be cancelled.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#quote_id ⇒ String
The ID of the cancellation quote to use for the cancellation.
Instance Attribute Details
#apply_cancellation_charges ⇒ String
Specifies the cancellation charge type to apply when cancelling a
future-dated Capacity Reservation during its commitment duration.
Possible values include commitment-wind-down, which continues
billing for the remaining commitment duration without delivering
capacity.
5357 5358 5359 5360 5361 5362 5363 5364 |
# File 'lib/aws-sdk-ec2/types.rb', line 5357 class CancelCapacityReservationRequest < Struct.new( :capacity_reservation_id, :dry_run, :apply_cancellation_charges, :quote_id) SENSITIVE = [] include Aws::Structure end |
#capacity_reservation_id ⇒ String
The ID of the Capacity Reservation to be cancelled.
5357 5358 5359 5360 5361 5362 5363 5364 |
# File 'lib/aws-sdk-ec2/types.rb', line 5357 class CancelCapacityReservationRequest < Struct.new( :capacity_reservation_id, :dry_run, :apply_cancellation_charges, :quote_id) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
5357 5358 5359 5360 5361 5362 5363 5364 |
# File 'lib/aws-sdk-ec2/types.rb', line 5357 class CancelCapacityReservationRequest < Struct.new( :capacity_reservation_id, :dry_run, :apply_cancellation_charges, :quote_id) SENSITIVE = [] include Aws::Structure end |
#quote_id ⇒ String
The ID of the cancellation quote to use for the cancellation. You
can generate a cancellation quote by using the
CreateCapacityReservationCancellationQuote action. The
cancellation quote must be in an active state.
5357 5358 5359 5360 5361 5362 5363 5364 |
# File 'lib/aws-sdk-ec2/types.rb', line 5357 class CancelCapacityReservationRequest < Struct.new( :capacity_reservation_id, :dry_run, :apply_cancellation_charges, :quote_id) SENSITIVE = [] include Aws::Structure end |