Class: Aws::EC2::Types::CancelConversionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CancelConversionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#conversion_task_id ⇒ String
The ID of the conversion task.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#reason_message ⇒ String
The reason for canceling the conversion task.
Instance Attribute Details
#conversion_task_id ⇒ String
The ID of the conversion task.
5396 5397 5398 5399 5400 5401 5402 |
# File 'lib/aws-sdk-ec2/types.rb', line 5396 class CancelConversionRequest < Struct.new( :dry_run, :conversion_task_id, :reason_message) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
5396 5397 5398 5399 5400 5401 5402 |
# File 'lib/aws-sdk-ec2/types.rb', line 5396 class CancelConversionRequest < Struct.new( :dry_run, :conversion_task_id, :reason_message) SENSITIVE = [] include Aws::Structure end |
#reason_message ⇒ String
The reason for canceling the conversion task.
5396 5397 5398 5399 5400 5401 5402 |
# File 'lib/aws-sdk-ec2/types.rb', line 5396 class CancelConversionRequest < Struct.new( :dry_run, :conversion_task_id, :reason_message) SENSITIVE = [] include Aws::Structure end |