Class: Aws::EC2::Types::CancelSpotInstanceRequestsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CancelSpotInstanceRequestsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for CancelSpotInstanceRequests.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#spot_instance_request_ids ⇒ Array<String>
The IDs of the Spot Instance requests.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
5690 5691 5692 5693 5694 5695 |
# File 'lib/aws-sdk-ec2/types.rb', line 5690 class CancelSpotInstanceRequestsRequest < Struct.new( :dry_run, :spot_instance_request_ids) SENSITIVE = [] include Aws::Structure end |
#spot_instance_request_ids ⇒ Array<String>
The IDs of the Spot Instance requests.
5690 5691 5692 5693 5694 5695 |
# File 'lib/aws-sdk-ec2/types.rb', line 5690 class CancelSpotInstanceRequestsRequest < Struct.new( :dry_run, :spot_instance_request_ids) SENSITIVE = [] include Aws::Structure end |