Class: Aws::EC2::Types::CancellationTerms

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes the cancellation terms for cancelling a future-dated Capacity Reservation during its commitment duration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cancellation_typeString

The type of cancellation charge. Possible values include ‘commitment-wind-down`.

Returns:

  • (String)


5073
5074
5075
5076
5077
5078
5079
5080
5081
# File 'lib/aws-sdk-ec2/types.rb', line 5073

class CancellationTerms < Struct.new(
  :cancellation_type,
  :reservation_state,
  :committed_instance_count,
  :charge_commitment_duration_hours,
  :charge_end_date)
  SENSITIVE = []
  include Aws::Structure
end

#charge_commitment_duration_hoursInteger

The number of hours for which cancellation charges will apply.

Returns:

  • (Integer)


5073
5074
5075
5076
5077
5078
5079
5080
5081
# File 'lib/aws-sdk-ec2/types.rb', line 5073

class CancellationTerms < Struct.new(
  :cancellation_type,
  :reservation_state,
  :committed_instance_count,
  :charge_commitment_duration_hours,
  :charge_end_date)
  SENSITIVE = []
  include Aws::Structure
end

#charge_end_dateTime

The date and time at which cancellation charges will stop.

Returns:

  • (Time)


5073
5074
5075
5076
5077
5078
5079
5080
5081
# File 'lib/aws-sdk-ec2/types.rb', line 5073

class CancellationTerms < Struct.new(
  :cancellation_type,
  :reservation_state,
  :committed_instance_count,
  :charge_commitment_duration_hours,
  :charge_end_date)
  SENSITIVE = []
  include Aws::Structure
end

#committed_instance_countInteger

The number of instances under commitment after cancellation.

Returns:

  • (Integer)


5073
5074
5075
5076
5077
5078
5079
5080
5081
# File 'lib/aws-sdk-ec2/types.rb', line 5073

class CancellationTerms < Struct.new(
  :cancellation_type,
  :reservation_state,
  :committed_instance_count,
  :charge_commitment_duration_hours,
  :charge_end_date)
  SENSITIVE = []
  include Aws::Structure
end

#reservation_stateString

The state that the Capacity Reservation will transition to after cancellation.

Returns:

  • (String)


5073
5074
5075
5076
5077
5078
5079
5080
5081
# File 'lib/aws-sdk-ec2/types.rb', line 5073

class CancellationTerms < Struct.new(
  :cancellation_type,
  :reservation_state,
  :committed_instance_count,
  :charge_commitment_duration_hours,
  :charge_end_date)
  SENSITIVE = []
  include Aws::Structure
end