Class: Aws::EC2::Types::CapacityReservationCancellationQuote
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CapacityReservationCancellationQuote
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a Capacity Reservation cancellation quote, which provides the cancellation terms for cancelling a future-dated Capacity Reservation during its commitment duration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cancellation_terms ⇒ Array<Types::CancellationTerms>
The cancellation terms associated with the quote, including the fee type and charge details.
-
#capacity_reservation_cancellation_quote_id ⇒ String
The ID of the cancellation quote.
-
#capacity_reservation_id ⇒ String
The ID of the Capacity Reservation associated with the cancellation quote.
-
#create_time ⇒ Time
The date and time at which the cancellation quote was created.
-
#current_configuration ⇒ Types::CapacityReservationConfiguration
The current configuration of the Capacity Reservation.
-
#expiration_time ⇒ Time
The date and time at which the cancellation quote expires.
-
#quote_state ⇒ String
The state of the cancellation quote.
-
#tags ⇒ Array<Types::Tag>
The tags assigned to the cancellation quote.
Instance Attribute Details
#cancellation_terms ⇒ Array<Types::CancellationTerms>
The cancellation terms associated with the quote, including the fee type and charge details.
6187 6188 6189 6190 6191 6192 6193 6194 6195 6196 6197 6198 |
# File 'lib/aws-sdk-ec2/types.rb', line 6187 class CapacityReservationCancellationQuote < Struct.new( :capacity_reservation_cancellation_quote_id, :capacity_reservation_id, :create_time, :expiration_time, :quote_state, :current_configuration, :cancellation_terms, :tags) SENSITIVE = [] include Aws::Structure end |
#capacity_reservation_cancellation_quote_id ⇒ String
The ID of the cancellation quote.
6187 6188 6189 6190 6191 6192 6193 6194 6195 6196 6197 6198 |
# File 'lib/aws-sdk-ec2/types.rb', line 6187 class CapacityReservationCancellationQuote < Struct.new( :capacity_reservation_cancellation_quote_id, :capacity_reservation_id, :create_time, :expiration_time, :quote_state, :current_configuration, :cancellation_terms, :tags) SENSITIVE = [] include Aws::Structure end |
#capacity_reservation_id ⇒ String
The ID of the Capacity Reservation associated with the cancellation quote.
6187 6188 6189 6190 6191 6192 6193 6194 6195 6196 6197 6198 |
# File 'lib/aws-sdk-ec2/types.rb', line 6187 class CapacityReservationCancellationQuote < Struct.new( :capacity_reservation_cancellation_quote_id, :capacity_reservation_id, :create_time, :expiration_time, :quote_state, :current_configuration, :cancellation_terms, :tags) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The date and time at which the cancellation quote was created.
6187 6188 6189 6190 6191 6192 6193 6194 6195 6196 6197 6198 |
# File 'lib/aws-sdk-ec2/types.rb', line 6187 class CapacityReservationCancellationQuote < Struct.new( :capacity_reservation_cancellation_quote_id, :capacity_reservation_id, :create_time, :expiration_time, :quote_state, :current_configuration, :cancellation_terms, :tags) SENSITIVE = [] include Aws::Structure end |
#current_configuration ⇒ Types::CapacityReservationConfiguration
The current configuration of the Capacity Reservation.
6187 6188 6189 6190 6191 6192 6193 6194 6195 6196 6197 6198 |
# File 'lib/aws-sdk-ec2/types.rb', line 6187 class CapacityReservationCancellationQuote < Struct.new( :capacity_reservation_cancellation_quote_id, :capacity_reservation_id, :create_time, :expiration_time, :quote_state, :current_configuration, :cancellation_terms, :tags) SENSITIVE = [] include Aws::Structure end |
#expiration_time ⇒ Time
The date and time at which the cancellation quote expires.
6187 6188 6189 6190 6191 6192 6193 6194 6195 6196 6197 6198 |
# File 'lib/aws-sdk-ec2/types.rb', line 6187 class CapacityReservationCancellationQuote < Struct.new( :capacity_reservation_cancellation_quote_id, :capacity_reservation_id, :create_time, :expiration_time, :quote_state, :current_configuration, :cancellation_terms, :tags) SENSITIVE = [] include Aws::Structure end |
#quote_state ⇒ String
The state of the cancellation quote. Possible values include ‘pending`, `active`, and `expired`.
6187 6188 6189 6190 6191 6192 6193 6194 6195 6196 6197 6198 |
# File 'lib/aws-sdk-ec2/types.rb', line 6187 class CapacityReservationCancellationQuote < Struct.new( :capacity_reservation_cancellation_quote_id, :capacity_reservation_id, :create_time, :expiration_time, :quote_state, :current_configuration, :cancellation_terms, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags assigned to the cancellation quote.
6187 6188 6189 6190 6191 6192 6193 6194 6195 6196 6197 6198 |
# File 'lib/aws-sdk-ec2/types.rb', line 6187 class CapacityReservationCancellationQuote < Struct.new( :capacity_reservation_cancellation_quote_id, :capacity_reservation_id, :create_time, :expiration_time, :quote_state, :current_configuration, :cancellation_terms, :tags) SENSITIVE = [] include Aws::Structure end |