Class: Aws::EC2::Types::CapacityReservationStatus
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CapacityReservationStatus
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the availability of capacity for a Capacity Reservation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_reservation_id ⇒ String
The ID of the Capacity Reservation.
-
#total_available_capacity ⇒ Integer
The remaining capacity.
-
#total_capacity ⇒ Integer
The combined amount of ‘Available` and `Unavailable` capacity in the Capacity Reservation.
-
#total_unavailable_capacity ⇒ Integer
The used capacity.
Instance Attribute Details
#capacity_reservation_id ⇒ String
The ID of the Capacity Reservation.
6286 6287 6288 6289 6290 6291 6292 6293 |
# File 'lib/aws-sdk-ec2/types.rb', line 6286 class CapacityReservationStatus < Struct.new( :capacity_reservation_id, :total_capacity, :total_available_capacity, :total_unavailable_capacity) SENSITIVE = [] include Aws::Structure end |
#total_available_capacity ⇒ Integer
The remaining capacity. Indicates the amount of resources that can be launched into the Capacity Reservation.
6286 6287 6288 6289 6290 6291 6292 6293 |
# File 'lib/aws-sdk-ec2/types.rb', line 6286 class CapacityReservationStatus < Struct.new( :capacity_reservation_id, :total_capacity, :total_available_capacity, :total_unavailable_capacity) SENSITIVE = [] include Aws::Structure end |
#total_capacity ⇒ Integer
The combined amount of ‘Available` and `Unavailable` capacity in the Capacity Reservation.
6286 6287 6288 6289 6290 6291 6292 6293 |
# File 'lib/aws-sdk-ec2/types.rb', line 6286 class CapacityReservationStatus < Struct.new( :capacity_reservation_id, :total_capacity, :total_available_capacity, :total_unavailable_capacity) SENSITIVE = [] include Aws::Structure end |
#total_unavailable_capacity ⇒ Integer
The used capacity. Indicates that the capacity is in use by resources that are running in the Capacity Reservation.
6286 6287 6288 6289 6290 6291 6292 6293 |
# File 'lib/aws-sdk-ec2/types.rb', line 6286 class CapacityReservationStatus < Struct.new( :capacity_reservation_id, :total_capacity, :total_available_capacity, :total_unavailable_capacity) SENSITIVE = [] include Aws::Structure end |