Class: Aws::EC2::Types::ClientRouteEnforcementResponseOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ClientRouteEnforcementResponseOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
The current status of Client Route Enforcement.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enforced ⇒ Boolean
Status of the client route enforcement feature, indicating whether Client Route Enforcement is
true(enabled) orfalse(disabled).
Instance Attribute Details
#enforced ⇒ Boolean
Status of the client route enforcement feature, indicating whether
Client Route Enforcement is true (enabled) or false (disabled).
Valid values: true | false
Default value: false
7188 7189 7190 7191 7192 |
# File 'lib/aws-sdk-ec2/types.rb', line 7188 class ClientRouteEnforcementResponseOptions < Struct.new( :enforced) SENSITIVE = [] include Aws::Structure end |