Class: Aws::EC2::Types::ClientVpnAuthorizationRuleStatus
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ClientVpnAuthorizationRuleStatus
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the state of an authorization rule.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
The state of the authorization rule.
-
#message ⇒ String
A message about the status of the authorization rule, if applicable.
Instance Attribute Details
#code ⇒ String
The state of the authorization rule.
6886 6887 6888 6889 6890 6891 |
# File 'lib/aws-sdk-ec2/types.rb', line 6886 class ClientVpnAuthorizationRuleStatus < Struct.new( :code, :message) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
A message about the status of the authorization rule, if applicable.
6886 6887 6888 6889 6890 6891 |
# File 'lib/aws-sdk-ec2/types.rb', line 6886 class ClientVpnAuthorizationRuleStatus < Struct.new( :code, :message) SENSITIVE = [] include Aws::Structure end |