Class: Aws::EC2::Types::ClientVpnConnection
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ClientVpnConnection
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a client connection.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_ip ⇒ String
The IP address of the client.
-
#client_ipv_6_address ⇒ String
The IPv6 address assigned to the client connection when using a dual-stack Client VPN endpoint.
-
#client_vpn_endpoint_id ⇒ String
The ID of the Client VPN endpoint to which the client is connected.
-
#common_name ⇒ String
The common name associated with the client.
-
#connection_end_time ⇒ String
The date and time the client connection was terminated.
-
#connection_established_time ⇒ String
The date and time the client connection was established.
-
#connection_id ⇒ String
The ID of the client connection.
-
#egress_bytes ⇒ String
The number of bytes received by the client.
-
#egress_packets ⇒ String
The number of packets received by the client.
-
#ingress_bytes ⇒ String
The number of bytes sent by the client.
-
#ingress_packets ⇒ String
The number of packets sent by the client.
-
#posture_compliance_statuses ⇒ Array<String>
The statuses returned by the client connect handler for posture compliance, if applicable.
-
#status ⇒ Types::ClientVpnConnectionStatus
The current state of the client connection.
-
#timestamp ⇒ String
The current date and time.
-
#username ⇒ String
The username of the client who established the client connection.
Instance Attribute Details
#client_ip ⇒ String
The IP address of the client.
7317 7318 7319 7320 7321 7322 7323 7324 7325 7326 7327 7328 7329 7330 7331 7332 7333 7334 7335 |
# File 'lib/aws-sdk-ec2/types.rb', line 7317 class ClientVpnConnection < Struct.new( :client_vpn_endpoint_id, :timestamp, :connection_id, :username, :connection_established_time, :ingress_bytes, :egress_bytes, :ingress_packets, :egress_packets, :client_ip, :client_ipv_6_address, :common_name, :status, :connection_end_time, :posture_compliance_statuses) SENSITIVE = [] include Aws::Structure end |
#client_ipv_6_address ⇒ String
The IPv6 address assigned to the client connection when using a dual-stack Client VPN endpoint. This field is only populated when the endpoint is configured for dual-stack addressing, and the client is using IPv6 for connectivity.
7317 7318 7319 7320 7321 7322 7323 7324 7325 7326 7327 7328 7329 7330 7331 7332 7333 7334 7335 |
# File 'lib/aws-sdk-ec2/types.rb', line 7317 class ClientVpnConnection < Struct.new( :client_vpn_endpoint_id, :timestamp, :connection_id, :username, :connection_established_time, :ingress_bytes, :egress_bytes, :ingress_packets, :egress_packets, :client_ip, :client_ipv_6_address, :common_name, :status, :connection_end_time, :posture_compliance_statuses) SENSITIVE = [] include Aws::Structure end |
#client_vpn_endpoint_id ⇒ String
The ID of the Client VPN endpoint to which the client is connected.
7317 7318 7319 7320 7321 7322 7323 7324 7325 7326 7327 7328 7329 7330 7331 7332 7333 7334 7335 |
# File 'lib/aws-sdk-ec2/types.rb', line 7317 class ClientVpnConnection < Struct.new( :client_vpn_endpoint_id, :timestamp, :connection_id, :username, :connection_established_time, :ingress_bytes, :egress_bytes, :ingress_packets, :egress_packets, :client_ip, :client_ipv_6_address, :common_name, :status, :connection_end_time, :posture_compliance_statuses) SENSITIVE = [] include Aws::Structure end |
#common_name ⇒ String
The common name associated with the client. This is either the name of the client certificate, or the Active Directory user name.
7317 7318 7319 7320 7321 7322 7323 7324 7325 7326 7327 7328 7329 7330 7331 7332 7333 7334 7335 |
# File 'lib/aws-sdk-ec2/types.rb', line 7317 class ClientVpnConnection < Struct.new( :client_vpn_endpoint_id, :timestamp, :connection_id, :username, :connection_established_time, :ingress_bytes, :egress_bytes, :ingress_packets, :egress_packets, :client_ip, :client_ipv_6_address, :common_name, :status, :connection_end_time, :posture_compliance_statuses) SENSITIVE = [] include Aws::Structure end |
#connection_end_time ⇒ String
The date and time the client connection was terminated.
7317 7318 7319 7320 7321 7322 7323 7324 7325 7326 7327 7328 7329 7330 7331 7332 7333 7334 7335 |
# File 'lib/aws-sdk-ec2/types.rb', line 7317 class ClientVpnConnection < Struct.new( :client_vpn_endpoint_id, :timestamp, :connection_id, :username, :connection_established_time, :ingress_bytes, :egress_bytes, :ingress_packets, :egress_packets, :client_ip, :client_ipv_6_address, :common_name, :status, :connection_end_time, :posture_compliance_statuses) SENSITIVE = [] include Aws::Structure end |
#connection_established_time ⇒ String
The date and time the client connection was established.
7317 7318 7319 7320 7321 7322 7323 7324 7325 7326 7327 7328 7329 7330 7331 7332 7333 7334 7335 |
# File 'lib/aws-sdk-ec2/types.rb', line 7317 class ClientVpnConnection < Struct.new( :client_vpn_endpoint_id, :timestamp, :connection_id, :username, :connection_established_time, :ingress_bytes, :egress_bytes, :ingress_packets, :egress_packets, :client_ip, :client_ipv_6_address, :common_name, :status, :connection_end_time, :posture_compliance_statuses) SENSITIVE = [] include Aws::Structure end |
#connection_id ⇒ String
The ID of the client connection.
7317 7318 7319 7320 7321 7322 7323 7324 7325 7326 7327 7328 7329 7330 7331 7332 7333 7334 7335 |
# File 'lib/aws-sdk-ec2/types.rb', line 7317 class ClientVpnConnection < Struct.new( :client_vpn_endpoint_id, :timestamp, :connection_id, :username, :connection_established_time, :ingress_bytes, :egress_bytes, :ingress_packets, :egress_packets, :client_ip, :client_ipv_6_address, :common_name, :status, :connection_end_time, :posture_compliance_statuses) SENSITIVE = [] include Aws::Structure end |
#egress_bytes ⇒ String
The number of bytes received by the client.
7317 7318 7319 7320 7321 7322 7323 7324 7325 7326 7327 7328 7329 7330 7331 7332 7333 7334 7335 |
# File 'lib/aws-sdk-ec2/types.rb', line 7317 class ClientVpnConnection < Struct.new( :client_vpn_endpoint_id, :timestamp, :connection_id, :username, :connection_established_time, :ingress_bytes, :egress_bytes, :ingress_packets, :egress_packets, :client_ip, :client_ipv_6_address, :common_name, :status, :connection_end_time, :posture_compliance_statuses) SENSITIVE = [] include Aws::Structure end |
#egress_packets ⇒ String
The number of packets received by the client.
7317 7318 7319 7320 7321 7322 7323 7324 7325 7326 7327 7328 7329 7330 7331 7332 7333 7334 7335 |
# File 'lib/aws-sdk-ec2/types.rb', line 7317 class ClientVpnConnection < Struct.new( :client_vpn_endpoint_id, :timestamp, :connection_id, :username, :connection_established_time, :ingress_bytes, :egress_bytes, :ingress_packets, :egress_packets, :client_ip, :client_ipv_6_address, :common_name, :status, :connection_end_time, :posture_compliance_statuses) SENSITIVE = [] include Aws::Structure end |
#ingress_bytes ⇒ String
The number of bytes sent by the client.
7317 7318 7319 7320 7321 7322 7323 7324 7325 7326 7327 7328 7329 7330 7331 7332 7333 7334 7335 |
# File 'lib/aws-sdk-ec2/types.rb', line 7317 class ClientVpnConnection < Struct.new( :client_vpn_endpoint_id, :timestamp, :connection_id, :username, :connection_established_time, :ingress_bytes, :egress_bytes, :ingress_packets, :egress_packets, :client_ip, :client_ipv_6_address, :common_name, :status, :connection_end_time, :posture_compliance_statuses) SENSITIVE = [] include Aws::Structure end |
#ingress_packets ⇒ String
The number of packets sent by the client.
7317 7318 7319 7320 7321 7322 7323 7324 7325 7326 7327 7328 7329 7330 7331 7332 7333 7334 7335 |
# File 'lib/aws-sdk-ec2/types.rb', line 7317 class ClientVpnConnection < Struct.new( :client_vpn_endpoint_id, :timestamp, :connection_id, :username, :connection_established_time, :ingress_bytes, :egress_bytes, :ingress_packets, :egress_packets, :client_ip, :client_ipv_6_address, :common_name, :status, :connection_end_time, :posture_compliance_statuses) SENSITIVE = [] include Aws::Structure end |
#posture_compliance_statuses ⇒ Array<String>
The statuses returned by the client connect handler for posture compliance, if applicable.
7317 7318 7319 7320 7321 7322 7323 7324 7325 7326 7327 7328 7329 7330 7331 7332 7333 7334 7335 |
# File 'lib/aws-sdk-ec2/types.rb', line 7317 class ClientVpnConnection < Struct.new( :client_vpn_endpoint_id, :timestamp, :connection_id, :username, :connection_established_time, :ingress_bytes, :egress_bytes, :ingress_packets, :egress_packets, :client_ip, :client_ipv_6_address, :common_name, :status, :connection_end_time, :posture_compliance_statuses) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::ClientVpnConnectionStatus
The current state of the client connection.
7317 7318 7319 7320 7321 7322 7323 7324 7325 7326 7327 7328 7329 7330 7331 7332 7333 7334 7335 |
# File 'lib/aws-sdk-ec2/types.rb', line 7317 class ClientVpnConnection < Struct.new( :client_vpn_endpoint_id, :timestamp, :connection_id, :username, :connection_established_time, :ingress_bytes, :egress_bytes, :ingress_packets, :egress_packets, :client_ip, :client_ipv_6_address, :common_name, :status, :connection_end_time, :posture_compliance_statuses) SENSITIVE = [] include Aws::Structure end |
#timestamp ⇒ String
The current date and time.
7317 7318 7319 7320 7321 7322 7323 7324 7325 7326 7327 7328 7329 7330 7331 7332 7333 7334 7335 |
# File 'lib/aws-sdk-ec2/types.rb', line 7317 class ClientVpnConnection < Struct.new( :client_vpn_endpoint_id, :timestamp, :connection_id, :username, :connection_established_time, :ingress_bytes, :egress_bytes, :ingress_packets, :egress_packets, :client_ip, :client_ipv_6_address, :common_name, :status, :connection_end_time, :posture_compliance_statuses) SENSITIVE = [] include Aws::Structure end |
#username ⇒ String
The username of the client who established the client connection. This information is only provided if Active Directory client authentication is used.
7317 7318 7319 7320 7321 7322 7323 7324 7325 7326 7327 7328 7329 7330 7331 7332 7333 7334 7335 |
# File 'lib/aws-sdk-ec2/types.rb', line 7317 class ClientVpnConnection < Struct.new( :client_vpn_endpoint_id, :timestamp, :connection_id, :username, :connection_established_time, :ingress_bytes, :egress_bytes, :ingress_packets, :egress_packets, :client_ip, :client_ipv_6_address, :common_name, :status, :connection_end_time, :posture_compliance_statuses) SENSITIVE = [] include Aws::Structure end |