Class: Aws::EC2::Types::ClientVpnEndpoint
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ClientVpnEndpoint
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a Client VPN endpoint.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#associated_target_networks ⇒ Array<Types::AssociatedTargetNetwork>
Information about the associated target networks.
-
#authentication_options ⇒ Array<Types::ClientVpnAuthentication>
Information about the authentication method used by the Client VPN endpoint.
-
#client_cidr_block ⇒ String
The IPv4 address range, in CIDR notation, from which client IP addresses are assigned.
-
#client_connect_options ⇒ Types::ClientConnectResponseOptions
The options for managing connection authorization for new client connections.
-
#client_login_banner_options ⇒ Types::ClientLoginBannerResponseOptions
Options for enabling a customizable text banner that will be displayed on Amazon Web Services provided clients when a VPN session is established.
-
#client_route_enforcement_options ⇒ Types::ClientRouteEnforcementResponseOptions
Client route enforcement is a feature of the Client VPN service that helps enforce administrator defined routes on devices connected through the VPN.
-
#client_vpn_endpoint_id ⇒ String
The ID of the Client VPN endpoint.
-
#connection_log_options ⇒ Types::ConnectionLogResponseOptions
Information about the client connection logging options for the Client VPN endpoint.
-
#creation_time ⇒ String
The date and time the Client VPN endpoint was created.
-
#deletion_time ⇒ String
The date and time the Client VPN endpoint was deleted, if applicable.
-
#description ⇒ String
A brief description of the endpoint.
-
#disconnect_on_session_timeout ⇒ Boolean
Indicates whether the client VPN session is disconnected after the maximum ‘sessionTimeoutHours` is reached.
-
#dns_name ⇒ String
The DNS name to be used by clients when connecting to the Client VPN endpoint.
-
#dns_servers ⇒ Array<String>
Information about the DNS servers to be used for DNS resolution.
-
#endpoint_ip_address_type ⇒ String
The IP address type of the Client VPN endpoint.
-
#security_group_ids ⇒ Array<String>
The IDs of the security groups for the target network.
-
#self_service_portal_url ⇒ String
The URL of the self-service portal.
-
#server_certificate_arn ⇒ String
The ARN of the server certificate.
-
#session_timeout_hours ⇒ Integer
The maximum VPN session duration time in hours.
-
#split_tunnel ⇒ Boolean
Indicates whether split-tunnel is enabled in the Client VPN endpoint.
-
#status ⇒ Types::ClientVpnEndpointStatus
The current state of the Client VPN endpoint.
-
#tags ⇒ Array<Types::Tag>
Any tags assigned to the Client VPN endpoint.
-
#traffic_ip_address_type ⇒ String
The IP address type of the Client VPN endpoint.
-
#transit_gateway_configuration ⇒ Types::TransitGatewayConfigurationDescribeEndpointStructure
The Transit Gateway configuration for the Client VPN endpoint.
-
#transport_protocol ⇒ String
The transport protocol used by the Client VPN endpoint.
-
#vpc_id ⇒ String
The ID of the VPC.
-
#vpn_port ⇒ Integer
The port number for the Client VPN endpoint.
-
#vpn_protocol ⇒ String
The protocol used by the VPN session.
Instance Attribute Details
#associated_target_networks ⇒ Array<Types::AssociatedTargetNetwork>
Information about the associated target networks. A target network is a subnet in a VPC.
7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 7376 7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 7393 7394 7395 7396 |
# File 'lib/aws-sdk-ec2/types.rb', line 7365 class ClientVpnEndpoint < Struct.new( :client_vpn_endpoint_id, :description, :status, :creation_time, :deletion_time, :dns_name, :client_cidr_block, :dns_servers, :split_tunnel, :vpn_protocol, :transport_protocol, :vpn_port, :associated_target_networks, :server_certificate_arn, :authentication_options, :connection_log_options, :tags, :security_group_ids, :vpc_id, :self_service_portal_url, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#authentication_options ⇒ Array<Types::ClientVpnAuthentication>
Information about the authentication method used by the Client VPN endpoint.
7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 7376 7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 7393 7394 7395 7396 |
# File 'lib/aws-sdk-ec2/types.rb', line 7365 class ClientVpnEndpoint < Struct.new( :client_vpn_endpoint_id, :description, :status, :creation_time, :deletion_time, :dns_name, :client_cidr_block, :dns_servers, :split_tunnel, :vpn_protocol, :transport_protocol, :vpn_port, :associated_target_networks, :server_certificate_arn, :authentication_options, :connection_log_options, :tags, :security_group_ids, :vpc_id, :self_service_portal_url, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#client_cidr_block ⇒ String
The IPv4 address range, in CIDR notation, from which client IP addresses are assigned.
7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 7376 7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 7393 7394 7395 7396 |
# File 'lib/aws-sdk-ec2/types.rb', line 7365 class ClientVpnEndpoint < Struct.new( :client_vpn_endpoint_id, :description, :status, :creation_time, :deletion_time, :dns_name, :client_cidr_block, :dns_servers, :split_tunnel, :vpn_protocol, :transport_protocol, :vpn_port, :associated_target_networks, :server_certificate_arn, :authentication_options, :connection_log_options, :tags, :security_group_ids, :vpc_id, :self_service_portal_url, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#client_connect_options ⇒ Types::ClientConnectResponseOptions
The options for managing connection authorization for new client connections.
7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 7376 7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 7393 7394 7395 7396 |
# File 'lib/aws-sdk-ec2/types.rb', line 7365 class ClientVpnEndpoint < Struct.new( :client_vpn_endpoint_id, :description, :status, :creation_time, :deletion_time, :dns_name, :client_cidr_block, :dns_servers, :split_tunnel, :vpn_protocol, :transport_protocol, :vpn_port, :associated_target_networks, :server_certificate_arn, :authentication_options, :connection_log_options, :tags, :security_group_ids, :vpc_id, :self_service_portal_url, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#client_login_banner_options ⇒ Types::ClientLoginBannerResponseOptions
Options for enabling a customizable text banner that will be displayed on Amazon Web Services provided clients when a VPN session is established.
7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 7376 7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 7393 7394 7395 7396 |
# File 'lib/aws-sdk-ec2/types.rb', line 7365 class ClientVpnEndpoint < Struct.new( :client_vpn_endpoint_id, :description, :status, :creation_time, :deletion_time, :dns_name, :client_cidr_block, :dns_servers, :split_tunnel, :vpn_protocol, :transport_protocol, :vpn_port, :associated_target_networks, :server_certificate_arn, :authentication_options, :connection_log_options, :tags, :security_group_ids, :vpc_id, :self_service_portal_url, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#client_route_enforcement_options ⇒ Types::ClientRouteEnforcementResponseOptions
Client route enforcement is a feature of the Client VPN service that helps enforce administrator defined routes on devices connected through the VPN. T his feature helps improve your security posture by ensuring that network traffic originating from a connected client is not inadvertently sent outside the VPN tunnel.
Client route enforcement works by monitoring the route table of a connected device for routing policy changes to the VPN connection. If the feature detects any VPN routing policy modifications, it will automatically force an update to the route table, reverting it back to the expected route configurations.
7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 7376 7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 7393 7394 7395 7396 |
# File 'lib/aws-sdk-ec2/types.rb', line 7365 class ClientVpnEndpoint < Struct.new( :client_vpn_endpoint_id, :description, :status, :creation_time, :deletion_time, :dns_name, :client_cidr_block, :dns_servers, :split_tunnel, :vpn_protocol, :transport_protocol, :vpn_port, :associated_target_networks, :server_certificate_arn, :authentication_options, :connection_log_options, :tags, :security_group_ids, :vpc_id, :self_service_portal_url, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#client_vpn_endpoint_id ⇒ String
The ID of the Client VPN endpoint.
7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 7376 7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 7393 7394 7395 7396 |
# File 'lib/aws-sdk-ec2/types.rb', line 7365 class ClientVpnEndpoint < Struct.new( :client_vpn_endpoint_id, :description, :status, :creation_time, :deletion_time, :dns_name, :client_cidr_block, :dns_servers, :split_tunnel, :vpn_protocol, :transport_protocol, :vpn_port, :associated_target_networks, :server_certificate_arn, :authentication_options, :connection_log_options, :tags, :security_group_ids, :vpc_id, :self_service_portal_url, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#connection_log_options ⇒ Types::ConnectionLogResponseOptions
Information about the client connection logging options for the Client VPN endpoint.
7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 7376 7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 7393 7394 7395 7396 |
# File 'lib/aws-sdk-ec2/types.rb', line 7365 class ClientVpnEndpoint < Struct.new( :client_vpn_endpoint_id, :description, :status, :creation_time, :deletion_time, :dns_name, :client_cidr_block, :dns_servers, :split_tunnel, :vpn_protocol, :transport_protocol, :vpn_port, :associated_target_networks, :server_certificate_arn, :authentication_options, :connection_log_options, :tags, :security_group_ids, :vpc_id, :self_service_portal_url, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ String
The date and time the Client VPN endpoint was created.
7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 7376 7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 7393 7394 7395 7396 |
# File 'lib/aws-sdk-ec2/types.rb', line 7365 class ClientVpnEndpoint < Struct.new( :client_vpn_endpoint_id, :description, :status, :creation_time, :deletion_time, :dns_name, :client_cidr_block, :dns_servers, :split_tunnel, :vpn_protocol, :transport_protocol, :vpn_port, :associated_target_networks, :server_certificate_arn, :authentication_options, :connection_log_options, :tags, :security_group_ids, :vpc_id, :self_service_portal_url, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#deletion_time ⇒ String
The date and time the Client VPN endpoint was deleted, if applicable.
7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 7376 7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 7393 7394 7395 7396 |
# File 'lib/aws-sdk-ec2/types.rb', line 7365 class ClientVpnEndpoint < Struct.new( :client_vpn_endpoint_id, :description, :status, :creation_time, :deletion_time, :dns_name, :client_cidr_block, :dns_servers, :split_tunnel, :vpn_protocol, :transport_protocol, :vpn_port, :associated_target_networks, :server_certificate_arn, :authentication_options, :connection_log_options, :tags, :security_group_ids, :vpc_id, :self_service_portal_url, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A brief description of the endpoint.
7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 7376 7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 7393 7394 7395 7396 |
# File 'lib/aws-sdk-ec2/types.rb', line 7365 class ClientVpnEndpoint < Struct.new( :client_vpn_endpoint_id, :description, :status, :creation_time, :deletion_time, :dns_name, :client_cidr_block, :dns_servers, :split_tunnel, :vpn_protocol, :transport_protocol, :vpn_port, :associated_target_networks, :server_certificate_arn, :authentication_options, :connection_log_options, :tags, :security_group_ids, :vpc_id, :self_service_portal_url, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#disconnect_on_session_timeout ⇒ Boolean
Indicates whether the client VPN session is disconnected after the maximum ‘sessionTimeoutHours` is reached. If `true`, users are prompted to reconnect client VPN. If `false`, client VPN attempts to reconnect automatically. The default value is `true`.
7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 7376 7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 7393 7394 7395 7396 |
# File 'lib/aws-sdk-ec2/types.rb', line 7365 class ClientVpnEndpoint < Struct.new( :client_vpn_endpoint_id, :description, :status, :creation_time, :deletion_time, :dns_name, :client_cidr_block, :dns_servers, :split_tunnel, :vpn_protocol, :transport_protocol, :vpn_port, :associated_target_networks, :server_certificate_arn, :authentication_options, :connection_log_options, :tags, :security_group_ids, :vpc_id, :self_service_portal_url, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#dns_name ⇒ String
The DNS name to be used by clients when connecting to the Client VPN endpoint.
7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 7376 7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 7393 7394 7395 7396 |
# File 'lib/aws-sdk-ec2/types.rb', line 7365 class ClientVpnEndpoint < Struct.new( :client_vpn_endpoint_id, :description, :status, :creation_time, :deletion_time, :dns_name, :client_cidr_block, :dns_servers, :split_tunnel, :vpn_protocol, :transport_protocol, :vpn_port, :associated_target_networks, :server_certificate_arn, :authentication_options, :connection_log_options, :tags, :security_group_ids, :vpc_id, :self_service_portal_url, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#dns_servers ⇒ Array<String>
Information about the DNS servers to be used for DNS resolution.
7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 7376 7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 7393 7394 7395 7396 |
# File 'lib/aws-sdk-ec2/types.rb', line 7365 class ClientVpnEndpoint < Struct.new( :client_vpn_endpoint_id, :description, :status, :creation_time, :deletion_time, :dns_name, :client_cidr_block, :dns_servers, :split_tunnel, :vpn_protocol, :transport_protocol, :vpn_port, :associated_target_networks, :server_certificate_arn, :authentication_options, :connection_log_options, :tags, :security_group_ids, :vpc_id, :self_service_portal_url, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#endpoint_ip_address_type ⇒ String
The IP address type of the Client VPN endpoint. Possible values are ‘ipv4` for IPv4 addressing only, `ipv6` for IPv6 addressing only, or `dual-stack `for both IPv4 and IPv6 addressing.
7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 7376 7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 7393 7394 7395 7396 |
# File 'lib/aws-sdk-ec2/types.rb', line 7365 class ClientVpnEndpoint < Struct.new( :client_vpn_endpoint_id, :description, :status, :creation_time, :deletion_time, :dns_name, :client_cidr_block, :dns_servers, :split_tunnel, :vpn_protocol, :transport_protocol, :vpn_port, :associated_target_networks, :server_certificate_arn, :authentication_options, :connection_log_options, :tags, :security_group_ids, :vpc_id, :self_service_portal_url, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
The IDs of the security groups for the target network.
7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 7376 7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 7393 7394 7395 7396 |
# File 'lib/aws-sdk-ec2/types.rb', line 7365 class ClientVpnEndpoint < Struct.new( :client_vpn_endpoint_id, :description, :status, :creation_time, :deletion_time, :dns_name, :client_cidr_block, :dns_servers, :split_tunnel, :vpn_protocol, :transport_protocol, :vpn_port, :associated_target_networks, :server_certificate_arn, :authentication_options, :connection_log_options, :tags, :security_group_ids, :vpc_id, :self_service_portal_url, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#self_service_portal_url ⇒ String
The URL of the self-service portal.
7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 7376 7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 7393 7394 7395 7396 |
# File 'lib/aws-sdk-ec2/types.rb', line 7365 class ClientVpnEndpoint < Struct.new( :client_vpn_endpoint_id, :description, :status, :creation_time, :deletion_time, :dns_name, :client_cidr_block, :dns_servers, :split_tunnel, :vpn_protocol, :transport_protocol, :vpn_port, :associated_target_networks, :server_certificate_arn, :authentication_options, :connection_log_options, :tags, :security_group_ids, :vpc_id, :self_service_portal_url, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#server_certificate_arn ⇒ String
The ARN of the server certificate.
7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 7376 7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 7393 7394 7395 7396 |
# File 'lib/aws-sdk-ec2/types.rb', line 7365 class ClientVpnEndpoint < Struct.new( :client_vpn_endpoint_id, :description, :status, :creation_time, :deletion_time, :dns_name, :client_cidr_block, :dns_servers, :split_tunnel, :vpn_protocol, :transport_protocol, :vpn_port, :associated_target_networks, :server_certificate_arn, :authentication_options, :connection_log_options, :tags, :security_group_ids, :vpc_id, :self_service_portal_url, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#session_timeout_hours ⇒ Integer
The maximum VPN session duration time in hours.
Valid values: ‘8 | 10 | 12 | 24`
Default value: ‘24`
7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 7376 7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 7393 7394 7395 7396 |
# File 'lib/aws-sdk-ec2/types.rb', line 7365 class ClientVpnEndpoint < Struct.new( :client_vpn_endpoint_id, :description, :status, :creation_time, :deletion_time, :dns_name, :client_cidr_block, :dns_servers, :split_tunnel, :vpn_protocol, :transport_protocol, :vpn_port, :associated_target_networks, :server_certificate_arn, :authentication_options, :connection_log_options, :tags, :security_group_ids, :vpc_id, :self_service_portal_url, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#split_tunnel ⇒ Boolean
Indicates whether split-tunnel is enabled in the Client VPN endpoint.
For information about split-tunnel VPN endpoints, see [Split-Tunnel Client VPN endpoint] in the *Client VPN Administrator Guide*.
[1]: docs.aws.amazon.com/vpn/latest/clientvpn-admin/split-tunnel-vpn.html
7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 7376 7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 7393 7394 7395 7396 |
# File 'lib/aws-sdk-ec2/types.rb', line 7365 class ClientVpnEndpoint < Struct.new( :client_vpn_endpoint_id, :description, :status, :creation_time, :deletion_time, :dns_name, :client_cidr_block, :dns_servers, :split_tunnel, :vpn_protocol, :transport_protocol, :vpn_port, :associated_target_networks, :server_certificate_arn, :authentication_options, :connection_log_options, :tags, :security_group_ids, :vpc_id, :self_service_portal_url, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::ClientVpnEndpointStatus
The current state of the Client VPN endpoint.
7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 7376 7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 7393 7394 7395 7396 |
# File 'lib/aws-sdk-ec2/types.rb', line 7365 class ClientVpnEndpoint < Struct.new( :client_vpn_endpoint_id, :description, :status, :creation_time, :deletion_time, :dns_name, :client_cidr_block, :dns_servers, :split_tunnel, :vpn_protocol, :transport_protocol, :vpn_port, :associated_target_networks, :server_certificate_arn, :authentication_options, :connection_log_options, :tags, :security_group_ids, :vpc_id, :self_service_portal_url, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Any tags assigned to the Client VPN endpoint.
7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 7376 7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 7393 7394 7395 7396 |
# File 'lib/aws-sdk-ec2/types.rb', line 7365 class ClientVpnEndpoint < Struct.new( :client_vpn_endpoint_id, :description, :status, :creation_time, :deletion_time, :dns_name, :client_cidr_block, :dns_servers, :split_tunnel, :vpn_protocol, :transport_protocol, :vpn_port, :associated_target_networks, :server_certificate_arn, :authentication_options, :connection_log_options, :tags, :security_group_ids, :vpc_id, :self_service_portal_url, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#traffic_ip_address_type ⇒ String
The IP address type of the Client VPN endpoint. Possible values are either ‘ipv4` for IPv4 addressing only, `ipv6` for IPv6 addressing only, or `dual-stack` for both IPv4 and IPv6 addressing.
7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 7376 7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 7393 7394 7395 7396 |
# File 'lib/aws-sdk-ec2/types.rb', line 7365 class ClientVpnEndpoint < Struct.new( :client_vpn_endpoint_id, :description, :status, :creation_time, :deletion_time, :dns_name, :client_cidr_block, :dns_servers, :split_tunnel, :vpn_protocol, :transport_protocol, :vpn_port, :associated_target_networks, :server_certificate_arn, :authentication_options, :connection_log_options, :tags, :security_group_ids, :vpc_id, :self_service_portal_url, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_configuration ⇒ Types::TransitGatewayConfigurationDescribeEndpointStructure
The Transit Gateway configuration for the Client VPN endpoint.
7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 7376 7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 7393 7394 7395 7396 |
# File 'lib/aws-sdk-ec2/types.rb', line 7365 class ClientVpnEndpoint < Struct.new( :client_vpn_endpoint_id, :description, :status, :creation_time, :deletion_time, :dns_name, :client_cidr_block, :dns_servers, :split_tunnel, :vpn_protocol, :transport_protocol, :vpn_port, :associated_target_networks, :server_certificate_arn, :authentication_options, :connection_log_options, :tags, :security_group_ids, :vpc_id, :self_service_portal_url, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#transport_protocol ⇒ String
The transport protocol used by the Client VPN endpoint.
7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 7376 7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 7393 7394 7395 7396 |
# File 'lib/aws-sdk-ec2/types.rb', line 7365 class ClientVpnEndpoint < Struct.new( :client_vpn_endpoint_id, :description, :status, :creation_time, :deletion_time, :dns_name, :client_cidr_block, :dns_servers, :split_tunnel, :vpn_protocol, :transport_protocol, :vpn_port, :associated_target_networks, :server_certificate_arn, :authentication_options, :connection_log_options, :tags, :security_group_ids, :vpc_id, :self_service_portal_url, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC.
7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 7376 7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 7393 7394 7395 7396 |
# File 'lib/aws-sdk-ec2/types.rb', line 7365 class ClientVpnEndpoint < Struct.new( :client_vpn_endpoint_id, :description, :status, :creation_time, :deletion_time, :dns_name, :client_cidr_block, :dns_servers, :split_tunnel, :vpn_protocol, :transport_protocol, :vpn_port, :associated_target_networks, :server_certificate_arn, :authentication_options, :connection_log_options, :tags, :security_group_ids, :vpc_id, :self_service_portal_url, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#vpn_port ⇒ Integer
The port number for the Client VPN endpoint.
7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 7376 7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 7393 7394 7395 7396 |
# File 'lib/aws-sdk-ec2/types.rb', line 7365 class ClientVpnEndpoint < Struct.new( :client_vpn_endpoint_id, :description, :status, :creation_time, :deletion_time, :dns_name, :client_cidr_block, :dns_servers, :split_tunnel, :vpn_protocol, :transport_protocol, :vpn_port, :associated_target_networks, :server_certificate_arn, :authentication_options, :connection_log_options, :tags, :security_group_ids, :vpc_id, :self_service_portal_url, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#vpn_protocol ⇒ String
The protocol used by the VPN session.
7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 7376 7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 7393 7394 7395 7396 |
# File 'lib/aws-sdk-ec2/types.rb', line 7365 class ClientVpnEndpoint < Struct.new( :client_vpn_endpoint_id, :description, :status, :creation_time, :deletion_time, :dns_name, :client_cidr_block, :dns_servers, :split_tunnel, :vpn_protocol, :transport_protocol, :vpn_port, :associated_target_networks, :server_certificate_arn, :authentication_options, :connection_log_options, :tags, :security_group_ids, :vpc_id, :self_service_portal_url, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |