Class: Aws::EC2::Types::ConversionTask
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ConversionTask
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a conversion task.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#conversion_task_id ⇒ String
The ID of the conversion task.
-
#expiration_time ⇒ String
The time when the task expires.
-
#import_instance ⇒ Types::ImportInstanceTaskDetails
If the task is for importing an instance, this contains information about the import instance task.
-
#import_volume ⇒ Types::ImportVolumeTaskDetails
If the task is for importing a volume, this contains information about the import volume task.
-
#state ⇒ String
The state of the conversion task.
-
#status_message ⇒ String
The status message related to the conversion task.
-
#tags ⇒ Array<Types::Tag>
Any tags assigned to the task.
Instance Attribute Details
#conversion_task_id ⇒ String
The ID of the conversion task.
8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 |
# File 'lib/aws-sdk-ec2/types.rb', line 8872 class ConversionTask < Struct.new( :conversion_task_id, :expiration_time, :import_instance, :import_volume, :state, :status_message, :tags) SENSITIVE = [] include Aws::Structure end |
#expiration_time ⇒ String
The time when the task expires. If the upload isn't complete before the expiration time, we automatically cancel the task.
8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 |
# File 'lib/aws-sdk-ec2/types.rb', line 8872 class ConversionTask < Struct.new( :conversion_task_id, :expiration_time, :import_instance, :import_volume, :state, :status_message, :tags) SENSITIVE = [] include Aws::Structure end |
#import_instance ⇒ Types::ImportInstanceTaskDetails
If the task is for importing an instance, this contains information about the import instance task.
8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 |
# File 'lib/aws-sdk-ec2/types.rb', line 8872 class ConversionTask < Struct.new( :conversion_task_id, :expiration_time, :import_instance, :import_volume, :state, :status_message, :tags) SENSITIVE = [] include Aws::Structure end |
#import_volume ⇒ Types::ImportVolumeTaskDetails
If the task is for importing a volume, this contains information about the import volume task.
8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 |
# File 'lib/aws-sdk-ec2/types.rb', line 8872 class ConversionTask < Struct.new( :conversion_task_id, :expiration_time, :import_instance, :import_volume, :state, :status_message, :tags) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the conversion task.
8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 |
# File 'lib/aws-sdk-ec2/types.rb', line 8872 class ConversionTask < Struct.new( :conversion_task_id, :expiration_time, :import_instance, :import_volume, :state, :status_message, :tags) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
The status message related to the conversion task.
8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 |
# File 'lib/aws-sdk-ec2/types.rb', line 8872 class ConversionTask < Struct.new( :conversion_task_id, :expiration_time, :import_instance, :import_volume, :state, :status_message, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Any tags assigned to the task.
8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 |
# File 'lib/aws-sdk-ec2/types.rb', line 8872 class ConversionTask < Struct.new( :conversion_task_id, :expiration_time, :import_instance, :import_volume, :state, :status_message, :tags) SENSITIVE = [] include Aws::Structure end |