Class: Aws::EC2::Types::CopyImageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CopyImageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for CopyImage.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier you provide to ensure idempotency of the request.
-
#copy_image_tags ⇒ Boolean
Specifies whether to copy your user-defined AMI tags to the new AMI.
-
#description ⇒ String
A description for the new AMI.
-
#destination_availability_zone ⇒ String
The Local Zone for the new AMI (for example, ‘cn-north-1-pkx-1a`).
-
#destination_availability_zone_id ⇒ String
The ID of the Local Zone for the new AMI (for example, ‘cnn1-pkx1-az1`).
-
#destination_outpost_arn ⇒ String
The Amazon Resource Name (ARN) of the Outpost for the new AMI.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#encrypted ⇒ Boolean
Specifies whether to encrypt the snapshots of the copied image.
-
#kms_key_id ⇒ String
The identifier of the symmetric Key Management Service (KMS) KMS key to use when creating encrypted volumes.
-
#name ⇒ String
The name of the new AMI.
-
#snapshot_copy_completion_duration_minutes ⇒ Integer
Specify a completion duration, in 15 minute increments, to initiate a time-based AMI copy.
-
#source_image_id ⇒ String
The ID of the AMI to copy.
-
#source_region ⇒ String
The name of the Region that contains the AMI to copy.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the new AMI and new snapshots.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier you provide to ensure idempotency of the request. For more information, see [Ensuring idempotency in Amazon EC2 API requests] in the *Amazon EC2 API Reference*.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html
8070 8071 8072 8073 8074 8075 8076 8077 8078 8079 8080 8081 8082 8083 8084 8085 8086 8087 |
# File 'lib/aws-sdk-ec2/types.rb', line 8070 class CopyImageRequest < Struct.new( :client_token, :description, :encrypted, :kms_key_id, :name, :source_image_id, :source_region, :destination_outpost_arn, :copy_image_tags, :tag_specifications, :snapshot_copy_completion_duration_minutes, :destination_availability_zone, :destination_availability_zone_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#copy_image_tags ⇒ Boolean
Specifies whether to copy your user-defined AMI tags to the new AMI.
The following tags are not be copied:
-
System tags (prefixed with ‘aws:`)
-
For public and shared AMIs, user-defined tags that are attached by other Amazon Web Services accounts
Default: Your user-defined AMI tags are not copied.
8070 8071 8072 8073 8074 8075 8076 8077 8078 8079 8080 8081 8082 8083 8084 8085 8086 8087 |
# File 'lib/aws-sdk-ec2/types.rb', line 8070 class CopyImageRequest < Struct.new( :client_token, :description, :encrypted, :kms_key_id, :name, :source_image_id, :source_region, :destination_outpost_arn, :copy_image_tags, :tag_specifications, :snapshot_copy_completion_duration_minutes, :destination_availability_zone, :destination_availability_zone_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description for the new AMI.
8070 8071 8072 8073 8074 8075 8076 8077 8078 8079 8080 8081 8082 8083 8084 8085 8086 8087 |
# File 'lib/aws-sdk-ec2/types.rb', line 8070 class CopyImageRequest < Struct.new( :client_token, :description, :encrypted, :kms_key_id, :name, :source_image_id, :source_region, :destination_outpost_arn, :copy_image_tags, :tag_specifications, :snapshot_copy_completion_duration_minutes, :destination_availability_zone, :destination_availability_zone_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#destination_availability_zone ⇒ String
The Local Zone for the new AMI (for example, ‘cn-north-1-pkx-1a`).
Only one of ‘DestinationAvailabilityZone`, `DestinationAvailabilityZoneId`, or `DestinationOutpostArn` can be specified.
8070 8071 8072 8073 8074 8075 8076 8077 8078 8079 8080 8081 8082 8083 8084 8085 8086 8087 |
# File 'lib/aws-sdk-ec2/types.rb', line 8070 class CopyImageRequest < Struct.new( :client_token, :description, :encrypted, :kms_key_id, :name, :source_image_id, :source_region, :destination_outpost_arn, :copy_image_tags, :tag_specifications, :snapshot_copy_completion_duration_minutes, :destination_availability_zone, :destination_availability_zone_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#destination_availability_zone_id ⇒ String
The ID of the Local Zone for the new AMI (for example, ‘cnn1-pkx1-az1`).
Only one of ‘DestinationAvailabilityZone`, `DestinationAvailabilityZoneId`, or `DestinationOutpostArn` can be specified.
8070 8071 8072 8073 8074 8075 8076 8077 8078 8079 8080 8081 8082 8083 8084 8085 8086 8087 |
# File 'lib/aws-sdk-ec2/types.rb', line 8070 class CopyImageRequest < Struct.new( :client_token, :description, :encrypted, :kms_key_id, :name, :source_image_id, :source_region, :destination_outpost_arn, :copy_image_tags, :tag_specifications, :snapshot_copy_completion_duration_minutes, :destination_availability_zone, :destination_availability_zone_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#destination_outpost_arn ⇒ String
The Amazon Resource Name (ARN) of the Outpost for the new AMI.
Only specify this parameter when copying an AMI from an Amazon Web Services Region to an Outpost. The AMI must be in the Region of the destination Outpost. You can’t copy an AMI from an Outpost to a Region, from one Outpost to another, or within the same Outpost.
For more information, see [Copy AMIs from an Amazon Web Services Region to an Outpost] in the *Amazon EBS User Guide*.
Only one of ‘DestinationAvailabilityZone`, `DestinationAvailabilityZoneId`, or `DestinationOutpostArn` can be specified.
[1]: docs.aws.amazon.com/ebs/latest/userguide/snapshots-outposts.html#copy-amis
8070 8071 8072 8073 8074 8075 8076 8077 8078 8079 8080 8081 8082 8083 8084 8085 8086 8087 |
# File 'lib/aws-sdk-ec2/types.rb', line 8070 class CopyImageRequest < Struct.new( :client_token, :description, :encrypted, :kms_key_id, :name, :source_image_id, :source_region, :destination_outpost_arn, :copy_image_tags, :tag_specifications, :snapshot_copy_completion_duration_minutes, :destination_availability_zone, :destination_availability_zone_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
8070 8071 8072 8073 8074 8075 8076 8077 8078 8079 8080 8081 8082 8083 8084 8085 8086 8087 |
# File 'lib/aws-sdk-ec2/types.rb', line 8070 class CopyImageRequest < Struct.new( :client_token, :description, :encrypted, :kms_key_id, :name, :source_image_id, :source_region, :destination_outpost_arn, :copy_image_tags, :tag_specifications, :snapshot_copy_completion_duration_minutes, :destination_availability_zone, :destination_availability_zone_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#encrypted ⇒ Boolean
Specifies whether to encrypt the snapshots of the copied image.
You can encrypt a copy of an unencrypted snapshot, but you cannot create an unencrypted copy of an encrypted snapshot. The default KMS key for Amazon EBS is used unless you specify a non-default Key Management Service (KMS) KMS key using ‘KmsKeyId`. For more information, see [Use encryption with EBS-backed AMIs] in the *Amazon EC2 User Guide*.
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/AMIEncryption.html
8070 8071 8072 8073 8074 8075 8076 8077 8078 8079 8080 8081 8082 8083 8084 8085 8086 8087 |
# File 'lib/aws-sdk-ec2/types.rb', line 8070 class CopyImageRequest < Struct.new( :client_token, :description, :encrypted, :kms_key_id, :name, :source_image_id, :source_region, :destination_outpost_arn, :copy_image_tags, :tag_specifications, :snapshot_copy_completion_duration_minutes, :destination_availability_zone, :destination_availability_zone_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The identifier of the symmetric Key Management Service (KMS) KMS key to use when creating encrypted volumes. If this parameter is not specified, your Amazon Web Services managed KMS key for Amazon EBS is used. If you specify a KMS key, you must also set the encrypted state to ‘true`.
You can specify a KMS key using any of the following:
-
Key ID. For example, 1234abcd-12ab-34cd-56ef-1234567890ab.
-
Key alias. For example, alias/ExampleAlias.
-
Key ARN. For example, arn:aws:kms:us-east-1:012345678910:key/1234abcd-12ab-34cd-56ef-1234567890ab.
-
Alias ARN. For example, arn:aws:kms:us-east-1:012345678910:alias/ExampleAlias.
Amazon Web Services authenticates the KMS key asynchronously. Therefore, if you specify an identifier that is not valid, the action can appear to complete, but eventually fails.
The specified KMS key must exist in the destination Region.
Amazon EBS does not support asymmetric KMS keys.
8070 8071 8072 8073 8074 8075 8076 8077 8078 8079 8080 8081 8082 8083 8084 8085 8086 8087 |
# File 'lib/aws-sdk-ec2/types.rb', line 8070 class CopyImageRequest < Struct.new( :client_token, :description, :encrypted, :kms_key_id, :name, :source_image_id, :source_region, :destination_outpost_arn, :copy_image_tags, :tag_specifications, :snapshot_copy_completion_duration_minutes, :destination_availability_zone, :destination_availability_zone_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the new AMI.
8070 8071 8072 8073 8074 8075 8076 8077 8078 8079 8080 8081 8082 8083 8084 8085 8086 8087 |
# File 'lib/aws-sdk-ec2/types.rb', line 8070 class CopyImageRequest < Struct.new( :client_token, :description, :encrypted, :kms_key_id, :name, :source_image_id, :source_region, :destination_outpost_arn, :copy_image_tags, :tag_specifications, :snapshot_copy_completion_duration_minutes, :destination_availability_zone, :destination_availability_zone_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#snapshot_copy_completion_duration_minutes ⇒ Integer
Specify a completion duration, in 15 minute increments, to initiate a time-based AMI copy. The specified completion duration applies to each of the snapshots associated with the AMI. Each snapshot associated with the AMI will be completed within the specified completion duration, with copy throughput automatically adjusted for each snapshot based on its size to meet the timing target.
If you do not specify a value, the AMI copy operation is completed on a best-effort basis.
<note markdown=“1”> This parameter is not supported when copying an AMI to or from a Local Zone, or to an Outpost.
</note>
For more information, see [Time-based copies for Amazon EBS snapshots and EBS-backed AMIs].
[1]: docs.aws.amazon.com/ebs/latest/userguide/time-based-copies.html
8070 8071 8072 8073 8074 8075 8076 8077 8078 8079 8080 8081 8082 8083 8084 8085 8086 8087 |
# File 'lib/aws-sdk-ec2/types.rb', line 8070 class CopyImageRequest < Struct.new( :client_token, :description, :encrypted, :kms_key_id, :name, :source_image_id, :source_region, :destination_outpost_arn, :copy_image_tags, :tag_specifications, :snapshot_copy_completion_duration_minutes, :destination_availability_zone, :destination_availability_zone_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#source_image_id ⇒ String
The ID of the AMI to copy.
8070 8071 8072 8073 8074 8075 8076 8077 8078 8079 8080 8081 8082 8083 8084 8085 8086 8087 |
# File 'lib/aws-sdk-ec2/types.rb', line 8070 class CopyImageRequest < Struct.new( :client_token, :description, :encrypted, :kms_key_id, :name, :source_image_id, :source_region, :destination_outpost_arn, :copy_image_tags, :tag_specifications, :snapshot_copy_completion_duration_minutes, :destination_availability_zone, :destination_availability_zone_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#source_region ⇒ String
The name of the Region that contains the AMI to copy.
8070 8071 8072 8073 8074 8075 8076 8077 8078 8079 8080 8081 8082 8083 8084 8085 8086 8087 |
# File 'lib/aws-sdk-ec2/types.rb', line 8070 class CopyImageRequest < Struct.new( :client_token, :description, :encrypted, :kms_key_id, :name, :source_image_id, :source_region, :destination_outpost_arn, :copy_image_tags, :tag_specifications, :snapshot_copy_completion_duration_minutes, :destination_availability_zone, :destination_availability_zone_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the new AMI and new snapshots. You can tag the AMI, the snapshots, or both.
-
To tag the new AMI, the value for ‘ResourceType` must be `image`.
-
To tag the new snapshots, the value for ‘ResourceType` must be `snapshot`. The same tag is applied to all the new snapshots.
If you specify other values for ‘ResourceType`, the request fails.
To tag an AMI or snapshot after it has been created, see [CreateTags].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateTags.html
8070 8071 8072 8073 8074 8075 8076 8077 8078 8079 8080 8081 8082 8083 8084 8085 8086 8087 |
# File 'lib/aws-sdk-ec2/types.rb', line 8070 class CopyImageRequest < Struct.new( :client_token, :description, :encrypted, :kms_key_id, :name, :source_image_id, :source_region, :destination_outpost_arn, :copy_image_tags, :tag_specifications, :snapshot_copy_completion_duration_minutes, :destination_availability_zone, :destination_availability_zone_id, :dry_run) SENSITIVE = [] include Aws::Structure end |