Class: Aws::EC2::Types::CopyVolumesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CopyVolumesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#iops ⇒ Integer
The number of I/O operations per second (IOPS) to provision for the volume copy.
-
#multi_attach_enabled ⇒ Boolean
Indicates whether to enable Amazon EBS Multi-Attach for the volume copy.
-
#size ⇒ Integer
The size of the volume copy, in GiBs.
-
#source_volume_id ⇒ String
The ID of the source EBS volume to copy.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the volume copy during creation.
-
#throughput ⇒ Integer
The throughput to provision for the volume copy, in MiB/s.
-
#volume_type ⇒ String
The volume type for the volume copy.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [ Ensure Idempotency].
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html
8380 8381 8382 8383 8384 8385 8386 8387 8388 8389 8390 8391 8392 |
# File 'lib/aws-sdk-ec2/types.rb', line 8380 class CopyVolumesRequest < Struct.new( :source_volume_id, :iops, :size, :volume_type, :dry_run, :tag_specifications, :multi_attach_enabled, :throughput, :client_token) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
8380 8381 8382 8383 8384 8385 8386 8387 8388 8389 8390 8391 8392 |
# File 'lib/aws-sdk-ec2/types.rb', line 8380 class CopyVolumesRequest < Struct.new( :source_volume_id, :iops, :size, :volume_type, :dry_run, :tag_specifications, :multi_attach_enabled, :throughput, :client_token) SENSITIVE = [] include Aws::Structure end |
#iops ⇒ Integer
The number of I/O operations per second (IOPS) to provision for the volume copy. Required for ‘io1` and `io2` volumes. Optional for `gp3` volumes. Omit for all other volume types. Full provisioned IOPS performance can be achieved only once the volume copy is fully initialized.
Valid ranges:
-
gp3: ‘3,000 `(default)` - 80,000` IOPS
-
io1: ‘100 - 64,000` IOPS
-
io2: ‘100 - 256,000` IOPS
<note markdown=“1”> [ Instances built on the Nitro System] can support up to 256,000 IOPS. Other instances can support up to 32,000 IOPS.
</note>
[1]: docs.aws.amazon.com/ec2/latest/instancetypes/ec2-nitro-instances.html
8380 8381 8382 8383 8384 8385 8386 8387 8388 8389 8390 8391 8392 |
# File 'lib/aws-sdk-ec2/types.rb', line 8380 class CopyVolumesRequest < Struct.new( :source_volume_id, :iops, :size, :volume_type, :dry_run, :tag_specifications, :multi_attach_enabled, :throughput, :client_token) SENSITIVE = [] include Aws::Structure end |
#multi_attach_enabled ⇒ Boolean
Indicates whether to enable Amazon EBS Multi-Attach for the volume copy. If you enable Multi-Attach, you can attach the volume to up to 16 Nitro instances in the same Availability Zone simultaneously. Supported with ‘io1` and `io2` volumes only. For more information, see [ Amazon EBS Multi-Attach].
[1]: docs.aws.amazon.com/ebs/latest/userguide/ebs-volumes-multi.html
8380 8381 8382 8383 8384 8385 8386 8387 8388 8389 8390 8391 8392 |
# File 'lib/aws-sdk-ec2/types.rb', line 8380 class CopyVolumesRequest < Struct.new( :source_volume_id, :iops, :size, :volume_type, :dry_run, :tag_specifications, :multi_attach_enabled, :throughput, :client_token) SENSITIVE = [] include Aws::Structure end |
#size ⇒ Integer
The size of the volume copy, in GiBs. The size must be equal to or greater than the size of the source volume. If not specified, the size defaults to the size of the source volume.
Maximum supported sizes:
-
gp2: ‘16,384` GiB
-
gp3: ‘65,536` GiB
-
io1: ‘16,384` GiB
-
io2: ‘65,536` GiB
-
st1 and sc1: ‘16,384` GiB
-
standard: ‘1024` GiB
8380 8381 8382 8383 8384 8385 8386 8387 8388 8389 8390 8391 8392 |
# File 'lib/aws-sdk-ec2/types.rb', line 8380 class CopyVolumesRequest < Struct.new( :source_volume_id, :iops, :size, :volume_type, :dry_run, :tag_specifications, :multi_attach_enabled, :throughput, :client_token) SENSITIVE = [] include Aws::Structure end |
#source_volume_id ⇒ String
The ID of the source EBS volume to copy.
8380 8381 8382 8383 8384 8385 8386 8387 8388 8389 8390 8391 8392 |
# File 'lib/aws-sdk-ec2/types.rb', line 8380 class CopyVolumesRequest < Struct.new( :source_volume_id, :iops, :size, :volume_type, :dry_run, :tag_specifications, :multi_attach_enabled, :throughput, :client_token) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the volume copy during creation.
8380 8381 8382 8383 8384 8385 8386 8387 8388 8389 8390 8391 8392 |
# File 'lib/aws-sdk-ec2/types.rb', line 8380 class CopyVolumesRequest < Struct.new( :source_volume_id, :iops, :size, :volume_type, :dry_run, :tag_specifications, :multi_attach_enabled, :throughput, :client_token) SENSITIVE = [] include Aws::Structure end |
#throughput ⇒ Integer
The throughput to provision for the volume copy, in MiB/s. Supported for ‘gp3` volumes only. Omit for all other volume types. Full provisioned throughput performance can be achieved only once the volume copy is fully initialized.
Valid Range: ‘125 - 2000` MiB/s
8380 8381 8382 8383 8384 8385 8386 8387 8388 8389 8390 8391 8392 |
# File 'lib/aws-sdk-ec2/types.rb', line 8380 class CopyVolumesRequest < Struct.new( :source_volume_id, :iops, :size, :volume_type, :dry_run, :tag_specifications, :multi_attach_enabled, :throughput, :client_token) SENSITIVE = [] include Aws::Structure end |
#volume_type ⇒ String
The volume type for the volume copy. If not specified, the volume type defaults to ‘gp2`.
8380 8381 8382 8383 8384 8385 8386 8387 8388 8389 8390 8391 8392 |
# File 'lib/aws-sdk-ec2/types.rb', line 8380 class CopyVolumesRequest < Struct.new( :source_volume_id, :iops, :size, :volume_type, :dry_run, :tag_specifications, :multi_attach_enabled, :throughput, :client_token) SENSITIVE = [] include Aws::Structure end |