Class: Aws::EC2::Types::CreateCapacityManagerDataExportResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateCapacityManagerDataExportResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_manager_data_export_id ⇒ String
The unique identifier for the created data export configuration.
Instance Attribute Details
#capacity_manager_data_export_id ⇒ String
The unique identifier for the created data export configuration. Use this ID to reference the export in other API calls.
9779 9780 9781 9782 9783 |
# File 'lib/aws-sdk-ec2/types.rb', line 9779 class CreateCapacityManagerDataExportResult < Struct.new( :capacity_manager_data_export_id) SENSITIVE = [] include Aws::Structure end |