Class: Aws::EC2::Types::CreateCapacityReservationBySplittingRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensure Idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


9825
9826
9827
9828
9829
9830
9831
9832
9833
# File 'lib/aws-sdk-ec2/types.rb', line 9825

class CreateCapacityReservationBySplittingRequest < Struct.new(
  :dry_run,
  :client_token,
  :source_capacity_reservation_id,
  :instance_count,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


9825
9826
9827
9828
9829
9830
9831
9832
9833
# File 'lib/aws-sdk-ec2/types.rb', line 9825

class CreateCapacityReservationBySplittingRequest < Struct.new(
  :dry_run,
  :client_token,
  :source_capacity_reservation_id,
  :instance_count,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#instance_countInteger

The number of instances to split from the source Capacity Reservation.

Returns:

  • (Integer)


9825
9826
9827
9828
9829
9830
9831
9832
9833
# File 'lib/aws-sdk-ec2/types.rb', line 9825

class CreateCapacityReservationBySplittingRequest < Struct.new(
  :dry_run,
  :client_token,
  :source_capacity_reservation_id,
  :instance_count,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#source_capacity_reservation_idString

The ID of the Capacity Reservation from which you want to split the capacity.

Returns:

  • (String)


9825
9826
9827
9828
9829
9830
9831
9832
9833
# File 'lib/aws-sdk-ec2/types.rb', line 9825

class CreateCapacityReservationBySplittingRequest < Struct.new(
  :dry_run,
  :client_token,
  :source_capacity_reservation_id,
  :instance_count,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the new Capacity Reservation.

Returns:



9825
9826
9827
9828
9829
9830
9831
9832
9833
# File 'lib/aws-sdk-ec2/types.rb', line 9825

class CreateCapacityReservationBySplittingRequest < Struct.new(
  :dry_run,
  :client_token,
  :source_capacity_reservation_id,
  :instance_count,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end