Class: Aws::EC2::Types::CreateCarrierGatewayRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


10367
10368
10369
10370
10371
10372
10373
10374
# File 'lib/aws-sdk-ec2/types.rb', line 10367

class CreateCarrierGatewayRequest < Struct.new(
  :vpc_id,
  :tag_specifications,
  :dry_run,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


10367
10368
10369
10370
10371
10372
10373
10374
# File 'lib/aws-sdk-ec2/types.rb', line 10367

class CreateCarrierGatewayRequest < Struct.new(
  :vpc_id,
  :tag_specifications,
  :dry_run,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to associate with the carrier gateway.

Returns:



10367
10368
10369
10370
10371
10372
10373
10374
# File 'lib/aws-sdk-ec2/types.rb', line 10367

class CreateCarrierGatewayRequest < Struct.new(
  :vpc_id,
  :tag_specifications,
  :dry_run,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC to associate with the carrier gateway.

Returns:

  • (String)


10367
10368
10369
10370
10371
10372
10373
10374
# File 'lib/aws-sdk-ec2/types.rb', line 10367

class CreateCarrierGatewayRequest < Struct.new(
  :vpc_id,
  :tag_specifications,
  :dry_run,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end