Class: Aws::EC2::Types::CreateClientVpnEndpointRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateClientVpnEndpointRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#authentication_options ⇒ Array<Types::ClientVpnAuthenticationRequest>
Information about the authentication method to be used to authenticate clients.
-
#client_cidr_block ⇒ String
The IPv4 address range, in CIDR notation, from which to assign client IP addresses.
-
#client_connect_options ⇒ Types::ClientConnectOptions
The options for managing connection authorization for new client connections.
-
#client_login_banner_options ⇒ Types::ClientLoginBannerOptions
Options for enabling a customizable text banner that will be displayed on Amazon Web Services provided clients when a VPN session is established.
-
#client_route_enforcement_options ⇒ Types::ClientRouteEnforcementOptions
Client route enforcement is a feature of the Client VPN service that helps enforce administrator defined routes on devices connected through the VPN.
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#connection_log_options ⇒ Types::ConnectionLogOptions
Information about the client connection logging options.
-
#description ⇒ String
A brief description of the Client VPN endpoint.
-
#disconnect_on_session_timeout ⇒ Boolean
Indicates whether the client VPN session is disconnected after the maximum timeout specified in ‘SessionTimeoutHours` is reached.
-
#dns_servers ⇒ Array<String>
Information about the DNS servers to be used for DNS resolution.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#endpoint_ip_address_type ⇒ String
The IP address type for the Client VPN endpoint.
-
#security_group_ids ⇒ Array<String>
The IDs of one or more security groups to apply to the target network.
-
#self_service_portal ⇒ String
Specify whether to enable the self-service portal for the Client VPN endpoint.
-
#server_certificate_arn ⇒ String
The ARN of the server certificate.
-
#session_timeout_hours ⇒ Integer
The maximum VPN session duration time in hours.
-
#split_tunnel ⇒ Boolean
Indicates whether split-tunnel is enabled on the Client VPN endpoint.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the Client VPN endpoint during creation.
-
#traffic_ip_address_type ⇒ String
The IP address type for traffic within the Client VPN tunnel.
-
#transit_gateway_configuration ⇒ Types::TransitGatewayConfigurationInputStructure
The Transit Gateway configuration for the Client VPN endpoint.
-
#transport_protocol ⇒ String
The transport protocol to be used by the VPN session.
-
#vpc_id ⇒ String
The ID of the VPC to associate with the Client VPN endpoint.
-
#vpn_port ⇒ Integer
The port number to assign to the Client VPN endpoint for TCP and UDP traffic.
Instance Attribute Details
#authentication_options ⇒ Array<Types::ClientVpnAuthenticationRequest>
Information about the authentication method to be used to authenticate clients.
9567 9568 9569 9570 9571 9572 9573 9574 9575 9576 9577 9578 9579 9580 9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 |
# File 'lib/aws-sdk-ec2/types.rb', line 9567 class CreateClientVpnEndpointRequest < Struct.new( :client_cidr_block, :server_certificate_arn, :authentication_options, :connection_log_options, :dns_servers, :transport_protocol, :vpn_port, :description, :split_tunnel, :dry_run, :client_token, :tag_specifications, :security_group_ids, :vpc_id, :self_service_portal, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#client_cidr_block ⇒ String
The IPv4 address range, in CIDR notation, from which to assign client IP addresses. The address range cannot overlap with the local CIDR of the VPC in which the associated subnet is located, or the routes that you add manually. The address range cannot be changed after the Client VPN endpoint has been created. Client CIDR range must have a size of at least /22 and must not be greater than /12.
9567 9568 9569 9570 9571 9572 9573 9574 9575 9576 9577 9578 9579 9580 9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 |
# File 'lib/aws-sdk-ec2/types.rb', line 9567 class CreateClientVpnEndpointRequest < Struct.new( :client_cidr_block, :server_certificate_arn, :authentication_options, :connection_log_options, :dns_servers, :transport_protocol, :vpn_port, :description, :split_tunnel, :dry_run, :client_token, :tag_specifications, :security_group_ids, :vpc_id, :self_service_portal, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#client_connect_options ⇒ Types::ClientConnectOptions
The options for managing connection authorization for new client connections.
9567 9568 9569 9570 9571 9572 9573 9574 9575 9576 9577 9578 9579 9580 9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 |
# File 'lib/aws-sdk-ec2/types.rb', line 9567 class CreateClientVpnEndpointRequest < Struct.new( :client_cidr_block, :server_certificate_arn, :authentication_options, :connection_log_options, :dns_servers, :transport_protocol, :vpn_port, :description, :split_tunnel, :dry_run, :client_token, :tag_specifications, :security_group_ids, :vpc_id, :self_service_portal, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#client_login_banner_options ⇒ Types::ClientLoginBannerOptions
Options for enabling a customizable text banner that will be displayed on Amazon Web Services provided clients when a VPN session is established.
9567 9568 9569 9570 9571 9572 9573 9574 9575 9576 9577 9578 9579 9580 9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 |
# File 'lib/aws-sdk-ec2/types.rb', line 9567 class CreateClientVpnEndpointRequest < Struct.new( :client_cidr_block, :server_certificate_arn, :authentication_options, :connection_log_options, :dns_servers, :transport_protocol, :vpn_port, :description, :split_tunnel, :dry_run, :client_token, :tag_specifications, :security_group_ids, :vpc_id, :self_service_portal, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#client_route_enforcement_options ⇒ Types::ClientRouteEnforcementOptions
Client route enforcement is a feature of the Client VPN service that helps enforce administrator defined routes on devices connected through the VPN. T his feature helps improve your security posture by ensuring that network traffic originating from a connected client is not inadvertently sent outside the VPN tunnel.
Client route enforcement works by monitoring the route table of a connected device for routing policy changes to the VPN connection. If the feature detects any VPN routing policy modifications, it will automatically force an update to the route table, reverting it back to the expected route configurations.
9567 9568 9569 9570 9571 9572 9573 9574 9575 9576 9577 9578 9579 9580 9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 |
# File 'lib/aws-sdk-ec2/types.rb', line 9567 class CreateClientVpnEndpointRequest < Struct.new( :client_cidr_block, :server_certificate_arn, :authentication_options, :connection_log_options, :dns_servers, :transport_protocol, :vpn_port, :description, :split_tunnel, :dry_run, :client_token, :tag_specifications, :security_group_ids, :vpc_id, :self_service_portal, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [Ensuring idempotency].
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html
9567 9568 9569 9570 9571 9572 9573 9574 9575 9576 9577 9578 9579 9580 9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 |
# File 'lib/aws-sdk-ec2/types.rb', line 9567 class CreateClientVpnEndpointRequest < Struct.new( :client_cidr_block, :server_certificate_arn, :authentication_options, :connection_log_options, :dns_servers, :transport_protocol, :vpn_port, :description, :split_tunnel, :dry_run, :client_token, :tag_specifications, :security_group_ids, :vpc_id, :self_service_portal, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#connection_log_options ⇒ Types::ConnectionLogOptions
Information about the client connection logging options.
If you enable client connection logging, data about client connections is sent to a Cloudwatch Logs log stream. The following information is logged:
-
Client connection requests
-
Client connection results (successful and unsuccessful)
-
Reasons for unsuccessful client connection requests
-
Client connection termination time
9567 9568 9569 9570 9571 9572 9573 9574 9575 9576 9577 9578 9579 9580 9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 |
# File 'lib/aws-sdk-ec2/types.rb', line 9567 class CreateClientVpnEndpointRequest < Struct.new( :client_cidr_block, :server_certificate_arn, :authentication_options, :connection_log_options, :dns_servers, :transport_protocol, :vpn_port, :description, :split_tunnel, :dry_run, :client_token, :tag_specifications, :security_group_ids, :vpc_id, :self_service_portal, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A brief description of the Client VPN endpoint.
9567 9568 9569 9570 9571 9572 9573 9574 9575 9576 9577 9578 9579 9580 9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 |
# File 'lib/aws-sdk-ec2/types.rb', line 9567 class CreateClientVpnEndpointRequest < Struct.new( :client_cidr_block, :server_certificate_arn, :authentication_options, :connection_log_options, :dns_servers, :transport_protocol, :vpn_port, :description, :split_tunnel, :dry_run, :client_token, :tag_specifications, :security_group_ids, :vpc_id, :self_service_portal, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#disconnect_on_session_timeout ⇒ Boolean
Indicates whether the client VPN session is disconnected after the maximum timeout specified in ‘SessionTimeoutHours` is reached. If `true`, users are prompted to reconnect client VPN. If `false`, client VPN attempts to reconnect automatically. The default value is `true`.
9567 9568 9569 9570 9571 9572 9573 9574 9575 9576 9577 9578 9579 9580 9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 |
# File 'lib/aws-sdk-ec2/types.rb', line 9567 class CreateClientVpnEndpointRequest < Struct.new( :client_cidr_block, :server_certificate_arn, :authentication_options, :connection_log_options, :dns_servers, :transport_protocol, :vpn_port, :description, :split_tunnel, :dry_run, :client_token, :tag_specifications, :security_group_ids, :vpc_id, :self_service_portal, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#dns_servers ⇒ Array<String>
Information about the DNS servers to be used for DNS resolution. A Client VPN endpoint can have up to two DNS servers. If no DNS server is specified, the DNS address configured on the device is used for the DNS server.
9567 9568 9569 9570 9571 9572 9573 9574 9575 9576 9577 9578 9579 9580 9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 |
# File 'lib/aws-sdk-ec2/types.rb', line 9567 class CreateClientVpnEndpointRequest < Struct.new( :client_cidr_block, :server_certificate_arn, :authentication_options, :connection_log_options, :dns_servers, :transport_protocol, :vpn_port, :description, :split_tunnel, :dry_run, :client_token, :tag_specifications, :security_group_ids, :vpc_id, :self_service_portal, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
9567 9568 9569 9570 9571 9572 9573 9574 9575 9576 9577 9578 9579 9580 9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 |
# File 'lib/aws-sdk-ec2/types.rb', line 9567 class CreateClientVpnEndpointRequest < Struct.new( :client_cidr_block, :server_certificate_arn, :authentication_options, :connection_log_options, :dns_servers, :transport_protocol, :vpn_port, :description, :split_tunnel, :dry_run, :client_token, :tag_specifications, :security_group_ids, :vpc_id, :self_service_portal, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#endpoint_ip_address_type ⇒ String
The IP address type for the Client VPN endpoint. Valid values are ‘ipv4` (default) for IPv4 addressing only, `ipv6` for IPv6 addressing only, or `dual-stack` for both IPv4 and IPv6 addressing. When set to `dual-stack,` clients can connect to the endpoint using either IPv4 or IPv6 addresses..
9567 9568 9569 9570 9571 9572 9573 9574 9575 9576 9577 9578 9579 9580 9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 |
# File 'lib/aws-sdk-ec2/types.rb', line 9567 class CreateClientVpnEndpointRequest < Struct.new( :client_cidr_block, :server_certificate_arn, :authentication_options, :connection_log_options, :dns_servers, :transport_protocol, :vpn_port, :description, :split_tunnel, :dry_run, :client_token, :tag_specifications, :security_group_ids, :vpc_id, :self_service_portal, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
The IDs of one or more security groups to apply to the target network. You must also specify the ID of the VPC that contains the security groups.
9567 9568 9569 9570 9571 9572 9573 9574 9575 9576 9577 9578 9579 9580 9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 |
# File 'lib/aws-sdk-ec2/types.rb', line 9567 class CreateClientVpnEndpointRequest < Struct.new( :client_cidr_block, :server_certificate_arn, :authentication_options, :connection_log_options, :dns_servers, :transport_protocol, :vpn_port, :description, :split_tunnel, :dry_run, :client_token, :tag_specifications, :security_group_ids, :vpc_id, :self_service_portal, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#self_service_portal ⇒ String
Specify whether to enable the self-service portal for the Client VPN endpoint.
Default Value: ‘enabled`
9567 9568 9569 9570 9571 9572 9573 9574 9575 9576 9577 9578 9579 9580 9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 |
# File 'lib/aws-sdk-ec2/types.rb', line 9567 class CreateClientVpnEndpointRequest < Struct.new( :client_cidr_block, :server_certificate_arn, :authentication_options, :connection_log_options, :dns_servers, :transport_protocol, :vpn_port, :description, :split_tunnel, :dry_run, :client_token, :tag_specifications, :security_group_ids, :vpc_id, :self_service_portal, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#server_certificate_arn ⇒ String
The ARN of the server certificate. For more information, see the [Certificate Manager User Guide].
9567 9568 9569 9570 9571 9572 9573 9574 9575 9576 9577 9578 9579 9580 9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 |
# File 'lib/aws-sdk-ec2/types.rb', line 9567 class CreateClientVpnEndpointRequest < Struct.new( :client_cidr_block, :server_certificate_arn, :authentication_options, :connection_log_options, :dns_servers, :transport_protocol, :vpn_port, :description, :split_tunnel, :dry_run, :client_token, :tag_specifications, :security_group_ids, :vpc_id, :self_service_portal, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#session_timeout_hours ⇒ Integer
The maximum VPN session duration time in hours.
Valid values: ‘8 | 10 | 12 | 24`
Default value: ‘24`
9567 9568 9569 9570 9571 9572 9573 9574 9575 9576 9577 9578 9579 9580 9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 |
# File 'lib/aws-sdk-ec2/types.rb', line 9567 class CreateClientVpnEndpointRequest < Struct.new( :client_cidr_block, :server_certificate_arn, :authentication_options, :connection_log_options, :dns_servers, :transport_protocol, :vpn_port, :description, :split_tunnel, :dry_run, :client_token, :tag_specifications, :security_group_ids, :vpc_id, :self_service_portal, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#split_tunnel ⇒ Boolean
Indicates whether split-tunnel is enabled on the Client VPN endpoint.
By default, split-tunnel on a VPN endpoint is disabled.
For information about split-tunnel VPN endpoints, see [Split-tunnel Client VPN endpoint] in the *Client VPN Administrator Guide*.
[1]: docs.aws.amazon.com/vpn/latest/clientvpn-admin/split-tunnel-vpn.html
9567 9568 9569 9570 9571 9572 9573 9574 9575 9576 9577 9578 9579 9580 9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 |
# File 'lib/aws-sdk-ec2/types.rb', line 9567 class CreateClientVpnEndpointRequest < Struct.new( :client_cidr_block, :server_certificate_arn, :authentication_options, :connection_log_options, :dns_servers, :transport_protocol, :vpn_port, :description, :split_tunnel, :dry_run, :client_token, :tag_specifications, :security_group_ids, :vpc_id, :self_service_portal, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the Client VPN endpoint during creation.
9567 9568 9569 9570 9571 9572 9573 9574 9575 9576 9577 9578 9579 9580 9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 |
# File 'lib/aws-sdk-ec2/types.rb', line 9567 class CreateClientVpnEndpointRequest < Struct.new( :client_cidr_block, :server_certificate_arn, :authentication_options, :connection_log_options, :dns_servers, :transport_protocol, :vpn_port, :description, :split_tunnel, :dry_run, :client_token, :tag_specifications, :security_group_ids, :vpc_id, :self_service_portal, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#traffic_ip_address_type ⇒ String
The IP address type for traffic within the Client VPN tunnel. Valid values are ‘ipv4` (default) for IPv4 traffic only, `ipv6` for IPv6 addressing only, or `dual-stack` for both IPv4 and IPv6 traffic. When set to `dual-stack`, clients can access both IPv4 and IPv6 resources through the VPN .
9567 9568 9569 9570 9571 9572 9573 9574 9575 9576 9577 9578 9579 9580 9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 |
# File 'lib/aws-sdk-ec2/types.rb', line 9567 class CreateClientVpnEndpointRequest < Struct.new( :client_cidr_block, :server_certificate_arn, :authentication_options, :connection_log_options, :dns_servers, :transport_protocol, :vpn_port, :description, :split_tunnel, :dry_run, :client_token, :tag_specifications, :security_group_ids, :vpc_id, :self_service_portal, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_configuration ⇒ Types::TransitGatewayConfigurationInputStructure
The Transit Gateway configuration for the Client VPN endpoint. Use this parameter to associate the endpoint with a Transit Gateway instead of a VPC. You cannot specify both ‘TransitGatewayConfiguration` and `VpcId`/`SecurityGroupIds`.
9567 9568 9569 9570 9571 9572 9573 9574 9575 9576 9577 9578 9579 9580 9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 |
# File 'lib/aws-sdk-ec2/types.rb', line 9567 class CreateClientVpnEndpointRequest < Struct.new( :client_cidr_block, :server_certificate_arn, :authentication_options, :connection_log_options, :dns_servers, :transport_protocol, :vpn_port, :description, :split_tunnel, :dry_run, :client_token, :tag_specifications, :security_group_ids, :vpc_id, :self_service_portal, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#transport_protocol ⇒ String
The transport protocol to be used by the VPN session.
Default value: ‘udp`
9567 9568 9569 9570 9571 9572 9573 9574 9575 9576 9577 9578 9579 9580 9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 |
# File 'lib/aws-sdk-ec2/types.rb', line 9567 class CreateClientVpnEndpointRequest < Struct.new( :client_cidr_block, :server_certificate_arn, :authentication_options, :connection_log_options, :dns_servers, :transport_protocol, :vpn_port, :description, :split_tunnel, :dry_run, :client_token, :tag_specifications, :security_group_ids, :vpc_id, :self_service_portal, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC to associate with the Client VPN endpoint. If no security group IDs are specified in the request, the default security group for the VPC is applied.
9567 9568 9569 9570 9571 9572 9573 9574 9575 9576 9577 9578 9579 9580 9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 |
# File 'lib/aws-sdk-ec2/types.rb', line 9567 class CreateClientVpnEndpointRequest < Struct.new( :client_cidr_block, :server_certificate_arn, :authentication_options, :connection_log_options, :dns_servers, :transport_protocol, :vpn_port, :description, :split_tunnel, :dry_run, :client_token, :tag_specifications, :security_group_ids, :vpc_id, :self_service_portal, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |
#vpn_port ⇒ Integer
The port number to assign to the Client VPN endpoint for TCP and UDP traffic.
Valid Values: ‘443` | `1194`
Default Value: ‘443`
9567 9568 9569 9570 9571 9572 9573 9574 9575 9576 9577 9578 9579 9580 9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 |
# File 'lib/aws-sdk-ec2/types.rb', line 9567 class CreateClientVpnEndpointRequest < Struct.new( :client_cidr_block, :server_certificate_arn, :authentication_options, :connection_log_options, :dns_servers, :transport_protocol, :vpn_port, :description, :split_tunnel, :dry_run, :client_token, :tag_specifications, :security_group_ids, :vpc_id, :self_service_portal, :client_connect_options, :session_timeout_hours, :client_login_banner_options, :client_route_enforcement_options, :disconnect_on_session_timeout, :endpoint_ip_address_type, :traffic_ip_address_type, :transit_gateway_configuration) SENSITIVE = [] include Aws::Structure end |