Class: Aws::EC2::Types::CreateClientVpnRouteRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateClientVpnRouteRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#client_vpn_endpoint_id ⇒ String
The ID of the Client VPN endpoint to which to add the route.
-
#description ⇒ String
A brief description of the route.
-
#destination_cidr_block ⇒ String
The IPv4 address range, in CIDR notation, of the route destination.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#target_vpc_subnet_id ⇒ String
The ID of the subnet through which you want to route traffic.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring idempotency.
A suitable default value is auto-generated. You should normally not need to pass this option.
10684 10685 10686 10687 10688 10689 10690 10691 10692 10693 |
# File 'lib/aws-sdk-ec2/types.rb', line 10684 class CreateClientVpnRouteRequest < Struct.new( :client_vpn_endpoint_id, :destination_cidr_block, :target_vpc_subnet_id, :description, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#client_vpn_endpoint_id ⇒ String
The ID of the Client VPN endpoint to which to add the route.
10684 10685 10686 10687 10688 10689 10690 10691 10692 10693 |
# File 'lib/aws-sdk-ec2/types.rb', line 10684 class CreateClientVpnRouteRequest < Struct.new( :client_vpn_endpoint_id, :destination_cidr_block, :target_vpc_subnet_id, :description, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A brief description of the route.
10684 10685 10686 10687 10688 10689 10690 10691 10692 10693 |
# File 'lib/aws-sdk-ec2/types.rb', line 10684 class CreateClientVpnRouteRequest < Struct.new( :client_vpn_endpoint_id, :destination_cidr_block, :target_vpc_subnet_id, :description, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#destination_cidr_block ⇒ String
The IPv4 address range, in CIDR notation, of the route destination. For example:
-
To add a route for Internet access, enter
0.0.0.0/0 -
To add a route for a peered VPC, enter the peered VPC's IPv4 CIDR range
-
To add a route for an on-premises network, enter the Amazon Web Services Site-to-Site VPN connection's IPv4 CIDR range
-
To add a route for the local network, enter the client CIDR range
10684 10685 10686 10687 10688 10689 10690 10691 10692 10693 |
# File 'lib/aws-sdk-ec2/types.rb', line 10684 class CreateClientVpnRouteRequest < Struct.new( :client_vpn_endpoint_id, :destination_cidr_block, :target_vpc_subnet_id, :description, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
10684 10685 10686 10687 10688 10689 10690 10691 10692 10693 |
# File 'lib/aws-sdk-ec2/types.rb', line 10684 class CreateClientVpnRouteRequest < Struct.new( :client_vpn_endpoint_id, :destination_cidr_block, :target_vpc_subnet_id, :description, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#target_vpc_subnet_id ⇒ String
The ID of the subnet through which you want to route traffic. The specified subnet must be an existing target network of the Client VPN endpoint.
Alternatively, if you're adding a route for the local network,
specify local.
This parameter is required for VPC-based Client VPN endpoints. For Transit Gateway-based endpoints, this parameter is not required.
10684 10685 10686 10687 10688 10689 10690 10691 10692 10693 |
# File 'lib/aws-sdk-ec2/types.rb', line 10684 class CreateClientVpnRouteRequest < Struct.new( :client_vpn_endpoint_id, :destination_cidr_block, :target_vpc_subnet_id, :description, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |