Class: Aws::EC2::Types::CreateCoipPoolRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateCoipPoolRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#local_gateway_route_table_id ⇒ String
The ID of the local gateway route table.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the CoIP address pool.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
10761 10762 10763 10764 10765 10766 10767 |
# File 'lib/aws-sdk-ec2/types.rb', line 10761 class CreateCoipPoolRequest < Struct.new( :local_gateway_route_table_id, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#local_gateway_route_table_id ⇒ String
The ID of the local gateway route table.
10761 10762 10763 10764 10765 10766 10767 |
# File 'lib/aws-sdk-ec2/types.rb', line 10761 class CreateCoipPoolRequest < Struct.new( :local_gateway_route_table_id, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the CoIP address pool.
10761 10762 10763 10764 10765 10766 10767 |
# File 'lib/aws-sdk-ec2/types.rb', line 10761 class CreateCoipPoolRequest < Struct.new( :local_gateway_route_table_id, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |