Class: Aws::EC2::Types::CreateCustomerGatewayRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for CreateCustomerGateway.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bgp_asnInteger

For customer gateway devices that support BGP, specify the device's ASN. You must specify either BgpAsn or BgpAsnExtended when creating the customer gateway. If the ASN is larger than 2,147,483,647, you must use BgpAsnExtended.

Default: 65000

Valid values: 1 to 2,147,483,647

Returns:

  • (Integer)


10780
10781
10782
10783
10784
10785
10786
10787
10788
10789
10790
10791
10792
# File 'lib/aws-sdk-ec2/types.rb', line 10780

class CreateCustomerGatewayRequest < Struct.new(
  :bgp_asn,
  :public_ip,
  :certificate_arn,
  :type,
  :tag_specifications,
  :device_name,
  :ip_address,
  :bgp_asn_extended,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#bgp_asn_extendedInteger

For customer gateway devices that support BGP, specify the device's ASN. You must specify either BgpAsn or BgpAsnExtended when creating the customer gateway. If the ASN is larger than 2,147,483,647, you must use BgpAsnExtended.

Valid values: 2,147,483,648 to 4,294,967,295

Returns:

  • (Integer)


10780
10781
10782
10783
10784
10785
10786
10787
10788
10789
10790
10791
10792
# File 'lib/aws-sdk-ec2/types.rb', line 10780

class CreateCustomerGatewayRequest < Struct.new(
  :bgp_asn,
  :public_ip,
  :certificate_arn,
  :type,
  :tag_specifications,
  :device_name,
  :ip_address,
  :bgp_asn_extended,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#certificate_arnString

The Amazon Resource Name (ARN) for the customer gateway certificate.

Returns:

  • (String)


10780
10781
10782
10783
10784
10785
10786
10787
10788
10789
10790
10791
10792
# File 'lib/aws-sdk-ec2/types.rb', line 10780

class CreateCustomerGatewayRequest < Struct.new(
  :bgp_asn,
  :public_ip,
  :certificate_arn,
  :type,
  :tag_specifications,
  :device_name,
  :ip_address,
  :bgp_asn_extended,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#device_nameString

A name for the customer gateway device.

Length Constraints: Up to 255 characters.

Returns:

  • (String)


10780
10781
10782
10783
10784
10785
10786
10787
10788
10789
10790
10791
10792
# File 'lib/aws-sdk-ec2/types.rb', line 10780

class CreateCustomerGatewayRequest < Struct.new(
  :bgp_asn,
  :public_ip,
  :certificate_arn,
  :type,
  :tag_specifications,
  :device_name,
  :ip_address,
  :bgp_asn_extended,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


10780
10781
10782
10783
10784
10785
10786
10787
10788
10789
10790
10791
10792
# File 'lib/aws-sdk-ec2/types.rb', line 10780

class CreateCustomerGatewayRequest < Struct.new(
  :bgp_asn,
  :public_ip,
  :certificate_arn,
  :type,
  :tag_specifications,
  :device_name,
  :ip_address,
  :bgp_asn_extended,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#ip_addressString

The IP address for the customer gateway device's outside interface. The address must be static. If OutsideIpAddressType in your VPN connection options is set to PrivateIpv4, you can use an RFC6598 or RFC1918 private IPv4 address. If OutsideIpAddressType is set to Ipv6, you can use an IPv6 address.

Returns:

  • (String)


10780
10781
10782
10783
10784
10785
10786
10787
10788
10789
10790
10791
10792
# File 'lib/aws-sdk-ec2/types.rb', line 10780

class CreateCustomerGatewayRequest < Struct.new(
  :bgp_asn,
  :public_ip,
  :certificate_arn,
  :type,
  :tag_specifications,
  :device_name,
  :ip_address,
  :bgp_asn_extended,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#public_ipString

This member has been deprecated. The Internet-routable IP address for the customer gateway's outside interface. The address must be static.

Returns:

  • (String)


10780
10781
10782
10783
10784
10785
10786
10787
10788
10789
10790
10791
10792
# File 'lib/aws-sdk-ec2/types.rb', line 10780

class CreateCustomerGatewayRequest < Struct.new(
  :bgp_asn,
  :public_ip,
  :certificate_arn,
  :type,
  :tag_specifications,
  :device_name,
  :ip_address,
  :bgp_asn_extended,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the customer gateway.

Returns:



10780
10781
10782
10783
10784
10785
10786
10787
10788
10789
10790
10791
10792
# File 'lib/aws-sdk-ec2/types.rb', line 10780

class CreateCustomerGatewayRequest < Struct.new(
  :bgp_asn,
  :public_ip,
  :certificate_arn,
  :type,
  :tag_specifications,
  :device_name,
  :ip_address,
  :bgp_asn_extended,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of VPN connection that this customer gateway supports (ipsec.1).

Returns:

  • (String)


10780
10781
10782
10783
10784
10785
10786
10787
10788
10789
10790
10791
10792
# File 'lib/aws-sdk-ec2/types.rb', line 10780

class CreateCustomerGatewayRequest < Struct.new(
  :bgp_asn,
  :public_ip,
  :certificate_arn,
  :type,
  :tag_specifications,
  :device_name,
  :ip_address,
  :bgp_asn_extended,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end