Class: Aws::EC2::Types::CreateDhcpOptionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dhcp_configurationsArray<Types::NewDhcpConfiguration>

A DHCP configuration option.

Returns:



11046
11047
11048
11049
11050
11051
11052
# File 'lib/aws-sdk-ec2/types.rb', line 11046

class CreateDhcpOptionsRequest < Struct.new(
  :dhcp_configurations,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


11046
11047
11048
11049
11050
11051
11052
# File 'lib/aws-sdk-ec2/types.rb', line 11046

class CreateDhcpOptionsRequest < Struct.new(
  :dhcp_configurations,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to assign to the DHCP option.

Returns:



11046
11047
11048
11049
11050
11051
11052
# File 'lib/aws-sdk-ec2/types.rb', line 11046

class CreateDhcpOptionsRequest < Struct.new(
  :dhcp_configurations,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end