Class: Aws::EC2::Types::CreateEgressOnlyInternetGatewayRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateEgressOnlyInternetGatewayRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the egress-only internet gateway.
-
#vpc_id ⇒ String
The ID of the VPC for which to create the egress-only internet gateway.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [Ensuring idempotency].
[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html
10332 10333 10334 10335 10336 10337 10338 10339 |
# File 'lib/aws-sdk-ec2/types.rb', line 10332 class CreateEgressOnlyInternetGatewayRequest < Struct.new( :client_token, :dry_run, :vpc_id, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
10332 10333 10334 10335 10336 10337 10338 10339 |
# File 'lib/aws-sdk-ec2/types.rb', line 10332 class CreateEgressOnlyInternetGatewayRequest < Struct.new( :client_token, :dry_run, :vpc_id, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the egress-only internet gateway.
10332 10333 10334 10335 10336 10337 10338 10339 |
# File 'lib/aws-sdk-ec2/types.rb', line 10332 class CreateEgressOnlyInternetGatewayRequest < Struct.new( :client_token, :dry_run, :vpc_id, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC for which to create the egress-only internet gateway.
10332 10333 10334 10335 10336 10337 10338 10339 |
# File 'lib/aws-sdk-ec2/types.rb', line 10332 class CreateEgressOnlyInternetGatewayRequest < Struct.new( :client_token, :dry_run, :vpc_id, :tag_specifications) SENSITIVE = [] include Aws::Structure end |