Class: Aws::EC2::Types::CreateFleetError
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateFleetError
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the instances that could not be launched by the fleet.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#error_code ⇒ String
The error code that indicates why the instance could not be launched.
-
#error_message ⇒ String
The error message that describes why the instance could not be launched.
-
#launch_template_and_overrides ⇒ Types::LaunchTemplateAndOverridesResponse
The launch templates and overrides that were used for launching the instances.
-
#lifecycle ⇒ String
Indicates if the instance that could not be launched was a Spot, On-Demand, Capacity Block for ML, or interruptible Capacity Reservation instance.
Instance Attribute Details
#error_code ⇒ String
The error code that indicates why the instance could not be launched. For more information about error codes, see Error codes.
11163 11164 11165 11166 11167 11168 11169 11170 |
# File 'lib/aws-sdk-ec2/types.rb', line 11163 class CreateFleetError < Struct.new( :launch_template_and_overrides, :lifecycle, :error_code, :error_message) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
The error message that describes why the instance could not be launched. For more information about error messages, see Error codes.
11163 11164 11165 11166 11167 11168 11169 11170 |
# File 'lib/aws-sdk-ec2/types.rb', line 11163 class CreateFleetError < Struct.new( :launch_template_and_overrides, :lifecycle, :error_code, :error_message) SENSITIVE = [] include Aws::Structure end |
#launch_template_and_overrides ⇒ Types::LaunchTemplateAndOverridesResponse
The launch templates and overrides that were used for launching the instances. The values that you specify in the Overrides replace the values in the launch template.
11163 11164 11165 11166 11167 11168 11169 11170 |
# File 'lib/aws-sdk-ec2/types.rb', line 11163 class CreateFleetError < Struct.new( :launch_template_and_overrides, :lifecycle, :error_code, :error_message) SENSITIVE = [] include Aws::Structure end |
#lifecycle ⇒ String
Indicates if the instance that could not be launched was a Spot,
On-Demand, Capacity Block for ML, or interruptible Capacity
Reservation instance. If you are using ReservedCapacityOptions
with on-demand-capacity-reservation in the ReservationTypes
list, the value can also be on-demand-capacity-reservation.
11163 11164 11165 11166 11167 11168 11169 11170 |
# File 'lib/aws-sdk-ec2/types.rb', line 11163 class CreateFleetError < Struct.new( :launch_template_and_overrides, :lifecycle, :error_code, :error_message) SENSITIVE = [] include Aws::Structure end |