Class: Aws::EC2::Types::CreateImageUsageReportRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateImageUsageReportRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_ids ⇒ Array<String>
The Amazon Web Services account IDs to include in the report.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure idempotency of the request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#image_id ⇒ String
The ID of the image to report on.
-
#resource_types ⇒ Array<Types::ImageUsageResourceTypeRequest>
The resource types to include in the report.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the report on creation.
Instance Attribute Details
#account_ids ⇒ Array<String>
The Amazon Web Services account IDs to include in the report. To include all accounts, omit this parameter.
11831 11832 11833 11834 11835 11836 11837 11838 11839 11840 |
# File 'lib/aws-sdk-ec2/types.rb', line 11831 class CreateImageUsageReportRequest < Struct.new( :image_id, :dry_run, :resource_types, :account_ids, :client_token, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure idempotency of the request.
A suitable default value is auto-generated. You should normally not need to pass this option.
11831 11832 11833 11834 11835 11836 11837 11838 11839 11840 |
# File 'lib/aws-sdk-ec2/types.rb', line 11831 class CreateImageUsageReportRequest < Struct.new( :image_id, :dry_run, :resource_types, :account_ids, :client_token, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
11831 11832 11833 11834 11835 11836 11837 11838 11839 11840 |
# File 'lib/aws-sdk-ec2/types.rb', line 11831 class CreateImageUsageReportRequest < Struct.new( :image_id, :dry_run, :resource_types, :account_ids, :client_token, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#image_id ⇒ String
The ID of the image to report on.
11831 11832 11833 11834 11835 11836 11837 11838 11839 11840 |
# File 'lib/aws-sdk-ec2/types.rb', line 11831 class CreateImageUsageReportRequest < Struct.new( :image_id, :dry_run, :resource_types, :account_ids, :client_token, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#resource_types ⇒ Array<Types::ImageUsageResourceTypeRequest>
The resource types to include in the report.
11831 11832 11833 11834 11835 11836 11837 11838 11839 11840 |
# File 'lib/aws-sdk-ec2/types.rb', line 11831 class CreateImageUsageReportRequest < Struct.new( :image_id, :dry_run, :resource_types, :account_ids, :client_token, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the report on creation. The ResourceType must
be set to image-usage-report; any other value will cause the
report creation to fail.
To tag a report after it has been created, see CreateTags.
11831 11832 11833 11834 11835 11836 11837 11838 11839 11840 |
# File 'lib/aws-sdk-ec2/types.rb', line 11831 class CreateImageUsageReportRequest < Struct.new( :image_id, :dry_run, :resource_types, :account_ids, :client_token, :tag_specifications) SENSITIVE = [] include Aws::Structure end |