Class: Aws::EC2::Types::CreateInstanceEventWindowRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cron_expressionString

The cron expression for the event window, for example, ‘* 0-4,20-23

    • 1,5`. If you specify a cron expression, you can’t specify a

time range.

Constraints:

  • Only hour and day of the week values are supported.

  • For day of the week values, you can specify either integers ‘0` through `6`, or alternative single values `SUN` through `SAT`.

  • The minute, month, and year must be specified by ‘*`.

  • The hour value must be one or a multiple range, for example, ‘0-4` or `0-4,20-23`.

  • Each hour range must be >= 2 hours, for example, ‘0-2` or `20-23`.

  • The event window must be >= 4 hours. The combined total time ranges in the event window must be >= 4 hours.

For more information about cron expressions, see [cron] on the *Wikipedia website*.

[1]: en.wikipedia.org/wiki/Cron

Returns:

  • (String)


11210
11211
11212
11213
11214
11215
11216
11217
11218
# File 'lib/aws-sdk-ec2/types.rb', line 11210

class CreateInstanceEventWindowRequest < Struct.new(
  :dry_run,
  :name,
  :time_ranges,
  :cron_expression,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


11210
11211
11212
11213
11214
11215
11216
11217
11218
# File 'lib/aws-sdk-ec2/types.rb', line 11210

class CreateInstanceEventWindowRequest < Struct.new(
  :dry_run,
  :name,
  :time_ranges,
  :cron_expression,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the event window.

Returns:

  • (String)


11210
11211
11212
11213
11214
11215
11216
11217
11218
# File 'lib/aws-sdk-ec2/types.rb', line 11210

class CreateInstanceEventWindowRequest < Struct.new(
  :dry_run,
  :name,
  :time_ranges,
  :cron_expression,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the event window.

Returns:



11210
11211
11212
11213
11214
11215
11216
11217
11218
# File 'lib/aws-sdk-ec2/types.rb', line 11210

class CreateInstanceEventWindowRequest < Struct.new(
  :dry_run,
  :name,
  :time_ranges,
  :cron_expression,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#time_rangesArray<Types::InstanceEventWindowTimeRangeRequest>

The time range for the event window. If you specify a time range, you can’t specify a cron expression.



11210
11211
11212
11213
11214
11215
11216
11217
11218
# File 'lib/aws-sdk-ec2/types.rb', line 11210

class CreateInstanceEventWindowRequest < Struct.new(
  :dry_run,
  :name,
  :time_ranges,
  :cron_expression,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end