Class: Aws::EC2::Types::CreateInternetGatewayRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateInternetGatewayRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the internet gateway.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
12093 12094 12095 12096 12097 12098 |
# File 'lib/aws-sdk-ec2/types.rb', line 12093 class CreateInternetGatewayRequest < Struct.new( :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the internet gateway.
12093 12094 12095 12096 12097 12098 |
# File 'lib/aws-sdk-ec2/types.rb', line 12093 class CreateInternetGatewayRequest < Struct.new( :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |