Class: Aws::EC2::Types::CreateInterruptibleCapacityReservationAllocationResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#interruption_typeString

The type of interruption applied to the interruptible reservation.

Returns:

  • (String)


10861
10862
10863
10864
10865
10866
10867
10868
# File 'lib/aws-sdk-ec2/types.rb', line 10861

class CreateInterruptibleCapacityReservationAllocationResult < Struct.new(
  :source_capacity_reservation_id,
  :target_instance_count,
  :status,
  :interruption_type)
  SENSITIVE = []
  include Aws::Structure
end

#source_capacity_reservation_idString

The ID of the source Capacity Reservation from which the interruptible Capacity Reservation was created.

Returns:

  • (String)


10861
10862
10863
10864
10865
10866
10867
10868
# File 'lib/aws-sdk-ec2/types.rb', line 10861

class CreateInterruptibleCapacityReservationAllocationResult < Struct.new(
  :source_capacity_reservation_id,
  :target_instance_count,
  :status,
  :interruption_type)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the allocation request (creating, active, updating).

Returns:

  • (String)


10861
10862
10863
10864
10865
10866
10867
10868
# File 'lib/aws-sdk-ec2/types.rb', line 10861

class CreateInterruptibleCapacityReservationAllocationResult < Struct.new(
  :source_capacity_reservation_id,
  :target_instance_count,
  :status,
  :interruption_type)
  SENSITIVE = []
  include Aws::Structure
end

#target_instance_countInteger

The number of instances allocated to the interruptible reservation.

Returns:

  • (Integer)


10861
10862
10863
10864
10865
10866
10867
10868
# File 'lib/aws-sdk-ec2/types.rb', line 10861

class CreateInterruptibleCapacityReservationAllocationResult < Struct.new(
  :source_capacity_reservation_id,
  :target_instance_count,
  :status,
  :interruption_type)
  SENSITIVE = []
  include Aws::Structure
end