Class: Aws::EC2::Types::CreateIpamPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateIpamPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier to ensure the idempotency of the request.
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#ipam_id ⇒ String
The ID of the IPAM for which you're creating the policy.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the IPAM policy.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier to ensure the idempotency of the request.
A suitable default value is auto-generated. You should normally not need to pass this option.
12332 12333 12334 12335 12336 12337 12338 12339 |
# File 'lib/aws-sdk-ec2/types.rb', line 12332 class CreateIpamPolicyRequest < Struct.new( :dry_run, :tag_specifications, :client_token, :ipam_id) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action
without actually making the request and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
12332 12333 12334 12335 12336 12337 12338 12339 |
# File 'lib/aws-sdk-ec2/types.rb', line 12332 class CreateIpamPolicyRequest < Struct.new( :dry_run, :tag_specifications, :client_token, :ipam_id) SENSITIVE = [] include Aws::Structure end |
#ipam_id ⇒ String
The ID of the IPAM for which you're creating the policy.
12332 12333 12334 12335 12336 12337 12338 12339 |
# File 'lib/aws-sdk-ec2/types.rb', line 12332 class CreateIpamPolicyRequest < Struct.new( :dry_run, :tag_specifications, :client_token, :ipam_id) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the IPAM policy.
12332 12333 12334 12335 12336 12337 12338 12339 |
# File 'lib/aws-sdk-ec2/types.rb', line 12332 class CreateIpamPolicyRequest < Struct.new( :dry_run, :tag_specifications, :client_token, :ipam_id) SENSITIVE = [] include Aws::Structure end |