Class: Aws::EC2::Types::CreateIpamPolicyResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ipam_policyTypes::IpamPolicy

Information about the created IPAM policy.

An IPAM policy is a set of rules that define how public IPv4 addresses from IPAM pools are allocated to Amazon Web Services resources. Each rule maps an Amazon Web Services service to IPAM pools that the service will use to get IP addresses. A single policy can have multiple rules and be applied to multiple Amazon Web Services Regions. If the IPAM pool run out of addresses then the services fallback to Amazon-provided IP addresses. A policy can be applied to an individual Amazon Web Services account or an entity within Amazon Web Services Organizations.

Returns:



11043
11044
11045
11046
11047
# File 'lib/aws-sdk-ec2/types.rb', line 11043

class CreateIpamPolicyResult < Struct.new(
  :ipam_policy)
  SENSITIVE = []
  include Aws::Structure
end