Class: Aws::EC2::Types::CreateIpamRoutingPolicyRegistrationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateIpamRoutingPolicyRegistrationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asns ⇒ Array<String>
The Autonomous System Numbers (ASNs) authorized to originate the prefix.
-
#cidr ⇒ String
The IP address prefix in CIDR notation to authorize in the ROA.
-
#client_token ⇒ String
A unique, case-sensitive identifier to ensure that the operation completes no more than one time.
-
#description ⇒ String
A description for the routing policy registration.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#force ⇒ Boolean
Forces the creation of the routing policy registration even if it conflicts with an announced route.
-
#ipam_internet_registry_association_id ⇒ String
The ID of the IPAM internet registry association.
-
#max_length ⇒ Integer
The maximum prefix length that the ASNs are authorized to announce.
-
#permit_more_specific_announcements ⇒ Boolean
Specifies whether to permit more specific route announcements than the CIDR prefix.
Instance Attribute Details
#asns ⇒ Array<String>
The Autonomous System Numbers (ASNs) authorized to originate the prefix.
12924 12925 12926 12927 12928 12929 12930 12931 12932 12933 12934 12935 12936 |
# File 'lib/aws-sdk-ec2/types.rb', line 12924 class CreateIpamRoutingPolicyRegistrationRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id, :cidr, :asns, :permit_more_specific_announcements, :max_length, :description, :force, :client_token) SENSITIVE = [] include Aws::Structure end |
#cidr ⇒ String
The IP address prefix in CIDR notation to authorize in the ROA.
12924 12925 12926 12927 12928 12929 12930 12931 12932 12933 12934 12935 12936 |
# File 'lib/aws-sdk-ec2/types.rb', line 12924 class CreateIpamRoutingPolicyRegistrationRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id, :cidr, :asns, :permit_more_specific_announcements, :max_length, :description, :force, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, the operation ignores the request, but does not return an error.
A suitable default value is auto-generated. You should normally not need to pass this option.
12924 12925 12926 12927 12928 12929 12930 12931 12932 12933 12934 12935 12936 |
# File 'lib/aws-sdk-ec2/types.rb', line 12924 class CreateIpamRoutingPolicyRegistrationRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id, :cidr, :asns, :permit_more_specific_announcements, :max_length, :description, :force, :client_token) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description for the routing policy registration.
12924 12925 12926 12927 12928 12929 12930 12931 12932 12933 12934 12935 12936 |
# File 'lib/aws-sdk-ec2/types.rb', line 12924 class CreateIpamRoutingPolicyRegistrationRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id, :cidr, :asns, :permit_more_specific_announcements, :max_length, :description, :force, :client_token) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
12924 12925 12926 12927 12928 12929 12930 12931 12932 12933 12934 12935 12936 |
# File 'lib/aws-sdk-ec2/types.rb', line 12924 class CreateIpamRoutingPolicyRegistrationRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id, :cidr, :asns, :permit_more_specific_announcements, :max_length, :description, :force, :client_token) SENSITIVE = [] include Aws::Structure end |
#force ⇒ Boolean
Forces the creation of the routing policy registration even if it
conflicts with an announced route. Default: false.
12924 12925 12926 12927 12928 12929 12930 12931 12932 12933 12934 12935 12936 |
# File 'lib/aws-sdk-ec2/types.rb', line 12924 class CreateIpamRoutingPolicyRegistrationRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id, :cidr, :asns, :permit_more_specific_announcements, :max_length, :description, :force, :client_token) SENSITIVE = [] include Aws::Structure end |
#ipam_internet_registry_association_id ⇒ String
The ID of the IPAM internet registry association.
12924 12925 12926 12927 12928 12929 12930 12931 12932 12933 12934 12935 12936 |
# File 'lib/aws-sdk-ec2/types.rb', line 12924 class CreateIpamRoutingPolicyRegistrationRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id, :cidr, :asns, :permit_more_specific_announcements, :max_length, :description, :force, :client_token) SENSITIVE = [] include Aws::Structure end |
#max_length ⇒ Integer
The maximum prefix length that the ASNs are authorized to announce. Must be greater than or equal to the prefix length of the CIDR. If not specified, defaults to the prefix length of the CIDR (exact match only).
12924 12925 12926 12927 12928 12929 12930 12931 12932 12933 12934 12935 12936 |
# File 'lib/aws-sdk-ec2/types.rb', line 12924 class CreateIpamRoutingPolicyRegistrationRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id, :cidr, :asns, :permit_more_specific_announcements, :max_length, :description, :force, :client_token) SENSITIVE = [] include Aws::Structure end |
#permit_more_specific_announcements ⇒ Boolean
Specifies whether to permit more specific route announcements than
the CIDR prefix. When enabled, ASNs can announce sub-prefixes of the
authorized CIDR up to the specified maximum length. Default:
false.
12924 12925 12926 12927 12928 12929 12930 12931 12932 12933 12934 12935 12936 |
# File 'lib/aws-sdk-ec2/types.rb', line 12924 class CreateIpamRoutingPolicyRegistrationRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id, :cidr, :asns, :permit_more_specific_announcements, :max_length, :description, :force, :client_token) SENSITIVE = [] include Aws::Structure end |