Class: Aws::EC2::Types::CreateIpamScopeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


12775
12776
12777
12778
12779
12780
12781
12782
12783
12784
# File 'lib/aws-sdk-ec2/types.rb', line 12775

class CreateIpamScopeRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :description,
  :tag_specifications,
  :client_token,
  :external_authority_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description for the scope you're creating.

Returns:

  • (String)


12775
12776
12777
12778
12779
12780
12781
12782
12783
12784
# File 'lib/aws-sdk-ec2/types.rb', line 12775

class CreateIpamScopeRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :description,
  :tag_specifications,
  :client_token,
  :external_authority_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


12775
12776
12777
12778
12779
12780
12781
12782
12783
12784
# File 'lib/aws-sdk-ec2/types.rb', line 12775

class CreateIpamScopeRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :description,
  :tag_specifications,
  :client_token,
  :external_authority_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#external_authority_configurationTypes::ExternalAuthorityConfiguration

The configuration that links an Amazon VPC IPAM scope to an external authority system. It specifies the type of external system and the external resource identifier that identifies your account or instance in that system.

In IPAM, an external authority is a third-party IP address management system that provides CIDR blocks when you provision address space for top-level IPAM pools. This allows you to use your existing IP management system to control which address ranges are allocated to Amazon Web Services while using Amazon VPC IPAM to manage subnets within those ranges.



12775
12776
12777
12778
12779
12780
12781
12782
12783
12784
# File 'lib/aws-sdk-ec2/types.rb', line 12775

class CreateIpamScopeRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :description,
  :tag_specifications,
  :client_token,
  :external_authority_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_idString

The ID of the IPAM for which you're creating this scope.

Returns:

  • (String)


12775
12776
12777
12778
12779
12780
12781
12782
12783
12784
# File 'lib/aws-sdk-ec2/types.rb', line 12775

class CreateIpamScopeRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :description,
  :tag_specifications,
  :client_token,
  :external_authority_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.

Returns:



12775
12776
12777
12778
12779
12780
12781
12782
12783
12784
# File 'lib/aws-sdk-ec2/types.rb', line 12775

class CreateIpamScopeRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :description,
  :tag_specifications,
  :client_token,
  :external_authority_configuration)
  SENSITIVE = []
  include Aws::Structure
end