Class: Aws::EC2::Types::CreateLaunchTemplateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateLaunchTemplateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier you provide to ensure the idempotency of the request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#launch_template_data ⇒ Types::RequestLaunchTemplateData
The information for the launch template.
-
#launch_template_name ⇒ String
A name for the launch template.
-
#operator ⇒ Types::OperatorRequest
Reserved for internal use.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the launch template on creation.
-
#version_description ⇒ String
A description for the first version of the launch template.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier you provide to ensure the idempotency of the request. If a client token isn't specified, a randomly generated token is used in the request to ensure idempotency.
For more information, see Ensuring idempotency.
Constraint: Maximum 128 ASCII characters.
A suitable default value is auto-generated. You should normally not need to pass this option.
13115 13116 13117 13118 13119 13120 13121 13122 13123 13124 13125 |
# File 'lib/aws-sdk-ec2/types.rb', line 13115 class CreateLaunchTemplateRequest < Struct.new( :dry_run, :client_token, :launch_template_name, :version_description, :launch_template_data, :operator, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
13115 13116 13117 13118 13119 13120 13121 13122 13123 13124 13125 |
# File 'lib/aws-sdk-ec2/types.rb', line 13115 class CreateLaunchTemplateRequest < Struct.new( :dry_run, :client_token, :launch_template_name, :version_description, :launch_template_data, :operator, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#launch_template_data ⇒ Types::RequestLaunchTemplateData
The information for the launch template.
13115 13116 13117 13118 13119 13120 13121 13122 13123 13124 13125 |
# File 'lib/aws-sdk-ec2/types.rb', line 13115 class CreateLaunchTemplateRequest < Struct.new( :dry_run, :client_token, :launch_template_name, :version_description, :launch_template_data, :operator, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#launch_template_name ⇒ String
A name for the launch template.
13115 13116 13117 13118 13119 13120 13121 13122 13123 13124 13125 |
# File 'lib/aws-sdk-ec2/types.rb', line 13115 class CreateLaunchTemplateRequest < Struct.new( :dry_run, :client_token, :launch_template_name, :version_description, :launch_template_data, :operator, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#operator ⇒ Types::OperatorRequest
Reserved for internal use.
13115 13116 13117 13118 13119 13120 13121 13122 13123 13124 13125 |
# File 'lib/aws-sdk-ec2/types.rb', line 13115 class CreateLaunchTemplateRequest < Struct.new( :dry_run, :client_token, :launch_template_name, :version_description, :launch_template_data, :operator, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the launch template on creation. To tag the
launch template, the resource type must be launch-template.
To specify the tags for the resources that are created when an
instance is launched, you must use the TagSpecifications parameter
in the launch template data structure.
13115 13116 13117 13118 13119 13120 13121 13122 13123 13124 13125 |
# File 'lib/aws-sdk-ec2/types.rb', line 13115 class CreateLaunchTemplateRequest < Struct.new( :dry_run, :client_token, :launch_template_name, :version_description, :launch_template_data, :operator, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#version_description ⇒ String
A description for the first version of the launch template.
13115 13116 13117 13118 13119 13120 13121 13122 13123 13124 13125 |
# File 'lib/aws-sdk-ec2/types.rb', line 13115 class CreateLaunchTemplateRequest < Struct.new( :dry_run, :client_token, :launch_template_name, :version_description, :launch_template_data, :operator, :tag_specifications) SENSITIVE = [] include Aws::Structure end |