Class: Aws::EC2::Types::CreateLaunchTemplateVersionResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateLaunchTemplateVersionResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#launch_template_version ⇒ Types::LaunchTemplateVersion
Information about the launch template version.
-
#warning ⇒ Types::ValidationWarning
If the new version of the launch template contains parameters or parameter combinations that are not valid, an error code and an error message are returned for each issue that's found.
Instance Attribute Details
#launch_template_version ⇒ Types::LaunchTemplateVersion
Information about the launch template version.
13028 13029 13030 13031 13032 13033 |
# File 'lib/aws-sdk-ec2/types.rb', line 13028 class CreateLaunchTemplateVersionResult < Struct.new( :launch_template_version, :warning) SENSITIVE = [] include Aws::Structure end |
#warning ⇒ Types::ValidationWarning
If the new version of the launch template contains parameters or parameter combinations that are not valid, an error code and an error message are returned for each issue that's found.
13028 13029 13030 13031 13032 13033 |
# File 'lib/aws-sdk-ec2/types.rb', line 13028 class CreateLaunchTemplateVersionResult < Struct.new( :launch_template_version, :warning) SENSITIVE = [] include Aws::Structure end |