Class: Aws::EC2::Types::CreateLocalGatewayRouteRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateLocalGatewayRouteRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination_cidr_block ⇒ String
The CIDR range used for destination matches.
-
#destination_prefix_list_id ⇒ String
The ID of the prefix list.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#local_gateway_route_table_id ⇒ String
The ID of the local gateway route table.
-
#local_gateway_virtual_interface_group_id ⇒ String
The ID of the virtual interface group.
-
#network_interface_id ⇒ String
The ID of the network interface.
Instance Attribute Details
#destination_cidr_block ⇒ String
The CIDR range used for destination matches. Routing decisions are based on the most specific match.
13286 13287 13288 13289 13290 13291 13292 13293 13294 13295 |
# File 'lib/aws-sdk-ec2/types.rb', line 13286 class CreateLocalGatewayRouteRequest < Struct.new( :destination_cidr_block, :local_gateway_route_table_id, :local_gateway_virtual_interface_group_id, :dry_run, :network_interface_id, :destination_prefix_list_id) SENSITIVE = [] include Aws::Structure end |
#destination_prefix_list_id ⇒ String
The ID of the prefix list. Use a prefix list in place of
DestinationCidrBlock. You cannot use DestinationPrefixListId and
DestinationCidrBlock in the same request.
13286 13287 13288 13289 13290 13291 13292 13293 13294 13295 |
# File 'lib/aws-sdk-ec2/types.rb', line 13286 class CreateLocalGatewayRouteRequest < Struct.new( :destination_cidr_block, :local_gateway_route_table_id, :local_gateway_virtual_interface_group_id, :dry_run, :network_interface_id, :destination_prefix_list_id) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
13286 13287 13288 13289 13290 13291 13292 13293 13294 13295 |
# File 'lib/aws-sdk-ec2/types.rb', line 13286 class CreateLocalGatewayRouteRequest < Struct.new( :destination_cidr_block, :local_gateway_route_table_id, :local_gateway_virtual_interface_group_id, :dry_run, :network_interface_id, :destination_prefix_list_id) SENSITIVE = [] include Aws::Structure end |
#local_gateway_route_table_id ⇒ String
The ID of the local gateway route table.
13286 13287 13288 13289 13290 13291 13292 13293 13294 13295 |
# File 'lib/aws-sdk-ec2/types.rb', line 13286 class CreateLocalGatewayRouteRequest < Struct.new( :destination_cidr_block, :local_gateway_route_table_id, :local_gateway_virtual_interface_group_id, :dry_run, :network_interface_id, :destination_prefix_list_id) SENSITIVE = [] include Aws::Structure end |
#local_gateway_virtual_interface_group_id ⇒ String
The ID of the virtual interface group.
13286 13287 13288 13289 13290 13291 13292 13293 13294 13295 |
# File 'lib/aws-sdk-ec2/types.rb', line 13286 class CreateLocalGatewayRouteRequest < Struct.new( :destination_cidr_block, :local_gateway_route_table_id, :local_gateway_virtual_interface_group_id, :dry_run, :network_interface_id, :destination_prefix_list_id) SENSITIVE = [] include Aws::Structure end |
#network_interface_id ⇒ String
The ID of the network interface.
13286 13287 13288 13289 13290 13291 13292 13293 13294 13295 |
# File 'lib/aws-sdk-ec2/types.rb', line 13286 class CreateLocalGatewayRouteRequest < Struct.new( :destination_cidr_block, :local_gateway_route_table_id, :local_gateway_virtual_interface_group_id, :dry_run, :network_interface_id, :destination_prefix_list_id) SENSITIVE = [] include Aws::Structure end |