Class: Aws::EC2::Types::CreateMacSystemIntegrityProtectionModificationTaskRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateMacSystemIntegrityProtectionModificationTaskRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:mac_credentials]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#instance_id ⇒ String
The ID of the Amazon EC2 Mac instance.
-
#mac_credentials ⇒ String
**[Apple silicon Mac instances only]** Specifies the following credentials:.
-
#mac_system_integrity_protection_configuration ⇒ Types::MacSystemIntegrityProtectionConfigurationRequest
Specifies the overrides to selectively enable or disable individual SIP settings.
-
#mac_system_integrity_protection_status ⇒ String
Specifies the overall SIP status for the instance.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
Specifies tags to apply to the SIP modification task.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [Ensuring Idempotency].
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html
12174 12175 12176 12177 12178 12179 12180 12181 12182 12183 12184 |
# File 'lib/aws-sdk-ec2/types.rb', line 12174 class CreateMacSystemIntegrityProtectionModificationTaskRequest < Struct.new( :client_token, :dry_run, :instance_id, :mac_credentials, :mac_system_integrity_protection_configuration, :mac_system_integrity_protection_status, :tag_specifications) SENSITIVE = [:mac_credentials] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
12174 12175 12176 12177 12178 12179 12180 12181 12182 12183 12184 |
# File 'lib/aws-sdk-ec2/types.rb', line 12174 class CreateMacSystemIntegrityProtectionModificationTaskRequest < Struct.new( :client_token, :dry_run, :instance_id, :mac_credentials, :mac_system_integrity_protection_configuration, :mac_system_integrity_protection_status, :tag_specifications) SENSITIVE = [:mac_credentials] include Aws::Structure end |
#instance_id ⇒ String
The ID of the Amazon EC2 Mac instance.
12174 12175 12176 12177 12178 12179 12180 12181 12182 12183 12184 |
# File 'lib/aws-sdk-ec2/types.rb', line 12174 class CreateMacSystemIntegrityProtectionModificationTaskRequest < Struct.new( :client_token, :dry_run, :instance_id, :mac_credentials, :mac_system_integrity_protection_configuration, :mac_system_integrity_protection_status, :tag_specifications) SENSITIVE = [:mac_credentials] include Aws::Structure end |
#mac_credentials ⇒ String
**[Apple silicon Mac instances only]** Specifies the following credentials:
-
**Internal disk administrative user**
-
Username - Only the default administrative user (‘aws-managed-user`) is supported and it is used by default. You can’t specify a different administrative user.
-
Password - If you did not change the default password for ‘aws-managed-user`, specify the default password, which is blank. Otherwise, specify your password.
-
-
**Amazon EBS root volume administrative user**
-
Username - If you did not change the default administrative user, specify ‘ec2-user`. Otherwise, specify the username for your administrative user.
-
Password - Specify the password for the administrative user.
-
The credentials must be specified in the following JSON format:
‘{ “internalDiskPassword”:“internal-disk-admin_password”, “rootVolumeUsername”:“root-volume-admin_username”, “rootVolumepassword”:“root-volume-admin_password” }`
12174 12175 12176 12177 12178 12179 12180 12181 12182 12183 12184 |
# File 'lib/aws-sdk-ec2/types.rb', line 12174 class CreateMacSystemIntegrityProtectionModificationTaskRequest < Struct.new( :client_token, :dry_run, :instance_id, :mac_credentials, :mac_system_integrity_protection_configuration, :mac_system_integrity_protection_status, :tag_specifications) SENSITIVE = [:mac_credentials] include Aws::Structure end |
#mac_system_integrity_protection_configuration ⇒ Types::MacSystemIntegrityProtectionConfigurationRequest
Specifies the overrides to selectively enable or disable individual SIP settings. The individual settings you specify here override the overall SIP status you specify for MacSystemIntegrityProtectionStatus.
12174 12175 12176 12177 12178 12179 12180 12181 12182 12183 12184 |
# File 'lib/aws-sdk-ec2/types.rb', line 12174 class CreateMacSystemIntegrityProtectionModificationTaskRequest < Struct.new( :client_token, :dry_run, :instance_id, :mac_credentials, :mac_system_integrity_protection_configuration, :mac_system_integrity_protection_status, :tag_specifications) SENSITIVE = [:mac_credentials] include Aws::Structure end |
#mac_system_integrity_protection_status ⇒ String
Specifies the overall SIP status for the instance. To enable all SIP settings, specify ‘enabled`. To disable all SIP settings, specify `disabled`.
12174 12175 12176 12177 12178 12179 12180 12181 12182 12183 12184 |
# File 'lib/aws-sdk-ec2/types.rb', line 12174 class CreateMacSystemIntegrityProtectionModificationTaskRequest < Struct.new( :client_token, :dry_run, :instance_id, :mac_credentials, :mac_system_integrity_protection_configuration, :mac_system_integrity_protection_status, :tag_specifications) SENSITIVE = [:mac_credentials] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
Specifies tags to apply to the SIP modification task.
12174 12175 12176 12177 12178 12179 12180 12181 12182 12183 12184 |
# File 'lib/aws-sdk-ec2/types.rb', line 12174 class CreateMacSystemIntegrityProtectionModificationTaskRequest < Struct.new( :client_token, :dry_run, :instance_id, :mac_credentials, :mac_system_integrity_protection_configuration, :mac_system_integrity_protection_status, :tag_specifications) SENSITIVE = [:mac_credentials] include Aws::Structure end |