Class: Aws::EC2::Types::CreateNatGatewayRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allocation_idString

[Public NAT gateways only] The allocation ID of an Elastic IP address to associate with the NAT gateway. You cannot specify an Elastic IP address with a private NAT gateway. If the Elastic IP address is associated with another resource, you must first disassociate it.

Returns:

  • (String)


12660
12661
12662
12663
12664
12665
12666
12667
12668
12669
12670
12671
12672
12673
12674
12675
12676
# File 'lib/aws-sdk-ec2/types.rb', line 12660

class CreateNatGatewayRequest < Struct.new(
  :availability_mode,
  :allocation_id,
  :client_token,
  :dry_run,
  :subnet_id,
  :vpc_id,
  :availability_zone_addresses,
  :tag_specifications,
  :connectivity_type,
  :private_ip_address,
  :secondary_allocation_ids,
  :secondary_private_ip_addresses,
  :secondary_private_ip_address_count)
  SENSITIVE = []
  include Aws::Structure
end

#availability_modeString

Specifies whether to create a zonal (single-AZ) or regional (multi-AZ) NAT gateway. Defaults to ‘zonal`.

A zonal NAT gateway is a NAT Gateway that provides redundancy and scalability within a single availability zone. A regional NAT gateway is a single NAT Gateway that works across multiple availability zones (AZs) in your VPC, providing redundancy, scalability and availability across all the AZs in a Region.

For more information, see [Regional NAT gateways for automatic multi-AZ expansion] in the *Amazon VPC User Guide*.

[1]: docs.aws.amazon.com/vpc/latest/userguide/nat-gateways-regional.html

Returns:

  • (String)


12660
12661
12662
12663
12664
12665
12666
12667
12668
12669
12670
12671
12672
12673
12674
12675
12676
# File 'lib/aws-sdk-ec2/types.rb', line 12660

class CreateNatGatewayRequest < Struct.new(
  :availability_mode,
  :allocation_id,
  :client_token,
  :dry_run,
  :subnet_id,
  :vpc_id,
  :availability_zone_addresses,
  :tag_specifications,
  :connectivity_type,
  :private_ip_address,
  :secondary_allocation_ids,
  :secondary_private_ip_addresses,
  :secondary_private_ip_address_count)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zone_addressesArray<Types::AvailabilityZoneAddress>

For regional NAT gateways only: Specifies which Availability Zones you want the NAT gateway to support and the Elastic IP addresses (EIPs) to use in each AZ. The regional NAT gateway uses these EIPs to handle outbound NAT traffic from their respective AZs. If not specified, the NAT gateway will automatically expand to new AZs and associate EIPs upon detection of an elastic network interface. If you specify this parameter, auto-expansion is disabled and you must manually manage AZ coverage.

A regional NAT gateway is a single NAT Gateway that works across multiple availability zones (AZs) in your VPC, providing redundancy, scalability and availability across all the AZs in a Region.

For more information, see [Regional NAT gateways for automatic multi-AZ expansion] in the *Amazon VPC User Guide*.

[1]: docs.aws.amazon.com/vpc/latest/userguide/nat-gateways-regional.html

Returns:



12660
12661
12662
12663
12664
12665
12666
12667
12668
12669
12670
12671
12672
12673
12674
12675
12676
# File 'lib/aws-sdk-ec2/types.rb', line 12660

class CreateNatGatewayRequest < Struct.new(
  :availability_mode,
  :allocation_id,
  :client_token,
  :dry_run,
  :subnet_id,
  :vpc_id,
  :availability_zone_addresses,
  :tag_specifications,
  :connectivity_type,
  :private_ip_address,
  :secondary_allocation_ids,
  :secondary_private_ip_addresses,
  :secondary_private_ip_address_count)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [Ensuring idempotency].

Constraint: Maximum 64 ASCII characters.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html

Returns:

  • (String)


12660
12661
12662
12663
12664
12665
12666
12667
12668
12669
12670
12671
12672
12673
12674
12675
12676
# File 'lib/aws-sdk-ec2/types.rb', line 12660

class CreateNatGatewayRequest < Struct.new(
  :availability_mode,
  :allocation_id,
  :client_token,
  :dry_run,
  :subnet_id,
  :vpc_id,
  :availability_zone_addresses,
  :tag_specifications,
  :connectivity_type,
  :private_ip_address,
  :secondary_allocation_ids,
  :secondary_private_ip_addresses,
  :secondary_private_ip_address_count)
  SENSITIVE = []
  include Aws::Structure
end

#connectivity_typeString

Indicates whether the NAT gateway supports public or private connectivity. The default is public connectivity.

Returns:

  • (String)


12660
12661
12662
12663
12664
12665
12666
12667
12668
12669
12670
12671
12672
12673
12674
12675
12676
# File 'lib/aws-sdk-ec2/types.rb', line 12660

class CreateNatGatewayRequest < Struct.new(
  :availability_mode,
  :allocation_id,
  :client_token,
  :dry_run,
  :subnet_id,
  :vpc_id,
  :availability_zone_addresses,
  :tag_specifications,
  :connectivity_type,
  :private_ip_address,
  :secondary_allocation_ids,
  :secondary_private_ip_addresses,
  :secondary_private_ip_address_count)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


12660
12661
12662
12663
12664
12665
12666
12667
12668
12669
12670
12671
12672
12673
12674
12675
12676
# File 'lib/aws-sdk-ec2/types.rb', line 12660

class CreateNatGatewayRequest < Struct.new(
  :availability_mode,
  :allocation_id,
  :client_token,
  :dry_run,
  :subnet_id,
  :vpc_id,
  :availability_zone_addresses,
  :tag_specifications,
  :connectivity_type,
  :private_ip_address,
  :secondary_allocation_ids,
  :secondary_private_ip_addresses,
  :secondary_private_ip_address_count)
  SENSITIVE = []
  include Aws::Structure
end

#private_ip_addressString

The private IPv4 address to assign to the NAT gateway. If you don’t provide an address, a private IPv4 address will be automatically assigned.

Returns:

  • (String)


12660
12661
12662
12663
12664
12665
12666
12667
12668
12669
12670
12671
12672
12673
12674
12675
12676
# File 'lib/aws-sdk-ec2/types.rb', line 12660

class CreateNatGatewayRequest < Struct.new(
  :availability_mode,
  :allocation_id,
  :client_token,
  :dry_run,
  :subnet_id,
  :vpc_id,
  :availability_zone_addresses,
  :tag_specifications,
  :connectivity_type,
  :private_ip_address,
  :secondary_allocation_ids,
  :secondary_private_ip_addresses,
  :secondary_private_ip_address_count)
  SENSITIVE = []
  include Aws::Structure
end

#secondary_allocation_idsArray<String>

Secondary EIP allocation IDs. For more information, see [Create a NAT gateway] in the *Amazon VPC User Guide*.

[1]: docs.aws.amazon.com/vpc/latest/userguide/nat-gateway-working-with.html

Returns:

  • (Array<String>)


12660
12661
12662
12663
12664
12665
12666
12667
12668
12669
12670
12671
12672
12673
12674
12675
12676
# File 'lib/aws-sdk-ec2/types.rb', line 12660

class CreateNatGatewayRequest < Struct.new(
  :availability_mode,
  :allocation_id,
  :client_token,
  :dry_run,
  :subnet_id,
  :vpc_id,
  :availability_zone_addresses,
  :tag_specifications,
  :connectivity_type,
  :private_ip_address,
  :secondary_allocation_ids,
  :secondary_private_ip_addresses,
  :secondary_private_ip_address_count)
  SENSITIVE = []
  include Aws::Structure
end

#secondary_private_ip_address_countInteger

[Private NAT gateway only] The number of secondary private IPv4 addresses you want to assign to the NAT gateway. For more information about secondary addresses, see [Create a NAT gateway] in the *Amazon VPC User Guide*.

[1]: docs.aws.amazon.com/vpc/latest/userguide/nat-gateway-working-with.html

Returns:

  • (Integer)


12660
12661
12662
12663
12664
12665
12666
12667
12668
12669
12670
12671
12672
12673
12674
12675
12676
# File 'lib/aws-sdk-ec2/types.rb', line 12660

class CreateNatGatewayRequest < Struct.new(
  :availability_mode,
  :allocation_id,
  :client_token,
  :dry_run,
  :subnet_id,
  :vpc_id,
  :availability_zone_addresses,
  :tag_specifications,
  :connectivity_type,
  :private_ip_address,
  :secondary_allocation_ids,
  :secondary_private_ip_addresses,
  :secondary_private_ip_address_count)
  SENSITIVE = []
  include Aws::Structure
end

#secondary_private_ip_addressesArray<String>

Secondary private IPv4 addresses. For more information about secondary addresses, see [Create a NAT gateway] in the *Amazon VPC User Guide*.

[1]: docs.aws.amazon.com/vpc/latest/userguide/nat-gateway-working-with.html

Returns:

  • (Array<String>)


12660
12661
12662
12663
12664
12665
12666
12667
12668
12669
12670
12671
12672
12673
12674
12675
12676
# File 'lib/aws-sdk-ec2/types.rb', line 12660

class CreateNatGatewayRequest < Struct.new(
  :availability_mode,
  :allocation_id,
  :client_token,
  :dry_run,
  :subnet_id,
  :vpc_id,
  :availability_zone_addresses,
  :tag_specifications,
  :connectivity_type,
  :private_ip_address,
  :secondary_allocation_ids,
  :secondary_private_ip_addresses,
  :secondary_private_ip_address_count)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idString

The ID of the subnet in which to create the NAT gateway.

Returns:

  • (String)


12660
12661
12662
12663
12664
12665
12666
12667
12668
12669
12670
12671
12672
12673
12674
12675
12676
# File 'lib/aws-sdk-ec2/types.rb', line 12660

class CreateNatGatewayRequest < Struct.new(
  :availability_mode,
  :allocation_id,
  :client_token,
  :dry_run,
  :subnet_id,
  :vpc_id,
  :availability_zone_addresses,
  :tag_specifications,
  :connectivity_type,
  :private_ip_address,
  :secondary_allocation_ids,
  :secondary_private_ip_addresses,
  :secondary_private_ip_address_count)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to assign to the NAT gateway.

Returns:



12660
12661
12662
12663
12664
12665
12666
12667
12668
12669
12670
12671
12672
12673
12674
12675
12676
# File 'lib/aws-sdk-ec2/types.rb', line 12660

class CreateNatGatewayRequest < Struct.new(
  :availability_mode,
  :allocation_id,
  :client_token,
  :dry_run,
  :subnet_id,
  :vpc_id,
  :availability_zone_addresses,
  :tag_specifications,
  :connectivity_type,
  :private_ip_address,
  :secondary_allocation_ids,
  :secondary_private_ip_addresses,
  :secondary_private_ip_address_count)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC where you want to create a regional NAT gateway.

Returns:

  • (String)


12660
12661
12662
12663
12664
12665
12666
12667
12668
12669
12670
12671
12672
12673
12674
12675
12676
# File 'lib/aws-sdk-ec2/types.rb', line 12660

class CreateNatGatewayRequest < Struct.new(
  :availability_mode,
  :allocation_id,
  :client_token,
  :dry_run,
  :subnet_id,
  :vpc_id,
  :availability_zone_addresses,
  :tag_specifications,
  :connectivity_type,
  :private_ip_address,
  :secondary_allocation_ids,
  :secondary_private_ip_addresses,
  :secondary_private_ip_address_count)
  SENSITIVE = []
  include Aws::Structure
end