Class: Aws::EC2::Types::CreateNetworkAclEntryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cidr_blockString

The IPv4 network range to allow or deny, in CIDR notation (for example 172.16.0.0/24). We modify the specified CIDR block to its canonical form; for example, if you specify 100.68.0.18/18, we modify it to 100.68.0.0/18.

Returns:

  • (String)


13972
13973
13974
13975
13976
13977
13978
13979
13980
13981
13982
13983
13984
13985
# File 'lib/aws-sdk-ec2/types.rb', line 13972

class CreateNetworkAclEntryRequest < Struct.new(
  :dry_run,
  :network_acl_id,
  :rule_number,
  :protocol,
  :rule_action,
  :egress,
  :cidr_block,
  :ipv_6_cidr_block,
  :icmp_type_code,
  :port_range)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


13972
13973
13974
13975
13976
13977
13978
13979
13980
13981
13982
13983
13984
13985
# File 'lib/aws-sdk-ec2/types.rb', line 13972

class CreateNetworkAclEntryRequest < Struct.new(
  :dry_run,
  :network_acl_id,
  :rule_number,
  :protocol,
  :rule_action,
  :egress,
  :cidr_block,
  :ipv_6_cidr_block,
  :icmp_type_code,
  :port_range)
  SENSITIVE = []
  include Aws::Structure
end

#egressBoolean

Indicates whether this is an egress rule (rule is applied to traffic leaving the subnet).

Returns:

  • (Boolean)


13972
13973
13974
13975
13976
13977
13978
13979
13980
13981
13982
13983
13984
13985
# File 'lib/aws-sdk-ec2/types.rb', line 13972

class CreateNetworkAclEntryRequest < Struct.new(
  :dry_run,
  :network_acl_id,
  :rule_number,
  :protocol,
  :rule_action,
  :egress,
  :cidr_block,
  :ipv_6_cidr_block,
  :icmp_type_code,
  :port_range)
  SENSITIVE = []
  include Aws::Structure
end

#icmp_type_codeTypes::IcmpTypeCode

ICMP protocol: The ICMP or ICMPv6 type and code. Required if specifying protocol 1 (ICMP) or protocol 58 (ICMPv6) with an IPv6 CIDR block.

Returns:



13972
13973
13974
13975
13976
13977
13978
13979
13980
13981
13982
13983
13984
13985
# File 'lib/aws-sdk-ec2/types.rb', line 13972

class CreateNetworkAclEntryRequest < Struct.new(
  :dry_run,
  :network_acl_id,
  :rule_number,
  :protocol,
  :rule_action,
  :egress,
  :cidr_block,
  :ipv_6_cidr_block,
  :icmp_type_code,
  :port_range)
  SENSITIVE = []
  include Aws::Structure
end

#ipv_6_cidr_blockString

The IPv6 network range to allow or deny, in CIDR notation (for example 2001:db8:1234:1a00::/64).

Returns:

  • (String)


13972
13973
13974
13975
13976
13977
13978
13979
13980
13981
13982
13983
13984
13985
# File 'lib/aws-sdk-ec2/types.rb', line 13972

class CreateNetworkAclEntryRequest < Struct.new(
  :dry_run,
  :network_acl_id,
  :rule_number,
  :protocol,
  :rule_action,
  :egress,
  :cidr_block,
  :ipv_6_cidr_block,
  :icmp_type_code,
  :port_range)
  SENSITIVE = []
  include Aws::Structure
end

#network_acl_idString

The ID of the network ACL.

Returns:

  • (String)


13972
13973
13974
13975
13976
13977
13978
13979
13980
13981
13982
13983
13984
13985
# File 'lib/aws-sdk-ec2/types.rb', line 13972

class CreateNetworkAclEntryRequest < Struct.new(
  :dry_run,
  :network_acl_id,
  :rule_number,
  :protocol,
  :rule_action,
  :egress,
  :cidr_block,
  :ipv_6_cidr_block,
  :icmp_type_code,
  :port_range)
  SENSITIVE = []
  include Aws::Structure
end

#port_rangeTypes::PortRange

TCP or UDP protocols: The range of ports the rule applies to. Required if specifying protocol 6 (TCP) or 17 (UDP).

Returns:



13972
13973
13974
13975
13976
13977
13978
13979
13980
13981
13982
13983
13984
13985
# File 'lib/aws-sdk-ec2/types.rb', line 13972

class CreateNetworkAclEntryRequest < Struct.new(
  :dry_run,
  :network_acl_id,
  :rule_number,
  :protocol,
  :rule_action,
  :egress,
  :cidr_block,
  :ipv_6_cidr_block,
  :icmp_type_code,
  :port_range)
  SENSITIVE = []
  include Aws::Structure
end

#protocolString

The protocol number. A value of "-1" means all protocols. If you specify "-1" or a protocol number other than "6" (TCP), "17" (UDP), or "1" (ICMP), traffic on all ports is allowed, regardless of any ports or ICMP types or codes that you specify. If you specify protocol "58" (ICMPv6) and specify an IPv4 CIDR block, traffic for all ICMP types and codes allowed, regardless of any that you specify. If you specify protocol "58" (ICMPv6) and specify an IPv6 CIDR block, you must specify an ICMP type and code.

Returns:

  • (String)


13972
13973
13974
13975
13976
13977
13978
13979
13980
13981
13982
13983
13984
13985
# File 'lib/aws-sdk-ec2/types.rb', line 13972

class CreateNetworkAclEntryRequest < Struct.new(
  :dry_run,
  :network_acl_id,
  :rule_number,
  :protocol,
  :rule_action,
  :egress,
  :cidr_block,
  :ipv_6_cidr_block,
  :icmp_type_code,
  :port_range)
  SENSITIVE = []
  include Aws::Structure
end

#rule_actionString

Indicates whether to allow or deny the traffic that matches the rule.

Returns:

  • (String)


13972
13973
13974
13975
13976
13977
13978
13979
13980
13981
13982
13983
13984
13985
# File 'lib/aws-sdk-ec2/types.rb', line 13972

class CreateNetworkAclEntryRequest < Struct.new(
  :dry_run,
  :network_acl_id,
  :rule_number,
  :protocol,
  :rule_action,
  :egress,
  :cidr_block,
  :ipv_6_cidr_block,
  :icmp_type_code,
  :port_range)
  SENSITIVE = []
  include Aws::Structure
end

#rule_numberInteger

The rule number for the entry (for example, 100). ACL entries are processed in ascending order by rule number.

Constraints: Positive integer from 1 to 32766. The range 32767 to 65535 is reserved for internal use.

Returns:

  • (Integer)


13972
13973
13974
13975
13976
13977
13978
13979
13980
13981
13982
13983
13984
13985
# File 'lib/aws-sdk-ec2/types.rb', line 13972

class CreateNetworkAclEntryRequest < Struct.new(
  :dry_run,
  :network_acl_id,
  :rule_number,
  :protocol,
  :rule_action,
  :egress,
  :cidr_block,
  :ipv_6_cidr_block,
  :icmp_type_code,
  :port_range)
  SENSITIVE = []
  include Aws::Structure
end