Class: Aws::EC2::Types::CreateNetworkInterfacePermissionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateNetworkInterfacePermissionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for CreateNetworkInterfacePermission.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The Amazon Web Services account ID.
-
#aws_service ⇒ String
The Amazon Web Services service.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#network_interface_id ⇒ String
The ID of the network interface.
-
#permission ⇒ String
The type of permission to grant.
Instance Attribute Details
#aws_account_id ⇒ String
The Amazon Web Services account ID.
14218 14219 14220 14221 14222 14223 14224 14225 14226 |
# File 'lib/aws-sdk-ec2/types.rb', line 14218 class CreateNetworkInterfacePermissionRequest < Struct.new( :network_interface_id, :aws_account_id, :aws_service, :permission, :dry_run) SENSITIVE = [] include Aws::Structure end |
#aws_service ⇒ String
The Amazon Web Services service. Currently not supported.
14218 14219 14220 14221 14222 14223 14224 14225 14226 |
# File 'lib/aws-sdk-ec2/types.rb', line 14218 class CreateNetworkInterfacePermissionRequest < Struct.new( :network_interface_id, :aws_account_id, :aws_service, :permission, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
14218 14219 14220 14221 14222 14223 14224 14225 14226 |
# File 'lib/aws-sdk-ec2/types.rb', line 14218 class CreateNetworkInterfacePermissionRequest < Struct.new( :network_interface_id, :aws_account_id, :aws_service, :permission, :dry_run) SENSITIVE = [] include Aws::Structure end |
#network_interface_id ⇒ String
The ID of the network interface.
14218 14219 14220 14221 14222 14223 14224 14225 14226 |
# File 'lib/aws-sdk-ec2/types.rb', line 14218 class CreateNetworkInterfacePermissionRequest < Struct.new( :network_interface_id, :aws_account_id, :aws_service, :permission, :dry_run) SENSITIVE = [] include Aws::Structure end |
#permission ⇒ String
The type of permission to grant.
14218 14219 14220 14221 14222 14223 14224 14225 14226 |
# File 'lib/aws-sdk-ec2/types.rb', line 14218 class CreateNetworkInterfacePermissionRequest < Struct.new( :network_interface_id, :aws_account_id, :aws_service, :permission, :dry_run) SENSITIVE = [] include Aws::Structure end |