Class: Aws::EC2::Types::CreatePublicIpv4PoolRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


13543
13544
13545
13546
13547
13548
13549
# File 'lib/aws-sdk-ec2/types.rb', line 13543

class CreatePublicIpv4PoolRequest < Struct.new(
  :dry_run,
  :tag_specifications,
  :network_border_group)
  SENSITIVE = []
  include Aws::Structure
end

#network_border_groupString

The Availability Zone (AZ) or Local Zone (LZ) network border group that the resource that the IP address is assigned to is in. Defaults to an AZ network border group. For more information on available Local Zones, see [Local Zone availability] in the *Amazon EC2 User Guide*.

[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-byoip.html#byoip-zone-avail

Returns:

  • (String)


13543
13544
13545
13546
13547
13548
13549
# File 'lib/aws-sdk-ec2/types.rb', line 13543

class CreatePublicIpv4PoolRequest < Struct.new(
  :dry_run,
  :tag_specifications,
  :network_border_group)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key ‘Owner` and the value `TeamA`, specify `tag:Owner` for the filter name and `TeamA` for the filter value.

Returns:



13543
13544
13545
13546
13547
13548
13549
# File 'lib/aws-sdk-ec2/types.rb', line 13543

class CreatePublicIpv4PoolRequest < Struct.new(
  :dry_run,
  :tag_specifications,
  :network_border_group)
  SENSITIVE = []
  include Aws::Structure
end