Class: Aws::EC2::Types::CreateReplaceRootVolumeTaskRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier you provide to ensure the idempotency of the request. If you do not specify a client token, a randomly generated token is used for the request to ensure idempotency. For more information, see Ensuring idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


13834
13835
13836
13837
13838
13839
13840
13841
13842
13843
13844
13845
13846
# File 'lib/aws-sdk-ec2/types.rb', line 13834

class CreateReplaceRootVolumeTaskRequest < Struct.new(
  :instance_id,
  :snapshot_id,
  :client_token,
  :dry_run,
  :tag_specifications,
  :image_id,
  :delete_replaced_root_volume,
  :volume_initialization_rate,
  :volume_id)
  SENSITIVE = []
  include Aws::Structure
end

#delete_replaced_root_volumeBoolean

Indicates whether to automatically delete the original root volume after the root volume replacement task completes. To delete the original root volume, specify true. If you choose to keep the original root volume after the replacement task completes, you must manually delete it when you no longer need it.

Returns:

  • (Boolean)


13834
13835
13836
13837
13838
13839
13840
13841
13842
13843
13844
13845
13846
# File 'lib/aws-sdk-ec2/types.rb', line 13834

class CreateReplaceRootVolumeTaskRequest < Struct.new(
  :instance_id,
  :snapshot_id,
  :client_token,
  :dry_run,
  :tag_specifications,
  :image_id,
  :delete_replaced_root_volume,
  :volume_initialization_rate,
  :volume_id)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


13834
13835
13836
13837
13838
13839
13840
13841
13842
13843
13844
13845
13846
# File 'lib/aws-sdk-ec2/types.rb', line 13834

class CreateReplaceRootVolumeTaskRequest < Struct.new(
  :instance_id,
  :snapshot_id,
  :client_token,
  :dry_run,
  :tag_specifications,
  :image_id,
  :delete_replaced_root_volume,
  :volume_initialization_rate,
  :volume_id)
  SENSITIVE = []
  include Aws::Structure
end

#image_idString

The ID of the AMI to use to restore the root volume. The specified AMI must have the same product code, billing information, architecture type, and virtualization type as that of the instance.

If you want to restore the replacement volume from a specific snapshot, if you want to restore it to its launch state, or if you want to replace the root volume with a specified volume, omit this parameter.

Returns:

  • (String)


13834
13835
13836
13837
13838
13839
13840
13841
13842
13843
13844
13845
13846
# File 'lib/aws-sdk-ec2/types.rb', line 13834

class CreateReplaceRootVolumeTaskRequest < Struct.new(
  :instance_id,
  :snapshot_id,
  :client_token,
  :dry_run,
  :tag_specifications,
  :image_id,
  :delete_replaced_root_volume,
  :volume_initialization_rate,
  :volume_id)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The ID of the instance for which to replace the root volume.

Returns:

  • (String)


13834
13835
13836
13837
13838
13839
13840
13841
13842
13843
13844
13845
13846
# File 'lib/aws-sdk-ec2/types.rb', line 13834

class CreateReplaceRootVolumeTaskRequest < Struct.new(
  :instance_id,
  :snapshot_id,
  :client_token,
  :dry_run,
  :tag_specifications,
  :image_id,
  :delete_replaced_root_volume,
  :volume_initialization_rate,
  :volume_id)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_idString

The ID of the snapshot from which to restore the replacement root volume. The specified snapshot must be a snapshot that you previously created from the original root volume.

If you want to restore the replacement root volume to the initial launch state, if you want to restore the replacement root volume from an AMI, or if you want to replace the root volume with a specified volume, omit this parameter.

Returns:

  • (String)


13834
13835
13836
13837
13838
13839
13840
13841
13842
13843
13844
13845
13846
# File 'lib/aws-sdk-ec2/types.rb', line 13834

class CreateReplaceRootVolumeTaskRequest < Struct.new(
  :instance_id,
  :snapshot_id,
  :client_token,
  :dry_run,
  :tag_specifications,
  :image_id,
  :delete_replaced_root_volume,
  :volume_initialization_rate,
  :volume_id)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the root volume replacement task.

Returns:



13834
13835
13836
13837
13838
13839
13840
13841
13842
13843
13844
13845
13846
# File 'lib/aws-sdk-ec2/types.rb', line 13834

class CreateReplaceRootVolumeTaskRequest < Struct.new(
  :instance_id,
  :snapshot_id,
  :client_token,
  :dry_run,
  :tag_specifications,
  :image_id,
  :delete_replaced_root_volume,
  :volume_initialization_rate,
  :volume_id)
  SENSITIVE = []
  include Aws::Structure
end

#volume_idString

The ID of the volume to use as the replacement root volume. The specified volume must be in the same Availability Zone as the instance, must be in the available state, and must not be attached to an instance. If the original root volume is encrypted, the specified volume must also be encrypted.

If you want to restore the replacement root volume from a specific snapshot, an AMI, or to its launch state, omit this parameter.

Returns:

  • (String)


13834
13835
13836
13837
13838
13839
13840
13841
13842
13843
13844
13845
13846
# File 'lib/aws-sdk-ec2/types.rb', line 13834

class CreateReplaceRootVolumeTaskRequest < Struct.new(
  :instance_id,
  :snapshot_id,
  :client_token,
  :dry_run,
  :tag_specifications,
  :image_id,
  :delete_replaced_root_volume,
  :volume_initialization_rate,
  :volume_id)
  SENSITIVE = []
  include Aws::Structure
end

#volume_initialization_rateInteger

Specifies the Amazon EBS Provisioned Rate for Volume Initialization (volume initialization rate), in MiB/s, at which to download the snapshot blocks from Amazon S3 to the replacement root volume. This is also known as volume initialization. Specifying a volume initialization rate ensures that the volume is initialized at a predictable and consistent rate after creation.

Omit this parameter if:

  • You want to create the volume using fast snapshot restore. You must specify a snapshot that is enabled for fast snapshot restore. In this case, the volume is fully initialized at creation.

    If you specify a snapshot that is enabled for fast snapshot restore and a volume initialization rate, the volume will be initialized at the specified rate instead of fast snapshot restore.

  • You want to create a volume that is initialized at the default rate.

For more information, see Initialize Amazon EBS volumes in the Amazon EC2 User Guide.

Valid range: 100 - 300 MiB/s

Returns:

  • (Integer)


13834
13835
13836
13837
13838
13839
13840
13841
13842
13843
13844
13845
13846
# File 'lib/aws-sdk-ec2/types.rb', line 13834

class CreateReplaceRootVolumeTaskRequest < Struct.new(
  :instance_id,
  :snapshot_id,
  :client_token,
  :dry_run,
  :tag_specifications,
  :image_id,
  :delete_replaced_root_volume,
  :volume_initialization_rate,
  :volume_id)
  SENSITIVE = []
  include Aws::Structure
end