Class: Aws::EC2::Types::CreateSecondaryNetworkResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier to ensure the idempotency of the request. Only returned if a client token was provided in the request.

Returns:

  • (String)


13812
13813
13814
13815
13816
13817
# File 'lib/aws-sdk-ec2/types.rb', line 13812

class CreateSecondaryNetworkResult < Struct.new(
  :secondary_network,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#secondary_networkTypes::SecondaryNetwork

Information about the secondary network.



13812
13813
13814
13815
13816
13817
# File 'lib/aws-sdk-ec2/types.rb', line 13812

class CreateSecondaryNetworkResult < Struct.new(
  :secondary_network,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end