Class: Aws::EC2::Types::CreateSecondarySubnetResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier to ensure the idempotency of the request. Only returned if a client token was provided in the request.

Returns:

  • (String)


13893
13894
13895
13896
13897
13898
# File 'lib/aws-sdk-ec2/types.rb', line 13893

class CreateSecondarySubnetResult < Struct.new(
  :secondary_subnet,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#secondary_subnetTypes::SecondarySubnet

Information about the secondary subnet.



13893
13894
13895
13896
13897
13898
# File 'lib/aws-sdk-ec2/types.rb', line 13893

class CreateSecondarySubnetResult < Struct.new(
  :secondary_subnet,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end