Class: Aws::EC2::Types::CreateSnapshotRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description for the snapshot.

Returns:

  • (String)


15426
15427
15428
15429
15430
15431
15432
15433
15434
15435
# File 'lib/aws-sdk-ec2/types.rb', line 15426

class CreateSnapshotRequest < Struct.new(
  :description,
  :outpost_arn,
  :volume_id,
  :tag_specifications,
  :location,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


15426
15427
15428
15429
15430
15431
15432
15433
15434
15435
# File 'lib/aws-sdk-ec2/types.rb', line 15426

class CreateSnapshotRequest < Struct.new(
  :description,
  :outpost_arn,
  :volume_id,
  :tag_specifications,
  :location,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#locationString

Only supported for volumes in Local Zones. If the source volume is not in a Local Zone, omit this parameter.

  • To create a local snapshot in the same Local Zone as the source volume, specify local.

  • To create a regional snapshot in the parent Region of the Local Zone, specify regional or omit this parameter.

Default value: regional

Returns:

  • (String)


15426
15427
15428
15429
15430
15431
15432
15433
15434
15435
# File 'lib/aws-sdk-ec2/types.rb', line 15426

class CreateSnapshotRequest < Struct.new(
  :description,
  :outpost_arn,
  :volume_id,
  :tag_specifications,
  :location,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#outpost_arnString

Only supported for volumes on Outposts. If the source volume is not on an Outpost, omit this parameter.

  • To create the snapshot on the same Outpost as the source volume, specify the ARN of that Outpost. The snapshot must be created on the same Outpost as the volume.

  • To create the snapshot in the parent Region of the Outpost, omit this parameter.

For more information, see Create local snapshots from volumes on an Outpost in the Amazon EBS User Guide.

Returns:

  • (String)


15426
15427
15428
15429
15430
15431
15432
15433
15434
15435
# File 'lib/aws-sdk-ec2/types.rb', line 15426

class CreateSnapshotRequest < Struct.new(
  :description,
  :outpost_arn,
  :volume_id,
  :tag_specifications,
  :location,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the snapshot during creation.

Returns:



15426
15427
15428
15429
15430
15431
15432
15433
15434
15435
# File 'lib/aws-sdk-ec2/types.rb', line 15426

class CreateSnapshotRequest < Struct.new(
  :description,
  :outpost_arn,
  :volume_id,
  :tag_specifications,
  :location,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#volume_idString

The ID of the Amazon EBS volume.

Returns:

  • (String)


15426
15427
15428
15429
15430
15431
15432
15433
15434
15435
# File 'lib/aws-sdk-ec2/types.rb', line 15426

class CreateSnapshotRequest < Struct.new(
  :description,
  :outpost_arn,
  :volume_id,
  :tag_specifications,
  :location,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end