Class: Aws::EC2::Types::CreateSnapshotsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#copy_tags_from_sourceString

Copies the tags from the specified volume to corresponding snapshot.

Returns:

  • (String)


14100
14101
14102
14103
14104
14105
14106
14107
14108
14109
14110
# File 'lib/aws-sdk-ec2/types.rb', line 14100

class CreateSnapshotsRequest < Struct.new(
  :description,
  :instance_specification,
  :outpost_arn,
  :tag_specifications,
  :dry_run,
  :copy_tags_from_source,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description propagated to every snapshot specified by the instance.

Returns:

  • (String)


14100
14101
14102
14103
14104
14105
14106
14107
14108
14109
14110
# File 'lib/aws-sdk-ec2/types.rb', line 14100

class CreateSnapshotsRequest < Struct.new(
  :description,
  :instance_specification,
  :outpost_arn,
  :tag_specifications,
  :dry_run,
  :copy_tags_from_source,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


14100
14101
14102
14103
14104
14105
14106
14107
14108
14109
14110
# File 'lib/aws-sdk-ec2/types.rb', line 14100

class CreateSnapshotsRequest < Struct.new(
  :description,
  :instance_specification,
  :outpost_arn,
  :tag_specifications,
  :dry_run,
  :copy_tags_from_source,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#instance_specificationTypes::InstanceSpecification

The instance to specify which volumes should be included in the snapshots.



14100
14101
14102
14103
14104
14105
14106
14107
14108
14109
14110
# File 'lib/aws-sdk-ec2/types.rb', line 14100

class CreateSnapshotsRequest < Struct.new(
  :description,
  :instance_specification,
  :outpost_arn,
  :tag_specifications,
  :dry_run,
  :copy_tags_from_source,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#locationString

<note markdown=“1”> Only supported for instances in Local Zones. If the source instance is not in a Local Zone, omit this parameter.

</note>
  • To create local snapshots in the same Local Zone as the source instance, specify ‘local`.

  • To create regional snapshots in the parent Region of the Local Zone, specify ‘regional` or omit this parameter.

Default value: ‘regional`

Returns:

  • (String)


14100
14101
14102
14103
14104
14105
14106
14107
14108
14109
14110
# File 'lib/aws-sdk-ec2/types.rb', line 14100

class CreateSnapshotsRequest < Struct.new(
  :description,
  :instance_specification,
  :outpost_arn,
  :tag_specifications,
  :dry_run,
  :copy_tags_from_source,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#outpost_arnString

<note markdown=“1”> Only supported for instances on Outposts. If the source instance is not on an Outpost, omit this parameter.

</note>
  • To create the snapshots on the same Outpost as the source instance, specify the ARN of that Outpost. The snapshots must be created on the same Outpost as the instance.

  • To create the snapshots in the parent Region of the Outpost, omit this parameter.

For more information, see [ Create local snapshots from volumes on an Outpost] in the *Amazon EBS User Guide*.

[1]: docs.aws.amazon.com/ebs/latest/userguide/snapshots-outposts.html#create-snapshot

Returns:

  • (String)


14100
14101
14102
14103
14104
14105
14106
14107
14108
14109
14110
# File 'lib/aws-sdk-ec2/types.rb', line 14100

class CreateSnapshotsRequest < Struct.new(
  :description,
  :instance_specification,
  :outpost_arn,
  :tag_specifications,
  :dry_run,
  :copy_tags_from_source,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

Tags to apply to every snapshot specified by the instance.

Returns:



14100
14101
14102
14103
14104
14105
14106
14107
14108
14109
14110
# File 'lib/aws-sdk-ec2/types.rb', line 14100

class CreateSnapshotsRequest < Struct.new(
  :description,
  :instance_specification,
  :outpost_arn,
  :tag_specifications,
  :dry_run,
  :copy_tags_from_source,
  :location)
  SENSITIVE = []
  include Aws::Structure
end