Class: Aws::EC2::Types::CreateSubnetCidrReservationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cidrString

The IPv4 or IPV6 CIDR range to reserve.

Returns:

  • (String)


15653
15654
15655
15656
15657
15658
15659
15660
15661
15662
# File 'lib/aws-sdk-ec2/types.rb', line 15653

class CreateSubnetCidrReservationRequest < Struct.new(
  :subnet_id,
  :cidr,
  :reservation_type,
  :description,
  :dry_run,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description to assign to the subnet CIDR reservation.

Returns:

  • (String)


15653
15654
15655
15656
15657
15658
15659
15660
15661
15662
# File 'lib/aws-sdk-ec2/types.rb', line 15653

class CreateSubnetCidrReservationRequest < Struct.new(
  :subnet_id,
  :cidr,
  :reservation_type,
  :description,
  :dry_run,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


15653
15654
15655
15656
15657
15658
15659
15660
15661
15662
# File 'lib/aws-sdk-ec2/types.rb', line 15653

class CreateSubnetCidrReservationRequest < Struct.new(
  :subnet_id,
  :cidr,
  :reservation_type,
  :description,
  :dry_run,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#reservation_typeString

The type of reservation. The reservation type determines how the reserved IP addresses are assigned to resources.

  • prefix - Amazon Web Services assigns the reserved IP addresses to network interfaces.

  • explicit - You assign the reserved IP addresses to network interfaces.

Returns:

  • (String)


15653
15654
15655
15656
15657
15658
15659
15660
15661
15662
# File 'lib/aws-sdk-ec2/types.rb', line 15653

class CreateSubnetCidrReservationRequest < Struct.new(
  :subnet_id,
  :cidr,
  :reservation_type,
  :description,
  :dry_run,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idString

The ID of the subnet.

Returns:

  • (String)


15653
15654
15655
15656
15657
15658
15659
15660
15661
15662
# File 'lib/aws-sdk-ec2/types.rb', line 15653

class CreateSubnetCidrReservationRequest < Struct.new(
  :subnet_id,
  :cidr,
  :reservation_type,
  :description,
  :dry_run,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to assign to the subnet CIDR reservation.

Returns:



15653
15654
15655
15656
15657
15658
15659
15660
15661
15662
# File 'lib/aws-sdk-ec2/types.rb', line 15653

class CreateSubnetCidrReservationRequest < Struct.new(
  :subnet_id,
  :cidr,
  :reservation_type,
  :description,
  :dry_run,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end