Class: Aws::EC2::Types::CreateTransitGatewayConnectPeerRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bgp_optionsTypes::TransitGatewayConnectRequestBgpOptions

The BGP options for the Connect peer.



15219
15220
15221
15222
15223
15224
15225
15226
15227
15228
15229
# File 'lib/aws-sdk-ec2/types.rb', line 15219

class CreateTransitGatewayConnectPeerRequest < Struct.new(
  :transit_gateway_attachment_id,
  :transit_gateway_address,
  :peer_address,
  :bgp_options,
  :inside_cidr_blocks,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


15219
15220
15221
15222
15223
15224
15225
15226
15227
15228
15229
# File 'lib/aws-sdk-ec2/types.rb', line 15219

class CreateTransitGatewayConnectPeerRequest < Struct.new(
  :transit_gateway_attachment_id,
  :transit_gateway_address,
  :peer_address,
  :bgp_options,
  :inside_cidr_blocks,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#inside_cidr_blocksArray<String>

The range of inside IP addresses that are used for BGP peering. You must specify a size /29 IPv4 CIDR block from the ‘169.254.0.0/16` range. The first address from the range must be configured on the appliance as the BGP IP address. You can also optionally specify a size /125 IPv6 CIDR block from the `fd00::/8` range.

Returns:

  • (Array<String>)


15219
15220
15221
15222
15223
15224
15225
15226
15227
15228
15229
# File 'lib/aws-sdk-ec2/types.rb', line 15219

class CreateTransitGatewayConnectPeerRequest < Struct.new(
  :transit_gateway_attachment_id,
  :transit_gateway_address,
  :peer_address,
  :bgp_options,
  :inside_cidr_blocks,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#peer_addressString

The peer IP address (GRE outer IP address) on the appliance side of the Connect peer.

Returns:

  • (String)


15219
15220
15221
15222
15223
15224
15225
15226
15227
15228
15229
# File 'lib/aws-sdk-ec2/types.rb', line 15219

class CreateTransitGatewayConnectPeerRequest < Struct.new(
  :transit_gateway_attachment_id,
  :transit_gateway_address,
  :peer_address,
  :bgp_options,
  :inside_cidr_blocks,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the Connect peer.

Returns:



15219
15220
15221
15222
15223
15224
15225
15226
15227
15228
15229
# File 'lib/aws-sdk-ec2/types.rb', line 15219

class CreateTransitGatewayConnectPeerRequest < Struct.new(
  :transit_gateway_attachment_id,
  :transit_gateway_address,
  :peer_address,
  :bgp_options,
  :inside_cidr_blocks,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_addressString

The peer IP address (GRE outer IP address) on the transit gateway side of the Connect peer, which must be specified from a transit gateway CIDR block. If not specified, Amazon automatically assigns the first available IP address from the transit gateway CIDR block.

Returns:

  • (String)


15219
15220
15221
15222
15223
15224
15225
15226
15227
15228
15229
# File 'lib/aws-sdk-ec2/types.rb', line 15219

class CreateTransitGatewayConnectPeerRequest < Struct.new(
  :transit_gateway_attachment_id,
  :transit_gateway_address,
  :peer_address,
  :bgp_options,
  :inside_cidr_blocks,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_attachment_idString

The ID of the Connect attachment.

Returns:

  • (String)


15219
15220
15221
15222
15223
15224
15225
15226
15227
15228
15229
# File 'lib/aws-sdk-ec2/types.rb', line 15219

class CreateTransitGatewayConnectPeerRequest < Struct.new(
  :transit_gateway_attachment_id,
  :transit_gateway_address,
  :peer_address,
  :bgp_options,
  :inside_cidr_blocks,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end