Class: Aws::EC2::Types::CreateTransitGatewayMulticastDomainRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


16488
16489
16490
16491
16492
16493
16494
16495
# File 'lib/aws-sdk-ec2/types.rb', line 16488

class CreateTransitGatewayMulticastDomainRequest < Struct.new(
  :transit_gateway_id,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#optionsTypes::CreateTransitGatewayMulticastDomainRequestOptions

The options for the transit gateway multicast domain.



16488
16489
16490
16491
16492
16493
16494
16495
# File 'lib/aws-sdk-ec2/types.rb', line 16488

class CreateTransitGatewayMulticastDomainRequest < Struct.new(
  :transit_gateway_id,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags for the transit gateway multicast domain.

Returns:



16488
16489
16490
16491
16492
16493
16494
16495
# File 'lib/aws-sdk-ec2/types.rb', line 16488

class CreateTransitGatewayMulticastDomainRequest < Struct.new(
  :transit_gateway_id,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_idString

The ID of the transit gateway.

Returns:

  • (String)


16488
16489
16490
16491
16492
16493
16494
16495
# File 'lib/aws-sdk-ec2/types.rb', line 16488

class CreateTransitGatewayMulticastDomainRequest < Struct.new(
  :transit_gateway_id,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end