Class: Aws::EC2::Types::CreateTransitGatewayPeeringAttachmentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateTransitGatewayPeeringAttachmentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#options ⇒ Types::CreateTransitGatewayPeeringAttachmentRequestOptions
Requests a transit gateway peering attachment.
-
#peer_account_id ⇒ String
The ID of the Amazon Web Services account that owns the peer transit gateway.
-
#peer_region ⇒ String
The Region where the peer transit gateway is located.
-
#peer_transit_gateway_id ⇒ String
The ID of the peer transit gateway with which to create the peering attachment.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the transit gateway peering attachment.
-
#transit_gateway_id ⇒ String
The ID of the transit gateway.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
16337 16338 16339 16340 16341 16342 16343 16344 16345 16346 16347 |
# File 'lib/aws-sdk-ec2/types.rb', line 16337 class CreateTransitGatewayPeeringAttachmentRequest < Struct.new( :transit_gateway_id, :peer_transit_gateway_id, :peer_account_id, :peer_region, :options, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#options ⇒ Types::CreateTransitGatewayPeeringAttachmentRequestOptions
Requests a transit gateway peering attachment.
16337 16338 16339 16340 16341 16342 16343 16344 16345 16346 16347 |
# File 'lib/aws-sdk-ec2/types.rb', line 16337 class CreateTransitGatewayPeeringAttachmentRequest < Struct.new( :transit_gateway_id, :peer_transit_gateway_id, :peer_account_id, :peer_region, :options, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#peer_account_id ⇒ String
The ID of the Amazon Web Services account that owns the peer transit gateway.
16337 16338 16339 16340 16341 16342 16343 16344 16345 16346 16347 |
# File 'lib/aws-sdk-ec2/types.rb', line 16337 class CreateTransitGatewayPeeringAttachmentRequest < Struct.new( :transit_gateway_id, :peer_transit_gateway_id, :peer_account_id, :peer_region, :options, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#peer_region ⇒ String
The Region where the peer transit gateway is located.
16337 16338 16339 16340 16341 16342 16343 16344 16345 16346 16347 |
# File 'lib/aws-sdk-ec2/types.rb', line 16337 class CreateTransitGatewayPeeringAttachmentRequest < Struct.new( :transit_gateway_id, :peer_transit_gateway_id, :peer_account_id, :peer_region, :options, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#peer_transit_gateway_id ⇒ String
The ID of the peer transit gateway with which to create the peering attachment.
16337 16338 16339 16340 16341 16342 16343 16344 16345 16346 16347 |
# File 'lib/aws-sdk-ec2/types.rb', line 16337 class CreateTransitGatewayPeeringAttachmentRequest < Struct.new( :transit_gateway_id, :peer_transit_gateway_id, :peer_account_id, :peer_region, :options, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the transit gateway peering attachment.
16337 16338 16339 16340 16341 16342 16343 16344 16345 16346 16347 |
# File 'lib/aws-sdk-ec2/types.rb', line 16337 class CreateTransitGatewayPeeringAttachmentRequest < Struct.new( :transit_gateway_id, :peer_transit_gateway_id, :peer_account_id, :peer_region, :options, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_id ⇒ String
The ID of the transit gateway.
16337 16338 16339 16340 16341 16342 16343 16344 16345 16346 16347 |
# File 'lib/aws-sdk-ec2/types.rb', line 16337 class CreateTransitGatewayPeeringAttachmentRequest < Struct.new( :transit_gateway_id, :peer_transit_gateway_id, :peer_account_id, :peer_region, :options, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |