Class: Aws::EC2::Types::CreateTransitGatewayRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description of the transit gateway.

Returns:

  • (String)


16766
16767
16768
16769
16770
16771
16772
16773
# File 'lib/aws-sdk-ec2/types.rb', line 16766

class CreateTransitGatewayRequest < Struct.new(
  :description,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


16766
16767
16768
16769
16770
16771
16772
16773
# File 'lib/aws-sdk-ec2/types.rb', line 16766

class CreateTransitGatewayRequest < Struct.new(
  :description,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#optionsTypes::TransitGatewayRequestOptions

The transit gateway options.



16766
16767
16768
16769
16770
16771
16772
16773
# File 'lib/aws-sdk-ec2/types.rb', line 16766

class CreateTransitGatewayRequest < Struct.new(
  :description,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the transit gateway.

Returns:



16766
16767
16768
16769
16770
16771
16772
16773
# File 'lib/aws-sdk-ec2/types.rb', line 16766

class CreateTransitGatewayRequest < Struct.new(
  :description,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end