Class: Aws::EC2::Types::CreateTransitGatewayVpcAttachmentRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


16940
16941
16942
16943
16944
16945
16946
16947
16948
16949
# File 'lib/aws-sdk-ec2/types.rb', line 16940

class CreateTransitGatewayVpcAttachmentRequest < Struct.new(
  :transit_gateway_id,
  :vpc_id,
  :subnet_ids,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#optionsTypes::CreateTransitGatewayVpcAttachmentRequestOptions

The VPC attachment options.



16940
16941
16942
16943
16944
16945
16946
16947
16948
16949
# File 'lib/aws-sdk-ec2/types.rb', line 16940

class CreateTransitGatewayVpcAttachmentRequest < Struct.new(
  :transit_gateway_id,
  :vpc_id,
  :subnet_ids,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idsArray<String>

The IDs of one or more subnets. You can specify only one subnet per Availability Zone. You must specify at least one subnet, but we recommend that you specify two subnets for better availability. The transit gateway uses one IP address from each specified subnet.

Returns:

  • (Array<String>)


16940
16941
16942
16943
16944
16945
16946
16947
16948
16949
# File 'lib/aws-sdk-ec2/types.rb', line 16940

class CreateTransitGatewayVpcAttachmentRequest < Struct.new(
  :transit_gateway_id,
  :vpc_id,
  :subnet_ids,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the VPC attachment.

Returns:



16940
16941
16942
16943
16944
16945
16946
16947
16948
16949
# File 'lib/aws-sdk-ec2/types.rb', line 16940

class CreateTransitGatewayVpcAttachmentRequest < Struct.new(
  :transit_gateway_id,
  :vpc_id,
  :subnet_ids,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_idString

The ID of the transit gateway.

Returns:

  • (String)


16940
16941
16942
16943
16944
16945
16946
16947
16948
16949
# File 'lib/aws-sdk-ec2/types.rb', line 16940

class CreateTransitGatewayVpcAttachmentRequest < Struct.new(
  :transit_gateway_id,
  :vpc_id,
  :subnet_ids,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC.

Returns:

  • (String)


16940
16941
16942
16943
16944
16945
16946
16947
16948
16949
# File 'lib/aws-sdk-ec2/types.rb', line 16940

class CreateTransitGatewayVpcAttachmentRequest < Struct.new(
  :transit_gateway_id,
  :vpc_id,
  :subnet_ids,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end