Class: Aws::EC2::Types::CreateVerifiedAccessEndpointEniOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes the network interface options when creating an Amazon Web Services Verified Access endpoint using the network-interface type.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#network_interface_idString

The ID of the network interface.

Returns:

  • (String)


16193
16194
16195
16196
16197
16198
16199
16200
# File 'lib/aws-sdk-ec2/types.rb', line 16193

class CreateVerifiedAccessEndpointEniOptions < Struct.new(
  :network_interface_id,
  :protocol,
  :port,
  :port_ranges)
  SENSITIVE = []
  include Aws::Structure
end

#portInteger

The IP port number.

Returns:

  • (Integer)


16193
16194
16195
16196
16197
16198
16199
16200
# File 'lib/aws-sdk-ec2/types.rb', line 16193

class CreateVerifiedAccessEndpointEniOptions < Struct.new(
  :network_interface_id,
  :protocol,
  :port,
  :port_ranges)
  SENSITIVE = []
  include Aws::Structure
end

#port_rangesArray<Types::CreateVerifiedAccessEndpointPortRange>

The port ranges.



16193
16194
16195
16196
16197
16198
16199
16200
# File 'lib/aws-sdk-ec2/types.rb', line 16193

class CreateVerifiedAccessEndpointEniOptions < Struct.new(
  :network_interface_id,
  :protocol,
  :port,
  :port_ranges)
  SENSITIVE = []
  include Aws::Structure
end

#protocolString

The IP protocol.

Returns:

  • (String)


16193
16194
16195
16196
16197
16198
16199
16200
# File 'lib/aws-sdk-ec2/types.rb', line 16193

class CreateVerifiedAccessEndpointEniOptions < Struct.new(
  :network_interface_id,
  :protocol,
  :port,
  :port_ranges)
  SENSITIVE = []
  include Aws::Structure
end