Class: Aws::EC2::Types::CreateVpcBlockPublicAccessExclusionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


17151
17152
17153
17154
17155
17156
17157
17158
17159
# File 'lib/aws-sdk-ec2/types.rb', line 17151

class CreateVpcBlockPublicAccessExclusionRequest < Struct.new(
  :dry_run,
  :subnet_id,
  :vpc_id,
  :internet_gateway_exclusion_mode,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#internet_gateway_exclusion_modeString

The exclusion mode for internet gateway traffic.

  • allow-bidirectional: Allow all internet traffic to and from the excluded VPCs and subnets.

  • allow-egress: Allow outbound internet traffic from the excluded VPCs and subnets. Block inbound internet traffic to the excluded VPCs and subnets. Only applies when VPC Block Public Access is set to Bidirectional.

Returns:

  • (String)


17151
17152
17153
17154
17155
17156
17157
17158
17159
# File 'lib/aws-sdk-ec2/types.rb', line 17151

class CreateVpcBlockPublicAccessExclusionRequest < Struct.new(
  :dry_run,
  :subnet_id,
  :vpc_id,
  :internet_gateway_exclusion_mode,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idString

A subnet ID.

Returns:

  • (String)


17151
17152
17153
17154
17155
17156
17157
17158
17159
# File 'lib/aws-sdk-ec2/types.rb', line 17151

class CreateVpcBlockPublicAccessExclusionRequest < Struct.new(
  :dry_run,
  :subnet_id,
  :vpc_id,
  :internet_gateway_exclusion_mode,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

tag - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.

Returns:



17151
17152
17153
17154
17155
17156
17157
17158
17159
# File 'lib/aws-sdk-ec2/types.rb', line 17151

class CreateVpcBlockPublicAccessExclusionRequest < Struct.new(
  :dry_run,
  :subnet_id,
  :vpc_id,
  :internet_gateway_exclusion_mode,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

A VPC ID.

Returns:

  • (String)


17151
17152
17153
17154
17155
17156
17157
17158
17159
# File 'lib/aws-sdk-ec2/types.rb', line 17151

class CreateVpcBlockPublicAccessExclusionRequest < Struct.new(
  :dry_run,
  :subnet_id,
  :vpc_id,
  :internet_gateway_exclusion_mode,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end