Class: Aws::EC2::Types::CreateVpcEncryptionControlRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateVpcEncryptionControlRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the VPC Encryption Control resource.
-
#vpc_id ⇒ String
The ID of the VPC for which to create the encryption control configuration.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
18013 18014 18015 18016 18017 18018 18019 |
# File 'lib/aws-sdk-ec2/types.rb', line 18013 class CreateVpcEncryptionControlRequest < Struct.new( :dry_run, :vpc_id, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the VPC Encryption Control resource.
18013 18014 18015 18016 18017 18018 18019 |
# File 'lib/aws-sdk-ec2/types.rb', line 18013 class CreateVpcEncryptionControlRequest < Struct.new( :dry_run, :vpc_id, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC for which to create the encryption control configuration.
18013 18014 18015 18016 18017 18018 18019 |
# File 'lib/aws-sdk-ec2/types.rb', line 18013 class CreateVpcEncryptionControlRequest < Struct.new( :dry_run, :vpc_id, :tag_specifications) SENSITIVE = [] include Aws::Structure end |