Class: Aws::EC2::Types::CreateVpcEndpointRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency.

Returns:

  • (String)


18184
18185
18186
18187
18188
18189
18190
18191
18192
18193
18194
18195
18196
18197
18198
18199
18200
18201
18202
18203
18204
# File 'lib/aws-sdk-ec2/types.rb', line 18184

class CreateVpcEndpointRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :dns_options,
  :client_token,
  :private_dns_enabled,
  :tag_specifications,
  :subnet_configurations,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region)
  SENSITIVE = []
  include Aws::Structure
end

#dns_optionsTypes::DnsOptionsSpecification

The DNS options for the endpoint.



18184
18185
18186
18187
18188
18189
18190
18191
18192
18193
18194
18195
18196
18197
18198
18199
18200
18201
18202
18203
18204
# File 'lib/aws-sdk-ec2/types.rb', line 18184

class CreateVpcEndpointRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :dns_options,
  :client_token,
  :private_dns_enabled,
  :tag_specifications,
  :subnet_configurations,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


18184
18185
18186
18187
18188
18189
18190
18191
18192
18193
18194
18195
18196
18197
18198
18199
18200
18201
18202
18203
18204
# File 'lib/aws-sdk-ec2/types.rb', line 18184

class CreateVpcEndpointRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :dns_options,
  :client_token,
  :private_dns_enabled,
  :tag_specifications,
  :subnet_configurations,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region)
  SENSITIVE = []
  include Aws::Structure
end

#ip_address_typeString

The IP address type for the endpoint.

Returns:

  • (String)


18184
18185
18186
18187
18188
18189
18190
18191
18192
18193
18194
18195
18196
18197
18198
18199
18200
18201
18202
18203
18204
# File 'lib/aws-sdk-ec2/types.rb', line 18184

class CreateVpcEndpointRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :dns_options,
  :client_token,
  :private_dns_enabled,
  :tag_specifications,
  :subnet_configurations,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region)
  SENSITIVE = []
  include Aws::Structure
end

#policy_documentString

(Interface and gateway endpoints) A policy to attach to the endpoint that controls access to the service. The policy must be in valid JSON format. If this parameter is not specified, we attach a default policy that allows full access to the service.

Returns:

  • (String)


18184
18185
18186
18187
18188
18189
18190
18191
18192
18193
18194
18195
18196
18197
18198
18199
18200
18201
18202
18203
18204
# File 'lib/aws-sdk-ec2/types.rb', line 18184

class CreateVpcEndpointRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :dns_options,
  :client_token,
  :private_dns_enabled,
  :tag_specifications,
  :subnet_configurations,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region)
  SENSITIVE = []
  include Aws::Structure
end

#private_dns_enabledBoolean

(Interface endpoint) Indicates whether to associate a private hosted zone with the specified VPC. The private hosted zone contains a record set for the default public DNS name for the service for the Region (for example, kinesis.us-east-1.amazonaws.com), which resolves to the private IP addresses of the endpoint network interfaces in the VPC. This enables you to make requests to the default public DNS name for the service instead of the public DNS names that are automatically generated by the VPC endpoint service.

To use a private hosted zone, you must set the following VPC attributes to true: enableDnsHostnames and enableDnsSupport. Use ModifyVpcAttribute to set the VPC attributes.

Returns:

  • (Boolean)


18184
18185
18186
18187
18188
18189
18190
18191
18192
18193
18194
18195
18196
18197
18198
18199
18200
18201
18202
18203
18204
# File 'lib/aws-sdk-ec2/types.rb', line 18184

class CreateVpcEndpointRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :dns_options,
  :client_token,
  :private_dns_enabled,
  :tag_specifications,
  :subnet_configurations,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region)
  SENSITIVE = []
  include Aws::Structure
end

#resource_configuration_arnString

The Amazon Resource Name (ARN) of a resource configuration that will be associated with the VPC endpoint of type resource.

Returns:

  • (String)


18184
18185
18186
18187
18188
18189
18190
18191
18192
18193
18194
18195
18196
18197
18198
18199
18200
18201
18202
18203
18204
# File 'lib/aws-sdk-ec2/types.rb', line 18184

class CreateVpcEndpointRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :dns_options,
  :client_token,
  :private_dns_enabled,
  :tag_specifications,
  :subnet_configurations,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region)
  SENSITIVE = []
  include Aws::Structure
end

#route_table_idsArray<String>

(Gateway endpoint) The route table IDs.

Returns:

  • (Array<String>)


18184
18185
18186
18187
18188
18189
18190
18191
18192
18193
18194
18195
18196
18197
18198
18199
18200
18201
18202
18203
18204
# File 'lib/aws-sdk-ec2/types.rb', line 18184

class CreateVpcEndpointRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :dns_options,
  :client_token,
  :private_dns_enabled,
  :tag_specifications,
  :subnet_configurations,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region)
  SENSITIVE = []
  include Aws::Structure
end

#security_group_idsArray<String>

(Interface endpoint) The IDs of the security groups to associate with the endpoint network interfaces. If this parameter is not specified, we use the default security group for the VPC.

Returns:

  • (Array<String>)


18184
18185
18186
18187
18188
18189
18190
18191
18192
18193
18194
18195
18196
18197
18198
18199
18200
18201
18202
18203
18204
# File 'lib/aws-sdk-ec2/types.rb', line 18184

class CreateVpcEndpointRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :dns_options,
  :client_token,
  :private_dns_enabled,
  :tag_specifications,
  :subnet_configurations,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region)
  SENSITIVE = []
  include Aws::Structure
end

#service_nameString

The name of the endpoint service.

Returns:

  • (String)


18184
18185
18186
18187
18188
18189
18190
18191
18192
18193
18194
18195
18196
18197
18198
18199
18200
18201
18202
18203
18204
# File 'lib/aws-sdk-ec2/types.rb', line 18184

class CreateVpcEndpointRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :dns_options,
  :client_token,
  :private_dns_enabled,
  :tag_specifications,
  :subnet_configurations,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region)
  SENSITIVE = []
  include Aws::Structure
end

#service_network_arnString

The Amazon Resource Name (ARN) of a service network that will be associated with the VPC endpoint of type service-network.

Returns:

  • (String)


18184
18185
18186
18187
18188
18189
18190
18191
18192
18193
18194
18195
18196
18197
18198
18199
18200
18201
18202
18203
18204
# File 'lib/aws-sdk-ec2/types.rb', line 18184

class CreateVpcEndpointRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :dns_options,
  :client_token,
  :private_dns_enabled,
  :tag_specifications,
  :subnet_configurations,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region)
  SENSITIVE = []
  include Aws::Structure
end

#service_regionString

The Region where the service is hosted. The default is the current Region.

Returns:

  • (String)


18184
18185
18186
18187
18188
18189
18190
18191
18192
18193
18194
18195
18196
18197
18198
18199
18200
18201
18202
18203
18204
# File 'lib/aws-sdk-ec2/types.rb', line 18184

class CreateVpcEndpointRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :dns_options,
  :client_token,
  :private_dns_enabled,
  :tag_specifications,
  :subnet_configurations,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_configurationsArray<Types::SubnetConfiguration>

The subnet configurations for the endpoint.

Returns:



18184
18185
18186
18187
18188
18189
18190
18191
18192
18193
18194
18195
18196
18197
18198
18199
18200
18201
18202
18203
18204
# File 'lib/aws-sdk-ec2/types.rb', line 18184

class CreateVpcEndpointRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :dns_options,
  :client_token,
  :private_dns_enabled,
  :tag_specifications,
  :subnet_configurations,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idsArray<String>

(Interface and Gateway Load Balancer endpoints) The IDs of the subnets in which to create endpoint network interfaces. For a Gateway Load Balancer endpoint, you can specify only one subnet.

Returns:

  • (Array<String>)


18184
18185
18186
18187
18188
18189
18190
18191
18192
18193
18194
18195
18196
18197
18198
18199
18200
18201
18202
18203
18204
# File 'lib/aws-sdk-ec2/types.rb', line 18184

class CreateVpcEndpointRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :dns_options,
  :client_token,
  :private_dns_enabled,
  :tag_specifications,
  :subnet_configurations,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to associate with the endpoint.

Returns:



18184
18185
18186
18187
18188
18189
18190
18191
18192
18193
18194
18195
18196
18197
18198
18199
18200
18201
18202
18203
18204
# File 'lib/aws-sdk-ec2/types.rb', line 18184

class CreateVpcEndpointRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :dns_options,
  :client_token,
  :private_dns_enabled,
  :tag_specifications,
  :subnet_configurations,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_endpoint_typeString

The type of endpoint.

Default: Gateway

Returns:

  • (String)


18184
18185
18186
18187
18188
18189
18190
18191
18192
18193
18194
18195
18196
18197
18198
18199
18200
18201
18202
18203
18204
# File 'lib/aws-sdk-ec2/types.rb', line 18184

class CreateVpcEndpointRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :dns_options,
  :client_token,
  :private_dns_enabled,
  :tag_specifications,
  :subnet_configurations,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC.

Returns:

  • (String)


18184
18185
18186
18187
18188
18189
18190
18191
18192
18193
18194
18195
18196
18197
18198
18199
18200
18201
18202
18203
18204
# File 'lib/aws-sdk-ec2/types.rb', line 18184

class CreateVpcEndpointRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :dns_options,
  :client_token,
  :private_dns_enabled,
  :tag_specifications,
  :subnet_configurations,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region)
  SENSITIVE = []
  include Aws::Structure
end