Class: Aws::EC2::Types::CreateVpcPeeringConnectionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


18342
18343
18344
18345
18346
18347
18348
18349
18350
18351
# File 'lib/aws-sdk-ec2/types.rb', line 18342

class CreateVpcPeeringConnectionRequest < Struct.new(
  :peer_region,
  :tag_specifications,
  :dry_run,
  :vpc_id,
  :peer_vpc_id,
  :peer_owner_id)
  SENSITIVE = []
  include Aws::Structure
end

#peer_owner_idString

The Amazon Web Services account ID of the owner of the accepter VPC.

Default: Your Amazon Web Services account ID

Returns:

  • (String)


18342
18343
18344
18345
18346
18347
18348
18349
18350
18351
# File 'lib/aws-sdk-ec2/types.rb', line 18342

class CreateVpcPeeringConnectionRequest < Struct.new(
  :peer_region,
  :tag_specifications,
  :dry_run,
  :vpc_id,
  :peer_vpc_id,
  :peer_owner_id)
  SENSITIVE = []
  include Aws::Structure
end

#peer_regionString

The Region code for the accepter VPC, if the accepter VPC is located in a Region other than the Region in which you make the request.

Default: The Region in which you make the request.

Returns:

  • (String)


18342
18343
18344
18345
18346
18347
18348
18349
18350
18351
# File 'lib/aws-sdk-ec2/types.rb', line 18342

class CreateVpcPeeringConnectionRequest < Struct.new(
  :peer_region,
  :tag_specifications,
  :dry_run,
  :vpc_id,
  :peer_vpc_id,
  :peer_owner_id)
  SENSITIVE = []
  include Aws::Structure
end

#peer_vpc_idString

The ID of the VPC with which you are creating the VPC peering connection. You must specify this parameter in the request.

Returns:

  • (String)


18342
18343
18344
18345
18346
18347
18348
18349
18350
18351
# File 'lib/aws-sdk-ec2/types.rb', line 18342

class CreateVpcPeeringConnectionRequest < Struct.new(
  :peer_region,
  :tag_specifications,
  :dry_run,
  :vpc_id,
  :peer_vpc_id,
  :peer_owner_id)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to assign to the peering connection.

Returns:



18342
18343
18344
18345
18346
18347
18348
18349
18350
18351
# File 'lib/aws-sdk-ec2/types.rb', line 18342

class CreateVpcPeeringConnectionRequest < Struct.new(
  :peer_region,
  :tag_specifications,
  :dry_run,
  :vpc_id,
  :peer_vpc_id,
  :peer_owner_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the requester VPC. You must specify this parameter in the request.

Returns:

  • (String)


18342
18343
18344
18345
18346
18347
18348
18349
18350
18351
# File 'lib/aws-sdk-ec2/types.rb', line 18342

class CreateVpcPeeringConnectionRequest < Struct.new(
  :peer_region,
  :tag_specifications,
  :dry_run,
  :vpc_id,
  :peer_vpc_id,
  :peer_owner_id)
  SENSITIVE = []
  include Aws::Structure
end