Class: Aws::EC2::Types::CreateVpcRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateVpcRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#amazon_provided_ipv_6_cidr_block ⇒ Boolean
Requests an Amazon-provided IPv6 CIDR block with a /56 prefix length for the VPC.
-
#cidr_block ⇒ String
The IPv4 network range for the VPC, in CIDR notation.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#instance_tenancy ⇒ String
The tenancy options for instances launched into the VPC.
-
#ipv_4_ipam_pool_id ⇒ String
The ID of an IPv4 IPAM pool you want to use for allocating this VPC’s CIDR.
-
#ipv_4_netmask_length ⇒ Integer
The netmask length of the IPv4 CIDR you want to allocate to this VPC from an Amazon VPC IP Address Manager (IPAM) pool.
-
#ipv_6_cidr_block ⇒ String
The IPv6 CIDR block from the IPv6 address pool.
-
#ipv_6_cidr_block_network_border_group ⇒ String
The name of the location from which we advertise the IPV6 CIDR block.
-
#ipv_6_ipam_pool_id ⇒ String
The ID of an IPv6 IPAM pool which will be used to allocate this VPC an IPv6 CIDR.
-
#ipv_6_netmask_length ⇒ Integer
The netmask length of the IPv6 CIDR you want to allocate to this VPC from an Amazon VPC IP Address Manager (IPAM) pool.
-
#ipv_6_pool ⇒ String
The ID of an IPv6 address pool from which to allocate the IPv6 CIDR block.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the VPC.
-
#vpc_encryption_control ⇒ Types::VpcEncryptionControlConfiguration
Specifies the encryption control configuration to apply to the VPC during creation.
Instance Attribute Details
#amazon_provided_ipv_6_cidr_block ⇒ Boolean
Requests an Amazon-provided IPv6 CIDR block with a /56 prefix length for the VPC. You cannot specify the range of IP addresses, or the size of the CIDR block.
16803 16804 16805 16806 16807 16808 16809 16810 16811 16812 16813 16814 16815 16816 16817 16818 16819 |
# File 'lib/aws-sdk-ec2/types.rb', line 16803 class CreateVpcRequest < Struct.new( :cidr_block, :ipv_6_pool, :ipv_6_cidr_block, :ipv_4_ipam_pool_id, :ipv_4_netmask_length, :ipv_6_ipam_pool_id, :ipv_6_netmask_length, :ipv_6_cidr_block_network_border_group, :vpc_encryption_control, :tag_specifications, :dry_run, :instance_tenancy, :amazon_provided_ipv_6_cidr_block) SENSITIVE = [] include Aws::Structure end |
#cidr_block ⇒ String
The IPv4 network range for the VPC, in CIDR notation. For example, ‘10.0.0.0/16`. We modify the specified CIDR block to its canonical form; for example, if you specify `100.68.0.18/18`, we modify it to `100.68.0.0/18`.
16803 16804 16805 16806 16807 16808 16809 16810 16811 16812 16813 16814 16815 16816 16817 16818 16819 |
# File 'lib/aws-sdk-ec2/types.rb', line 16803 class CreateVpcRequest < Struct.new( :cidr_block, :ipv_6_pool, :ipv_6_cidr_block, :ipv_4_ipam_pool_id, :ipv_4_netmask_length, :ipv_6_ipam_pool_id, :ipv_6_netmask_length, :ipv_6_cidr_block_network_border_group, :vpc_encryption_control, :tag_specifications, :dry_run, :instance_tenancy, :amazon_provided_ipv_6_cidr_block) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
16803 16804 16805 16806 16807 16808 16809 16810 16811 16812 16813 16814 16815 16816 16817 16818 16819 |
# File 'lib/aws-sdk-ec2/types.rb', line 16803 class CreateVpcRequest < Struct.new( :cidr_block, :ipv_6_pool, :ipv_6_cidr_block, :ipv_4_ipam_pool_id, :ipv_4_netmask_length, :ipv_6_ipam_pool_id, :ipv_6_netmask_length, :ipv_6_cidr_block_network_border_group, :vpc_encryption_control, :tag_specifications, :dry_run, :instance_tenancy, :amazon_provided_ipv_6_cidr_block) SENSITIVE = [] include Aws::Structure end |
#instance_tenancy ⇒ String
The tenancy options for instances launched into the VPC. For ‘default`, instances are launched with shared tenancy by default. You can launch instances with any tenancy into a shared tenancy VPC. For `dedicated`, instances are launched as dedicated tenancy instances by default. You can only launch instances with a tenancy of `dedicated` or `host` into a dedicated tenancy VPC.
Important: The ‘host` value cannot be used with this parameter. Use the `default` or `dedicated` values only.
Default: ‘default`
16803 16804 16805 16806 16807 16808 16809 16810 16811 16812 16813 16814 16815 16816 16817 16818 16819 |
# File 'lib/aws-sdk-ec2/types.rb', line 16803 class CreateVpcRequest < Struct.new( :cidr_block, :ipv_6_pool, :ipv_6_cidr_block, :ipv_4_ipam_pool_id, :ipv_4_netmask_length, :ipv_6_ipam_pool_id, :ipv_6_netmask_length, :ipv_6_cidr_block_network_border_group, :vpc_encryption_control, :tag_specifications, :dry_run, :instance_tenancy, :amazon_provided_ipv_6_cidr_block) SENSITIVE = [] include Aws::Structure end |
#ipv_4_ipam_pool_id ⇒ String
The ID of an IPv4 IPAM pool you want to use for allocating this VPC’s CIDR. For more information, see [What is IPAM?] in the *Amazon VPC IPAM User Guide*.
[1]: docs.aws.amazon.com/vpc/latest/ipam/what-is-it-ipam.html
16803 16804 16805 16806 16807 16808 16809 16810 16811 16812 16813 16814 16815 16816 16817 16818 16819 |
# File 'lib/aws-sdk-ec2/types.rb', line 16803 class CreateVpcRequest < Struct.new( :cidr_block, :ipv_6_pool, :ipv_6_cidr_block, :ipv_4_ipam_pool_id, :ipv_4_netmask_length, :ipv_6_ipam_pool_id, :ipv_6_netmask_length, :ipv_6_cidr_block_network_border_group, :vpc_encryption_control, :tag_specifications, :dry_run, :instance_tenancy, :amazon_provided_ipv_6_cidr_block) SENSITIVE = [] include Aws::Structure end |
#ipv_4_netmask_length ⇒ Integer
The netmask length of the IPv4 CIDR you want to allocate to this VPC from an Amazon VPC IP Address Manager (IPAM) pool. For more information about IPAM, see [What is IPAM?] in the *Amazon VPC IPAM User Guide*.
[1]: docs.aws.amazon.com/vpc/latest/ipam/what-is-it-ipam.html
16803 16804 16805 16806 16807 16808 16809 16810 16811 16812 16813 16814 16815 16816 16817 16818 16819 |
# File 'lib/aws-sdk-ec2/types.rb', line 16803 class CreateVpcRequest < Struct.new( :cidr_block, :ipv_6_pool, :ipv_6_cidr_block, :ipv_4_ipam_pool_id, :ipv_4_netmask_length, :ipv_6_ipam_pool_id, :ipv_6_netmask_length, :ipv_6_cidr_block_network_border_group, :vpc_encryption_control, :tag_specifications, :dry_run, :instance_tenancy, :amazon_provided_ipv_6_cidr_block) SENSITIVE = [] include Aws::Structure end |
#ipv_6_cidr_block ⇒ String
The IPv6 CIDR block from the IPv6 address pool. You must also specify ‘Ipv6Pool` in the request.
To let Amazon choose the IPv6 CIDR block for you, omit this parameter.
16803 16804 16805 16806 16807 16808 16809 16810 16811 16812 16813 16814 16815 16816 16817 16818 16819 |
# File 'lib/aws-sdk-ec2/types.rb', line 16803 class CreateVpcRequest < Struct.new( :cidr_block, :ipv_6_pool, :ipv_6_cidr_block, :ipv_4_ipam_pool_id, :ipv_4_netmask_length, :ipv_6_ipam_pool_id, :ipv_6_netmask_length, :ipv_6_cidr_block_network_border_group, :vpc_encryption_control, :tag_specifications, :dry_run, :instance_tenancy, :amazon_provided_ipv_6_cidr_block) SENSITIVE = [] include Aws::Structure end |
#ipv_6_cidr_block_network_border_group ⇒ String
The name of the location from which we advertise the IPV6 CIDR block. Use this parameter to limit the address to this location.
You must set ‘AmazonProvidedIpv6CidrBlock` to `true` to use this parameter.
16803 16804 16805 16806 16807 16808 16809 16810 16811 16812 16813 16814 16815 16816 16817 16818 16819 |
# File 'lib/aws-sdk-ec2/types.rb', line 16803 class CreateVpcRequest < Struct.new( :cidr_block, :ipv_6_pool, :ipv_6_cidr_block, :ipv_4_ipam_pool_id, :ipv_4_netmask_length, :ipv_6_ipam_pool_id, :ipv_6_netmask_length, :ipv_6_cidr_block_network_border_group, :vpc_encryption_control, :tag_specifications, :dry_run, :instance_tenancy, :amazon_provided_ipv_6_cidr_block) SENSITIVE = [] include Aws::Structure end |
#ipv_6_ipam_pool_id ⇒ String
The ID of an IPv6 IPAM pool which will be used to allocate this VPC an IPv6 CIDR. IPAM is a VPC feature that you can use to automate your IP address management workflows including assigning, tracking, troubleshooting, and auditing IP addresses across Amazon Web Services Regions and accounts throughout your Amazon Web Services Organization. For more information, see [What is IPAM?] in the *Amazon VPC IPAM User Guide*.
[1]: docs.aws.amazon.com/vpc/latest/ipam/what-is-it-ipam.html
16803 16804 16805 16806 16807 16808 16809 16810 16811 16812 16813 16814 16815 16816 16817 16818 16819 |
# File 'lib/aws-sdk-ec2/types.rb', line 16803 class CreateVpcRequest < Struct.new( :cidr_block, :ipv_6_pool, :ipv_6_cidr_block, :ipv_4_ipam_pool_id, :ipv_4_netmask_length, :ipv_6_ipam_pool_id, :ipv_6_netmask_length, :ipv_6_cidr_block_network_border_group, :vpc_encryption_control, :tag_specifications, :dry_run, :instance_tenancy, :amazon_provided_ipv_6_cidr_block) SENSITIVE = [] include Aws::Structure end |
#ipv_6_netmask_length ⇒ Integer
The netmask length of the IPv6 CIDR you want to allocate to this VPC from an Amazon VPC IP Address Manager (IPAM) pool. For more information about IPAM, see [What is IPAM?] in the *Amazon VPC IPAM User Guide*.
[1]: docs.aws.amazon.com/vpc/latest/ipam/what-is-it-ipam.html
16803 16804 16805 16806 16807 16808 16809 16810 16811 16812 16813 16814 16815 16816 16817 16818 16819 |
# File 'lib/aws-sdk-ec2/types.rb', line 16803 class CreateVpcRequest < Struct.new( :cidr_block, :ipv_6_pool, :ipv_6_cidr_block, :ipv_4_ipam_pool_id, :ipv_4_netmask_length, :ipv_6_ipam_pool_id, :ipv_6_netmask_length, :ipv_6_cidr_block_network_border_group, :vpc_encryption_control, :tag_specifications, :dry_run, :instance_tenancy, :amazon_provided_ipv_6_cidr_block) SENSITIVE = [] include Aws::Structure end |
#ipv_6_pool ⇒ String
The ID of an IPv6 address pool from which to allocate the IPv6 CIDR block.
16803 16804 16805 16806 16807 16808 16809 16810 16811 16812 16813 16814 16815 16816 16817 16818 16819 |
# File 'lib/aws-sdk-ec2/types.rb', line 16803 class CreateVpcRequest < Struct.new( :cidr_block, :ipv_6_pool, :ipv_6_cidr_block, :ipv_4_ipam_pool_id, :ipv_4_netmask_length, :ipv_6_ipam_pool_id, :ipv_6_netmask_length, :ipv_6_cidr_block_network_border_group, :vpc_encryption_control, :tag_specifications, :dry_run, :instance_tenancy, :amazon_provided_ipv_6_cidr_block) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the VPC.
16803 16804 16805 16806 16807 16808 16809 16810 16811 16812 16813 16814 16815 16816 16817 16818 16819 |
# File 'lib/aws-sdk-ec2/types.rb', line 16803 class CreateVpcRequest < Struct.new( :cidr_block, :ipv_6_pool, :ipv_6_cidr_block, :ipv_4_ipam_pool_id, :ipv_4_netmask_length, :ipv_6_ipam_pool_id, :ipv_6_netmask_length, :ipv_6_cidr_block_network_border_group, :vpc_encryption_control, :tag_specifications, :dry_run, :instance_tenancy, :amazon_provided_ipv_6_cidr_block) SENSITIVE = [] include Aws::Structure end |
#vpc_encryption_control ⇒ Types::VpcEncryptionControlConfiguration
Specifies the encryption control configuration to apply to the VPC during creation. VPC Encryption Control enables you to enforce encryption for all data in transit within and between VPCs to meet compliance requirements.
For more information, see [Enforce VPC encryption in transit] in the *Amazon VPC User Guide*.
[1]: docs.aws.amazon.com/vpc/latest/userguide/vpc-encryption-controls.html
16803 16804 16805 16806 16807 16808 16809 16810 16811 16812 16813 16814 16815 16816 16817 16818 16819 |
# File 'lib/aws-sdk-ec2/types.rb', line 16803 class CreateVpcRequest < Struct.new( :cidr_block, :ipv_6_pool, :ipv_6_cidr_block, :ipv_4_ipam_pool_id, :ipv_4_netmask_length, :ipv_6_ipam_pool_id, :ipv_6_netmask_length, :ipv_6_cidr_block_network_border_group, :vpc_encryption_control, :tag_specifications, :dry_run, :instance_tenancy, :amazon_provided_ipv_6_cidr_block) SENSITIVE = [] include Aws::Structure end |