Class: Aws::EC2::Types::CreateVpnConnectionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for CreateVpnConnection.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#customer_gateway_idString

The ID of the customer gateway.

Returns:

  • (String)


18605
18606
18607
18608
18609
18610
18611
18612
18613
18614
18615
18616
18617
# File 'lib/aws-sdk-ec2/types.rb', line 18605

class CreateVpnConnectionRequest < Struct.new(
  :customer_gateway_id,
  :type,
  :vpn_gateway_id,
  :transit_gateway_id,
  :vpn_concentrator_id,
  :tag_specifications,
  :pre_shared_key_storage,
  :dry_run,
  :options)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


18605
18606
18607
18608
18609
18610
18611
18612
18613
18614
18615
18616
18617
# File 'lib/aws-sdk-ec2/types.rb', line 18605

class CreateVpnConnectionRequest < Struct.new(
  :customer_gateway_id,
  :type,
  :vpn_gateway_id,
  :transit_gateway_id,
  :vpn_concentrator_id,
  :tag_specifications,
  :pre_shared_key_storage,
  :dry_run,
  :options)
  SENSITIVE = []
  include Aws::Structure
end

#optionsTypes::VpnConnectionOptionsSpecification

The options for the VPN connection.



18605
18606
18607
18608
18609
18610
18611
18612
18613
18614
18615
18616
18617
# File 'lib/aws-sdk-ec2/types.rb', line 18605

class CreateVpnConnectionRequest < Struct.new(
  :customer_gateway_id,
  :type,
  :vpn_gateway_id,
  :transit_gateway_id,
  :vpn_concentrator_id,
  :tag_specifications,
  :pre_shared_key_storage,
  :dry_run,
  :options)
  SENSITIVE = []
  include Aws::Structure
end

#pre_shared_key_storageString

Specifies the storage mode for the pre-shared key (PSK). Valid values are Standard" (stored in the Site-to-Site VPN service) or SecretsManager (stored in Amazon Web Services Secrets Manager).

Returns:

  • (String)


18605
18606
18607
18608
18609
18610
18611
18612
18613
18614
18615
18616
18617
# File 'lib/aws-sdk-ec2/types.rb', line 18605

class CreateVpnConnectionRequest < Struct.new(
  :customer_gateway_id,
  :type,
  :vpn_gateway_id,
  :transit_gateway_id,
  :vpn_concentrator_id,
  :tag_specifications,
  :pre_shared_key_storage,
  :dry_run,
  :options)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the VPN connection.

Returns:



18605
18606
18607
18608
18609
18610
18611
18612
18613
18614
18615
18616
18617
# File 'lib/aws-sdk-ec2/types.rb', line 18605

class CreateVpnConnectionRequest < Struct.new(
  :customer_gateway_id,
  :type,
  :vpn_gateway_id,
  :transit_gateway_id,
  :vpn_concentrator_id,
  :tag_specifications,
  :pre_shared_key_storage,
  :dry_run,
  :options)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_idString

The ID of the transit gateway. If you specify a transit gateway, you cannot specify a virtual private gateway.

Returns:

  • (String)


18605
18606
18607
18608
18609
18610
18611
18612
18613
18614
18615
18616
18617
# File 'lib/aws-sdk-ec2/types.rb', line 18605

class CreateVpnConnectionRequest < Struct.new(
  :customer_gateway_id,
  :type,
  :vpn_gateway_id,
  :transit_gateway_id,
  :vpn_concentrator_id,
  :tag_specifications,
  :pre_shared_key_storage,
  :dry_run,
  :options)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of VPN connection (ipsec.1).

Returns:

  • (String)


18605
18606
18607
18608
18609
18610
18611
18612
18613
18614
18615
18616
18617
# File 'lib/aws-sdk-ec2/types.rb', line 18605

class CreateVpnConnectionRequest < Struct.new(
  :customer_gateway_id,
  :type,
  :vpn_gateway_id,
  :transit_gateway_id,
  :vpn_concentrator_id,
  :tag_specifications,
  :pre_shared_key_storage,
  :dry_run,
  :options)
  SENSITIVE = []
  include Aws::Structure
end

#vpn_concentrator_idString

The ID of the VPN concentrator to associate with the VPN connection.

Returns:

  • (String)


18605
18606
18607
18608
18609
18610
18611
18612
18613
18614
18615
18616
18617
# File 'lib/aws-sdk-ec2/types.rb', line 18605

class CreateVpnConnectionRequest < Struct.new(
  :customer_gateway_id,
  :type,
  :vpn_gateway_id,
  :transit_gateway_id,
  :vpn_concentrator_id,
  :tag_specifications,
  :pre_shared_key_storage,
  :dry_run,
  :options)
  SENSITIVE = []
  include Aws::Structure
end

#vpn_gateway_idString

The ID of the virtual private gateway. If you specify a virtual private gateway, you cannot specify a transit gateway.

Returns:

  • (String)


18605
18606
18607
18608
18609
18610
18611
18612
18613
18614
18615
18616
18617
# File 'lib/aws-sdk-ec2/types.rb', line 18605

class CreateVpnConnectionRequest < Struct.new(
  :customer_gateway_id,
  :type,
  :vpn_gateway_id,
  :transit_gateway_id,
  :vpn_concentrator_id,
  :tag_specifications,
  :pre_shared_key_storage,
  :dry_run,
  :options)
  SENSITIVE = []
  include Aws::Structure
end