Class: Aws::EC2::Types::CreateVpnGatewayRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for CreateVpnGateway.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#amazon_side_asnInteger

A private Autonomous System Number (ASN) for the Amazon side of a BGP session. If you're using a 16-bit ASN, it must be in the 64512 to 65534 range. If you're using a 32-bit ASN, it must be in the 4200000000 to 4294967294 range.

Default: 64512

Returns:

  • (Integer)


17799
17800
17801
17802
17803
17804
17805
17806
17807
# File 'lib/aws-sdk-ec2/types.rb', line 17799

class CreateVpnGatewayRequest < Struct.new(
  :availability_zone,
  :type,
  :tag_specifications,
  :amazon_side_asn,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zoneString

The Availability Zone for the virtual private gateway.

Returns:

  • (String)


17799
17800
17801
17802
17803
17804
17805
17806
17807
# File 'lib/aws-sdk-ec2/types.rb', line 17799

class CreateVpnGatewayRequest < Struct.new(
  :availability_zone,
  :type,
  :tag_specifications,
  :amazon_side_asn,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


17799
17800
17801
17802
17803
17804
17805
17806
17807
# File 'lib/aws-sdk-ec2/types.rb', line 17799

class CreateVpnGatewayRequest < Struct.new(
  :availability_zone,
  :type,
  :tag_specifications,
  :amazon_side_asn,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the virtual private gateway.

Returns:



17799
17800
17801
17802
17803
17804
17805
17806
17807
# File 'lib/aws-sdk-ec2/types.rb', line 17799

class CreateVpnGatewayRequest < Struct.new(
  :availability_zone,
  :type,
  :tag_specifications,
  :amazon_side_asn,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of VPN connection this virtual private gateway supports.

Returns:

  • (String)


17799
17800
17801
17802
17803
17804
17805
17806
17807
# File 'lib/aws-sdk-ec2/types.rb', line 17799

class CreateVpnGatewayRequest < Struct.new(
  :availability_zone,
  :type,
  :tag_specifications,
  :amazon_side_asn,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end