Class: Aws::EC2::Types::CreationDateCondition

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

The maximum age for allowed images.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#maximum_days_since_createdInteger

The maximum number of days that have elapsed since the image was created. For example, a value of ‘300` allows images that were created within the last 300 days.

Returns:

  • (Integer)


17036
17037
17038
17039
17040
# File 'lib/aws-sdk-ec2/types.rb', line 17036

class CreationDateCondition < Struct.new(
  :maximum_days_since_created)
  SENSITIVE = []
  include Aws::Structure
end