Class: Aws::EC2::Types::DefaultConnectionTrackingConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Indicates default conntrack information for the instance type. For more information, see Connection tracking timeouts in the Amazon EC2 User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#default_tcp_established_timeoutInteger

Default timeout (in seconds) for idle TCP connections in an established state.

Returns:

  • (Integer)


18007
18008
18009
18010
18011
18012
18013
# File 'lib/aws-sdk-ec2/types.rb', line 18007

class DefaultConnectionTrackingConfiguration < Struct.new(
  :default_tcp_established_timeout,
  :default_udp_timeout,
  :default_udp_stream_timeout)
  SENSITIVE = []
  include Aws::Structure
end

#default_udp_stream_timeoutInteger

Default timeout (in seconds) for idle UDP flows classified as streams which have seen more than one request-response transaction.

Returns:

  • (Integer)


18007
18008
18009
18010
18011
18012
18013
# File 'lib/aws-sdk-ec2/types.rb', line 18007

class DefaultConnectionTrackingConfiguration < Struct.new(
  :default_tcp_established_timeout,
  :default_udp_timeout,
  :default_udp_stream_timeout)
  SENSITIVE = []
  include Aws::Structure
end

#default_udp_timeoutInteger

Default timeout (in seconds) for idle UDP flows that have seen traffic only in a single direction or a single request-response transaction.

Returns:

  • (Integer)


18007
18008
18009
18010
18011
18012
18013
# File 'lib/aws-sdk-ec2/types.rb', line 18007

class DefaultConnectionTrackingConfiguration < Struct.new(
  :default_tcp_established_timeout,
  :default_udp_timeout,
  :default_udp_stream_timeout)
  SENSITIVE = []
  include Aws::Structure
end