Class: Aws::EC2::Types::DeleteCapacityManagerDataExportResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteCapacityManagerDataExportResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_manager_data_export_id ⇒ String
The unique identifier of the deleted data export configuration.
Instance Attribute Details
#capacity_manager_data_export_id ⇒ String
The unique identifier of the deleted data export configuration.
17562 17563 17564 17565 17566 |
# File 'lib/aws-sdk-ec2/types.rb', line 17562 class DeleteCapacityManagerDataExportResult < Struct.new( :capacity_manager_data_export_id) SENSITIVE = [] include Aws::Structure end |