Class: Aws::EC2::Types::DeleteClientVpnRouteRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteClientVpnRouteRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_vpn_endpoint_id ⇒ String
The ID of the Client VPN endpoint from which the route is to be deleted.
-
#destination_cidr_block ⇒ String
The IPv4 address range, in CIDR notation, of the route to be deleted.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#target_vpc_subnet_id ⇒ String
The ID of the target subnet used by the route.
Instance Attribute Details
#client_vpn_endpoint_id ⇒ String
The ID of the Client VPN endpoint from which the route is to be deleted.
19011 19012 19013 19014 19015 19016 19017 19018 |
# File 'lib/aws-sdk-ec2/types.rb', line 19011 class DeleteClientVpnRouteRequest < Struct.new( :client_vpn_endpoint_id, :target_vpc_subnet_id, :destination_cidr_block, :dry_run) SENSITIVE = [] include Aws::Structure end |
#destination_cidr_block ⇒ String
The IPv4 address range, in CIDR notation, of the route to be deleted.
19011 19012 19013 19014 19015 19016 19017 19018 |
# File 'lib/aws-sdk-ec2/types.rb', line 19011 class DeleteClientVpnRouteRequest < Struct.new( :client_vpn_endpoint_id, :target_vpc_subnet_id, :destination_cidr_block, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
19011 19012 19013 19014 19015 19016 19017 19018 |
# File 'lib/aws-sdk-ec2/types.rb', line 19011 class DeleteClientVpnRouteRequest < Struct.new( :client_vpn_endpoint_id, :target_vpc_subnet_id, :destination_cidr_block, :dry_run) SENSITIVE = [] include Aws::Structure end |
#target_vpc_subnet_id ⇒ String
The ID of the target subnet used by the route.
19011 19012 19013 19014 19015 19016 19017 19018 |
# File 'lib/aws-sdk-ec2/types.rb', line 19011 class DeleteClientVpnRouteRequest < Struct.new( :client_vpn_endpoint_id, :target_vpc_subnet_id, :destination_cidr_block, :dry_run) SENSITIVE = [] include Aws::Structure end |