Class: Aws::EC2::Types::DeleteDhcpOptionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dhcp_options_idString

The ID of the DHCP options set.

Returns:

  • (String)


19373
19374
19375
19376
19377
19378
# File 'lib/aws-sdk-ec2/types.rb', line 19373

class DeleteDhcpOptionsRequest < Struct.new(
  :dhcp_options_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


19373
19374
19375
19376
19377
19378
# File 'lib/aws-sdk-ec2/types.rb', line 19373

class DeleteDhcpOptionsRequest < Struct.new(
  :dhcp_options_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end