Class: Aws::EC2::Types::DeleteFleetsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteFleetsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#fleet_ids ⇒ Array<String>
The IDs of the EC2 Fleets.
-
#terminate_instances ⇒ Boolean
Indicates whether to terminate the associated instances when the EC2 Fleet is deleted.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
19494 19495 19496 19497 19498 19499 19500 |
# File 'lib/aws-sdk-ec2/types.rb', line 19494 class DeleteFleetsRequest < Struct.new( :dry_run, :fleet_ids, :terminate_instances) SENSITIVE = [] include Aws::Structure end |
#fleet_ids ⇒ Array<String>
The IDs of the EC2 Fleets.
Constraints: In a single request, you can specify up to 25 instant
fleet IDs and up to 100 maintain or request fleet IDs.
19494 19495 19496 19497 19498 19499 19500 |
# File 'lib/aws-sdk-ec2/types.rb', line 19494 class DeleteFleetsRequest < Struct.new( :dry_run, :fleet_ids, :terminate_instances) SENSITIVE = [] include Aws::Structure end |
#terminate_instances ⇒ Boolean
Indicates whether to terminate the associated instances when the EC2 Fleet is deleted. The default is to terminate the instances.
To let the instances continue to run after the EC2 Fleet is deleted,
specify no-terminate-instances. Supported only for fleets of type
maintain and request.
For instant fleets, you cannot specify NoTerminateInstances. A
deleted instant fleet with running instances is not supported.
19494 19495 19496 19497 19498 19499 19500 |
# File 'lib/aws-sdk-ec2/types.rb', line 19494 class DeleteFleetsRequest < Struct.new( :dry_run, :fleet_ids, :terminate_instances) SENSITIVE = [] include Aws::Structure end |