Class: Aws::EC2::Types::DeleteFlowLogsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteFlowLogsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#unsuccessful ⇒ Array<Types::UnsuccessfulItem>
Information about the flow logs that could not be deleted successfully.
Instance Attribute Details
#unsuccessful ⇒ Array<Types::UnsuccessfulItem>
Information about the flow logs that could not be deleted successfully.
19557 19558 19559 19560 19561 |
# File 'lib/aws-sdk-ec2/types.rb', line 19557 class DeleteFlowLogsResult < Struct.new( :unsuccessful) SENSITIVE = [] include Aws::Structure end |