Class: Aws::EC2::Types::DeleteInstanceEventWindowRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


19679
19680
19681
19682
19683
19684
19685
# File 'lib/aws-sdk-ec2/types.rb', line 19679

class DeleteInstanceEventWindowRequest < Struct.new(
  :dry_run,
  :force_delete,
  :instance_event_window_id)
  SENSITIVE = []
  include Aws::Structure
end

#force_deleteBoolean

Specify true to force delete the event window. Use the force delete parameter if the event window is currently associated with targets.

Returns:

  • (Boolean)


19679
19680
19681
19682
19683
19684
19685
# File 'lib/aws-sdk-ec2/types.rb', line 19679

class DeleteInstanceEventWindowRequest < Struct.new(
  :dry_run,
  :force_delete,
  :instance_event_window_id)
  SENSITIVE = []
  include Aws::Structure
end

#instance_event_window_idString

The ID of the event window.

Returns:

  • (String)


19679
19680
19681
19682
19683
19684
19685
# File 'lib/aws-sdk-ec2/types.rb', line 19679

class DeleteInstanceEventWindowRequest < Struct.new(
  :dry_run,
  :force_delete,
  :instance_event_window_id)
  SENSITIVE = []
  include Aws::Structure
end