Class: Aws::EC2::Types::DeleteIpamPoolRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteIpamPoolRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cascade ⇒ Boolean
Enables you to quickly delete an IPAM pool and all resources within that pool, including provisioned CIDRs, allocations, and other pools.
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#ipam_pool_id ⇒ String
The ID of the pool to delete.
Instance Attribute Details
#cascade ⇒ Boolean
Enables you to quickly delete an IPAM pool and all resources within that pool, including provisioned CIDRs, allocations, and other pools.
You can only use this option to delete pools in the private scope or pools in the public scope with a source resource. A source resource is a resource used to provision CIDRs to a resource planning pool.
18223 18224 18225 18226 18227 18228 18229 |
# File 'lib/aws-sdk-ec2/types.rb', line 18223 class DeleteIpamPoolRequest < Struct.new( :dry_run, :ipam_pool_id, :cascade) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
18223 18224 18225 18226 18227 18228 18229 |
# File 'lib/aws-sdk-ec2/types.rb', line 18223 class DeleteIpamPoolRequest < Struct.new( :dry_run, :ipam_pool_id, :cascade) SENSITIVE = [] include Aws::Structure end |
#ipam_pool_id ⇒ String
The ID of the pool to delete.
18223 18224 18225 18226 18227 18228 18229 |
# File 'lib/aws-sdk-ec2/types.rb', line 18223 class DeleteIpamPoolRequest < Struct.new( :dry_run, :ipam_pool_id, :cascade) SENSITIVE = [] include Aws::Structure end |