Class: Aws::EC2::Types::DeleteIpamRoutingPolicyRegistrationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cidrString

The IP address prefix in CIDR notation identifying the routing policy registration to delete.

Returns:

  • (String)


20038
20039
20040
20041
20042
20043
20044
20045
20046
# File 'lib/aws-sdk-ec2/types.rb', line 20038

class DeleteIpamRoutingPolicyRegistrationRequest < Struct.new(
  :dry_run,
  :ipam_internet_registry_association_id,
  :cidr,
  :force,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, the operation ignores the request, but does not return an error.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


20038
20039
20040
20041
20042
20043
20044
20045
20046
# File 'lib/aws-sdk-ec2/types.rb', line 20038

class DeleteIpamRoutingPolicyRegistrationRequest < Struct.new(
  :dry_run,
  :ipam_internet_registry_association_id,
  :cidr,
  :force,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


20038
20039
20040
20041
20042
20043
20044
20045
20046
# File 'lib/aws-sdk-ec2/types.rb', line 20038

class DeleteIpamRoutingPolicyRegistrationRequest < Struct.new(
  :dry_run,
  :ipam_internet_registry_association_id,
  :cidr,
  :force,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#forceBoolean

Forces the deletion even if it conflicts with an announced route. Default: false.

Returns:

  • (Boolean)


20038
20039
20040
20041
20042
20043
20044
20045
20046
# File 'lib/aws-sdk-ec2/types.rb', line 20038

class DeleteIpamRoutingPolicyRegistrationRequest < Struct.new(
  :dry_run,
  :ipam_internet_registry_association_id,
  :cidr,
  :force,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_internet_registry_association_idString

The ID of the IPAM internet registry association.

Returns:

  • (String)


20038
20039
20040
20041
20042
20043
20044
20045
20046
# File 'lib/aws-sdk-ec2/types.rb', line 20038

class DeleteIpamRoutingPolicyRegistrationRequest < Struct.new(
  :dry_run,
  :ipam_internet_registry_association_id,
  :cidr,
  :force,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end