Class: Aws::EC2::Types::DeleteIpamScopeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


20083
20084
20085
20086
20087
20088
# File 'lib/aws-sdk-ec2/types.rb', line 20083

class DeleteIpamScopeRequest < Struct.new(
  :dry_run,
  :ipam_scope_id)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_scope_idString

The ID of the scope to delete.

Returns:

  • (String)


20083
20084
20085
20086
20087
20088
# File 'lib/aws-sdk-ec2/types.rb', line 20083

class DeleteIpamScopeRequest < Struct.new(
  :dry_run,
  :ipam_scope_id)
  SENSITIVE = []
  include Aws::Structure
end