Class: Aws::EC2::Types::DeleteLaunchTemplateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteLaunchTemplateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#launch_template_id ⇒ String
The ID of the launch template.
-
#launch_template_name ⇒ String
The name of the launch template.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
20158 20159 20160 20161 20162 20163 20164 |
# File 'lib/aws-sdk-ec2/types.rb', line 20158 class DeleteLaunchTemplateRequest < Struct.new( :dry_run, :launch_template_id, :launch_template_name) SENSITIVE = [] include Aws::Structure end |
#launch_template_id ⇒ String
The ID of the launch template.
You must specify either the launch template ID or the launch template name, but not both.
20158 20159 20160 20161 20162 20163 20164 |
# File 'lib/aws-sdk-ec2/types.rb', line 20158 class DeleteLaunchTemplateRequest < Struct.new( :dry_run, :launch_template_id, :launch_template_name) SENSITIVE = [] include Aws::Structure end |
#launch_template_name ⇒ String
The name of the launch template.
You must specify either the launch template ID or the launch template name, but not both.
20158 20159 20160 20161 20162 20163 20164 |
# File 'lib/aws-sdk-ec2/types.rb', line 20158 class DeleteLaunchTemplateRequest < Struct.new( :dry_run, :launch_template_id, :launch_template_name) SENSITIVE = [] include Aws::Structure end |