Class: Aws::EC2::Types::DeleteLocalGatewayVirtualInterfaceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteLocalGatewayVirtualInterfaceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#local_gateway_virtual_interface_id ⇒ String
The ID of the local virtual interface to delete.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
20492 20493 20494 20495 20496 20497 |
# File 'lib/aws-sdk-ec2/types.rb', line 20492 class DeleteLocalGatewayVirtualInterfaceRequest < Struct.new( :local_gateway_virtual_interface_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#local_gateway_virtual_interface_id ⇒ String
The ID of the local virtual interface to delete.
20492 20493 20494 20495 20496 20497 |
# File 'lib/aws-sdk-ec2/types.rb', line 20492 class DeleteLocalGatewayVirtualInterfaceRequest < Struct.new( :local_gateway_virtual_interface_id, :dry_run) SENSITIVE = [] include Aws::Structure end |