Class: Aws::EC2::Types::DeletePlacementGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


20830
20831
20832
20833
20834
20835
# File 'lib/aws-sdk-ec2/types.rb', line 20830

class DeletePlacementGroupRequest < Struct.new(
  :dry_run,
  :group_name)
  SENSITIVE = []
  include Aws::Structure
end

#group_nameString

The name of the placement group.

Returns:

  • (String)


20830
20831
20832
20833
20834
20835
# File 'lib/aws-sdk-ec2/types.rb', line 20830

class DeletePlacementGroupRequest < Struct.new(
  :dry_run,
  :group_name)
  SENSITIVE = []
  include Aws::Structure
end