Class: Aws::EC2::Types::DeleteRouteServerPeerRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


21022
21023
21024
21025
21026
21027
# File 'lib/aws-sdk-ec2/types.rb', line 21022

class DeleteRouteServerPeerRequest < Struct.new(
  :route_server_peer_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#route_server_peer_idString

The ID of the route server peer to delete.

Returns:

  • (String)


21022
21023
21024
21025
21026
21027
# File 'lib/aws-sdk-ec2/types.rb', line 21022

class DeleteRouteServerPeerRequest < Struct.new(
  :route_server_peer_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end