Class: Aws::EC2::Types::DeleteSecondaryNetworkResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteSecondaryNetworkResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier to ensure the idempotency of the request.
-
#secondary_network ⇒ Types::SecondaryNetwork
Information about the secondary network.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier to ensure the idempotency of the request. Only returned if a client token was provided in the request.
20086 20087 20088 20089 20090 20091 |
# File 'lib/aws-sdk-ec2/types.rb', line 20086 class DeleteSecondaryNetworkResult < Struct.new( :secondary_network, :client_token) SENSITIVE = [] include Aws::Structure end |
#secondary_network ⇒ Types::SecondaryNetwork
Information about the secondary network.
20086 20087 20088 20089 20090 20091 |
# File 'lib/aws-sdk-ec2/types.rb', line 20086 class DeleteSecondaryNetworkResult < Struct.new( :secondary_network, :client_token) SENSITIVE = [] include Aws::Structure end |