Class: Aws::EC2::Types::DeleteSecondarySubnetResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteSecondarySubnetResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier to ensure the idempotency of the request.
-
#secondary_subnet ⇒ Types::SecondarySubnet
Information about the secondary subnet being deleted.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier to ensure the idempotency of the request. Only returned if a client token was provided in the request.
19731 19732 19733 19734 19735 19736 |
# File 'lib/aws-sdk-ec2/types.rb', line 19731 class DeleteSecondarySubnetResult < Struct.new( :secondary_subnet, :client_token) SENSITIVE = [] include Aws::Structure end |
#secondary_subnet ⇒ Types::SecondarySubnet
Information about the secondary subnet being deleted.
19731 19732 19733 19734 19735 19736 |
# File 'lib/aws-sdk-ec2/types.rb', line 19731 class DeleteSecondarySubnetResult < Struct.new( :secondary_subnet, :client_token) SENSITIVE = [] include Aws::Structure end |