Class: Aws::EC2::Types::DeleteSecurityGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteSecurityGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#group_id ⇒ String
The ID of the security group.
-
#group_name ⇒ String
[Default VPC] The name of the security group.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
21219 21220 21221 21222 21223 21224 21225 |
# File 'lib/aws-sdk-ec2/types.rb', line 21219 class DeleteSecurityGroupRequest < Struct.new( :group_id, :group_name, :dry_run) SENSITIVE = [] include Aws::Structure end |
#group_id ⇒ String
The ID of the security group.
21219 21220 21221 21222 21223 21224 21225 |
# File 'lib/aws-sdk-ec2/types.rb', line 21219 class DeleteSecurityGroupRequest < Struct.new( :group_id, :group_name, :dry_run) SENSITIVE = [] include Aws::Structure end |
#group_name ⇒ String
[Default VPC] The name of the security group. You can specify either the security group name or the security group ID. For security groups in a nondefault VPC, you must specify the security group ID.
21219 21220 21221 21222 21223 21224 21225 |
# File 'lib/aws-sdk-ec2/types.rb', line 21219 class DeleteSecurityGroupRequest < Struct.new( :group_id, :group_name, :dry_run) SENSITIVE = [] include Aws::Structure end |