Class: Aws::EC2::Types::DeleteSnapshotRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


21257
21258
21259
21260
21261
21262
# File 'lib/aws-sdk-ec2/types.rb', line 21257

class DeleteSnapshotRequest < Struct.new(
  :snapshot_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_idString

The ID of the EBS snapshot.

Returns:

  • (String)


21257
21258
21259
21260
21261
21262
# File 'lib/aws-sdk-ec2/types.rb', line 21257

class DeleteSnapshotRequest < Struct.new(
  :snapshot_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end