Class: Aws::EC2::Types::DeleteSubnetCidrReservationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteSubnetCidrReservationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#subnet_cidr_reservation_id ⇒ String
The ID of the subnet CIDR reservation.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
21337 21338 21339 21340 21341 21342 |
# File 'lib/aws-sdk-ec2/types.rb', line 21337 class DeleteSubnetCidrReservationRequest < Struct.new( :subnet_cidr_reservation_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#subnet_cidr_reservation_id ⇒ String
The ID of the subnet CIDR reservation.
21337 21338 21339 21340 21341 21342 |
# File 'lib/aws-sdk-ec2/types.rb', line 21337 class DeleteSubnetCidrReservationRequest < Struct.new( :subnet_cidr_reservation_id, :dry_run) SENSITIVE = [] include Aws::Structure end |