Class: Aws::EC2::Types::DeleteTransitGatewayMulticastDomainRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


21721
21722
21723
21724
21725
21726
# File 'lib/aws-sdk-ec2/types.rb', line 21721

class DeleteTransitGatewayMulticastDomainRequest < Struct.new(
  :transit_gateway_multicast_domain_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_multicast_domain_idString

The ID of the transit gateway multicast domain.

Returns:

  • (String)


21721
21722
21723
21724
21725
21726
# File 'lib/aws-sdk-ec2/types.rb', line 21721

class DeleteTransitGatewayMulticastDomainRequest < Struct.new(
  :transit_gateway_multicast_domain_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end