Class: Aws::EC2::Types::DeleteTransitGatewayRouteRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#destination_cidr_blockString

The CIDR range for the route. This must match the CIDR for the route exactly.

Returns:

  • (String)


21910
21911
21912
21913
21914
21915
21916
# File 'lib/aws-sdk-ec2/types.rb', line 21910

class DeleteTransitGatewayRouteRequest < Struct.new(
  :transit_gateway_route_table_id,
  :destination_cidr_block,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


21910
21911
21912
21913
21914
21915
21916
# File 'lib/aws-sdk-ec2/types.rb', line 21910

class DeleteTransitGatewayRouteRequest < Struct.new(
  :transit_gateway_route_table_id,
  :destination_cidr_block,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_route_table_idString

The ID of the transit gateway route table.

Returns:

  • (String)


21910
21911
21912
21913
21914
21915
21916
# File 'lib/aws-sdk-ec2/types.rb', line 21910

class DeleteTransitGatewayRouteRequest < Struct.new(
  :transit_gateway_route_table_id,
  :destination_cidr_block,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end