Class: Aws::EC2::Types::DeleteVerifiedAccessEndpointRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteVerifiedAccessEndpointRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#verified_access_endpoint_id ⇒ String
The ID of the Verified Access endpoint.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring idempotency.
A suitable default value is auto-generated. You should normally not need to pass this option.
22067 22068 22069 22070 22071 22072 22073 |
# File 'lib/aws-sdk-ec2/types.rb', line 22067 class DeleteVerifiedAccessEndpointRequest < Struct.new( :verified_access_endpoint_id, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
22067 22068 22069 22070 22071 22072 22073 |
# File 'lib/aws-sdk-ec2/types.rb', line 22067 class DeleteVerifiedAccessEndpointRequest < Struct.new( :verified_access_endpoint_id, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#verified_access_endpoint_id ⇒ String
The ID of the Verified Access endpoint.
22067 22068 22069 22070 22071 22072 22073 |
# File 'lib/aws-sdk-ec2/types.rb', line 22067 class DeleteVerifiedAccessEndpointRequest < Struct.new( :verified_access_endpoint_id, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |