Class: Aws::EC2::Types::DeleteVpcEndpointConnectionNotificationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#connection_notification_idsArray<String>

The IDs of the notifications.

Returns:

  • (Array<String>)


22307
22308
22309
22310
22311
22312
# File 'lib/aws-sdk-ec2/types.rb', line 22307

class DeleteVpcEndpointConnectionNotificationsRequest < Struct.new(
  :dry_run,
  :connection_notification_ids)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


22307
22308
22309
22310
22311
22312
# File 'lib/aws-sdk-ec2/types.rb', line 22307

class DeleteVpcEndpointConnectionNotificationsRequest < Struct.new(
  :dry_run,
  :connection_notification_ids)
  SENSITIVE = []
  include Aws::Structure
end