Class: Aws::EC2::Types::DeleteVpcEndpointsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


22391
22392
22393
22394
22395
22396
# File 'lib/aws-sdk-ec2/types.rb', line 22391

class DeleteVpcEndpointsRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_ids)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_endpoint_idsArray<String>

The IDs of the VPC endpoints.

Returns:

  • (Array<String>)


22391
22392
22393
22394
22395
22396
# File 'lib/aws-sdk-ec2/types.rb', line 22391

class DeleteVpcEndpointsRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_ids)
  SENSITIVE = []
  include Aws::Structure
end