Class: Aws::EC2::Types::DeprovisionByoipCidrRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cidrString

The address range, in CIDR notation. The prefix must be the same prefix that you specified when you provisioned the address range.

Returns:

  • (String)


22605
22606
22607
22608
22609
22610
# File 'lib/aws-sdk-ec2/types.rb', line 22605

class DeprovisionByoipCidrRequest < Struct.new(
  :cidr,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


22605
22606
22607
22608
22609
22610
# File 'lib/aws-sdk-ec2/types.rb', line 22605

class DeprovisionByoipCidrRequest < Struct.new(
  :cidr,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end