Class: Aws::EC2::Types::DescribeAggregateIdFormatRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


23180
23181
23182
23183
23184
# File 'lib/aws-sdk-ec2/types.rb', line 23180

class DescribeAggregateIdFormatRequest < Struct.new(
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end