Class: Aws::EC2::Types::DescribeApplicationStatusCheckAssociationsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeApplicationStatusCheckAssociationsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#associations ⇒ Array<Types::ApplicationStatusCheckAssociationObject>
The associations for the specified application status checks.
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#tags ⇒ Array<Types::Tag>
The tags associated with the application status checks.
Instance Attribute Details
#associations ⇒ Array<Types::ApplicationStatusCheckAssociationObject>
The associations for the specified application status checks.
22948 22949 22950 22951 22952 22953 22954 |
# File 'lib/aws-sdk-ec2/types.rb', line 22948 class DescribeApplicationStatusCheckAssociationsResult < Struct.new( :associations, :next_token, :tags) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of items. This value is <code>null</code> when there are no more items to return.
22948 22949 22950 22951 22952 22953 22954 |
# File 'lib/aws-sdk-ec2/types.rb', line 22948 class DescribeApplicationStatusCheckAssociationsResult < Struct.new( :associations, :next_token, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags associated with the application status checks.
22948 22949 22950 22951 22952 22953 22954 |
# File 'lib/aws-sdk-ec2/types.rb', line 22948 class DescribeApplicationStatusCheckAssociationsResult < Struct.new( :associations, :next_token, :tags) SENSITIVE = [] include Aws::Structure end |