Class: Aws::EC2::Types::DescribeApplicationStatusChecksResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeApplicationStatusChecksResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_status_checks ⇒ Array<Types::ApplicationStatusCheckResponseObject>
Information about the application status checks.
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
Instance Attribute Details
#application_status_checks ⇒ Array<Types::ApplicationStatusCheckResponseObject>
Information about the application status checks.
23024 23025 23026 23027 23028 23029 |
# File 'lib/aws-sdk-ec2/types.rb', line 23024 class DescribeApplicationStatusChecksResult < Struct.new( :application_status_checks, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of items. This value is <code>null</code> when there are no more items to return.
23024 23025 23026 23027 23028 23029 |
# File 'lib/aws-sdk-ec2/types.rb', line 23024 class DescribeApplicationStatusChecksResult < Struct.new( :application_status_checks, :next_token) SENSITIVE = [] include Aws::Structure end |