Class: Aws::EC2::Types::DescribeApplicationStatusResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeApplicationStatusResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_statuses ⇒ Types::ApplicationStatusesResponseType
The application statuses for the specified instances.
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
Instance Attribute Details
#application_statuses ⇒ Types::ApplicationStatusesResponseType
The application statuses for the specified instances.
23091 23092 23093 23094 23095 23096 |
# File 'lib/aws-sdk-ec2/types.rb', line 23091 class DescribeApplicationStatusResult < Struct.new( :application_statuses, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of items. This value is <code>null</code> when there are no more items to return.
23091 23092 23093 23094 23095 23096 |
# File 'lib/aws-sdk-ec2/types.rb', line 23091 class DescribeApplicationStatusResult < Struct.new( :application_statuses, :next_token) SENSITIVE = [] include Aws::Structure end |