Class: Aws::EC2::Types::DescribeBundleTasksRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeBundleTasksRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bundle_ids ⇒ Array<String>
The bundle task IDs.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The filters.
Instance Attribute Details
#bundle_ids ⇒ Array<String>
The bundle task IDs.
Default: Describes all your bundle tasks.
23603 23604 23605 23606 23607 23608 23609 |
# File 'lib/aws-sdk-ec2/types.rb', line 23603 class DescribeBundleTasksRequest < Struct.new( :bundle_ids, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
23603 23604 23605 23606 23607 23608 23609 |
# File 'lib/aws-sdk-ec2/types.rb', line 23603 class DescribeBundleTasksRequest < Struct.new( :bundle_ids, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters.
-
bundle-id- The ID of the bundle task. -
error-code- If the task failed, the error code returned. -
error-message- If the task failed, the error message returned. -
instance-id- The ID of the instance. -
progress- The level of task completion, as a percentage (for example, 20%). -
s3-bucket- The Amazon S3 bucket to store the AMI. -
s3-prefix- The beginning of the AMI name. -
start-time- The time the task started (for example, 2013-09-15T17:15:20.000Z). -
state- The state of the task (pending|waiting-for-shutdown|bundling|storing|cancelling|complete|failed). -
update-time- The time of the most recent update for the task.
23603 23604 23605 23606 23607 23608 23609 |
# File 'lib/aws-sdk-ec2/types.rb', line 23603 class DescribeBundleTasksRequest < Struct.new( :bundle_ids, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |