Class: Aws::EC2::Types::DescribeByoipCidrsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeByoipCidrsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
23651 23652 23653 23654 23655 23656 23657 |
# File 'lib/aws-sdk-ec2/types.rb', line 23651 class DescribeByoipCidrsRequest < Struct.new( :dry_run, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To
retrieve the remaining results, make another call with the returned
nextToken value.
23651 23652 23653 23654 23655 23656 23657 |
# File 'lib/aws-sdk-ec2/types.rb', line 23651 class DescribeByoipCidrsRequest < Struct.new( :dry_run, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
23651 23652 23653 23654 23655 23656 23657 |
# File 'lib/aws-sdk-ec2/types.rb', line 23651 class DescribeByoipCidrsRequest < Struct.new( :dry_run, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |