Class: Aws::EC2::Types::DescribeCapacityBlockExtensionOfferingsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeCapacityBlockExtensionOfferingsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_block_extension_duration_hours ⇒ Integer
The duration of the Capacity Block extension offering in hours.
-
#capacity_reservation_id ⇒ String
The ID of the Capacity reservation to be extended.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token to use to retrieve the next page of results.
Instance Attribute Details
#capacity_block_extension_duration_hours ⇒ Integer
The duration of the Capacity Block extension offering in hours.
23776 23777 23778 23779 23780 23781 23782 23783 23784 |
# File 'lib/aws-sdk-ec2/types.rb', line 23776 class DescribeCapacityBlockExtensionOfferingsRequest < Struct.new( :dry_run, :capacity_block_extension_duration_hours, :capacity_reservation_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#capacity_reservation_id ⇒ String
The ID of the Capacity reservation to be extended.
23776 23777 23778 23779 23780 23781 23782 23783 23784 |
# File 'lib/aws-sdk-ec2/types.rb', line 23776 class DescribeCapacityBlockExtensionOfferingsRequest < Struct.new( :dry_run, :capacity_block_extension_duration_hours, :capacity_reservation_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
23776 23777 23778 23779 23780 23781 23782 23783 23784 |
# File 'lib/aws-sdk-ec2/types.rb', line 23776 class DescribeCapacityBlockExtensionOfferingsRequest < Struct.new( :dry_run, :capacity_block_extension_duration_hours, :capacity_reservation_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
23776 23777 23778 23779 23780 23781 23782 23783 23784 |
# File 'lib/aws-sdk-ec2/types.rb', line 23776 class DescribeCapacityBlockExtensionOfferingsRequest < Struct.new( :dry_run, :capacity_block_extension_duration_hours, :capacity_reservation_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to retrieve the next page of results.
23776 23777 23778 23779 23780 23781 23782 23783 23784 |
# File 'lib/aws-sdk-ec2/types.rb', line 23776 class DescribeCapacityBlockExtensionOfferingsRequest < Struct.new( :dry_run, :capacity_block_extension_duration_hours, :capacity_reservation_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |