Class: Aws::EC2::Types::DescribeCapacityBlockOfferingsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#all_availability_zonesBoolean

Include all Availability Zones and Local Zones, regardless of your opt-in status. If you do not use this parameter, the results include available offerings from all Availability Zones in the Amazon Web Services Region and Local Zones you are opted into.

Returns:

  • (Boolean)


23868
23869
23870
23871
23872
23873
23874
23875
23876
23877
23878
23879
23880
23881
23882
# File 'lib/aws-sdk-ec2/types.rb', line 23868

class DescribeCapacityBlockOfferingsRequest < Struct.new(
  :dry_run,
  :instance_type,
  :instance_count,
  :start_date_range,
  :end_date_range,
  :capacity_duration_hours,
  :next_token,
  :max_results,
  :ultraserver_type,
  :ultraserver_count,
  :all_availability_zones)
  SENSITIVE = []
  include Aws::Structure
end

#capacity_duration_hoursInteger

The reservation duration for the Capacity Block, in hours. You must specify the duration in 1-day increments up 14 days, and in 7-day increments up to 182 days.

Returns:

  • (Integer)


23868
23869
23870
23871
23872
23873
23874
23875
23876
23877
23878
23879
23880
23881
23882
# File 'lib/aws-sdk-ec2/types.rb', line 23868

class DescribeCapacityBlockOfferingsRequest < Struct.new(
  :dry_run,
  :instance_type,
  :instance_count,
  :start_date_range,
  :end_date_range,
  :capacity_duration_hours,
  :next_token,
  :max_results,
  :ultraserver_type,
  :ultraserver_count,
  :all_availability_zones)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


23868
23869
23870
23871
23872
23873
23874
23875
23876
23877
23878
23879
23880
23881
23882
# File 'lib/aws-sdk-ec2/types.rb', line 23868

class DescribeCapacityBlockOfferingsRequest < Struct.new(
  :dry_run,
  :instance_type,
  :instance_count,
  :start_date_range,
  :end_date_range,
  :capacity_duration_hours,
  :next_token,
  :max_results,
  :ultraserver_type,
  :ultraserver_count,
  :all_availability_zones)
  SENSITIVE = []
  include Aws::Structure
end

#end_date_rangeTime

The latest end date for the Capacity Block offering.

Returns:

  • (Time)


23868
23869
23870
23871
23872
23873
23874
23875
23876
23877
23878
23879
23880
23881
23882
# File 'lib/aws-sdk-ec2/types.rb', line 23868

class DescribeCapacityBlockOfferingsRequest < Struct.new(
  :dry_run,
  :instance_type,
  :instance_count,
  :start_date_range,
  :end_date_range,
  :capacity_duration_hours,
  :next_token,
  :max_results,
  :ultraserver_type,
  :ultraserver_count,
  :all_availability_zones)
  SENSITIVE = []
  include Aws::Structure
end

#instance_countInteger

The number of instances for which to reserve capacity. Each Capacity Block can have up to 64 instances, and you can have up to 256 instances across Capacity Blocks.

Returns:

  • (Integer)


23868
23869
23870
23871
23872
23873
23874
23875
23876
23877
23878
23879
23880
23881
23882
# File 'lib/aws-sdk-ec2/types.rb', line 23868

class DescribeCapacityBlockOfferingsRequest < Struct.new(
  :dry_run,
  :instance_type,
  :instance_count,
  :start_date_range,
  :end_date_range,
  :capacity_duration_hours,
  :next_token,
  :max_results,
  :ultraserver_type,
  :ultraserver_count,
  :all_availability_zones)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

The type of instance for which the Capacity Block offering reserves capacity.

Returns:

  • (String)


23868
23869
23870
23871
23872
23873
23874
23875
23876
23877
23878
23879
23880
23881
23882
# File 'lib/aws-sdk-ec2/types.rb', line 23868

class DescribeCapacityBlockOfferingsRequest < Struct.new(
  :dry_run,
  :instance_type,
  :instance_count,
  :start_date_range,
  :end_date_range,
  :capacity_duration_hours,
  :next_token,
  :max_results,
  :ultraserver_type,
  :ultraserver_count,
  :all_availability_zones)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.

Returns:

  • (Integer)


23868
23869
23870
23871
23872
23873
23874
23875
23876
23877
23878
23879
23880
23881
23882
# File 'lib/aws-sdk-ec2/types.rb', line 23868

class DescribeCapacityBlockOfferingsRequest < Struct.new(
  :dry_run,
  :instance_type,
  :instance_count,
  :start_date_range,
  :end_date_range,
  :capacity_duration_hours,
  :next_token,
  :max_results,
  :ultraserver_type,
  :ultraserver_count,
  :all_availability_zones)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to use to retrieve the next page of results.

Returns:

  • (String)


23868
23869
23870
23871
23872
23873
23874
23875
23876
23877
23878
23879
23880
23881
23882
# File 'lib/aws-sdk-ec2/types.rb', line 23868

class DescribeCapacityBlockOfferingsRequest < Struct.new(
  :dry_run,
  :instance_type,
  :instance_count,
  :start_date_range,
  :end_date_range,
  :capacity_duration_hours,
  :next_token,
  :max_results,
  :ultraserver_type,
  :ultraserver_count,
  :all_availability_zones)
  SENSITIVE = []
  include Aws::Structure
end

#start_date_rangeTime

The earliest start date for the Capacity Block offering.

Returns:

  • (Time)


23868
23869
23870
23871
23872
23873
23874
23875
23876
23877
23878
23879
23880
23881
23882
# File 'lib/aws-sdk-ec2/types.rb', line 23868

class DescribeCapacityBlockOfferingsRequest < Struct.new(
  :dry_run,
  :instance_type,
  :instance_count,
  :start_date_range,
  :end_date_range,
  :capacity_duration_hours,
  :next_token,
  :max_results,
  :ultraserver_type,
  :ultraserver_count,
  :all_availability_zones)
  SENSITIVE = []
  include Aws::Structure
end

#ultraserver_countInteger

The number of EC2 UltraServers in the offerings.

Returns:

  • (Integer)


23868
23869
23870
23871
23872
23873
23874
23875
23876
23877
23878
23879
23880
23881
23882
# File 'lib/aws-sdk-ec2/types.rb', line 23868

class DescribeCapacityBlockOfferingsRequest < Struct.new(
  :dry_run,
  :instance_type,
  :instance_count,
  :start_date_range,
  :end_date_range,
  :capacity_duration_hours,
  :next_token,
  :max_results,
  :ultraserver_type,
  :ultraserver_count,
  :all_availability_zones)
  SENSITIVE = []
  include Aws::Structure
end

#ultraserver_typeString

The EC2 UltraServer type of the Capacity Block offerings.

Returns:

  • (String)


23868
23869
23870
23871
23872
23873
23874
23875
23876
23877
23878
23879
23880
23881
23882
# File 'lib/aws-sdk-ec2/types.rb', line 23868

class DescribeCapacityBlockOfferingsRequest < Struct.new(
  :dry_run,
  :instance_type,
  :instance_count,
  :start_date_range,
  :end_date_range,
  :capacity_duration_hours,
  :next_token,
  :max_results,
  :ultraserver_type,
  :ultraserver_count,
  :all_availability_zones)
  SENSITIVE = []
  include Aws::Structure
end