Class: Aws::EC2::Types::DescribeCapacityManagerDataExportsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeCapacityManagerDataExportsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_manager_data_exports ⇒ Array<Types::CapacityManagerDataExportResponse>
Information about the data export configurations, including export settings, delivery status, and recent activity.
-
#next_token ⇒ String
The token to use to retrieve the next page of results.
Instance Attribute Details
#capacity_manager_data_exports ⇒ Array<Types::CapacityManagerDataExportResponse>
Information about the data export configurations, including export settings, delivery status, and recent activity.
21773 21774 21775 21776 21777 21778 |
# File 'lib/aws-sdk-ec2/types.rb', line 21773 class DescribeCapacityManagerDataExportsResult < Struct.new( :capacity_manager_data_exports, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to retrieve the next page of results. This value is null when there are no more results to return.
21773 21774 21775 21776 21777 21778 |
# File 'lib/aws-sdk-ec2/types.rb', line 21773 class DescribeCapacityManagerDataExportsResult < Struct.new( :capacity_manager_data_exports, :next_token) SENSITIVE = [] include Aws::Structure end |