Class: Aws::EC2::Types::DescribeCapacityReservationBillingRequestsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_reservation_idsArray<String>

The ID of the Capacity Reservation.

Returns:

  • (Array<String>)


24161
24162
24163
24164
24165
24166
24167
24168
24169
24170
# File 'lib/aws-sdk-ec2/types.rb', line 24161

class DescribeCapacityReservationBillingRequestsRequest < Struct.new(
  :capacity_reservation_ids,
  :role,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


24161
24162
24163
24164
24165
24166
24167
24168
24169
24170
# File 'lib/aws-sdk-ec2/types.rb', line 24161

class DescribeCapacityReservationBillingRequestsRequest < Struct.new(
  :capacity_reservation_ids,
  :role,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters.

  • status - The state of the request (pending | accepted | rejected | cancelled | revoked | expired).

  • requested-by - The account ID of the Capacity Reservation owner that initiated the request. Not supported if you specify requested-by for Role.

  • unused-reservation-billing-owner - The ID of the consumer account to which the request was sent. Not supported if you specify unused-reservation-billing-owner for Role.

Returns:



24161
24162
24163
24164
24165
24166
24167
24168
24169
24170
# File 'lib/aws-sdk-ec2/types.rb', line 24161

class DescribeCapacityReservationBillingRequestsRequest < Struct.new(
  :capacity_reservation_ids,
  :role,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.

Returns:

  • (Integer)


24161
24162
24163
24164
24165
24166
24167
24168
24169
24170
# File 'lib/aws-sdk-ec2/types.rb', line 24161

class DescribeCapacityReservationBillingRequestsRequest < Struct.new(
  :capacity_reservation_ids,
  :role,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to use to retrieve the next page of results.

Returns:

  • (String)


24161
24162
24163
24164
24165
24166
24167
24168
24169
24170
# File 'lib/aws-sdk-ec2/types.rb', line 24161

class DescribeCapacityReservationBillingRequestsRequest < Struct.new(
  :capacity_reservation_ids,
  :role,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#roleString

Specify one of the following:

  • odcr-owner - If you are the Capacity Reservation owner, specify this value to view requests that you have initiated. Not supported with the requested-by filter.

  • unused-reservation-billing-owner - If you are the consumer account, specify this value to view requests that have been sent to you. Not supported with the unused-reservation-billing-owner filter.

Returns:

  • (String)


24161
24162
24163
24164
24165
24166
24167
24168
24169
24170
# File 'lib/aws-sdk-ec2/types.rb', line 24161

class DescribeCapacityReservationBillingRequestsRequest < Struct.new(
  :capacity_reservation_ids,
  :role,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end