Class: Aws::EC2::Types::DescribeCapacityReservationTopologyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_reservation_idsArray<String>

The Capacity Reservation IDs.

Default: Describes all your Capacity Reservations.

Constraints: Maximum 100 explicitly specified Capacity Reservation IDs.

Returns:

  • (Array<String>)


22581
22582
22583
22584
22585
22586
22587
22588
22589
# File 'lib/aws-sdk-ec2/types.rb', line 22581

class DescribeCapacityReservationTopologyRequest < Struct.new(
  :dry_run,
  :next_token,
  :max_results,
  :capacity_reservation_ids,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


22581
22582
22583
22584
22585
22586
22587
22588
22589
# File 'lib/aws-sdk-ec2/types.rb', line 22581

class DescribeCapacityReservationTopologyRequest < Struct.new(
  :dry_run,
  :next_token,
  :max_results,
  :capacity_reservation_ids,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters.

  • ‘availability-zone` - The name of the Availability Zone (for example, `us-west-2a`) or Local Zone (for example, `us-west-2-lax-1b`) that the Capacity Reservation is in.

  • ‘instance-type` - The instance type (for example, `p4d.24xlarge`) or instance family (for example, `p4d*`). You can use the `*` wildcard to match zero or more characters, or the `?` wildcard to match zero or one character.

Returns:



22581
22582
22583
22584
22585
22586
22587
22588
22589
# File 'lib/aws-sdk-ec2/types.rb', line 22581

class DescribeCapacityReservationTopologyRequest < Struct.new(
  :dry_run,
  :next_token,
  :max_results,
  :capacity_reservation_ids,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].

You can’t specify this parameter and the Capacity Reservation IDs parameter in the same request.

Default: ‘10`

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination

Returns:

  • (Integer)


22581
22582
22583
22584
22585
22586
22587
22588
22589
# File 'lib/aws-sdk-ec2/types.rb', line 22581

class DescribeCapacityReservationTopologyRequest < Struct.new(
  :dry_run,
  :next_token,
  :max_results,
  :capacity_reservation_ids,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Returns:

  • (String)


22581
22582
22583
22584
22585
22586
22587
22588
22589
# File 'lib/aws-sdk-ec2/types.rb', line 22581

class DescribeCapacityReservationTopologyRequest < Struct.new(
  :dry_run,
  :next_token,
  :max_results,
  :capacity_reservation_ids,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end