Class: Aws::EC2::Types::DescribeCarrierGatewaysRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#carrier_gateway_idsArray<String>

One or more carrier gateway IDs.

Returns:

  • (Array<String>)


23114
23115
23116
23117
23118
23119
23120
23121
23122
# File 'lib/aws-sdk-ec2/types.rb', line 23114

class DescribeCarrierGatewaysRequest < Struct.new(
  :carrier_gateway_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


23114
23115
23116
23117
23118
23119
23120
23121
23122
# File 'lib/aws-sdk-ec2/types.rb', line 23114

class DescribeCarrierGatewaysRequest < Struct.new(
  :carrier_gateway_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters.

  • carrier-gateway-id - The ID of the carrier gateway.

  • state - The state of the carrier gateway (pending | failed | available | deleting | deleted).

  • owner-id - The Amazon Web Services account ID of the owner of the carrier gateway.

  • tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.

  • tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.

  • vpc-id - The ID of the VPC associated with the carrier gateway.

Returns:



23114
23115
23116
23117
23118
23119
23120
23121
23122
# File 'lib/aws-sdk-ec2/types.rb', line 23114

class DescribeCarrierGatewaysRequest < Struct.new(
  :carrier_gateway_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.

Returns:

  • (Integer)


23114
23115
23116
23117
23118
23119
23120
23121
23122
# File 'lib/aws-sdk-ec2/types.rb', line 23114

class DescribeCarrierGatewaysRequest < Struct.new(
  :carrier_gateway_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


23114
23115
23116
23117
23118
23119
23120
23121
23122
# File 'lib/aws-sdk-ec2/types.rb', line 23114

class DescribeCarrierGatewaysRequest < Struct.new(
  :carrier_gateway_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end