Class: Aws::EC2::Types::DescribeClientVpnAuthorizationRulesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_vpn_endpoint_idString

The ID of the Client VPN endpoint.

Returns:

  • (String)


23253
23254
23255
23256
23257
23258
23259
23260
23261
# File 'lib/aws-sdk-ec2/types.rb', line 23253

class DescribeClientVpnAuthorizationRulesRequest < Struct.new(
  :client_vpn_endpoint_id,
  :dry_run,
  :next_token,
  :filters,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


23253
23254
23255
23256
23257
23258
23259
23260
23261
# File 'lib/aws-sdk-ec2/types.rb', line 23253

class DescribeClientVpnAuthorizationRulesRequest < Struct.new(
  :client_vpn_endpoint_id,
  :dry_run,
  :next_token,
  :filters,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters. Filter names and values are case-sensitive.

  • ‘description` - The description of the authorization rule.

  • ‘destination-cidr` - The CIDR of the network to which the authorization rule applies.

  • ‘group-id` - The ID of the Active Directory group to which the authorization rule grants access.

Returns:



23253
23254
23255
23256
23257
23258
23259
23260
23261
# File 'lib/aws-sdk-ec2/types.rb', line 23253

class DescribeClientVpnAuthorizationRulesRequest < Struct.new(
  :client_vpn_endpoint_id,
  :dry_run,
  :next_token,
  :filters,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the nextToken value.

Returns:

  • (Integer)


23253
23254
23255
23256
23257
23258
23259
23260
23261
# File 'lib/aws-sdk-ec2/types.rb', line 23253

class DescribeClientVpnAuthorizationRulesRequest < Struct.new(
  :client_vpn_endpoint_id,
  :dry_run,
  :next_token,
  :filters,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to retrieve the next page of results.

Returns:

  • (String)


23253
23254
23255
23256
23257
23258
23259
23260
23261
# File 'lib/aws-sdk-ec2/types.rb', line 23253

class DescribeClientVpnAuthorizationRulesRequest < Struct.new(
  :client_vpn_endpoint_id,
  :dry_run,
  :next_token,
  :filters,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end