Class: Aws::EC2::Types::DescribeClientVpnEndpointsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeClientVpnEndpointsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_vpn_endpoints ⇒ Array<Types::ClientVpnEndpoint>
Information about the Client VPN endpoints.
-
#next_token ⇒ String
The token to use to retrieve the next page of results.
Instance Attribute Details
#client_vpn_endpoints ⇒ Array<Types::ClientVpnEndpoint>
Information about the Client VPN endpoints.
24556 24557 24558 24559 24560 24561 |
# File 'lib/aws-sdk-ec2/types.rb', line 24556 class DescribeClientVpnEndpointsResult < Struct.new( :client_vpn_endpoints, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to retrieve the next page of results. This value is
null when there are no more results to return.
24556 24557 24558 24559 24560 24561 |
# File 'lib/aws-sdk-ec2/types.rb', line 24556 class DescribeClientVpnEndpointsResult < Struct.new( :client_vpn_endpoints, :next_token) SENSITIVE = [] include Aws::Structure end |