Class: Aws::EC2::Types::DescribeEgressOnlyInternetGatewaysRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeEgressOnlyInternetGatewaysRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#egress_only_internet_gateway_ids ⇒ Array<String>
The IDs of the egress-only internet gateways.
-
#filters ⇒ Array<Types::Filter>
The filters.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token returned from a previous paginated request.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
23306 23307 23308 23309 23310 23311 23312 23313 23314 |
# File 'lib/aws-sdk-ec2/types.rb', line 23306 class DescribeEgressOnlyInternetGatewaysRequest < Struct.new( :dry_run, :egress_only_internet_gateway_ids, :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#egress_only_internet_gateway_ids ⇒ Array<String>
The IDs of the egress-only internet gateways.
23306 23307 23308 23309 23310 23311 23312 23313 23314 |
# File 'lib/aws-sdk-ec2/types.rb', line 23306 class DescribeEgressOnlyInternetGatewaysRequest < Struct.new( :dry_run, :egress_only_internet_gateway_ids, :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters.
-
‘tag` - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key `Owner` and the value `TeamA`, specify `tag:Owner` for the filter name and `TeamA` for the filter value.
-
‘tag-key` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.
23306 23307 23308 23309 23310 23311 23312 23313 23314 |
# File 'lib/aws-sdk-ec2/types.rb', line 23306 class DescribeEgressOnlyInternetGatewaysRequest < Struct.new( :dry_run, :egress_only_internet_gateway_ids, :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination
23306 23307 23308 23309 23310 23311 23312 23313 23314 |
# File 'lib/aws-sdk-ec2/types.rb', line 23306 class DescribeEgressOnlyInternetGatewaysRequest < Struct.new( :dry_run, :egress_only_internet_gateway_ids, :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
23306 23307 23308 23309 23310 23311 23312 23313 23314 |
# File 'lib/aws-sdk-ec2/types.rb', line 23306 class DescribeEgressOnlyInternetGatewaysRequest < Struct.new( :dry_run, :egress_only_internet_gateway_ids, :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |