Class: Aws::EC2::Types::DescribeElasticGpusRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


24215
24216
24217
24218
24219
24220
24221
24222
24223
# File 'lib/aws-sdk-ec2/types.rb', line 24215

class DescribeElasticGpusRequest < Struct.new(
  :elastic_gpu_ids,
  :dry_run,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#elastic_gpu_idsArray<String>

The Elastic Graphics accelerator IDs.

Returns:

  • (Array<String>)


24215
24216
24217
24218
24219
24220
24221
24222
24223
# File 'lib/aws-sdk-ec2/types.rb', line 24215

class DescribeElasticGpusRequest < Struct.new(
  :elastic_gpu_ids,
  :dry_run,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters.

  • availability-zone - The Availability Zone in which the Elastic Graphics accelerator resides.

  • elastic-gpu-health - The status of the Elastic Graphics accelerator (OK | IMPAIRED).

  • elastic-gpu-state - The state of the Elastic Graphics accelerator (ATTACHED).

  • elastic-gpu-type - The type of Elastic Graphics accelerator; for example, eg1.medium.

  • instance-id - The ID of the instance to which the Elastic Graphics accelerator is associated.

Returns:



24215
24216
24217
24218
24219
24220
24221
24222
24223
# File 'lib/aws-sdk-ec2/types.rb', line 24215

class DescribeElasticGpusRequest < Struct.new(
  :elastic_gpu_ids,
  :dry_run,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned NextToken value. This value can be between 5 and 1000.

Returns:

  • (Integer)


24215
24216
24217
24218
24219
24220
24221
24222
24223
# File 'lib/aws-sdk-ec2/types.rb', line 24215

class DescribeElasticGpusRequest < Struct.new(
  :elastic_gpu_ids,
  :dry_run,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to request the next page of results.

Returns:

  • (String)


24215
24216
24217
24218
24219
24220
24221
24222
24223
# File 'lib/aws-sdk-ec2/types.rb', line 24215

class DescribeElasticGpusRequest < Struct.new(
  :elastic_gpu_ids,
  :dry_run,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end