Class: Aws::EC2::Types::DescribeElasticGpusResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeElasticGpusResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#elastic_gpu_set ⇒ Array<Types::ElasticGpus>
Information about the Elastic Graphics accelerators.
-
#max_results ⇒ Integer
The total number of items to return.
-
#next_token ⇒ String
The token to use to retrieve the next page of results.
Instance Attribute Details
#elastic_gpu_set ⇒ Array<Types::ElasticGpus>
Information about the Elastic Graphics accelerators.
25131 25132 25133 25134 25135 25136 25137 |
# File 'lib/aws-sdk-ec2/types.rb', line 25131 class DescribeElasticGpusResult < Struct.new( :elastic_gpu_set, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The total number of items to return. If the total number of items available is more than the value specified in max-items then a Next-Token will be provided in the output that you can use to resume pagination.
25131 25132 25133 25134 25135 25136 25137 |
# File 'lib/aws-sdk-ec2/types.rb', line 25131 class DescribeElasticGpusResult < Struct.new( :elastic_gpu_set, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to retrieve the next page of results. This value is
null when there are no more results to return.
25131 25132 25133 25134 25135 25136 25137 |
# File 'lib/aws-sdk-ec2/types.rb', line 25131 class DescribeElasticGpusResult < Struct.new( :elastic_gpu_set, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |