Class: Aws::EC2::Types::DescribeFastLaunchImagesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeFastLaunchImagesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
Use the following filters to streamline results.
-
#image_ids ⇒ Array<String>
Specify one or more Windows AMI image IDs for the request.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token returned from a previous paginated request.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
24281 24282 24283 24284 24285 24286 24287 24288 24289 |
# File 'lib/aws-sdk-ec2/types.rb', line 24281 class DescribeFastLaunchImagesRequest < Struct.new( :image_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
Use the following filters to streamline results.
-
resource-type- The resource type for pre-provisioning. -
owner-id- The owner ID for the pre-provisioning resource. -
state- The current state of fast launching for the Windows AMI.
24281 24282 24283 24284 24285 24286 24287 24288 24289 |
# File 'lib/aws-sdk-ec2/types.rb', line 24281 class DescribeFastLaunchImagesRequest < Struct.new( :image_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#image_ids ⇒ Array<String>
Specify one or more Windows AMI image IDs for the request.
24281 24282 24283 24284 24285 24286 24287 24288 24289 |
# File 'lib/aws-sdk-ec2/types.rb', line 24281 class DescribeFastLaunchImagesRequest < Struct.new( :image_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
24281 24282 24283 24284 24285 24286 24287 24288 24289 |
# File 'lib/aws-sdk-ec2/types.rb', line 24281 class DescribeFastLaunchImagesRequest < Struct.new( :image_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
24281 24282 24283 24284 24285 24286 24287 24288 24289 |
# File 'lib/aws-sdk-ec2/types.rb', line 24281 class DescribeFastLaunchImagesRequest < Struct.new( :image_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |