Class: Aws::EC2::Types::DescribeFastLaunchImagesResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeFastLaunchImagesResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#fast_launch_images ⇒ Array<Types::DescribeFastLaunchImagesSuccessItem>
A collection of details about the fast-launch enabled Windows images that meet the requested criteria.
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
Instance Attribute Details
#fast_launch_images ⇒ Array<Types::DescribeFastLaunchImagesSuccessItem>
A collection of details about the fast-launch enabled Windows images that meet the requested criteria.
25608 25609 25610 25611 25612 25613 |
# File 'lib/aws-sdk-ec2/types.rb', line 25608 class DescribeFastLaunchImagesResult < Struct.new( :fast_launch_images, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
25608 25609 25610 25611 25612 25613 |
# File 'lib/aws-sdk-ec2/types.rb', line 25608 class DescribeFastLaunchImagesResult < Struct.new( :fast_launch_images, :next_token) SENSITIVE = [] include Aws::Structure end |