Class: Aws::EC2::Types::DescribeFastSnapshotRestoresRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeFastSnapshotRestoresRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The filters.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token returned from a previous paginated request.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
25798 25799 25800 25801 25802 25803 25804 25805 |
# File 'lib/aws-sdk-ec2/types.rb', line 25798 class DescribeFastSnapshotRestoresRequest < Struct.new( :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters. The possible values are:
-
availability-zone: The Availability Zone of the snapshot. For example,us-east-2a. -
availability-zone-id: The ID of the Availability Zone of the snapshot. For example,use2-az1. -
owner-id: The ID of the Amazon Web Services account that enabled fast snapshot restore on the snapshot. -
snapshot-id: The ID of the snapshot. -
state: The state of fast snapshot restores for the snapshot (enabling|optimizing|enabled|disabling|disabled).
25798 25799 25800 25801 25802 25803 25804 25805 |
# File 'lib/aws-sdk-ec2/types.rb', line 25798 class DescribeFastSnapshotRestoresRequest < Struct.new( :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
25798 25799 25800 25801 25802 25803 25804 25805 |
# File 'lib/aws-sdk-ec2/types.rb', line 25798 class DescribeFastSnapshotRestoresRequest < Struct.new( :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
25798 25799 25800 25801 25802 25803 25804 25805 |
# File 'lib/aws-sdk-ec2/types.rb', line 25798 class DescribeFastSnapshotRestoresRequest < Struct.new( :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |