Class: Aws::EC2::Types::DescribeFleetError
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeFleetError
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the instances that could not be launched by the fleet.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#error_code ⇒ String
The error code that indicates why the instance could not be launched.
-
#error_message ⇒ String
The error message that describes why the instance could not be launched.
-
#launch_template_and_overrides ⇒ Types::LaunchTemplateAndOverridesResponse
The launch templates and overrides that were used for launching the instances.
-
#lifecycle ⇒ String
Indicates if the instance that could not be launched was a Spot, On-Demand, Capacity Block for ML, or interruptible Capacity Reservation instance.
Instance Attribute Details
#error_code ⇒ String
The error code that indicates why the instance could not be launched. For more information about error codes, see Error codes.
25872 25873 25874 25875 25876 25877 25878 25879 |
# File 'lib/aws-sdk-ec2/types.rb', line 25872 class DescribeFleetError < Struct.new( :launch_template_and_overrides, :lifecycle, :error_code, :error_message) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
The error message that describes why the instance could not be launched. For more information about error messages, see Error codes.
25872 25873 25874 25875 25876 25877 25878 25879 |
# File 'lib/aws-sdk-ec2/types.rb', line 25872 class DescribeFleetError < Struct.new( :launch_template_and_overrides, :lifecycle, :error_code, :error_message) SENSITIVE = [] include Aws::Structure end |
#launch_template_and_overrides ⇒ Types::LaunchTemplateAndOverridesResponse
The launch templates and overrides that were used for launching the instances. The values that you specify in the Overrides replace the values in the launch template.
25872 25873 25874 25875 25876 25877 25878 25879 |
# File 'lib/aws-sdk-ec2/types.rb', line 25872 class DescribeFleetError < Struct.new( :launch_template_and_overrides, :lifecycle, :error_code, :error_message) SENSITIVE = [] include Aws::Structure end |
#lifecycle ⇒ String
Indicates if the instance that could not be launched was a Spot,
On-Demand, Capacity Block for ML, or interruptible Capacity
Reservation instance. If you are using ReservedCapacityOptions
with on-demand-capacity-reservation in the ReservationTypes
list, the value can also be on-demand-capacity-reservation.
25872 25873 25874 25875 25876 25877 25878 25879 |
# File 'lib/aws-sdk-ec2/types.rb', line 25872 class DescribeFleetError < Struct.new( :launch_template_and_overrides, :lifecycle, :error_code, :error_message) SENSITIVE = [] include Aws::Structure end |