Class: Aws::EC2::Types::DescribeFleetInstancesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeFleetInstancesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The filters.
-
#fleet_id ⇒ String
The ID of the EC2 Fleet.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token returned from a previous paginated request.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
24205 24206 24207 24208 24209 24210 24211 24212 24213 |
# File 'lib/aws-sdk-ec2/types.rb', line 24205 class DescribeFleetInstancesRequest < Struct.new( :dry_run, :max_results, :next_token, :fleet_id, :filters) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters.
-
‘instance-type` - The instance type.
^
24205 24206 24207 24208 24209 24210 24211 24212 24213 |
# File 'lib/aws-sdk-ec2/types.rb', line 24205 class DescribeFleetInstancesRequest < Struct.new( :dry_run, :max_results, :next_token, :fleet_id, :filters) SENSITIVE = [] include Aws::Structure end |
#fleet_id ⇒ String
The ID of the EC2 Fleet.
24205 24206 24207 24208 24209 24210 24211 24212 24213 |
# File 'lib/aws-sdk-ec2/types.rb', line 24205 class DescribeFleetInstancesRequest < Struct.new( :dry_run, :max_results, :next_token, :fleet_id, :filters) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination
24205 24206 24207 24208 24209 24210 24211 24212 24213 |
# File 'lib/aws-sdk-ec2/types.rb', line 24205 class DescribeFleetInstancesRequest < Struct.new( :dry_run, :max_results, :next_token, :fleet_id, :filters) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
24205 24206 24207 24208 24209 24210 24211 24212 24213 |
# File 'lib/aws-sdk-ec2/types.rb', line 24205 class DescribeFleetInstancesRequest < Struct.new( :dry_run, :max_results, :next_token, :fleet_id, :filters) SENSITIVE = [] include Aws::Structure end |