Class: Aws::EC2::Types::DescribeHostsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeHostsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filter ⇒ Array<Types::Filter>
The filters.
-
#host_ids ⇒ Array<String>
The IDs of the Dedicated Hosts.
-
#max_results ⇒ Integer
The maximum number of results to return for the request in a single page.
-
#next_token ⇒ String
The token to use to retrieve the next page of results.
Instance Attribute Details
#filter ⇒ Array<Types::Filter>
The filters.
-
auto-placement- Whether auto-placement is enabled or disabled (on|off). -
availability-zone- The Availability Zone of the host. -
client-token- The idempotency token that you provided when you allocated the host. -
host-reservation-id- The ID of the reservation assigned to this host. -
instance-type- The instance type size that the Dedicated Host is configured to support. -
state- The allocation state of the Dedicated Host (available|under-assessment|permanent-failure|released|released-permanent-failure). -
tag-key- The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.
25083 25084 25085 25086 25087 25088 25089 25090 |
# File 'lib/aws-sdk-ec2/types.rb', line 25083 class DescribeHostsRequest < Struct.new( :host_ids, :next_token, :max_results, :filter) SENSITIVE = [] include Aws::Structure end |
#host_ids ⇒ Array<String>
The IDs of the Dedicated Hosts. The IDs are used for targeted instance launches.
25083 25084 25085 25086 25087 25088 25089 25090 |
# File 'lib/aws-sdk-ec2/types.rb', line 25083 class DescribeHostsRequest < Struct.new( :host_ids, :next_token, :max_results, :filter) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return for the request in a single
page. The remaining results can be seen by sending another request
with the returned nextToken value. This value can be between 5 and
500. If maxResults is given a larger value than 500, you receive
an error.
You cannot specify this parameter and the host IDs parameter in the same request.
25083 25084 25085 25086 25087 25088 25089 25090 |
# File 'lib/aws-sdk-ec2/types.rb', line 25083 class DescribeHostsRequest < Struct.new( :host_ids, :next_token, :max_results, :filter) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to retrieve the next page of results.
25083 25084 25085 25086 25087 25088 25089 25090 |
# File 'lib/aws-sdk-ec2/types.rb', line 25083 class DescribeHostsRequest < Struct.new( :host_ids, :next_token, :max_results, :filter) SENSITIVE = [] include Aws::Structure end |