Class: Aws::EC2::Types::DescribeImageReferencesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


26814
26815
26816
26817
26818
26819
26820
26821
26822
26823
# File 'lib/aws-sdk-ec2/types.rb', line 26814

class DescribeImageReferencesRequest < Struct.new(
  :image_ids,
  :include_all_resource_types,
  :resource_types,
  :next_token,
  :dry_run,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#image_idsArray<String>

The IDs of the images to check for resource references.

Returns:

  • (Array<String>)


26814
26815
26816
26817
26818
26819
26820
26821
26822
26823
# File 'lib/aws-sdk-ec2/types.rb', line 26814

class DescribeImageReferencesRequest < Struct.new(
  :image_ids,
  :include_all_resource_types,
  :resource_types,
  :next_token,
  :dry_run,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#include_all_resource_typesBoolean

Specifies whether to check all supported Amazon Web Services resource types for image references. When specified, default values are applied for ResourceTypeOptions. For the default values, see How AMI reference checks work in the Amazon EC2 User Guide. If you also specify ResourceTypes with ResourceTypeOptions, your specified values override the default values.

Supported resource types: ec2:Instance | ec2:LaunchTemplate | ssm:Parameter | imagebuilder:ImageRecipe | imagebuilder:ContainerRecipe

Either IncludeAllResourceTypes or ResourceTypes must be specified.

Returns:

  • (Boolean)


26814
26815
26816
26817
26818
26819
26820
26821
26822
26823
# File 'lib/aws-sdk-ec2/types.rb', line 26814

class DescribeImageReferencesRequest < Struct.new(
  :image_ids,
  :include_all_resource_types,
  :resource_types,
  :next_token,
  :dry_run,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.

Returns:

  • (Integer)


26814
26815
26816
26817
26818
26819
26820
26821
26822
26823
# File 'lib/aws-sdk-ec2/types.rb', line 26814

class DescribeImageReferencesRequest < Struct.new(
  :image_ids,
  :include_all_resource_types,
  :resource_types,
  :next_token,
  :dry_run,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Returns:

  • (String)


26814
26815
26816
26817
26818
26819
26820
26821
26822
26823
# File 'lib/aws-sdk-ec2/types.rb', line 26814

class DescribeImageReferencesRequest < Struct.new(
  :image_ids,
  :include_all_resource_types,
  :resource_types,
  :next_token,
  :dry_run,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typesArray<Types::ResourceTypeRequest>

The Amazon Web Services resource types to check for image references.

Either IncludeAllResourceTypes or ResourceTypes must be specified.

Returns:



26814
26815
26816
26817
26818
26819
26820
26821
26822
26823
# File 'lib/aws-sdk-ec2/types.rb', line 26814

class DescribeImageReferencesRequest < Struct.new(
  :image_ids,
  :include_all_resource_types,
  :resource_types,
  :next_token,
  :dry_run,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end