Class: Aws::EC2::Types::DescribeInstanceSqlHaHistoryStatesResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeInstanceSqlHaHistoryStatesResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instances ⇒ Array<Types::RegisteredInstance>
Information about the historical SQL Server High Availability states of the SQL Server High Availability instances.
-
#next_token ⇒ String
The token to use to retrieve the next page of results.
Instance Attribute Details
#instances ⇒ Array<Types::RegisteredInstance>
Information about the historical SQL Server High Availability states of the SQL Server High Availability instances.
25452 25453 25454 25455 25456 25457 |
# File 'lib/aws-sdk-ec2/types.rb', line 25452 class DescribeInstanceSqlHaHistoryStatesResult < Struct.new( :instances, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to retrieve the next page of results. This value is ‘null` when there are no more results to return.
25452 25453 25454 25455 25456 25457 |
# File 'lib/aws-sdk-ec2/types.rb', line 25452 class DescribeInstanceSqlHaHistoryStatesResult < Struct.new( :instances, :next_token) SENSITIVE = [] include Aws::Structure end |