Class: Aws::EC2::Types::DescribeInstanceSqlHaStatesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeInstanceSqlHaStatesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters to apply to the results.
-
#instance_ids ⇒ Array<String>
The IDs of the SQL Server High Availability instances to describe.
-
#max_results ⇒ Integer
The maximum number of results to return for the request in a single page.
-
#next_token ⇒ String
The token to use to retrieve the next page of results.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
26098 26099 26100 26101 26102 26103 26104 26105 26106 |
# File 'lib/aws-sdk-ec2/types.rb', line 26098 class DescribeInstanceSqlHaStatesRequest < Struct.new( :instance_ids, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters to apply to the results. Supported filters include:
-
‘tag:<key>` - The tag key and value pair assigned to the instance. For example, to find all instances tagged with `Owner:TeamA`, specify `tag:Owner` for the filter name and `TeamA` for the filter value.
-
‘tag-key` - The tag key assigned to the instance.
-
‘haStatus` - The SQL Server High Availability status of the SQL Server High Availability instance (`processing` | `active` | `standby` | `invalid`).
-
‘sqlServerLicenseUsage` - The license type for the SQL Server license (`full` | `waived`).
26098 26099 26100 26101 26102 26103 26104 26105 26106 |
# File 'lib/aws-sdk-ec2/types.rb', line 26098 class DescribeInstanceSqlHaStatesRequest < Struct.new( :instance_ids, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#instance_ids ⇒ Array<String>
The IDs of the SQL Server High Availability instances to describe. If omitted, the API returns SQL Server High Availability states for all SQL Server High Availability instances.
26098 26099 26100 26101 26102 26103 26104 26105 26106 |
# File 'lib/aws-sdk-ec2/types.rb', line 26098 class DescribeInstanceSqlHaStatesRequest < Struct.new( :instance_ids, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the returned ‘nextToken` value.
26098 26099 26100 26101 26102 26103 26104 26105 26106 |
# File 'lib/aws-sdk-ec2/types.rb', line 26098 class DescribeInstanceSqlHaStatesRequest < Struct.new( :instance_ids, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to retrieve the next page of results.
26098 26099 26100 26101 26102 26103 26104 26105 26106 |
# File 'lib/aws-sdk-ec2/types.rb', line 26098 class DescribeInstanceSqlHaStatesRequest < Struct.new( :instance_ids, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |