Class: Aws::EC2::Types::DescribeInstanceTopologyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeInstanceTopologyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The filters.
-
#group_names ⇒ Array<String>
The name of the placement group that each instance is in.
-
#instance_ids ⇒ Array<String>
The instance IDs.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token returned from a previous paginated request.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
26323 26324 26325 26326 26327 26328 26329 26330 26331 26332 |
# File 'lib/aws-sdk-ec2/types.rb', line 26323 class DescribeInstanceTopologyRequest < Struct.new( :dry_run, :next_token, :max_results, :instance_ids, :group_names, :filters) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters.
-
‘availability-zone` - The name of the Availability Zone (for example, `us-west-2a`) or Local Zone (for example, `us-west-2-lax-1b`) that the instance is in.
-
‘instance-type` - The instance type (for example, `p4d.24xlarge`) or instance family (for example, `p4d*`). You can use the `*` wildcard to match zero or more characters, or the `?` wildcard to match zero or one character.
-
‘zone-id` - The ID of the Availability Zone (for example, `usw2-az2`) or Local Zone (for example, `usw2-lax1-az1`) that the instance is in.
26323 26324 26325 26326 26327 26328 26329 26330 26331 26332 |
# File 'lib/aws-sdk-ec2/types.rb', line 26323 class DescribeInstanceTopologyRequest < Struct.new( :dry_run, :next_token, :max_results, :instance_ids, :group_names, :filters) SENSITIVE = [] include Aws::Structure end |
#group_names ⇒ Array<String>
The name of the placement group that each instance is in.
Constraints: Maximum 100 explicitly specified placement group names.
26323 26324 26325 26326 26327 26328 26329 26330 26331 26332 |
# File 'lib/aws-sdk-ec2/types.rb', line 26323 class DescribeInstanceTopologyRequest < Struct.new( :dry_run, :next_token, :max_results, :instance_ids, :group_names, :filters) SENSITIVE = [] include Aws::Structure end |
#instance_ids ⇒ Array<String>
The instance IDs.
Default: Describes all your instances.
Constraints: Maximum 100 explicitly specified instance IDs.
26323 26324 26325 26326 26327 26328 26329 26330 26331 26332 |
# File 'lib/aws-sdk-ec2/types.rb', line 26323 class DescribeInstanceTopologyRequest < Struct.new( :dry_run, :next_token, :max_results, :instance_ids, :group_names, :filters) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].
You can’t specify this parameter and the instance IDs parameter in the same request.
Default: ‘20`
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination
26323 26324 26325 26326 26327 26328 26329 26330 26331 26332 |
# File 'lib/aws-sdk-ec2/types.rb', line 26323 class DescribeInstanceTopologyRequest < Struct.new( :dry_run, :next_token, :max_results, :instance_ids, :group_names, :filters) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
26323 26324 26325 26326 26327 26328 26329 26330 26331 26332 |
# File 'lib/aws-sdk-ec2/types.rb', line 26323 class DescribeInstanceTopologyRequest < Struct.new( :dry_run, :next_token, :max_results, :instance_ids, :group_names, :filters) SENSITIVE = [] include Aws::Structure end |