Class: Aws::EC2::Types::DescribeInstanceTypeOfferingsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeInstanceTypeOfferingsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters.
-
#location_type ⇒ String
The location type.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token returned from a previous paginated request.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
26156 26157 26158 26159 26160 26161 26162 26163 26164 |
# File 'lib/aws-sdk-ec2/types.rb', line 26156 class DescribeInstanceTypeOfferingsRequest < Struct.new( :dry_run, :location_type, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters. Filter names and values are case-sensitive.
-
‘instance-type` - The instance type. For a list of possible values, see [Instance].
-
‘location` - The location. For a list of possible identifiers, see [Regions and Zones].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/API_Instance.html [2]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-regions-availability-zones.html
26156 26157 26158 26159 26160 26161 26162 26163 26164 |
# File 'lib/aws-sdk-ec2/types.rb', line 26156 class DescribeInstanceTypeOfferingsRequest < Struct.new( :dry_run, :location_type, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#location_type ⇒ String
The location type.
-
‘availability-zone` - The Availability Zone. When you specify a location filter, it must be an Availability Zone for the current Region.
-
‘availability-zone-id` - The AZ ID. When you specify a location filter, it must be an AZ ID for the current Region.
-
‘outpost` - The Outpost ARN. When you specify a location filter, it must be an Outpost ARN for the current Region.
-
‘region` - The current Region. If you specify a location filter, it must match the current Region.
26156 26157 26158 26159 26160 26161 26162 26163 26164 |
# File 'lib/aws-sdk-ec2/types.rb', line 26156 class DescribeInstanceTypeOfferingsRequest < Struct.new( :dry_run, :location_type, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination
26156 26157 26158 26159 26160 26161 26162 26163 26164 |
# File 'lib/aws-sdk-ec2/types.rb', line 26156 class DescribeInstanceTypeOfferingsRequest < Struct.new( :dry_run, :location_type, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
26156 26157 26158 26159 26160 26161 26162 26163 26164 |
# File 'lib/aws-sdk-ec2/types.rb', line 26156 class DescribeInstanceTypeOfferingsRequest < Struct.new( :dry_run, :location_type, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |