Class: Aws::EC2::Types::DescribeIpamInternetRegistryAssociationsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeIpamInternetRegistryAssociationsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ipam_internet_registry_associations ⇒ Array<Types::IpamInternetRegistryAssociation>
The internet registry associations.
-
#next_token ⇒ String
The token to use to retrieve the next page of results.
Instance Attribute Details
#ipam_internet_registry_associations ⇒ Array<Types::IpamInternetRegistryAssociation>
The internet registry associations.
29290 29291 29292 29293 29294 29295 |
# File 'lib/aws-sdk-ec2/types.rb', line 29290 class DescribeIpamInternetRegistryAssociationsResult < Struct.new( :next_token, :ipam_internet_registry_associations) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to retrieve the next page of results.
29290 29291 29292 29293 29294 29295 |
# File 'lib/aws-sdk-ec2/types.rb', line 29290 class DescribeIpamInternetRegistryAssociationsResult < Struct.new( :next_token, :ipam_internet_registry_associations) SENSITIVE = [] include Aws::Structure end |