Class: Aws::EC2::Types::DescribeIpamPoolAllocationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeIpamPoolAllocationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters for the request.
-
#ipam_pool_allocation_ids ⇒ Array<String>
The IDs of the IPAM pool allocations you want to describe.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token for the next page of results.
Instance Attribute Details
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action
without actually making the request and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
29034 29035 29036 29037 29038 29039 29040 29041 29042 |
# File 'lib/aws-sdk-ec2/types.rb', line 29034 class DescribeIpamPoolAllocationsRequest < Struct.new( :dry_run, :ipam_pool_allocation_ids, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters for the request. For more information about filtering, see Filtering CLI output.
29034 29035 29036 29037 29038 29039 29040 29041 29042 |
# File 'lib/aws-sdk-ec2/types.rb', line 29034 class DescribeIpamPoolAllocationsRequest < Struct.new( :dry_run, :ipam_pool_allocation_ids, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#ipam_pool_allocation_ids ⇒ Array<String>
The IDs of the IPAM pool allocations you want to describe.
29034 29035 29036 29037 29038 29039 29040 29041 29042 |
# File 'lib/aws-sdk-ec2/types.rb', line 29034 class DescribeIpamPoolAllocationsRequest < Struct.new( :dry_run, :ipam_pool_allocation_ids, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
29034 29035 29036 29037 29038 29039 29040 29041 29042 |
# File 'lib/aws-sdk-ec2/types.rb', line 29034 class DescribeIpamPoolAllocationsRequest < Struct.new( :dry_run, :ipam_pool_allocation_ids, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
29034 29035 29036 29037 29038 29039 29040 29041 29042 |
# File 'lib/aws-sdk-ec2/types.rb', line 29034 class DescribeIpamPoolAllocationsRequest < Struct.new( :dry_run, :ipam_pool_allocation_ids, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |