Class: Aws::EC2::Types::DescribeIpv6PoolsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeIpv6PoolsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
-
#pool_ids ⇒ Array<String>
The IDs of the IPv6 address pools.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
29897 29898 29899 29900 29901 29902 29903 29904 29905 |
# File 'lib/aws-sdk-ec2/types.rb', line 29897 class DescribeIpv6PoolsRequest < Struct.new( :pool_ids, :next_token, :max_results, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters.
-
tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the keyOwnerand the valueTeamA, specifytag:Ownerfor the filter name andTeamAfor the filter value. -
tag-key- The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.
29897 29898 29899 29900 29901 29902 29903 29904 29905 |
# File 'lib/aws-sdk-ec2/types.rb', line 29897 class DescribeIpv6PoolsRequest < Struct.new( :pool_ids, :next_token, :max_results, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To
retrieve the remaining results, make another call with the returned
nextToken value.
29897 29898 29899 29900 29901 29902 29903 29904 29905 |
# File 'lib/aws-sdk-ec2/types.rb', line 29897 class DescribeIpv6PoolsRequest < Struct.new( :pool_ids, :next_token, :max_results, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
29897 29898 29899 29900 29901 29902 29903 29904 29905 |
# File 'lib/aws-sdk-ec2/types.rb', line 29897 class DescribeIpv6PoolsRequest < Struct.new( :pool_ids, :next_token, :max_results, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |
#pool_ids ⇒ Array<String>
The IDs of the IPv6 address pools.
29897 29898 29899 29900 29901 29902 29903 29904 29905 |
# File 'lib/aws-sdk-ec2/types.rb', line 29897 class DescribeIpv6PoolsRequest < Struct.new( :pool_ids, :next_token, :max_results, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |