Class: Aws::EC2::Types::DescribeKeyPairsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeKeyPairsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The filters.
-
#include_public_key ⇒ Boolean
If ‘true`, the public key material is included in the response.
-
#key_names ⇒ Array<String>
The key pair names.
-
#key_pair_ids ⇒ Array<String>
The IDs of the key pairs.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
28011 28012 28013 28014 28015 28016 28017 28018 28019 |
# File 'lib/aws-sdk-ec2/types.rb', line 28011 class DescribeKeyPairsRequest < Struct.new( :key_names, :key_pair_ids, :include_public_key, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters.
-
‘key-pair-id` - The ID of the key pair.
-
‘fingerprint` - The fingerprint of the key pair.
-
‘key-name` - The name of the key pair.
-
‘tag-key` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.
-
‘tag`:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key `Owner` and the value `TeamA`, specify `tag:Owner` for the filter name and `TeamA` for the filter value.
28011 28012 28013 28014 28015 28016 28017 28018 28019 |
# File 'lib/aws-sdk-ec2/types.rb', line 28011 class DescribeKeyPairsRequest < Struct.new( :key_names, :key_pair_ids, :include_public_key, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |
#include_public_key ⇒ Boolean
If ‘true`, the public key material is included in the response.
Default: ‘false`
28011 28012 28013 28014 28015 28016 28017 28018 28019 |
# File 'lib/aws-sdk-ec2/types.rb', line 28011 class DescribeKeyPairsRequest < Struct.new( :key_names, :key_pair_ids, :include_public_key, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |
#key_names ⇒ Array<String>
The key pair names.
Default: Describes all of your key pairs.
28011 28012 28013 28014 28015 28016 28017 28018 28019 |
# File 'lib/aws-sdk-ec2/types.rb', line 28011 class DescribeKeyPairsRequest < Struct.new( :key_names, :key_pair_ids, :include_public_key, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |
#key_pair_ids ⇒ Array<String>
The IDs of the key pairs.
28011 28012 28013 28014 28015 28016 28017 28018 28019 |
# File 'lib/aws-sdk-ec2/types.rb', line 28011 class DescribeKeyPairsRequest < Struct.new( :key_names, :key_pair_ids, :include_public_key, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |