Class: Aws::EC2::Types::DescribeLaunchTemplateVersionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


28153
28154
28155
28156
28157
28158
28159
28160
28161
28162
28163
28164
28165
28166
28167
# File 'lib/aws-sdk-ec2/types.rb', line 28153

class DescribeLaunchTemplateVersionsRequest < Struct.new(
  :dry_run,
  :launch_template_id,
  :launch_template_name,
  :versions,
  :min_version,
  :max_version,
  :next_token,
  :max_results,
  :filters,
  :resolve_alias,
  :include_managed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters.

  • ‘create-time` - The time the launch template version was created.

  • ‘ebs-optimized` - A boolean that indicates whether the instance is optimized for Amazon EBS I/O.

  • ‘http-endpoint` - Indicates whether the HTTP metadata endpoint on your instances is enabled (`enabled` | `disabled`).

  • ‘http-protocol-ipv4` - Indicates whether the IPv4 endpoint for the instance metadata service is enabled (`enabled` | `disabled`).

  • ‘host-resource-group-arn` - The ARN of the host resource group in which to launch the instances.

  • ‘http-tokens` - The state of token usage for your instance metadata requests (`optional` | `required`).

  • ‘iam-instance-profile` - The ARN of the IAM instance profile.

  • ‘image-id` - The ID of the AMI.

  • ‘instance-type` - The instance type.

  • ‘is-default-version` - A boolean that indicates whether the launch template version is the default version.

  • ‘kernel-id` - The kernel ID.

  • ‘license-configuration-arn` - The ARN of the license configuration.

  • ‘network-card-index` - The index of the network card.

  • ‘ram-disk-id` - The RAM disk ID.

Returns:



28153
28154
28155
28156
28157
28158
28159
28160
28161
28162
28163
28164
28165
28166
28167
# File 'lib/aws-sdk-ec2/types.rb', line 28153

class DescribeLaunchTemplateVersionsRequest < Struct.new(
  :dry_run,
  :launch_template_id,
  :launch_template_name,
  :versions,
  :min_version,
  :max_version,
  :next_token,
  :max_results,
  :filters,
  :resolve_alias,
  :include_managed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#include_managed_resourcesBoolean

Indicates whether to include managed resources in the output. If this parameter is set to ‘true`, the output includes resources that are managed by Amazon Web Services services, even if managed resource visibility is set to hidden.

Returns:

  • (Boolean)


28153
28154
28155
28156
28157
28158
28159
28160
28161
28162
28163
28164
28165
28166
28167
# File 'lib/aws-sdk-ec2/types.rb', line 28153

class DescribeLaunchTemplateVersionsRequest < Struct.new(
  :dry_run,
  :launch_template_id,
  :launch_template_name,
  :versions,
  :min_version,
  :max_version,
  :next_token,
  :max_results,
  :filters,
  :resolve_alias,
  :include_managed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#launch_template_idString

The ID of the launch template.

To describe one or more versions of a specified launch template, you must specify either the launch template ID or the launch template name, but not both.

To describe all the latest or default launch template versions in your account, you must omit this parameter.

Returns:

  • (String)


28153
28154
28155
28156
28157
28158
28159
28160
28161
28162
28163
28164
28165
28166
28167
# File 'lib/aws-sdk-ec2/types.rb', line 28153

class DescribeLaunchTemplateVersionsRequest < Struct.new(
  :dry_run,
  :launch_template_id,
  :launch_template_name,
  :versions,
  :min_version,
  :max_version,
  :next_token,
  :max_results,
  :filters,
  :resolve_alias,
  :include_managed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#launch_template_nameString

The name of the launch template.

To describe one or more versions of a specified launch template, you must specify either the launch template name or the launch template ID, but not both.

To describe all the latest or default launch template versions in your account, you must omit this parameter.

Returns:

  • (String)


28153
28154
28155
28156
28157
28158
28159
28160
28161
28162
28163
28164
28165
28166
28167
# File 'lib/aws-sdk-ec2/types.rb', line 28153

class DescribeLaunchTemplateVersionsRequest < Struct.new(
  :dry_run,
  :launch_template_id,
  :launch_template_name,
  :versions,
  :min_version,
  :max_version,
  :next_token,
  :max_results,
  :filters,
  :resolve_alias,
  :include_managed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned ‘NextToken` value. This value can be between 1 and 200.

Returns:

  • (Integer)


28153
28154
28155
28156
28157
28158
28159
28160
28161
28162
28163
28164
28165
28166
28167
# File 'lib/aws-sdk-ec2/types.rb', line 28153

class DescribeLaunchTemplateVersionsRequest < Struct.new(
  :dry_run,
  :launch_template_id,
  :launch_template_name,
  :versions,
  :min_version,
  :max_version,
  :next_token,
  :max_results,
  :filters,
  :resolve_alias,
  :include_managed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#max_versionString

The version number up to which to describe launch template versions.

Returns:

  • (String)


28153
28154
28155
28156
28157
28158
28159
28160
28161
28162
28163
28164
28165
28166
28167
# File 'lib/aws-sdk-ec2/types.rb', line 28153

class DescribeLaunchTemplateVersionsRequest < Struct.new(
  :dry_run,
  :launch_template_id,
  :launch_template_name,
  :versions,
  :min_version,
  :max_version,
  :next_token,
  :max_results,
  :filters,
  :resolve_alias,
  :include_managed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#min_versionString

The version number after which to describe launch template versions.

Returns:

  • (String)


28153
28154
28155
28156
28157
28158
28159
28160
28161
28162
28163
28164
28165
28166
28167
# File 'lib/aws-sdk-ec2/types.rb', line 28153

class DescribeLaunchTemplateVersionsRequest < Struct.new(
  :dry_run,
  :launch_template_id,
  :launch_template_name,
  :versions,
  :min_version,
  :max_version,
  :next_token,
  :max_results,
  :filters,
  :resolve_alias,
  :include_managed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to request the next page of results.

Returns:

  • (String)


28153
28154
28155
28156
28157
28158
28159
28160
28161
28162
28163
28164
28165
28166
28167
# File 'lib/aws-sdk-ec2/types.rb', line 28153

class DescribeLaunchTemplateVersionsRequest < Struct.new(
  :dry_run,
  :launch_template_id,
  :launch_template_name,
  :versions,
  :min_version,
  :max_version,
  :next_token,
  :max_results,
  :filters,
  :resolve_alias,
  :include_managed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#resolve_aliasBoolean

If ‘true`, and if a Systems Manager parameter is specified for `ImageId`, the AMI ID is displayed in the response for `imageId`.

If ‘false`, and if a Systems Manager parameter is specified for `ImageId`, the parameter is displayed in the response for `imageId`.

For more information, see [Use a Systems Manager parameter instead of an AMI ID] in the *Amazon EC2 User Guide*.

Default: ‘false`

[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/create-launch-template.html#use-an-ssm-parameter-instead-of-an-ami-id

Returns:

  • (Boolean)


28153
28154
28155
28156
28157
28158
28159
28160
28161
28162
28163
28164
28165
28166
28167
# File 'lib/aws-sdk-ec2/types.rb', line 28153

class DescribeLaunchTemplateVersionsRequest < Struct.new(
  :dry_run,
  :launch_template_id,
  :launch_template_name,
  :versions,
  :min_version,
  :max_version,
  :next_token,
  :max_results,
  :filters,
  :resolve_alias,
  :include_managed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#versionsArray<String>

One or more versions of the launch template. Valid values depend on whether you are describing a specified launch template (by ID or name) or all launch templates in your account.

To describe one or more versions of a specified launch template, valid values are ‘$Latest`, `$Default`, and numbers.

To describe all launch templates in your account that are defined as the latest version, the valid value is ‘$Latest`. To describe all launch templates in your account that are defined as the default version, the valid value is `$Default`. You can specify `$Latest` and `$Default` in the same request. You cannot specify numbers.

Returns:

  • (Array<String>)


28153
28154
28155
28156
28157
28158
28159
28160
28161
28162
28163
28164
28165
28166
28167
# File 'lib/aws-sdk-ec2/types.rb', line 28153

class DescribeLaunchTemplateVersionsRequest < Struct.new(
  :dry_run,
  :launch_template_id,
  :launch_template_name,
  :versions,
  :min_version,
  :max_version,
  :next_token,
  :max_results,
  :filters,
  :resolve_alias,
  :include_managed_resources)
  SENSITIVE = []
  include Aws::Structure
end