Class: Aws::EC2::Types::DescribeLaunchTemplatesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeLaunchTemplatesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters.
-
#include_managed_resources ⇒ Boolean
Indicates whether to include managed resources in the output.
-
#launch_template_ids ⇒ Array<String>
One or more launch template IDs.
-
#launch_template_names ⇒ Array<String>
One or more launch template names.
-
#max_results ⇒ Integer
The maximum number of results to return in a single call.
-
#next_token ⇒ String
The token to request the next page of results.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
30196 30197 30198 30199 30200 30201 30202 30203 30204 30205 30206 |
# File 'lib/aws-sdk-ec2/types.rb', line 30196 class DescribeLaunchTemplatesRequest < Struct.new( :dry_run, :launch_template_ids, :launch_template_names, :filters, :next_token, :max_results, :include_managed_resources) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters.
-
create-time- The time the launch template was created. -
launch-template-name- The name of the launch template. -
tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the keyOwnerand the valueTeamA, specifytag:Ownerfor the filter name andTeamAfor the filter value. -
tag-key- The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.
30196 30197 30198 30199 30200 30201 30202 30203 30204 30205 30206 |
# File 'lib/aws-sdk-ec2/types.rb', line 30196 class DescribeLaunchTemplatesRequest < Struct.new( :dry_run, :launch_template_ids, :launch_template_names, :filters, :next_token, :max_results, :include_managed_resources) SENSITIVE = [] include Aws::Structure end |
#include_managed_resources ⇒ Boolean
Indicates whether to include managed resources in the output. If
this parameter is set to true, the output includes resources that
are managed by Amazon Web Services services, even if managed
resource visibility is set to hidden.
30196 30197 30198 30199 30200 30201 30202 30203 30204 30205 30206 |
# File 'lib/aws-sdk-ec2/types.rb', line 30196 class DescribeLaunchTemplatesRequest < Struct.new( :dry_run, :launch_template_ids, :launch_template_names, :filters, :next_token, :max_results, :include_managed_resources) SENSITIVE = [] include Aws::Structure end |
#launch_template_ids ⇒ Array<String>
One or more launch template IDs.
30196 30197 30198 30199 30200 30201 30202 30203 30204 30205 30206 |
# File 'lib/aws-sdk-ec2/types.rb', line 30196 class DescribeLaunchTemplatesRequest < Struct.new( :dry_run, :launch_template_ids, :launch_template_names, :filters, :next_token, :max_results, :include_managed_resources) SENSITIVE = [] include Aws::Structure end |
#launch_template_names ⇒ Array<String>
One or more launch template names.
30196 30197 30198 30199 30200 30201 30202 30203 30204 30205 30206 |
# File 'lib/aws-sdk-ec2/types.rb', line 30196 class DescribeLaunchTemplatesRequest < Struct.new( :dry_run, :launch_template_ids, :launch_template_names, :filters, :next_token, :max_results, :include_managed_resources) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in a single call. To
retrieve the remaining results, make another call with the returned
NextToken value. This value can be between 1 and 200.
30196 30197 30198 30199 30200 30201 30202 30203 30204 30205 30206 |
# File 'lib/aws-sdk-ec2/types.rb', line 30196 class DescribeLaunchTemplatesRequest < Struct.new( :dry_run, :launch_template_ids, :launch_template_names, :filters, :next_token, :max_results, :include_managed_resources) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to request the next page of results.
30196 30197 30198 30199 30200 30201 30202 30203 30204 30205 30206 |
# File 'lib/aws-sdk-ec2/types.rb', line 30196 class DescribeLaunchTemplatesRequest < Struct.new( :dry_run, :launch_template_ids, :launch_template_names, :filters, :next_token, :max_results, :include_managed_resources) SENSITIVE = [] include Aws::Structure end |