Class: Aws::EC2::Types::DescribeLocalGatewayVirtualInterfaceGroupsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


28882
28883
28884
28885
28886
28887
28888
28889
28890
# File 'lib/aws-sdk-ec2/types.rb', line 28882

class DescribeLocalGatewayVirtualInterfaceGroupsRequest < Struct.new(
  :local_gateway_virtual_interface_group_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters.

  • ‘local-gateway-id` - The ID of a local gateway.

  • ‘local-gateway-virtual-interface-group-id` - The ID of the virtual interface group.

  • ‘local-gateway-virtual-interface-id` - The ID of the virtual interface.

  • ‘owner-id` - The ID of the Amazon Web Services account that owns the local gateway virtual interface group.

Returns:



28882
28883
28884
28885
28886
28887
28888
28889
28890
# File 'lib/aws-sdk-ec2/types.rb', line 28882

class DescribeLocalGatewayVirtualInterfaceGroupsRequest < Struct.new(
  :local_gateway_virtual_interface_group_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#local_gateway_virtual_interface_group_idsArray<String>

The IDs of the virtual interface groups.

Returns:

  • (Array<String>)


28882
28883
28884
28885
28886
28887
28888
28889
28890
# File 'lib/aws-sdk-ec2/types.rb', line 28882

class DescribeLocalGatewayVirtualInterfaceGroupsRequest < Struct.new(
  :local_gateway_virtual_interface_group_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.

Returns:

  • (Integer)


28882
28883
28884
28885
28886
28887
28888
28889
28890
# File 'lib/aws-sdk-ec2/types.rb', line 28882

class DescribeLocalGatewayVirtualInterfaceGroupsRequest < Struct.new(
  :local_gateway_virtual_interface_group_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


28882
28883
28884
28885
28886
28887
28888
28889
28890
# File 'lib/aws-sdk-ec2/types.rb', line 28882

class DescribeLocalGatewayVirtualInterfaceGroupsRequest < Struct.new(
  :local_gateway_virtual_interface_group_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end