Class: Aws::EC2::Types::DescribeNetworkInterfaceAttributeResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeNetworkInterfaceAttributeResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the output of DescribeNetworkInterfaceAttribute.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#associate_public_ip_address ⇒ Boolean
Indicates whether to assign a public IPv4 address to a network interface.
-
#attachment ⇒ Types::NetworkInterfaceAttachment
The attachment (if any) of the network interface.
-
#description ⇒ Types::AttributeValue
The description of the network interface.
-
#groups ⇒ Array<Types::GroupIdentifier>
The security groups associated with the network interface.
-
#network_interface_id ⇒ String
The ID of the network interface.
-
#source_dest_check ⇒ Types::AttributeBooleanValue
Indicates whether source/destination checking is enabled.
Instance Attribute Details
#associate_public_ip_address ⇒ Boolean
Indicates whether to assign a public IPv4 address to a network interface. This option can be enabled for any network interface but will only apply to the primary network interface (eth0).
31517 31518 31519 31520 31521 31522 31523 31524 31525 31526 |
# File 'lib/aws-sdk-ec2/types.rb', line 31517 class DescribeNetworkInterfaceAttributeResult < Struct.new( :attachment, :description, :groups, :network_interface_id, :source_dest_check, :associate_public_ip_address) SENSITIVE = [] include Aws::Structure end |
#attachment ⇒ Types::NetworkInterfaceAttachment
The attachment (if any) of the network interface.
31517 31518 31519 31520 31521 31522 31523 31524 31525 31526 |
# File 'lib/aws-sdk-ec2/types.rb', line 31517 class DescribeNetworkInterfaceAttributeResult < Struct.new( :attachment, :description, :groups, :network_interface_id, :source_dest_check, :associate_public_ip_address) SENSITIVE = [] include Aws::Structure end |
#description ⇒ Types::AttributeValue
The description of the network interface.
31517 31518 31519 31520 31521 31522 31523 31524 31525 31526 |
# File 'lib/aws-sdk-ec2/types.rb', line 31517 class DescribeNetworkInterfaceAttributeResult < Struct.new( :attachment, :description, :groups, :network_interface_id, :source_dest_check, :associate_public_ip_address) SENSITIVE = [] include Aws::Structure end |
#groups ⇒ Array<Types::GroupIdentifier>
The security groups associated with the network interface.
31517 31518 31519 31520 31521 31522 31523 31524 31525 31526 |
# File 'lib/aws-sdk-ec2/types.rb', line 31517 class DescribeNetworkInterfaceAttributeResult < Struct.new( :attachment, :description, :groups, :network_interface_id, :source_dest_check, :associate_public_ip_address) SENSITIVE = [] include Aws::Structure end |
#network_interface_id ⇒ String
The ID of the network interface.
31517 31518 31519 31520 31521 31522 31523 31524 31525 31526 |
# File 'lib/aws-sdk-ec2/types.rb', line 31517 class DescribeNetworkInterfaceAttributeResult < Struct.new( :attachment, :description, :groups, :network_interface_id, :source_dest_check, :associate_public_ip_address) SENSITIVE = [] include Aws::Structure end |
#source_dest_check ⇒ Types::AttributeBooleanValue
Indicates whether source/destination checking is enabled.
31517 31518 31519 31520 31521 31522 31523 31524 31525 31526 |
# File 'lib/aws-sdk-ec2/types.rb', line 31517 class DescribeNetworkInterfaceAttributeResult < Struct.new( :attachment, :description, :groups, :network_interface_id, :source_dest_check, :associate_public_ip_address) SENSITIVE = [] include Aws::Structure end |