Class: Aws::EC2::Types::DescribeNetworkInterfacePermissionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for DescribeNetworkInterfacePermissions.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filtersArray<Types::Filter>

One or more filters.

  • network-interface-permission.network-interface-permission-id - The ID of the permission.

  • network-interface-permission.network-interface-id - The ID of the network interface.

  • network-interface-permission.aws-account-id - The Amazon Web Services account ID.

  • network-interface-permission.aws-service - The Amazon Web Services service.

  • network-interface-permission.permission - The type of permission (INSTANCE-ATTACH | EIP-ASSOCIATE).

Returns:



31572
31573
31574
31575
31576
31577
31578
31579
# File 'lib/aws-sdk-ec2/types.rb', line 31572

class DescribeNetworkInterfacePermissionsRequest < Struct.new(
  :network_interface_permission_ids,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. If this parameter is not specified, up to 50 results are returned by default. For more information, see Pagination.

Returns:

  • (Integer)


31572
31573
31574
31575
31576
31577
31578
31579
# File 'lib/aws-sdk-ec2/types.rb', line 31572

class DescribeNetworkInterfacePermissionsRequest < Struct.new(
  :network_interface_permission_ids,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#network_interface_permission_idsArray<String>

The network interface permission IDs.

Returns:

  • (Array<String>)


31572
31573
31574
31575
31576
31577
31578
31579
# File 'lib/aws-sdk-ec2/types.rb', line 31572

class DescribeNetworkInterfacePermissionsRequest < Struct.new(
  :network_interface_permission_ids,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Returns:

  • (String)


31572
31573
31574
31575
31576
31577
31578
31579
# File 'lib/aws-sdk-ec2/types.rb', line 31572

class DescribeNetworkInterfacePermissionsRequest < Struct.new(
  :network_interface_permission_ids,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end