Class: Aws::EC2::Types::DescribeOutpostLagsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeOutpostLagsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The filters to use for narrowing down the request.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
-
#outpost_lag_ids ⇒ Array<String>
The IDs of the Outpost LAGs.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
31866 31867 31868 31869 31870 31871 31872 31873 31874 |
# File 'lib/aws-sdk-ec2/types.rb', line 31866 class DescribeOutpostLagsRequest < Struct.new( :outpost_lag_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters to use for narrowing down the request. The following filters are supported:
-
service-link-virtual-interface-id- The ID of the service link virtual interface. -
service-link-virtual-interface-arn- The ARN of the service link virtual interface. -
outpost-id- The Outpost ID. -
outpost-arn- The Outpost ARN. -
owner-id- The ID of the Amazon Web Services account that owns the service link virtual interface. -
vlan- The ID of the address pool. -
local-address- The local address. -
peer-address- The peer address. -
peer-bgp-asn- The peer BGP ASN. -
outpost-lag-id- The Outpost LAG ID. -
configuration-state- The configuration state of the service link virtual interface.
31866 31867 31868 31869 31870 31871 31872 31873 31874 |
# File 'lib/aws-sdk-ec2/types.rb', line 31866 class DescribeOutpostLagsRequest < Struct.new( :outpost_lag_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To
retrieve the remaining results, make another call with the returned
nextToken value.
31866 31867 31868 31869 31870 31871 31872 31873 31874 |
# File 'lib/aws-sdk-ec2/types.rb', line 31866 class DescribeOutpostLagsRequest < Struct.new( :outpost_lag_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
31866 31867 31868 31869 31870 31871 31872 31873 31874 |
# File 'lib/aws-sdk-ec2/types.rb', line 31866 class DescribeOutpostLagsRequest < Struct.new( :outpost_lag_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#outpost_lag_ids ⇒ Array<String>
The IDs of the Outpost LAGs.
31866 31867 31868 31869 31870 31871 31872 31873 31874 |
# File 'lib/aws-sdk-ec2/types.rb', line 31866 class DescribeOutpostLagsRequest < Struct.new( :outpost_lag_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |