Class: Aws::EC2::Types::DescribePrincipalIdFormatResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The token to use to retrieve the next page of results. This value is null when there are no more results to return.

Returns:

  • (String)


30062
30063
30064
30065
30066
30067
# File 'lib/aws-sdk-ec2/types.rb', line 30062

class DescribePrincipalIdFormatResult < Struct.new(
  :principals,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#principalsArray<Types::PrincipalIdFormat>

Information about the ID format settings for the ARN.

Returns:



30062
30063
30064
30065
30066
30067
# File 'lib/aws-sdk-ec2/types.rb', line 30062

class DescribePrincipalIdFormatResult < Struct.new(
  :principals,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end