Class: Aws::EC2::Types::DescribeRegionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeRegionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#all_regions ⇒ Boolean
Indicates whether to display all Regions, including Regions that are disabled for your account.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The filters.
-
#region_names ⇒ Array<String>
The names of the Regions.
Instance Attribute Details
#all_regions ⇒ Boolean
Indicates whether to display all Regions, including Regions that are disabled for your account.
32163 32164 32165 32166 32167 32168 32169 32170 |
# File 'lib/aws-sdk-ec2/types.rb', line 32163 class DescribeRegionsRequest < Struct.new( :region_names, :all_regions, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
32163 32164 32165 32166 32167 32168 32169 32170 |
# File 'lib/aws-sdk-ec2/types.rb', line 32163 class DescribeRegionsRequest < Struct.new( :region_names, :all_regions, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters.
-
endpoint- The endpoint of the Region (for example,ec2.us-east-1.amazonaws.com). -
opt-in-status- The opt-in status of the Region (opt-in-not-required|opted-in|not-opted-in). -
region-name- The name of the Region (for example,us-east-1).
32163 32164 32165 32166 32167 32168 32169 32170 |
# File 'lib/aws-sdk-ec2/types.rb', line 32163 class DescribeRegionsRequest < Struct.new( :region_names, :all_regions, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |
#region_names ⇒ Array<String>
The names of the Regions. You can specify any Regions, whether they are enabled and disabled for your account.
32163 32164 32165 32166 32167 32168 32169 32170 |
# File 'lib/aws-sdk-ec2/types.rb', line 32163 class DescribeRegionsRequest < Struct.new( :region_names, :all_regions, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |