Class: Aws::EC2::Types::DescribeReservedInstancesOfferingsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeReservedInstancesOfferingsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for DescribeReservedInstancesOfferings.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone ⇒ String
The Availability Zone in which the Reserved Instance can be used.
-
#availability_zone_id ⇒ String
The ID of the Availability Zone.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters.
-
#include_marketplace ⇒ Boolean
Include Reserved Instance Marketplace offerings in the response.
-
#instance_tenancy ⇒ String
The tenancy of the instances covered by the reservation.
-
#instance_type ⇒ String
The instance type that the reservation will cover (for example,
m1.small). -
#max_duration ⇒ Integer
The maximum duration (in seconds) to filter when searching for offerings.
-
#max_instance_count ⇒ Integer
The maximum number of instances to filter when searching for offerings.
-
#max_results ⇒ Integer
The maximum number of results to return for the request in a single page.
-
#min_duration ⇒ Integer
The minimum duration (in seconds) to filter when searching for offerings.
-
#next_token ⇒ String
The token to retrieve the next page of results.
-
#offering_class ⇒ String
The offering class of the Reserved Instance.
-
#offering_type ⇒ String
The Reserved Instance offering type.
-
#product_description ⇒ String
The Reserved Instance product platform description.
-
#reserved_instances_offering_ids ⇒ Array<String>
One or more Reserved Instances offering IDs.
Instance Attribute Details
#availability_zone ⇒ String
The Availability Zone in which the Reserved Instance can be used.
Either AvailabilityZone or AvailabilityZoneId can be specified,
but not both.
32519 32520 32521 32522 32523 32524 32525 32526 32527 32528 32529 32530 32531 32532 32533 32534 32535 32536 32537 32538 |
# File 'lib/aws-sdk-ec2/types.rb', line 32519 class DescribeReservedInstancesOfferingsRequest < Struct.new( :availability_zone, :include_marketplace, :instance_type, :max_duration, :max_instance_count, :min_duration, :offering_class, :product_description, :reserved_instances_offering_ids, :availability_zone_id, :dry_run, :filters, :instance_tenancy, :offering_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
The ID of the Availability Zone.
Either AvailabilityZone or AvailabilityZoneId can be specified,
but not both.
32519 32520 32521 32522 32523 32524 32525 32526 32527 32528 32529 32530 32531 32532 32533 32534 32535 32536 32537 32538 |
# File 'lib/aws-sdk-ec2/types.rb', line 32519 class DescribeReservedInstancesOfferingsRequest < Struct.new( :availability_zone, :include_marketplace, :instance_type, :max_duration, :max_instance_count, :min_duration, :offering_class, :product_description, :reserved_instances_offering_ids, :availability_zone_id, :dry_run, :filters, :instance_tenancy, :offering_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
32519 32520 32521 32522 32523 32524 32525 32526 32527 32528 32529 32530 32531 32532 32533 32534 32535 32536 32537 32538 |
# File 'lib/aws-sdk-ec2/types.rb', line 32519 class DescribeReservedInstancesOfferingsRequest < Struct.new( :availability_zone, :include_marketplace, :instance_type, :max_duration, :max_instance_count, :min_duration, :offering_class, :product_description, :reserved_instances_offering_ids, :availability_zone_id, :dry_run, :filters, :instance_tenancy, :offering_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters.
-
availability-zone- The Availability Zone where the Reserved Instance can be used. -
availability-zone-id- The ID of the Availability Zone where the Reserved Instance can be used. -
duration- The duration of the Reserved Instance (for example, one year or three years), in seconds (31536000|94608000). -
fixed-price- The purchase price of the Reserved Instance (for example, 9800.0). -
instance-type- The instance type that is covered by the reservation. -
marketplace- Set totrueto show only Reserved Instance Marketplace offerings. When this filter is not used, which is the default behavior, all offerings from both Amazon Web Services and the Reserved Instance Marketplace are listed. -
product-description- The Reserved Instance product platform description (Linux/UNIX|Linux with SQL Server Standard|Linux with SQL Server Web|Linux with SQL Server Enterprise|SUSE Linux|Red Hat Enterprise Linux|Red Hat Enterprise Linux with HA|Windows|Windows with SQL Server Standard|Windows with SQL Server Web|Windows with SQL Server Enterprise). -
reserved-instances-offering-id- The Reserved Instances offering ID. -
scope- The scope of the Reserved Instance (Availability ZoneorRegion). -
usage-price- The usage price of the Reserved Instance, per hour (for example, 0.84).
32519 32520 32521 32522 32523 32524 32525 32526 32527 32528 32529 32530 32531 32532 32533 32534 32535 32536 32537 32538 |
# File 'lib/aws-sdk-ec2/types.rb', line 32519 class DescribeReservedInstancesOfferingsRequest < Struct.new( :availability_zone, :include_marketplace, :instance_type, :max_duration, :max_instance_count, :min_duration, :offering_class, :product_description, :reserved_instances_offering_ids, :availability_zone_id, :dry_run, :filters, :instance_tenancy, :offering_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#include_marketplace ⇒ Boolean
Include Reserved Instance Marketplace offerings in the response.
32519 32520 32521 32522 32523 32524 32525 32526 32527 32528 32529 32530 32531 32532 32533 32534 32535 32536 32537 32538 |
# File 'lib/aws-sdk-ec2/types.rb', line 32519 class DescribeReservedInstancesOfferingsRequest < Struct.new( :availability_zone, :include_marketplace, :instance_type, :max_duration, :max_instance_count, :min_duration, :offering_class, :product_description, :reserved_instances_offering_ids, :availability_zone_id, :dry_run, :filters, :instance_tenancy, :offering_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#instance_tenancy ⇒ String
The tenancy of the instances covered by the reservation. A Reserved
Instance with a tenancy of dedicated is applied to instances that
run in a VPC on single-tenant hardware (i.e., Dedicated Instances).
Important: The host value cannot be used with this parameter.
Use the default or dedicated values only.
Default: default
32519 32520 32521 32522 32523 32524 32525 32526 32527 32528 32529 32530 32531 32532 32533 32534 32535 32536 32537 32538 |
# File 'lib/aws-sdk-ec2/types.rb', line 32519 class DescribeReservedInstancesOfferingsRequest < Struct.new( :availability_zone, :include_marketplace, :instance_type, :max_duration, :max_instance_count, :min_duration, :offering_class, :product_description, :reserved_instances_offering_ids, :availability_zone_id, :dry_run, :filters, :instance_tenancy, :offering_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The instance type that the reservation will cover (for example,
m1.small). For more information, see Amazon EC2 instance
types in the Amazon EC2 User Guide.
32519 32520 32521 32522 32523 32524 32525 32526 32527 32528 32529 32530 32531 32532 32533 32534 32535 32536 32537 32538 |
# File 'lib/aws-sdk-ec2/types.rb', line 32519 class DescribeReservedInstancesOfferingsRequest < Struct.new( :availability_zone, :include_marketplace, :instance_type, :max_duration, :max_instance_count, :min_duration, :offering_class, :product_description, :reserved_instances_offering_ids, :availability_zone_id, :dry_run, :filters, :instance_tenancy, :offering_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_duration ⇒ Integer
The maximum duration (in seconds) to filter when searching for offerings.
Default: 94608000 (3 years)
32519 32520 32521 32522 32523 32524 32525 32526 32527 32528 32529 32530 32531 32532 32533 32534 32535 32536 32537 32538 |
# File 'lib/aws-sdk-ec2/types.rb', line 32519 class DescribeReservedInstancesOfferingsRequest < Struct.new( :availability_zone, :include_marketplace, :instance_type, :max_duration, :max_instance_count, :min_duration, :offering_class, :product_description, :reserved_instances_offering_ids, :availability_zone_id, :dry_run, :filters, :instance_tenancy, :offering_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_instance_count ⇒ Integer
The maximum number of instances to filter when searching for offerings.
Default: 20
32519 32520 32521 32522 32523 32524 32525 32526 32527 32528 32529 32530 32531 32532 32533 32534 32535 32536 32537 32538 |
# File 'lib/aws-sdk-ec2/types.rb', line 32519 class DescribeReservedInstancesOfferingsRequest < Struct.new( :availability_zone, :include_marketplace, :instance_type, :max_duration, :max_instance_count, :min_duration, :offering_class, :product_description, :reserved_instances_offering_ids, :availability_zone_id, :dry_run, :filters, :instance_tenancy, :offering_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return for the request in a single
page. The remaining results of the initial request can be seen by
sending another request with the returned NextToken value. The
maximum is 100.
Default: 100
32519 32520 32521 32522 32523 32524 32525 32526 32527 32528 32529 32530 32531 32532 32533 32534 32535 32536 32537 32538 |
# File 'lib/aws-sdk-ec2/types.rb', line 32519 class DescribeReservedInstancesOfferingsRequest < Struct.new( :availability_zone, :include_marketplace, :instance_type, :max_duration, :max_instance_count, :min_duration, :offering_class, :product_description, :reserved_instances_offering_ids, :availability_zone_id, :dry_run, :filters, :instance_tenancy, :offering_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#min_duration ⇒ Integer
The minimum duration (in seconds) to filter when searching for offerings.
Default: 2592000 (1 month)
32519 32520 32521 32522 32523 32524 32525 32526 32527 32528 32529 32530 32531 32532 32533 32534 32535 32536 32537 32538 |
# File 'lib/aws-sdk-ec2/types.rb', line 32519 class DescribeReservedInstancesOfferingsRequest < Struct.new( :availability_zone, :include_marketplace, :instance_type, :max_duration, :max_instance_count, :min_duration, :offering_class, :product_description, :reserved_instances_offering_ids, :availability_zone_id, :dry_run, :filters, :instance_tenancy, :offering_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to retrieve the next page of results.
32519 32520 32521 32522 32523 32524 32525 32526 32527 32528 32529 32530 32531 32532 32533 32534 32535 32536 32537 32538 |
# File 'lib/aws-sdk-ec2/types.rb', line 32519 class DescribeReservedInstancesOfferingsRequest < Struct.new( :availability_zone, :include_marketplace, :instance_type, :max_duration, :max_instance_count, :min_duration, :offering_class, :product_description, :reserved_instances_offering_ids, :availability_zone_id, :dry_run, :filters, :instance_tenancy, :offering_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#offering_class ⇒ String
The offering class of the Reserved Instance. Can be standard or
convertible.
32519 32520 32521 32522 32523 32524 32525 32526 32527 32528 32529 32530 32531 32532 32533 32534 32535 32536 32537 32538 |
# File 'lib/aws-sdk-ec2/types.rb', line 32519 class DescribeReservedInstancesOfferingsRequest < Struct.new( :availability_zone, :include_marketplace, :instance_type, :max_duration, :max_instance_count, :min_duration, :offering_class, :product_description, :reserved_instances_offering_ids, :availability_zone_id, :dry_run, :filters, :instance_tenancy, :offering_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#offering_type ⇒ String
The Reserved Instance offering type. If you are using tools that
predate the 2011-11-01 API version, you only have access to the
Medium Utilization Reserved Instance offering type.
32519 32520 32521 32522 32523 32524 32525 32526 32527 32528 32529 32530 32531 32532 32533 32534 32535 32536 32537 32538 |
# File 'lib/aws-sdk-ec2/types.rb', line 32519 class DescribeReservedInstancesOfferingsRequest < Struct.new( :availability_zone, :include_marketplace, :instance_type, :max_duration, :max_instance_count, :min_duration, :offering_class, :product_description, :reserved_instances_offering_ids, :availability_zone_id, :dry_run, :filters, :instance_tenancy, :offering_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#product_description ⇒ String
The Reserved Instance product platform description. Instances that
include (Amazon VPC) in the description are for use with Amazon
VPC.
32519 32520 32521 32522 32523 32524 32525 32526 32527 32528 32529 32530 32531 32532 32533 32534 32535 32536 32537 32538 |
# File 'lib/aws-sdk-ec2/types.rb', line 32519 class DescribeReservedInstancesOfferingsRequest < Struct.new( :availability_zone, :include_marketplace, :instance_type, :max_duration, :max_instance_count, :min_duration, :offering_class, :product_description, :reserved_instances_offering_ids, :availability_zone_id, :dry_run, :filters, :instance_tenancy, :offering_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#reserved_instances_offering_ids ⇒ Array<String>
One or more Reserved Instances offering IDs.
32519 32520 32521 32522 32523 32524 32525 32526 32527 32528 32529 32530 32531 32532 32533 32534 32535 32536 32537 32538 |
# File 'lib/aws-sdk-ec2/types.rb', line 32519 class DescribeReservedInstancesOfferingsRequest < Struct.new( :availability_zone, :include_marketplace, :instance_type, :max_duration, :max_instance_count, :min_duration, :offering_class, :product_description, :reserved_instances_offering_ids, :availability_zone_id, :dry_run, :filters, :instance_tenancy, :offering_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |