Class: Aws::EC2::Types::DescribeRouteTablesResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeRouteTablesResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the output of DescribeRouteTables.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#route_tables ⇒ Array<Types::RouteTable>
Information about the route tables.
Instance Attribute Details
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
32952 32953 32954 32955 32956 32957 |
# File 'lib/aws-sdk-ec2/types.rb', line 32952 class DescribeRouteTablesResult < Struct.new( :route_tables, :next_token) SENSITIVE = [] include Aws::Structure end |
#route_tables ⇒ Array<Types::RouteTable>
Information about the route tables.
32952 32953 32954 32955 32956 32957 |
# File 'lib/aws-sdk-ec2/types.rb', line 32952 class DescribeRouteTablesResult < Struct.new( :route_tables, :next_token) SENSITIVE = [] include Aws::Structure end |