Class: Aws::EC2::Types::DescribeScheduledInstanceAvailabilityResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the output of DescribeScheduledInstanceAvailability.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The token required to retrieve the next set of results. This value is null when there are no more results to return.

Returns:

  • (String)


32676
32677
32678
32679
32680
32681
# File 'lib/aws-sdk-ec2/types.rb', line 32676

class DescribeScheduledInstanceAvailabilityResult < Struct.new(
  :next_token,
  :scheduled_instance_availability_set)
  SENSITIVE = []
  include Aws::Structure
end

#scheduled_instance_availability_setArray<Types::ScheduledInstanceAvailability>

Information about the available Scheduled Instances.



32676
32677
32678
32679
32680
32681
# File 'lib/aws-sdk-ec2/types.rb', line 32676

class DescribeScheduledInstanceAvailabilityResult < Struct.new(
  :next_token,
  :scheduled_instance_availability_set)
  SENSITIVE = []
  include Aws::Structure
end