Class: Aws::EC2::Types::DescribeSecondaryInterfacesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeSecondaryInterfacesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The filters.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
-
#secondary_interface_ids ⇒ Array<String>
The IDs of the secondary interfaces.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
30940 30941 30942 30943 30944 30945 30946 30947 30948 |
# File 'lib/aws-sdk-ec2/types.rb', line 30940 class DescribeSecondaryInterfacesRequest < Struct.new( :dry_run, :filters, :max_results, :next_token, :secondary_interface_ids) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters.
-
‘attachment.attachment-id` - The ID of the secondary interface attachment.
-
‘attachment.instance-id` - The ID of the instance to which the secondary interface is attached.
-
‘attachment.instance-owner-id` - The ID of the Amazon Web Services account that owns the instance to which the secondary interface is attached.
-
‘attachment.status` - The attachment status (`attaching` | `attached` | `detaching` | `detached`).
-
‘private-ipv4-addresses.private-ip-address` - The private IPv4 address associated with the secondary interface.
-
‘owner-id` - The ID of the Amazon Web Services account that owns the secondary interface.
-
‘secondary-interface-arn` - The ARN of the secondary interface.
-
‘secondary-interface-id` - The ID of the secondary interface.
-
‘secondary-interface-type` - The type of secondary interface (`secondary`).
-
‘secondary-network-id` - The ID of the secondary network.
-
‘secondary-network-type` - The type of the secondary network (`rdma`).
-
‘secondary-subnet-id` - The ID of the secondary subnet.
-
‘status` - The status of the secondary interface (`available` | `in-use`).
-
‘tag`:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key `Owner` and the value `TeamA`, specify `tag:Owner` for the filter name and `TeamA` for the filter value.
-
‘tag-key` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.
30940 30941 30942 30943 30944 30945 30946 30947 30948 |
# File 'lib/aws-sdk-ec2/types.rb', line 30940 class DescribeSecondaryInterfacesRequest < Struct.new( :dry_run, :filters, :max_results, :next_token, :secondary_interface_ids) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.
30940 30941 30942 30943 30944 30945 30946 30947 30948 |
# File 'lib/aws-sdk-ec2/types.rb', line 30940 class DescribeSecondaryInterfacesRequest < Struct.new( :dry_run, :filters, :max_results, :next_token, :secondary_interface_ids) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
30940 30941 30942 30943 30944 30945 30946 30947 30948 |
# File 'lib/aws-sdk-ec2/types.rb', line 30940 class DescribeSecondaryInterfacesRequest < Struct.new( :dry_run, :filters, :max_results, :next_token, :secondary_interface_ids) SENSITIVE = [] include Aws::Structure end |
#secondary_interface_ids ⇒ Array<String>
The IDs of the secondary interfaces.
30940 30941 30942 30943 30944 30945 30946 30947 30948 |
# File 'lib/aws-sdk-ec2/types.rb', line 30940 class DescribeSecondaryInterfacesRequest < Struct.new( :dry_run, :filters, :max_results, :next_token, :secondary_interface_ids) SENSITIVE = [] include Aws::Structure end |