Class: Aws::EC2::Types::DescribeSecondaryNetworksRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


31327
31328
31329
31330
31331
31332
31333
31334
31335
# File 'lib/aws-sdk-ec2/types.rb', line 31327

class DescribeSecondaryNetworksRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :secondary_network_ids)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters. The following are the possible values:

  • ‘ipv4-cidr-block-association.association-id` - The association ID for an IPv4 CIDR block associated with the secondary network.

  • ‘ipv4-cidr-block-association.cidr-block` - An IPv4 CIDR block associated with the secondary network.

  • ‘ipv4-cidr-block-association.state` - The state of an IPv4 CIDR block associated with the secondary network.

  • ‘owner-id` - The ID of the Amazon Web Services account that owns the secondary network.

  • ‘secondary-network-id` - The ID of the secondary network.

  • ‘secondary-network-arn` - The ARN of the secondary network.

  • ‘state` - The state of the secondary network (`create-in-progress` | `create-complete` | `create-failed` | `delete-in-progress` | `delete-complete` | `delete-failed`).

  • ‘tag`:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key `Owner` and the value `TeamA`, specify `tag:Owner` for the filter name and `TeamA` for the filter value.

  • ‘tag-key` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.

  • ‘type` - The type of the secondary network (`rdma`).

Returns:



31327
31328
31329
31330
31331
31332
31333
31334
31335
# File 'lib/aws-sdk-ec2/types.rb', line 31327

class DescribeSecondaryNetworksRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :secondary_network_ids)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.

Returns:

  • (Integer)


31327
31328
31329
31330
31331
31332
31333
31334
31335
# File 'lib/aws-sdk-ec2/types.rb', line 31327

class DescribeSecondaryNetworksRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :secondary_network_ids)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


31327
31328
31329
31330
31331
31332
31333
31334
31335
# File 'lib/aws-sdk-ec2/types.rb', line 31327

class DescribeSecondaryNetworksRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :secondary_network_ids)
  SENSITIVE = []
  include Aws::Structure
end

#secondary_network_idsArray<String>

The IDs of the secondary networks.

Returns:

  • (Array<String>)


31327
31328
31329
31330
31331
31332
31333
31334
31335
# File 'lib/aws-sdk-ec2/types.rb', line 31327

class DescribeSecondaryNetworksRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :secondary_network_ids)
  SENSITIVE = []
  include Aws::Structure
end