Class: Aws::EC2::Types::DescribeServiceLinkVirtualInterfacesResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The token to use to retrieve the next page of results. This value is null when there are no more results to return.

Returns:

  • (String)


33809
33810
33811
33812
33813
33814
# File 'lib/aws-sdk-ec2/types.rb', line 33809

class DescribeServiceLinkVirtualInterfacesResult < Struct.new(
  :service_link_virtual_interfaces,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

Describes the service link virtual interfaces.



33809
33810
33811
33812
33813
33814
# File 'lib/aws-sdk-ec2/types.rb', line 33809

class DescribeServiceLinkVirtualInterfacesResult < Struct.new(
  :service_link_virtual_interfaces,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end