Class: Aws::EC2::Types::DescribeSnapshotTierStatusRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeSnapshotTierStatusRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The filters.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token returned from a previous paginated request.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
33883 33884 33885 33886 33887 33888 33889 33890 |
# File 'lib/aws-sdk-ec2/types.rb', line 33883 class DescribeSnapshotTierStatusRequest < Struct.new( :filters, :dry_run, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters.
-
snapshot-id- The snapshot ID. -
volume-id- The ID of the volume the snapshot is for. -
last-tiering-operation- The state of the last archive or restore action. (archival-in-progress|archival-completed|archival-failed|permanent-restore-in-progress|permanent-restore-completed|permanent-restore-failed|temporary-restore-in-progress|temporary-restore-completed|temporary-restore-failed)
33883 33884 33885 33886 33887 33888 33889 33890 |
# File 'lib/aws-sdk-ec2/types.rb', line 33883 class DescribeSnapshotTierStatusRequest < Struct.new( :filters, :dry_run, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
33883 33884 33885 33886 33887 33888 33889 33890 |
# File 'lib/aws-sdk-ec2/types.rb', line 33883 class DescribeSnapshotTierStatusRequest < Struct.new( :filters, :dry_run, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
33883 33884 33885 33886 33887 33888 33889 33890 |
# File 'lib/aws-sdk-ec2/types.rb', line 33883 class DescribeSnapshotTierStatusRequest < Struct.new( :filters, :dry_run, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |