Class: Aws::EC2::Types::DescribeSpotFleetRequestsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for DescribeSpotFleetRequests.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


32996
32997
32998
32999
33000
33001
33002
33003
# File 'lib/aws-sdk-ec2/types.rb', line 32996

class DescribeSpotFleetRequestsRequest < Struct.new(
  :dry_run,
  :spot_fleet_request_ids,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.

Returns:

  • (Integer)


32996
32997
32998
32999
33000
33001
33002
33003
# File 'lib/aws-sdk-ec2/types.rb', line 32996

class DescribeSpotFleetRequestsRequest < Struct.new(
  :dry_run,
  :spot_fleet_request_ids,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to include in another request to get the next page of items. This value is null when there are no more items to return.

Returns:

  • (String)


32996
32997
32998
32999
33000
33001
33002
33003
# File 'lib/aws-sdk-ec2/types.rb', line 32996

class DescribeSpotFleetRequestsRequest < Struct.new(
  :dry_run,
  :spot_fleet_request_ids,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#spot_fleet_request_idsArray<String>

The IDs of the Spot Fleet requests.

Returns:

  • (Array<String>)


32996
32997
32998
32999
33000
33001
33002
33003
# File 'lib/aws-sdk-ec2/types.rb', line 32996

class DescribeSpotFleetRequestsRequest < Struct.new(
  :dry_run,
  :spot_fleet_request_ids,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end