Class: Aws::EC2::Types::DescribeSpotPriceHistoryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for DescribeSpotPriceHistory.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_zoneString

Filters the results by the specified Availability Zone.

Either ‘AvailabilityZone` or `AvailabilityZoneId` can be specified, but not both

Returns:

  • (String)


32998
32999
33000
33001
33002
33003
33004
33005
33006
33007
33008
33009
33010
33011
# File 'lib/aws-sdk-ec2/types.rb', line 32998

class DescribeSpotPriceHistoryRequest < Struct.new(
  :availability_zone_id,
  :dry_run,
  :start_time,
  :end_time,
  :instance_types,
  :product_descriptions,
  :filters,
  :availability_zone,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zone_idString

Filters the results by the specified ID of the Availability Zone.

Either ‘AvailabilityZone` or `AvailabilityZoneId` can be specified, but not both

Returns:

  • (String)


32998
32999
33000
33001
33002
33003
33004
33005
33006
33007
33008
33009
33010
33011
# File 'lib/aws-sdk-ec2/types.rb', line 32998

class DescribeSpotPriceHistoryRequest < Struct.new(
  :availability_zone_id,
  :dry_run,
  :start_time,
  :end_time,
  :instance_types,
  :product_descriptions,
  :filters,
  :availability_zone,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


32998
32999
33000
33001
33002
33003
33004
33005
33006
33007
33008
33009
33010
33011
# File 'lib/aws-sdk-ec2/types.rb', line 32998

class DescribeSpotPriceHistoryRequest < Struct.new(
  :availability_zone_id,
  :dry_run,
  :start_time,
  :end_time,
  :instance_types,
  :product_descriptions,
  :filters,
  :availability_zone,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

The date and time, up to the current date, from which to stop retrieving the price history data, in UTC format (for example, YYYY-MM-*DD*T*HH*:MM:*SS*Z).

Returns:

  • (Time)


32998
32999
33000
33001
33002
33003
33004
33005
33006
33007
33008
33009
33010
33011
# File 'lib/aws-sdk-ec2/types.rb', line 32998

class DescribeSpotPriceHistoryRequest < Struct.new(
  :availability_zone_id,
  :dry_run,
  :start_time,
  :end_time,
  :instance_types,
  :product_descriptions,
  :filters,
  :availability_zone,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters.

  • ‘availability-zone` - The Availability Zone for which prices should be returned.

  • ‘availability-zone-id` - The ID of the Availability Zone for which prices should be returned.

  • ‘instance-type` - The type of instance (for example, `m3.medium`).

  • ‘product-description` - The product description for the Spot price (`Linux/UNIX` | `Red Hat Enterprise Linux` | `SUSE Linux` | `Windows` | `Linux/UNIX (Amazon VPC)` | `Red Hat Enterprise Linux (Amazon VPC)` | `SUSE Linux (Amazon VPC)` | `Windows (Amazon VPC)`).

  • ‘spot-price` - The Spot price. The value must match exactly (or use wildcards; greater than or less than comparison is not supported).

  • ‘timestamp` - The time stamp of the Spot price history, in UTC format (for example, *ddd MMM dd HH*:mm:ss UTC YYYY). You can use wildcards (`*` and `?`). Greater than or less than comparison is not supported.

Returns:



32998
32999
33000
33001
33002
33003
33004
33005
33006
33007
33008
33009
33010
33011
# File 'lib/aws-sdk-ec2/types.rb', line 32998

class DescribeSpotPriceHistoryRequest < Struct.new(
  :availability_zone_id,
  :dry_run,
  :start_time,
  :end_time,
  :instance_types,
  :product_descriptions,
  :filters,
  :availability_zone,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typesArray<String>

Filters the results by the specified instance types.

Returns:

  • (Array<String>)


32998
32999
33000
33001
33002
33003
33004
33005
33006
33007
33008
33009
33010
33011
# File 'lib/aws-sdk-ec2/types.rb', line 32998

class DescribeSpotPriceHistoryRequest < Struct.new(
  :availability_zone_id,
  :dry_run,
  :start_time,
  :end_time,
  :instance_types,
  :product_descriptions,
  :filters,
  :availability_zone,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination

Returns:

  • (Integer)


32998
32999
33000
33001
33002
33003
33004
33005
33006
33007
33008
33009
33010
33011
# File 'lib/aws-sdk-ec2/types.rb', line 32998

class DescribeSpotPriceHistoryRequest < Struct.new(
  :availability_zone_id,
  :dry_run,
  :start_time,
  :end_time,
  :instance_types,
  :product_descriptions,
  :filters,
  :availability_zone,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Returns:

  • (String)


32998
32999
33000
33001
33002
33003
33004
33005
33006
33007
33008
33009
33010
33011
# File 'lib/aws-sdk-ec2/types.rb', line 32998

class DescribeSpotPriceHistoryRequest < Struct.new(
  :availability_zone_id,
  :dry_run,
  :start_time,
  :end_time,
  :instance_types,
  :product_descriptions,
  :filters,
  :availability_zone,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#product_descriptionsArray<String>

Filters the results by the specified basic product descriptions.

Returns:

  • (Array<String>)


32998
32999
33000
33001
33002
33003
33004
33005
33006
33007
33008
33009
33010
33011
# File 'lib/aws-sdk-ec2/types.rb', line 32998

class DescribeSpotPriceHistoryRequest < Struct.new(
  :availability_zone_id,
  :dry_run,
  :start_time,
  :end_time,
  :instance_types,
  :product_descriptions,
  :filters,
  :availability_zone,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The date and time, up to the past 90 days, from which to start retrieving the price history data, in UTC format (for example, YYYY-MM-*DD*T*HH*:MM:*SS*Z).

Returns:

  • (Time)


32998
32999
33000
33001
33002
33003
33004
33005
33006
33007
33008
33009
33010
33011
# File 'lib/aws-sdk-ec2/types.rb', line 32998

class DescribeSpotPriceHistoryRequest < Struct.new(
  :availability_zone_id,
  :dry_run,
  :start_time,
  :end_time,
  :instance_types,
  :product_descriptions,
  :filters,
  :availability_zone,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end