Class: Aws::EC2::Types::DescribeStoreImageTasksRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


34695
34696
34697
34698
34699
34700
34701
34702
34703
# File 'lib/aws-sdk-ec2/types.rb', line 34695

class DescribeStoreImageTasksRequest < Struct.new(
  :image_ids,
  :dry_run,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters.

  • task-state - Returns tasks in a certain state (InProgress | Completed | Failed)

  • bucket - Returns task information for tasks that targeted a specific bucket. For the filter value, specify the bucket name.

When you specify the ImageIds parameter, any filters that you specify are ignored. To use the filters, you must remove the ImageIds parameter.

Returns:



34695
34696
34697
34698
34699
34700
34701
34702
34703
# File 'lib/aws-sdk-ec2/types.rb', line 34695

class DescribeStoreImageTasksRequest < Struct.new(
  :image_ids,
  :dry_run,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#image_idsArray<String>

The AMI IDs for which to show progress. Up to 20 AMI IDs can be included in a request.

Returns:

  • (Array<String>)


34695
34696
34697
34698
34699
34700
34701
34702
34703
# File 'lib/aws-sdk-ec2/types.rb', line 34695

class DescribeStoreImageTasksRequest < Struct.new(
  :image_ids,
  :dry_run,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.

You cannot specify this parameter and the ImageIds parameter in the same call.

Returns:

  • (Integer)


34695
34696
34697
34698
34699
34700
34701
34702
34703
# File 'lib/aws-sdk-ec2/types.rb', line 34695

class DescribeStoreImageTasksRequest < Struct.new(
  :image_ids,
  :dry_run,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Returns:

  • (String)


34695
34696
34697
34698
34699
34700
34701
34702
34703
# File 'lib/aws-sdk-ec2/types.rb', line 34695

class DescribeStoreImageTasksRequest < Struct.new(
  :image_ids,
  :dry_run,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end