Class: Aws::EC2::Types::DescribeStoreImageTasksResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeStoreImageTasksResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#store_image_task_results ⇒ Array<Types::StoreImageTaskResult>
The information about the AMI store tasks.
Instance Attribute Details
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
34737 34738 34739 34740 34741 34742 |
# File 'lib/aws-sdk-ec2/types.rb', line 34737 class DescribeStoreImageTasksResult < Struct.new( :store_image_task_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#store_image_task_results ⇒ Array<Types::StoreImageTaskResult>
The information about the AMI store tasks.
34737 34738 34739 34740 34741 34742 |
# File 'lib/aws-sdk-ec2/types.rb', line 34737 class DescribeStoreImageTasksResult < Struct.new( :store_image_task_results, :next_token) SENSITIVE = [] include Aws::Structure end |