Class: Aws::EC2::Types::DescribeTransitGatewayMulticastDomainsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeTransitGatewayMulticastDomainsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
-
#transit_gateway_multicast_domain_ids ⇒ Array<String>
The ID of the transit gateway multicast domain.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
34196 34197 34198 34199 34200 34201 34202 34203 34204 |
# File 'lib/aws-sdk-ec2/types.rb', line 34196 class DescribeTransitGatewayMulticastDomainsRequest < Struct.new( :transit_gateway_multicast_domain_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters. The possible values are:
-
state- The state of the transit gateway multicast domain. Valid values arepending|available|deleting|deleted. -
transit-gateway-id- The ID of the transit gateway. -
transit-gateway-multicast-domain-id- The ID of the transit gateway multicast domain.
34196 34197 34198 34199 34200 34201 34202 34203 34204 |
# File 'lib/aws-sdk-ec2/types.rb', line 34196 class DescribeTransitGatewayMulticastDomainsRequest < Struct.new( :transit_gateway_multicast_domain_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To
retrieve the remaining results, make another call with the returned
nextToken value.
34196 34197 34198 34199 34200 34201 34202 34203 34204 |
# File 'lib/aws-sdk-ec2/types.rb', line 34196 class DescribeTransitGatewayMulticastDomainsRequest < Struct.new( :transit_gateway_multicast_domain_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
34196 34197 34198 34199 34200 34201 34202 34203 34204 |
# File 'lib/aws-sdk-ec2/types.rb', line 34196 class DescribeTransitGatewayMulticastDomainsRequest < Struct.new( :transit_gateway_multicast_domain_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_multicast_domain_ids ⇒ Array<String>
The ID of the transit gateway multicast domain.
34196 34197 34198 34199 34200 34201 34202 34203 34204 |
# File 'lib/aws-sdk-ec2/types.rb', line 34196 class DescribeTransitGatewayMulticastDomainsRequest < Struct.new( :transit_gateway_multicast_domain_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |