Class: Aws::EC2::Types::DescribeTransitGatewayRouteTablesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeTransitGatewayRouteTablesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
-
#transit_gateway_route_table_ids ⇒ Array<String>
The IDs of the transit gateway route tables.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
35802 35803 35804 35805 35806 35807 35808 35809 35810 |
# File 'lib/aws-sdk-ec2/types.rb', line 35802 class DescribeTransitGatewayRouteTablesRequest < Struct.new( :transit_gateway_route_table_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters. The possible values are:
-
default-association-route-table- Indicates whether this is the default association route table for the transit gateway (true|false). -
default-propagation-route-table- Indicates whether this is the default propagation route table for the transit gateway (true|false). -
state- The state of the route table (available|deleting|deleted|pending). -
transit-gateway-id- The ID of the transit gateway. -
transit-gateway-route-table-id- The ID of the transit gateway route table.
35802 35803 35804 35805 35806 35807 35808 35809 35810 |
# File 'lib/aws-sdk-ec2/types.rb', line 35802 class DescribeTransitGatewayRouteTablesRequest < Struct.new( :transit_gateway_route_table_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To
retrieve the remaining results, make another call with the returned
nextToken value.
35802 35803 35804 35805 35806 35807 35808 35809 35810 |
# File 'lib/aws-sdk-ec2/types.rb', line 35802 class DescribeTransitGatewayRouteTablesRequest < Struct.new( :transit_gateway_route_table_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
35802 35803 35804 35805 35806 35807 35808 35809 35810 |
# File 'lib/aws-sdk-ec2/types.rb', line 35802 class DescribeTransitGatewayRouteTablesRequest < Struct.new( :transit_gateway_route_table_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_route_table_ids ⇒ Array<String>
The IDs of the transit gateway route tables.
35802 35803 35804 35805 35806 35807 35808 35809 35810 |
# File 'lib/aws-sdk-ec2/types.rb', line 35802 class DescribeTransitGatewayRouteTablesRequest < Struct.new( :transit_gateway_route_table_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |