Class: Aws::EC2::Types::DescribeTrunkInterfaceAssociationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeTrunkInterfaceAssociationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#association_ids ⇒ Array<String>
The IDs of the associations.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
Instance Attribute Details
#association_ids ⇒ Array<String>
The IDs of the associations.
36045 36046 36047 36048 36049 36050 36051 36052 36053 |
# File 'lib/aws-sdk-ec2/types.rb', line 36045 class DescribeTrunkInterfaceAssociationsRequest < Struct.new( :association_ids, :dry_run, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
36045 36046 36047 36048 36049 36050 36051 36052 36053 |
# File 'lib/aws-sdk-ec2/types.rb', line 36045 class DescribeTrunkInterfaceAssociationsRequest < Struct.new( :association_ids, :dry_run, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters.
-
gre-key- The ID of a trunk interface association. -
interface-protocol- The interface protocol. Valid values areVLANandGRE.
36045 36046 36047 36048 36049 36050 36051 36052 36053 |
# File 'lib/aws-sdk-ec2/types.rb', line 36045 class DescribeTrunkInterfaceAssociationsRequest < Struct.new( :association_ids, :dry_run, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To
retrieve the remaining results, make another call with the returned
nextToken value.
36045 36046 36047 36048 36049 36050 36051 36052 36053 |
# File 'lib/aws-sdk-ec2/types.rb', line 36045 class DescribeTrunkInterfaceAssociationsRequest < Struct.new( :association_ids, :dry_run, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
36045 36046 36047 36048 36049 36050 36051 36052 36053 |
# File 'lib/aws-sdk-ec2/types.rb', line 36045 class DescribeTrunkInterfaceAssociationsRequest < Struct.new( :association_ids, :dry_run, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |