Class: Aws::EC2::Types::DescribeVerifiedAccessEndpointsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeVerifiedAccessEndpointsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
-
#verified_access_endpoint_ids ⇒ Array<String>
The ID of the Verified Access endpoint.
-
#verified_access_group_id ⇒ String
The ID of the Verified Access group.
-
#verified_access_instance_id ⇒ String
The ID of the Verified Access instance.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
36108 36109 36110 36111 36112 36113 36114 36115 36116 36117 36118 |
# File 'lib/aws-sdk-ec2/types.rb', line 36108 class DescribeVerifiedAccessEndpointsRequest < Struct.new( :verified_access_endpoint_ids, :verified_access_instance_id, :verified_access_group_id, :max_results, :next_token, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters. Filter names and values are case-sensitive.
36108 36109 36110 36111 36112 36113 36114 36115 36116 36117 36118 |
# File 'lib/aws-sdk-ec2/types.rb', line 36108 class DescribeVerifiedAccessEndpointsRequest < Struct.new( :verified_access_endpoint_ids, :verified_access_instance_id, :verified_access_group_id, :max_results, :next_token, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To
retrieve the remaining results, make another call with the returned
nextToken value.
36108 36109 36110 36111 36112 36113 36114 36115 36116 36117 36118 |
# File 'lib/aws-sdk-ec2/types.rb', line 36108 class DescribeVerifiedAccessEndpointsRequest < Struct.new( :verified_access_endpoint_ids, :verified_access_instance_id, :verified_access_group_id, :max_results, :next_token, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
36108 36109 36110 36111 36112 36113 36114 36115 36116 36117 36118 |
# File 'lib/aws-sdk-ec2/types.rb', line 36108 class DescribeVerifiedAccessEndpointsRequest < Struct.new( :verified_access_endpoint_ids, :verified_access_instance_id, :verified_access_group_id, :max_results, :next_token, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#verified_access_endpoint_ids ⇒ Array<String>
The ID of the Verified Access endpoint.
36108 36109 36110 36111 36112 36113 36114 36115 36116 36117 36118 |
# File 'lib/aws-sdk-ec2/types.rb', line 36108 class DescribeVerifiedAccessEndpointsRequest < Struct.new( :verified_access_endpoint_ids, :verified_access_instance_id, :verified_access_group_id, :max_results, :next_token, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#verified_access_group_id ⇒ String
The ID of the Verified Access group.
36108 36109 36110 36111 36112 36113 36114 36115 36116 36117 36118 |
# File 'lib/aws-sdk-ec2/types.rb', line 36108 class DescribeVerifiedAccessEndpointsRequest < Struct.new( :verified_access_endpoint_ids, :verified_access_instance_id, :verified_access_group_id, :max_results, :next_token, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#verified_access_instance_id ⇒ String
The ID of the Verified Access instance.
36108 36109 36110 36111 36112 36113 36114 36115 36116 36117 36118 |
# File 'lib/aws-sdk-ec2/types.rb', line 36108 class DescribeVerifiedAccessEndpointsRequest < Struct.new( :verified_access_endpoint_ids, :verified_access_instance_id, :verified_access_group_id, :max_results, :next_token, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |