Class: Aws::EC2::Types::DescribeVolumesModificationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeVolumesModificationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The filters.
-
#include_managed_resources ⇒ Boolean
Indicates whether to include managed resources in the output.
-
#max_results ⇒ Integer
The maximum number of results (up to a limit of 500) to be returned in a paginated request.
-
#next_token ⇒ String
The token returned from a previous paginated request.
-
#volume_ids ⇒ Array<String>
The IDs of the volumes.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
36196 36197 36198 36199 36200 36201 36202 36203 36204 36205 |
# File 'lib/aws-sdk-ec2/types.rb', line 36196 class DescribeVolumesModificationsRequest < Struct.new( :dry_run, :volume_ids, :filters, :next_token, :max_results, :include_managed_resources) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters.
-
modification-state- The current modification state (modifying | optimizing | completed | failed). -
original-iops- The original IOPS rate of the volume. -
original-size- The original size of the volume, in GiB. -
original-volume-type- The original volume type of the volume (standard | io1 | io2 | gp2 | sc1 | st1). -
originalMultiAttachEnabled- Indicates whether Multi-Attach support was enabled (true | false). -
start-time- The modification start time. -
target-iops- The target IOPS rate of the volume. -
target-size- The target size of the volume, in GiB. -
target-volume-type- The target volume type of the volume (standard | io1 | io2 | gp2 | sc1 | st1). -
targetMultiAttachEnabled- Indicates whether Multi-Attach support is to be enabled (true | false). -
volume-id- The ID of the volume.
36196 36197 36198 36199 36200 36201 36202 36203 36204 36205 |
# File 'lib/aws-sdk-ec2/types.rb', line 36196 class DescribeVolumesModificationsRequest < Struct.new( :dry_run, :volume_ids, :filters, :next_token, :max_results, :include_managed_resources) SENSITIVE = [] include Aws::Structure end |
#include_managed_resources ⇒ Boolean
Indicates whether to include managed resources in the output. If
this parameter is set to true, the output includes resources that
are managed by Amazon Web Services services, even if managed
resource visibility is set to hidden.
36196 36197 36198 36199 36200 36201 36202 36203 36204 36205 |
# File 'lib/aws-sdk-ec2/types.rb', line 36196 class DescribeVolumesModificationsRequest < Struct.new( :dry_run, :volume_ids, :filters, :next_token, :max_results, :include_managed_resources) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results (up to a limit of 500) to be returned in a paginated request. For more information, see Pagination.
36196 36197 36198 36199 36200 36201 36202 36203 36204 36205 |
# File 'lib/aws-sdk-ec2/types.rb', line 36196 class DescribeVolumesModificationsRequest < Struct.new( :dry_run, :volume_ids, :filters, :next_token, :max_results, :include_managed_resources) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
36196 36197 36198 36199 36200 36201 36202 36203 36204 36205 |
# File 'lib/aws-sdk-ec2/types.rb', line 36196 class DescribeVolumesModificationsRequest < Struct.new( :dry_run, :volume_ids, :filters, :next_token, :max_results, :include_managed_resources) SENSITIVE = [] include Aws::Structure end |
#volume_ids ⇒ Array<String>
The IDs of the volumes.
36196 36197 36198 36199 36200 36201 36202 36203 36204 36205 |
# File 'lib/aws-sdk-ec2/types.rb', line 36196 class DescribeVolumesModificationsRequest < Struct.new( :dry_run, :volume_ids, :filters, :next_token, :max_results, :include_managed_resources) SENSITIVE = [] include Aws::Structure end |