Class: Aws::EC2::Types::DescribeVpcClassicLinkDnsSupportResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeVpcClassicLinkDnsSupportResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#vpcs ⇒ Array<Types::ClassicLinkDnsSupport>
Information about the ClassicLink DNS support status of the VPCs.
Instance Attribute Details
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
36950 36951 36952 36953 36954 36955 |
# File 'lib/aws-sdk-ec2/types.rb', line 36950 class DescribeVpcClassicLinkDnsSupportResult < Struct.new( :next_token, :vpcs) SENSITIVE = [] include Aws::Structure end |
#vpcs ⇒ Array<Types::ClassicLinkDnsSupport>
Information about the ClassicLink DNS support status of the VPCs.
36950 36951 36952 36953 36954 36955 |
# File 'lib/aws-sdk-ec2/types.rb', line 36950 class DescribeVpcClassicLinkDnsSupportResult < Struct.new( :next_token, :vpcs) SENSITIVE = [] include Aws::Structure end |