Class: Aws::EC2::Types::DescribeVpcClassicLinkRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


35402
35403
35404
35405
35406
35407
35408
# File 'lib/aws-sdk-ec2/types.rb', line 35402

class DescribeVpcClassicLinkRequest < Struct.new(
  :dry_run,
  :vpc_ids,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters.

  • ‘is-classic-link-enabled` - Whether the VPC is enabled for ClassicLink (`true` | `false`).

  • ‘tag` - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key `Owner` and the value `TeamA`, specify `tag:Owner` for the filter name and `TeamA` for the filter value.

  • ‘tag-key` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.

Returns:



35402
35403
35404
35405
35406
35407
35408
# File 'lib/aws-sdk-ec2/types.rb', line 35402

class DescribeVpcClassicLinkRequest < Struct.new(
  :dry_run,
  :vpc_ids,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idsArray<String>

The VPCs for which you want to describe the ClassicLink status.

Returns:

  • (Array<String>)


35402
35403
35404
35405
35406
35407
35408
# File 'lib/aws-sdk-ec2/types.rb', line 35402

class DescribeVpcClassicLinkRequest < Struct.new(
  :dry_run,
  :vpc_ids,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end