Class: Aws::EC2::Types::DescribeVpcEndpointConnectionNotificationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#connection_notification_idString

The ID of the notification.

Returns:

  • (String)


35607
35608
35609
35610
35611
35612
35613
35614
35615
# File 'lib/aws-sdk-ec2/types.rb', line 35607

class DescribeVpcEndpointConnectionNotificationsRequest < Struct.new(
  :dry_run,
  :connection_notification_id,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


35607
35608
35609
35610
35611
35612
35613
35614
35615
# File 'lib/aws-sdk-ec2/types.rb', line 35607

class DescribeVpcEndpointConnectionNotificationsRequest < Struct.new(
  :dry_run,
  :connection_notification_id,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters.

  • connection-notification-arn - The ARN of the SNS topic for the notification.

  • connection-notification-id - The ID of the notification.

  • connection-notification-state - The state of the notification (Enabled | Disabled).

  • connection-notification-type - The type of notification (Topic).

  • service-id - The ID of the endpoint service.

  • vpc-endpoint-id - The ID of the VPC endpoint.

Returns:



35607
35608
35609
35610
35611
35612
35613
35614
35615
# File 'lib/aws-sdk-ec2/types.rb', line 35607

class DescribeVpcEndpointConnectionNotificationsRequest < Struct.new(
  :dry_run,
  :connection_notification_id,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in a single call. To retrieve the remaining results, make another request with the returned NextToken value.

Returns:

  • (Integer)


35607
35608
35609
35610
35611
35612
35613
35614
35615
# File 'lib/aws-sdk-ec2/types.rb', line 35607

class DescribeVpcEndpointConnectionNotificationsRequest < Struct.new(
  :dry_run,
  :connection_notification_id,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to request the next page of results.

Returns:

  • (String)


35607
35608
35609
35610
35611
35612
35613
35614
35615
# File 'lib/aws-sdk-ec2/types.rb', line 35607

class DescribeVpcEndpointConnectionNotificationsRequest < Struct.new(
  :dry_run,
  :connection_notification_id,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end