Class: Aws::EC2::Types::DescribeVpcEndpointConnectionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeVpcEndpointConnectionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The filters.
-
#max_results ⇒ Integer
The maximum number of results to return for the request in a single page.
-
#next_token ⇒ String
The token to retrieve the next page of results.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
37255 37256 37257 37258 37259 37260 37261 37262 |
# File 'lib/aws-sdk-ec2/types.rb', line 37255 class DescribeVpcEndpointConnectionsRequest < Struct.new( :dry_run, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters.
-
ip-address-type- The IP address type (ipv4|ipv6). -
service-id- The ID of the service. -
vpc-endpoint-owner- The ID of the Amazon Web Services account ID that owns the endpoint. -
vpc-endpoint-region- The Region of the endpoint orcross-regionto find endpoints for other Regions. -
vpc-endpoint-state- The state of the endpoint (pendingAcceptance|pending|available|deleting|deleted|rejected|failed). -
vpc-endpoint-id- The ID of the endpoint.
37255 37256 37257 37258 37259 37260 37261 37262 |
# File 'lib/aws-sdk-ec2/types.rb', line 37255 class DescribeVpcEndpointConnectionsRequest < Struct.new( :dry_run, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return for the request in a single
page. The remaining results of the initial request can be seen by
sending another request with the returned NextToken value. This
value can be between 5 and 1,000; if MaxResults is given a value
larger than 1,000, only 1,000 results are returned.
37255 37256 37257 37258 37259 37260 37261 37262 |
# File 'lib/aws-sdk-ec2/types.rb', line 37255 class DescribeVpcEndpointConnectionsRequest < Struct.new( :dry_run, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to retrieve the next page of results.
37255 37256 37257 37258 37259 37260 37261 37262 |
# File 'lib/aws-sdk-ec2/types.rb', line 37255 class DescribeVpcEndpointConnectionsRequest < Struct.new( :dry_run, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |