Class: Aws::EC2::Types::DescribeVpcEndpointServiceConfigurationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeVpcEndpointServiceConfigurationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The filters.
-
#max_results ⇒ Integer
The maximum number of results to return for the request in a single page.
-
#next_token ⇒ String
The token to retrieve the next page of results.
-
#service_ids ⇒ Array<String>
The IDs of the endpoint services.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
35752 35753 35754 35755 35756 35757 35758 35759 35760 |
# File 'lib/aws-sdk-ec2/types.rb', line 35752 class DescribeVpcEndpointServiceConfigurationsRequest < Struct.new( :dry_run, :service_ids, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters.
-
service-name- The name of the service. -
service-id- The ID of the service. -
service-state- The state of the service (Pending|Available|Deleting|Deleted|Failed). -
supported-ip-address-types- The IP address type (ipv4|ipv6). -
tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the keyOwnerand the valueTeamA, specifytag:Ownerfor the filter name andTeamAfor the filter value. -
tag-key- The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.
35752 35753 35754 35755 35756 35757 35758 35759 35760 |
# File 'lib/aws-sdk-ec2/types.rb', line 35752 class DescribeVpcEndpointServiceConfigurationsRequest < Struct.new( :dry_run, :service_ids, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return for the request in a single
page. The remaining results of the initial request can be seen by
sending another request with the returned NextToken value. This
value can be between 5 and 1,000; if MaxResults is given a value
larger than 1,000, only 1,000 results are returned.
35752 35753 35754 35755 35756 35757 35758 35759 35760 |
# File 'lib/aws-sdk-ec2/types.rb', line 35752 class DescribeVpcEndpointServiceConfigurationsRequest < Struct.new( :dry_run, :service_ids, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to retrieve the next page of results.
35752 35753 35754 35755 35756 35757 35758 35759 35760 |
# File 'lib/aws-sdk-ec2/types.rb', line 35752 class DescribeVpcEndpointServiceConfigurationsRequest < Struct.new( :dry_run, :service_ids, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#service_ids ⇒ Array<String>
The IDs of the endpoint services.
35752 35753 35754 35755 35756 35757 35758 35759 35760 |
# File 'lib/aws-sdk-ec2/types.rb', line 35752 class DescribeVpcEndpointServiceConfigurationsRequest < Struct.new( :dry_run, :service_ids, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |