Class: Aws::EC2::Types::DescribeVpcEndpointServiceConfigurationsResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The token to use to retrieve the next page of results. This value is null when there are no more results to return.

Returns:

  • (String)


36969
36970
36971
36972
36973
36974
# File 'lib/aws-sdk-ec2/types.rb', line 36969

class DescribeVpcEndpointServiceConfigurationsResult < Struct.new(
  :service_configurations,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#service_configurationsArray<Types::ServiceConfiguration>

Information about the services.

Returns:



36969
36970
36971
36972
36973
36974
# File 'lib/aws-sdk-ec2/types.rb', line 36969

class DescribeVpcEndpointServiceConfigurationsResult < Struct.new(
  :service_configurations,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end