Class: Aws::EC2::Types::DescribeVpnConcentratorsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeVpnConcentratorsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters to limit the results.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
-
#vpn_concentrator_ids ⇒ Array<String>
One or more VPN concentrator IDs.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
37837 37838 37839 37840 37841 37842 37843 37844 37845 |
# File 'lib/aws-sdk-ec2/types.rb', line 37837 class DescribeVpnConcentratorsRequest < Struct.new( :vpn_concentrator_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters to limit the results.
37837 37838 37839 37840 37841 37842 37843 37844 37845 |
# File 'lib/aws-sdk-ec2/types.rb', line 37837 class DescribeVpnConcentratorsRequest < Struct.new( :vpn_concentrator_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To
retrieve the remaining results, make another call with the returned
nextToken value.
37837 37838 37839 37840 37841 37842 37843 37844 37845 |
# File 'lib/aws-sdk-ec2/types.rb', line 37837 class DescribeVpnConcentratorsRequest < Struct.new( :vpn_concentrator_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
37837 37838 37839 37840 37841 37842 37843 37844 37845 |
# File 'lib/aws-sdk-ec2/types.rb', line 37837 class DescribeVpnConcentratorsRequest < Struct.new( :vpn_concentrator_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#vpn_concentrator_ids ⇒ Array<String>
One or more VPN concentrator IDs.
37837 37838 37839 37840 37841 37842 37843 37844 37845 |
# File 'lib/aws-sdk-ec2/types.rb', line 37837 class DescribeVpnConcentratorsRequest < Struct.new( :vpn_concentrator_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |