Class: Aws::EC2::Types::DetachNetworkInterfaceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for DetachNetworkInterface.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attachment_idString

The ID of the attachment.

Returns:

  • (String)


36634
36635
36636
36637
36638
36639
36640
# File 'lib/aws-sdk-ec2/types.rb', line 36634

class DetachNetworkInterfaceRequest < Struct.new(
  :dry_run,
  :attachment_id,
  :force)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


36634
36635
36636
36637
36638
36639
36640
# File 'lib/aws-sdk-ec2/types.rb', line 36634

class DetachNetworkInterfaceRequest < Struct.new(
  :dry_run,
  :attachment_id,
  :force)
  SENSITIVE = []
  include Aws::Structure
end

#forceBoolean

Specifies whether to force a detachment.

* Use the Force parameter only as a last resort to detach a network interface from a failed instance.

  • If you use the Force parameter to detach a network interface, you might not be able to attach a different network interface to the same index on the instance without first stopping and starting the instance.

  • If you force the detachment of a network interface, the instance metadata might not get updated. This means that the attributes associated with the detached network interface might still be visible. The instance metadata will get updated when you stop and start the instance.

Returns:

  • (Boolean)


36634
36635
36636
36637
36638
36639
36640
# File 'lib/aws-sdk-ec2/types.rb', line 36634

class DetachNetworkInterfaceRequest < Struct.new(
  :dry_run,
  :attachment_id,
  :force)
  SENSITIVE = []
  include Aws::Structure
end