Class: Aws::EC2::Types::DetachVolumeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#deviceString

The device name.

Returns:

  • (String)


36643
36644
36645
36646
36647
36648
36649
36650
36651
# File 'lib/aws-sdk-ec2/types.rb', line 36643

class DetachVolumeRequest < Struct.new(
  :device,
  :force,
  :instance_id,
  :volume_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


36643
36644
36645
36646
36647
36648
36649
36650
36651
# File 'lib/aws-sdk-ec2/types.rb', line 36643

class DetachVolumeRequest < Struct.new(
  :device,
  :force,
  :instance_id,
  :volume_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#forceBoolean

Forces detachment if the previous detachment attempt did not occur cleanly (for example, logging into an instance, unmounting the volume, and detaching normally). This option can lead to data loss or a corrupted file system. Use this option only as a last resort to detach a volume from a failed instance. The instance won’t have an opportunity to flush file system caches or file system metadata. If you use this option, you must perform file system check and repair procedures.

Returns:

  • (Boolean)


36643
36644
36645
36646
36647
36648
36649
36650
36651
# File 'lib/aws-sdk-ec2/types.rb', line 36643

class DetachVolumeRequest < Struct.new(
  :device,
  :force,
  :instance_id,
  :volume_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The ID of the instance. If you are detaching a Multi-Attach enabled volume, you must specify an instance ID.

Returns:

  • (String)


36643
36644
36645
36646
36647
36648
36649
36650
36651
# File 'lib/aws-sdk-ec2/types.rb', line 36643

class DetachVolumeRequest < Struct.new(
  :device,
  :force,
  :instance_id,
  :volume_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#volume_idString

The ID of the volume.

Returns:

  • (String)


36643
36644
36645
36646
36647
36648
36649
36650
36651
# File 'lib/aws-sdk-ec2/types.rb', line 36643

class DetachVolumeRequest < Struct.new(
  :device,
  :force,
  :instance_id,
  :volume_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end