Class: Aws::EC2::Types::DirectoryServiceAuthenticationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes the Active Directory to be used for client authentication.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#directory_idString

The ID of the Active Directory to be used for authentication.

Returns:

  • (String)


36386
36387
36388
36389
36390
# File 'lib/aws-sdk-ec2/types.rb', line 36386

class DirectoryServiceAuthenticationRequest < Struct.new(
  :directory_id)
  SENSITIVE = []
  include Aws::Structure
end