Class: Aws::EC2::Types::DisableAddressTransferRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allocation_idString

The allocation ID of an Elastic IP address.

Returns:

  • (String)


38486
38487
38488
38489
38490
38491
# File 'lib/aws-sdk-ec2/types.rb', line 38486

class DisableAddressTransferRequest < Struct.new(
  :allocation_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


38486
38487
38488
38489
38490
38491
# File 'lib/aws-sdk-ec2/types.rb', line 38486

class DisableAddressTransferRequest < Struct.new(
  :allocation_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end