Class: Aws::EC2::Types::DisableCapacityManagerResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisableCapacityManagerResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_manager_status ⇒ String
The current status of Capacity Manager after the disable operation.
-
#organizations_access ⇒ Boolean
Indicates whether Organizations access is enabled.
Instance Attribute Details
#capacity_manager_status ⇒ String
The current status of Capacity Manager after the disable operation.
37250 37251 37252 37253 37254 37255 |
# File 'lib/aws-sdk-ec2/types.rb', line 37250 class DisableCapacityManagerResult < Struct.new( :capacity_manager_status, :organizations_access) SENSITIVE = [] include Aws::Structure end |
#organizations_access ⇒ Boolean
Indicates whether Organizations access is enabled. This will be
false after disabling Capacity Manager.
37250 37251 37252 37253 37254 37255 |
# File 'lib/aws-sdk-ec2/types.rb', line 37250 class DisableCapacityManagerResult < Struct.new( :capacity_manager_status, :organizations_access) SENSITIVE = [] include Aws::Structure end |