Class: Aws::EC2::Types::DisableFastSnapshotRestoreSuccessItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisableFastSnapshotRestoreSuccessItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes fast snapshot restores that were successfully disabled.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone ⇒ String
The Availability Zone.
-
#availability_zone_id ⇒ String
The ID of the Availability Zone.
-
#disabled_time ⇒ Time
The time at which fast snapshot restores entered the
disabledstate. -
#disabling_time ⇒ Time
The time at which fast snapshot restores entered the
disablingstate. -
#enabled_time ⇒ Time
The time at which fast snapshot restores entered the
enabledstate. -
#enabling_time ⇒ Time
The time at which fast snapshot restores entered the
enablingstate. -
#optimizing_time ⇒ Time
The time at which fast snapshot restores entered the
optimizingstate. -
#owner_alias ⇒ String
The Amazon Web Services owner alias that enabled fast snapshot restores on the snapshot.
-
#owner_id ⇒ String
The ID of the Amazon Web Services account that enabled fast snapshot restores on the snapshot.
-
#snapshot_id ⇒ String
The ID of the snapshot.
-
#state ⇒ String
The state of fast snapshot restores for the snapshot.
-
#state_transition_reason ⇒ String
The reason for the state transition.
Instance Attribute Details
#availability_zone ⇒ String
The Availability Zone.
38928 38929 38930 38931 38932 38933 38934 38935 38936 38937 38938 38939 38940 38941 38942 38943 |
# File 'lib/aws-sdk-ec2/types.rb', line 38928 class DisableFastSnapshotRestoreSuccessItem < Struct.new( :snapshot_id, :availability_zone, :availability_zone_id, :state, :state_transition_reason, :owner_id, :owner_alias, :enabling_time, :optimizing_time, :enabled_time, :disabling_time, :disabled_time) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
The ID of the Availability Zone.
38928 38929 38930 38931 38932 38933 38934 38935 38936 38937 38938 38939 38940 38941 38942 38943 |
# File 'lib/aws-sdk-ec2/types.rb', line 38928 class DisableFastSnapshotRestoreSuccessItem < Struct.new( :snapshot_id, :availability_zone, :availability_zone_id, :state, :state_transition_reason, :owner_id, :owner_alias, :enabling_time, :optimizing_time, :enabled_time, :disabling_time, :disabled_time) SENSITIVE = [] include Aws::Structure end |
#disabled_time ⇒ Time
The time at which fast snapshot restores entered the disabled
state.
38928 38929 38930 38931 38932 38933 38934 38935 38936 38937 38938 38939 38940 38941 38942 38943 |
# File 'lib/aws-sdk-ec2/types.rb', line 38928 class DisableFastSnapshotRestoreSuccessItem < Struct.new( :snapshot_id, :availability_zone, :availability_zone_id, :state, :state_transition_reason, :owner_id, :owner_alias, :enabling_time, :optimizing_time, :enabled_time, :disabling_time, :disabled_time) SENSITIVE = [] include Aws::Structure end |
#disabling_time ⇒ Time
The time at which fast snapshot restores entered the disabling
state.
38928 38929 38930 38931 38932 38933 38934 38935 38936 38937 38938 38939 38940 38941 38942 38943 |
# File 'lib/aws-sdk-ec2/types.rb', line 38928 class DisableFastSnapshotRestoreSuccessItem < Struct.new( :snapshot_id, :availability_zone, :availability_zone_id, :state, :state_transition_reason, :owner_id, :owner_alias, :enabling_time, :optimizing_time, :enabled_time, :disabling_time, :disabled_time) SENSITIVE = [] include Aws::Structure end |
#enabled_time ⇒ Time
The time at which fast snapshot restores entered the enabled
state.
38928 38929 38930 38931 38932 38933 38934 38935 38936 38937 38938 38939 38940 38941 38942 38943 |
# File 'lib/aws-sdk-ec2/types.rb', line 38928 class DisableFastSnapshotRestoreSuccessItem < Struct.new( :snapshot_id, :availability_zone, :availability_zone_id, :state, :state_transition_reason, :owner_id, :owner_alias, :enabling_time, :optimizing_time, :enabled_time, :disabling_time, :disabled_time) SENSITIVE = [] include Aws::Structure end |
#enabling_time ⇒ Time
The time at which fast snapshot restores entered the enabling
state.
38928 38929 38930 38931 38932 38933 38934 38935 38936 38937 38938 38939 38940 38941 38942 38943 |
# File 'lib/aws-sdk-ec2/types.rb', line 38928 class DisableFastSnapshotRestoreSuccessItem < Struct.new( :snapshot_id, :availability_zone, :availability_zone_id, :state, :state_transition_reason, :owner_id, :owner_alias, :enabling_time, :optimizing_time, :enabled_time, :disabling_time, :disabled_time) SENSITIVE = [] include Aws::Structure end |
#optimizing_time ⇒ Time
The time at which fast snapshot restores entered the optimizing
state.
38928 38929 38930 38931 38932 38933 38934 38935 38936 38937 38938 38939 38940 38941 38942 38943 |
# File 'lib/aws-sdk-ec2/types.rb', line 38928 class DisableFastSnapshotRestoreSuccessItem < Struct.new( :snapshot_id, :availability_zone, :availability_zone_id, :state, :state_transition_reason, :owner_id, :owner_alias, :enabling_time, :optimizing_time, :enabled_time, :disabling_time, :disabled_time) SENSITIVE = [] include Aws::Structure end |
#owner_alias ⇒ String
The Amazon Web Services owner alias that enabled fast snapshot restores on the snapshot. This is intended for future use.
38928 38929 38930 38931 38932 38933 38934 38935 38936 38937 38938 38939 38940 38941 38942 38943 |
# File 'lib/aws-sdk-ec2/types.rb', line 38928 class DisableFastSnapshotRestoreSuccessItem < Struct.new( :snapshot_id, :availability_zone, :availability_zone_id, :state, :state_transition_reason, :owner_id, :owner_alias, :enabling_time, :optimizing_time, :enabled_time, :disabling_time, :disabled_time) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
The ID of the Amazon Web Services account that enabled fast snapshot restores on the snapshot.
38928 38929 38930 38931 38932 38933 38934 38935 38936 38937 38938 38939 38940 38941 38942 38943 |
# File 'lib/aws-sdk-ec2/types.rb', line 38928 class DisableFastSnapshotRestoreSuccessItem < Struct.new( :snapshot_id, :availability_zone, :availability_zone_id, :state, :state_transition_reason, :owner_id, :owner_alias, :enabling_time, :optimizing_time, :enabled_time, :disabling_time, :disabled_time) SENSITIVE = [] include Aws::Structure end |
#snapshot_id ⇒ String
The ID of the snapshot.
38928 38929 38930 38931 38932 38933 38934 38935 38936 38937 38938 38939 38940 38941 38942 38943 |
# File 'lib/aws-sdk-ec2/types.rb', line 38928 class DisableFastSnapshotRestoreSuccessItem < Struct.new( :snapshot_id, :availability_zone, :availability_zone_id, :state, :state_transition_reason, :owner_id, :owner_alias, :enabling_time, :optimizing_time, :enabled_time, :disabling_time, :disabled_time) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of fast snapshot restores for the snapshot.
38928 38929 38930 38931 38932 38933 38934 38935 38936 38937 38938 38939 38940 38941 38942 38943 |
# File 'lib/aws-sdk-ec2/types.rb', line 38928 class DisableFastSnapshotRestoreSuccessItem < Struct.new( :snapshot_id, :availability_zone, :availability_zone_id, :state, :state_transition_reason, :owner_id, :owner_alias, :enabling_time, :optimizing_time, :enabled_time, :disabling_time, :disabled_time) SENSITIVE = [] include Aws::Structure end |
#state_transition_reason ⇒ String
The reason for the state transition. The possible values are as follows:
-
Client.UserInitiated- The state successfully transitioned toenablingordisabling. -
Client.UserInitiated - Lifecycle state transition- The state successfully transitioned tooptimizing,enabled, ordisabled.
38928 38929 38930 38931 38932 38933 38934 38935 38936 38937 38938 38939 38940 38941 38942 38943 |
# File 'lib/aws-sdk-ec2/types.rb', line 38928 class DisableFastSnapshotRestoreSuccessItem < Struct.new( :snapshot_id, :availability_zone, :availability_zone_id, :state, :state_transition_reason, :owner_id, :owner_alias, :enabling_time, :optimizing_time, :enabled_time, :disabling_time, :disabled_time) SENSITIVE = [] include Aws::Structure end |