Class: Aws::EC2::Types::DisableInstanceSqlHaStandbyDetectionsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisableInstanceSqlHaStandbyDetectionsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instances ⇒ Array<Types::RegisteredInstance>
Information about the instances that were disabled from SQL Server High Availability standby detection monitoring.
Instance Attribute Details
#instances ⇒ Array<Types::RegisteredInstance>
Information about the instances that were disabled from SQL Server High Availability standby detection monitoring.
36768 36769 36770 36771 36772 |
# File 'lib/aws-sdk-ec2/types.rb', line 36768 class DisableInstanceSqlHaStandbyDetectionsResult < Struct.new( :instances) SENSITIVE = [] include Aws::Structure end |