Class: Aws::EC2::Types::DisableIpamPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


37085
37086
37087
37088
37089
37090
37091
# File 'lib/aws-sdk-ec2/types.rb', line 37085

class DisableIpamPolicyRequest < Struct.new(
  :dry_run,
  :ipam_policy_id,
  :organization_target_id)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_policy_idString

The ID of the IPAM policy to disable.

Returns:

  • (String)


37085
37086
37087
37088
37089
37090
37091
# File 'lib/aws-sdk-ec2/types.rb', line 37085

class DisableIpamPolicyRequest < Struct.new(
  :dry_run,
  :ipam_policy_id,
  :organization_target_id)
  SENSITIVE = []
  include Aws::Structure
end

#organization_target_idString

The ID of the Amazon Web Services Organizations target for which to disable the IPAM policy. This parameter is required only when IPAM is integrated with Amazon Web Services Organizations. When IPAM is not integrated with Amazon Web Services Organizations, omit this parameter and the policy will be disabled for the current account.

A target can be an individual Amazon Web Services account or an entity within an Amazon Web Services Organization to which an IPAM policy can be applied.

Returns:

  • (String)


37085
37086
37087
37088
37089
37090
37091
# File 'lib/aws-sdk-ec2/types.rb', line 37085

class DisableIpamPolicyRequest < Struct.new(
  :dry_run,
  :ipam_policy_id,
  :organization_target_id)
  SENSITIVE = []
  include Aws::Structure
end