Class: Aws::EC2::Types::DisableVpcClassicLinkRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


39441
39442
39443
39444
39445
39446
# File 'lib/aws-sdk-ec2/types.rb', line 39441

class DisableVpcClassicLinkRequest < Struct.new(
  :dry_run,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC.

Returns:

  • (String)


39441
39442
39443
39444
39445
39446
# File 'lib/aws-sdk-ec2/types.rb', line 39441

class DisableVpcClassicLinkRequest < Struct.new(
  :dry_run,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end