Class: Aws::EC2::Types::DisassociateAddressRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#association_idString

The association ID. This parameter is required.

Returns:

  • (String)


39478
39479
39480
39481
39482
39483
39484
# File 'lib/aws-sdk-ec2/types.rb', line 39478

class DisassociateAddressRequest < Struct.new(
  :association_id,
  :public_ip,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


39478
39479
39480
39481
39482
39483
39484
# File 'lib/aws-sdk-ec2/types.rb', line 39478

class DisassociateAddressRequest < Struct.new(
  :association_id,
  :public_ip,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#public_ipString

Deprecated.

Returns:

  • (String)


39478
39479
39480
39481
39482
39483
39484
# File 'lib/aws-sdk-ec2/types.rb', line 39478

class DisassociateAddressRequest < Struct.new(
  :association_id,
  :public_ip,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end