Class: Aws::EC2::Types::DisassociateInstanceEventWindowRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#association_targetTypes::InstanceEventWindowDisassociationRequest

One or more targets to disassociate from the specified event window.



39716
39717
39718
39719
39720
39721
39722
# File 'lib/aws-sdk-ec2/types.rb', line 39716

class DisassociateInstanceEventWindowRequest < Struct.new(
  :dry_run,
  :instance_event_window_id,
  :association_target)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


39716
39717
39718
39719
39720
39721
39722
# File 'lib/aws-sdk-ec2/types.rb', line 39716

class DisassociateInstanceEventWindowRequest < Struct.new(
  :dry_run,
  :instance_event_window_id,
  :association_target)
  SENSITIVE = []
  include Aws::Structure
end

#instance_event_window_idString

The ID of the event window.

Returns:

  • (String)


39716
39717
39718
39719
39720
39721
39722
# File 'lib/aws-sdk-ec2/types.rb', line 39716

class DisassociateInstanceEventWindowRequest < Struct.new(
  :dry_run,
  :instance_event_window_id,
  :association_target)
  SENSITIVE = []
  include Aws::Structure
end