Class: Aws::EC2::Types::DisassociateNatGatewayAddressRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisassociateNatGatewayAddressRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#association_ids ⇒ Array<String>
The association IDs of EIPs that have been associated with the NAT gateway.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#max_drain_duration_seconds ⇒ Integer
The maximum amount of time to wait (in seconds) before forcibly releasing the IP addresses if connections are still in progress.
-
#nat_gateway_id ⇒ String
The ID of the NAT gateway.
Instance Attribute Details
#association_ids ⇒ Array<String>
The association IDs of EIPs that have been associated with the NAT gateway.
39804 39805 39806 39807 39808 39809 39810 39811 |
# File 'lib/aws-sdk-ec2/types.rb', line 39804 class DisassociateNatGatewayAddressRequest < Struct.new( :nat_gateway_id, :association_ids, :max_drain_duration_seconds, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
39804 39805 39806 39807 39808 39809 39810 39811 |
# File 'lib/aws-sdk-ec2/types.rb', line 39804 class DisassociateNatGatewayAddressRequest < Struct.new( :nat_gateway_id, :association_ids, :max_drain_duration_seconds, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_drain_duration_seconds ⇒ Integer
The maximum amount of time to wait (in seconds) before forcibly releasing the IP addresses if connections are still in progress. Default value is 350 seconds.
39804 39805 39806 39807 39808 39809 39810 39811 |
# File 'lib/aws-sdk-ec2/types.rb', line 39804 class DisassociateNatGatewayAddressRequest < Struct.new( :nat_gateway_id, :association_ids, :max_drain_duration_seconds, :dry_run) SENSITIVE = [] include Aws::Structure end |
#nat_gateway_id ⇒ String
The ID of the NAT gateway.
39804 39805 39806 39807 39808 39809 39810 39811 |
# File 'lib/aws-sdk-ec2/types.rb', line 39804 class DisassociateNatGatewayAddressRequest < Struct.new( :nat_gateway_id, :association_ids, :max_drain_duration_seconds, :dry_run) SENSITIVE = [] include Aws::Structure end |