Class: Aws::EC2::Types::DisassociateTransitGatewayPolicyTableRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisassociateTransitGatewayPolicyTableRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#transit_gateway_attachment_id ⇒ String
The ID of the transit gateway attachment to disassociate from the policy table.
-
#transit_gateway_policy_table_id ⇒ String
The ID of the disassociated policy table.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
40039 40040 40041 40042 40043 40044 40045 |
# File 'lib/aws-sdk-ec2/types.rb', line 40039 class DisassociateTransitGatewayPolicyTableRequest < Struct.new( :transit_gateway_policy_table_id, :transit_gateway_attachment_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_attachment_id ⇒ String
The ID of the transit gateway attachment to disassociate from the policy table.
40039 40040 40041 40042 40043 40044 40045 |
# File 'lib/aws-sdk-ec2/types.rb', line 40039 class DisassociateTransitGatewayPolicyTableRequest < Struct.new( :transit_gateway_policy_table_id, :transit_gateway_attachment_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_policy_table_id ⇒ String
The ID of the disassociated policy table.
40039 40040 40041 40042 40043 40044 40045 |
# File 'lib/aws-sdk-ec2/types.rb', line 40039 class DisassociateTransitGatewayPolicyTableRequest < Struct.new( :transit_gateway_policy_table_id, :transit_gateway_attachment_id, :dry_run) SENSITIVE = [] include Aws::Structure end |