Class: Aws::EC2::Types::DisassociateTransitGatewayRouteTableRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


40071
40072
40073
40074
40075
40076
40077
# File 'lib/aws-sdk-ec2/types.rb', line 40071

class DisassociateTransitGatewayRouteTableRequest < Struct.new(
  :transit_gateway_route_table_id,
  :transit_gateway_attachment_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_attachment_idString

The ID of the attachment.

Returns:

  • (String)


40071
40072
40073
40074
40075
40076
40077
# File 'lib/aws-sdk-ec2/types.rb', line 40071

class DisassociateTransitGatewayRouteTableRequest < Struct.new(
  :transit_gateway_route_table_id,
  :transit_gateway_attachment_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_route_table_idString

The ID of the transit gateway route table.

Returns:

  • (String)


40071
40072
40073
40074
40075
40076
40077
# File 'lib/aws-sdk-ec2/types.rb', line 40071

class DisassociateTransitGatewayRouteTableRequest < Struct.new(
  :transit_gateway_route_table_id,
  :transit_gateway_attachment_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end