Class: Aws::EC2::Types::DisassociateTrunkInterfaceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisassociateTrunkInterfaceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#association_id ⇒ String
The ID of the association.
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#association_id ⇒ String
The ID of the association
40107 40108 40109 40110 40111 40112 40113 |
# File 'lib/aws-sdk-ec2/types.rb', line 40107 class DisassociateTrunkInterfaceRequest < Struct.new( :association_id, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring idempotency.
A suitable default value is auto-generated. You should normally not need to pass this option.
40107 40108 40109 40110 40111 40112 40113 |
# File 'lib/aws-sdk-ec2/types.rb', line 40107 class DisassociateTrunkInterfaceRequest < Struct.new( :association_id, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
40107 40108 40109 40110 40111 40112 40113 |
# File 'lib/aws-sdk-ec2/types.rb', line 40107 class DisassociateTrunkInterfaceRequest < Struct.new( :association_id, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |