Class: Aws::EC2::Types::DiskImageDetail

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes a disk image.

Constant Summary collapse

SENSITIVE =
[:import_manifest_url]

Instance Attribute Summary collapse

Instance Attribute Details

#bytesInteger

The size of the disk image, in GiB.

Returns:

  • (Integer)


40282
40283
40284
40285
40286
40287
40288
# File 'lib/aws-sdk-ec2/types.rb', line 40282

class DiskImageDetail < Struct.new(
  :format,
  :bytes,
  :import_manifest_url)
  SENSITIVE = [:import_manifest_url]
  include Aws::Structure
end

#formatString

The disk image format.

Returns:

  • (String)


40282
40283
40284
40285
40286
40287
40288
# File 'lib/aws-sdk-ec2/types.rb', line 40282

class DiskImageDetail < Struct.new(
  :format,
  :bytes,
  :import_manifest_url)
  SENSITIVE = [:import_manifest_url]
  include Aws::Structure
end

#import_manifest_urlString

A presigned URL for the import manifest stored in Amazon S3 and presented here as an Amazon S3 presigned URL. For information about creating a presigned URL for an Amazon S3 object, read the "Query String Request Authentication Alternative" section of the Authenticating REST Requests topic in the Amazon Simple Storage Service Developer Guide.

For information about the import manifest referenced by this API action, see VM Import Manifest.

Returns:

  • (String)


40282
40283
40284
40285
40286
40287
40288
# File 'lib/aws-sdk-ec2/types.rb', line 40282

class DiskImageDetail < Struct.new(
  :format,
  :bytes,
  :import_manifest_url)
  SENSITIVE = [:import_manifest_url]
  include Aws::Structure
end