Class: Aws::EC2::Types::EbsBlockDeviceResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes a block device for an EBS volume.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#delete_on_terminationBoolean

Indicates whether the volume is deleted on instance termination.

Returns:

  • (Boolean)


40775
40776
40777
40778
40779
40780
40781
40782
40783
40784
40785
40786
# File 'lib/aws-sdk-ec2/types.rb', line 40775

class EbsBlockDeviceResponse < Struct.new(
  :encrypted,
  :delete_on_termination,
  :iops,
  :throughput,
  :kms_key_id,
  :snapshot_id,
  :volume_size,
  :volume_type)
  SENSITIVE = []
  include Aws::Structure
end

#encryptedBoolean

Indicates whether the volume is encrypted.

Returns:

  • (Boolean)


40775
40776
40777
40778
40779
40780
40781
40782
40783
40784
40785
40786
# File 'lib/aws-sdk-ec2/types.rb', line 40775

class EbsBlockDeviceResponse < Struct.new(
  :encrypted,
  :delete_on_termination,
  :iops,
  :throughput,
  :kms_key_id,
  :snapshot_id,
  :volume_size,
  :volume_type)
  SENSITIVE = []
  include Aws::Structure
end

#iopsInteger

The number of I/O operations per second (IOPS). For gp3, io1, and io2 volumes, this represents the number of IOPS that are provisioned for the volume. For gp2 volumes, this represents the baseline performance of the volume and the rate at which the volume accumulates I/O credits for bursting.

Returns:

  • (Integer)


40775
40776
40777
40778
40779
40780
40781
40782
40783
40784
40785
40786
# File 'lib/aws-sdk-ec2/types.rb', line 40775

class EbsBlockDeviceResponse < Struct.new(
  :encrypted,
  :delete_on_termination,
  :iops,
  :throughput,
  :kms_key_id,
  :snapshot_id,
  :volume_size,
  :volume_type)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

Identifier (key ID, key alias, key ARN, or alias ARN) of the customer managed KMS key to use for EBS encryption.

Returns:

  • (String)


40775
40776
40777
40778
40779
40780
40781
40782
40783
40784
40785
40786
# File 'lib/aws-sdk-ec2/types.rb', line 40775

class EbsBlockDeviceResponse < Struct.new(
  :encrypted,
  :delete_on_termination,
  :iops,
  :throughput,
  :kms_key_id,
  :snapshot_id,
  :volume_size,
  :volume_type)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_idString

The ID of the snapshot.

Returns:

  • (String)


40775
40776
40777
40778
40779
40780
40781
40782
40783
40784
40785
40786
# File 'lib/aws-sdk-ec2/types.rb', line 40775

class EbsBlockDeviceResponse < Struct.new(
  :encrypted,
  :delete_on_termination,
  :iops,
  :throughput,
  :kms_key_id,
  :snapshot_id,
  :volume_size,
  :volume_type)
  SENSITIVE = []
  include Aws::Structure
end

#throughputInteger

The throughput that the volume supports, in MiB/s.

Returns:

  • (Integer)


40775
40776
40777
40778
40779
40780
40781
40782
40783
40784
40785
40786
# File 'lib/aws-sdk-ec2/types.rb', line 40775

class EbsBlockDeviceResponse < Struct.new(
  :encrypted,
  :delete_on_termination,
  :iops,
  :throughput,
  :kms_key_id,
  :snapshot_id,
  :volume_size,
  :volume_type)
  SENSITIVE = []
  include Aws::Structure
end

#volume_sizeInteger

The size of the volume, in GiBs.

Returns:

  • (Integer)


40775
40776
40777
40778
40779
40780
40781
40782
40783
40784
40785
40786
# File 'lib/aws-sdk-ec2/types.rb', line 40775

class EbsBlockDeviceResponse < Struct.new(
  :encrypted,
  :delete_on_termination,
  :iops,
  :throughput,
  :kms_key_id,
  :snapshot_id,
  :volume_size,
  :volume_type)
  SENSITIVE = []
  include Aws::Structure
end

#volume_typeString

The volume type. For more information, see Amazon EBS volume types in the Amazon EBS User Guide.

Returns:

  • (String)


40775
40776
40777
40778
40779
40780
40781
40782
40783
40784
40785
40786
# File 'lib/aws-sdk-ec2/types.rb', line 40775

class EbsBlockDeviceResponse < Struct.new(
  :encrypted,
  :delete_on_termination,
  :iops,
  :throughput,
  :kms_key_id,
  :snapshot_id,
  :volume_size,
  :volume_type)
  SENSITIVE = []
  include Aws::Structure
end