Class: Aws::EC2::Types::EbsInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::EbsInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the Amazon EBS features supported by the instance type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attachment_limit_type ⇒ String
Indicates whether the instance type features a shared or dedicated Amazon EBS volume attachment limit.
-
#ebs_cards ⇒ Array<Types::EbsCardInfo>
Describes the EBS cards available for the instance type.
-
#ebs_optimized_info ⇒ Types::EbsOptimizedInfo
Describes the optimized EBS performance for the instance type.
-
#ebs_optimized_support ⇒ String
Indicates whether the instance type is Amazon EBS-optimized.
-
#encryption_support ⇒ String
Indicates whether Amazon EBS encryption is supported.
-
#maximum_ebs_attachments ⇒ Integer
Indicates the maximum number of Amazon EBS volumes that can be attached to the instance type.
-
#maximum_ebs_cards ⇒ Integer
Indicates the number of EBS cards supported by the instance type.
-
#nvme_support ⇒ String
Indicates whether non-volatile memory express (NVMe) is supported.
Instance Attribute Details
#attachment_limit_type ⇒ String
Indicates whether the instance type features a shared or dedicated Amazon EBS volume attachment limit. For more information, see Amazon EBS volume limits for Amazon EC2 instances in the Amazon EC2 User Guide.
39203 39204 39205 39206 39207 39208 39209 39210 39211 39212 39213 39214 |
# File 'lib/aws-sdk-ec2/types.rb', line 39203 class EbsInfo < Struct.new( :ebs_optimized_support, :encryption_support, :ebs_optimized_info, :nvme_support, :maximum_ebs_attachments, :attachment_limit_type, :maximum_ebs_cards, :ebs_cards) SENSITIVE = [] include Aws::Structure end |
#ebs_cards ⇒ Array<Types::EbsCardInfo>
Describes the EBS cards available for the instance type.
39203 39204 39205 39206 39207 39208 39209 39210 39211 39212 39213 39214 |
# File 'lib/aws-sdk-ec2/types.rb', line 39203 class EbsInfo < Struct.new( :ebs_optimized_support, :encryption_support, :ebs_optimized_info, :nvme_support, :maximum_ebs_attachments, :attachment_limit_type, :maximum_ebs_cards, :ebs_cards) SENSITIVE = [] include Aws::Structure end |
#ebs_optimized_info ⇒ Types::EbsOptimizedInfo
Describes the optimized EBS performance for the instance type.
39203 39204 39205 39206 39207 39208 39209 39210 39211 39212 39213 39214 |
# File 'lib/aws-sdk-ec2/types.rb', line 39203 class EbsInfo < Struct.new( :ebs_optimized_support, :encryption_support, :ebs_optimized_info, :nvme_support, :maximum_ebs_attachments, :attachment_limit_type, :maximum_ebs_cards, :ebs_cards) SENSITIVE = [] include Aws::Structure end |
#ebs_optimized_support ⇒ String
Indicates whether the instance type is Amazon EBS-optimized. For more information, see Amazon EBS-optimized instances in Amazon EC2 User Guide.
39203 39204 39205 39206 39207 39208 39209 39210 39211 39212 39213 39214 |
# File 'lib/aws-sdk-ec2/types.rb', line 39203 class EbsInfo < Struct.new( :ebs_optimized_support, :encryption_support, :ebs_optimized_info, :nvme_support, :maximum_ebs_attachments, :attachment_limit_type, :maximum_ebs_cards, :ebs_cards) SENSITIVE = [] include Aws::Structure end |
#encryption_support ⇒ String
Indicates whether Amazon EBS encryption is supported.
39203 39204 39205 39206 39207 39208 39209 39210 39211 39212 39213 39214 |
# File 'lib/aws-sdk-ec2/types.rb', line 39203 class EbsInfo < Struct.new( :ebs_optimized_support, :encryption_support, :ebs_optimized_info, :nvme_support, :maximum_ebs_attachments, :attachment_limit_type, :maximum_ebs_cards, :ebs_cards) SENSITIVE = [] include Aws::Structure end |
#maximum_ebs_attachments ⇒ Integer
Indicates the maximum number of Amazon EBS volumes that can be attached to the instance type. For more information, see Amazon EBS volume limits for Amazon EC2 instances in the Amazon EC2 User Guide.
39203 39204 39205 39206 39207 39208 39209 39210 39211 39212 39213 39214 |
# File 'lib/aws-sdk-ec2/types.rb', line 39203 class EbsInfo < Struct.new( :ebs_optimized_support, :encryption_support, :ebs_optimized_info, :nvme_support, :maximum_ebs_attachments, :attachment_limit_type, :maximum_ebs_cards, :ebs_cards) SENSITIVE = [] include Aws::Structure end |
#maximum_ebs_cards ⇒ Integer
Indicates the number of EBS cards supported by the instance type.
39203 39204 39205 39206 39207 39208 39209 39210 39211 39212 39213 39214 |
# File 'lib/aws-sdk-ec2/types.rb', line 39203 class EbsInfo < Struct.new( :ebs_optimized_support, :encryption_support, :ebs_optimized_info, :nvme_support, :maximum_ebs_attachments, :attachment_limit_type, :maximum_ebs_cards, :ebs_cards) SENSITIVE = [] include Aws::Structure end |
#nvme_support ⇒ String
Indicates whether non-volatile memory express (NVMe) is supported.
39203 39204 39205 39206 39207 39208 39209 39210 39211 39212 39213 39214 |
# File 'lib/aws-sdk-ec2/types.rb', line 39203 class EbsInfo < Struct.new( :ebs_optimized_support, :encryption_support, :ebs_optimized_info, :nvme_support, :maximum_ebs_attachments, :attachment_limit_type, :maximum_ebs_cards, :ebs_cards) SENSITIVE = [] include Aws::Structure end |