Class: Aws::EC2::Types::Ec2InstanceConnectEndpoint
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::Ec2InstanceConnectEndpoint
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes an EC2 Instance Connect Endpoint.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone ⇒ String
The Availability Zone of the EC2 Instance Connect Endpoint.
-
#availability_zone_id ⇒ String
The ID of the Availability Zone of the EC2 Instance Connect Endpoint.
-
#created_at ⇒ Time
The date and time that the EC2 Instance Connect Endpoint was created.
-
#dns_name ⇒ String
The DNS name of the EC2 Instance Connect Endpoint.
-
#fips_dns_name ⇒ String
The Federal Information Processing Standards (FIPS) compliant DNS name of the EC2 Instance Connect Endpoint.
-
#instance_connect_endpoint_arn ⇒ String
The Amazon Resource Name (ARN) of the EC2 Instance Connect Endpoint.
-
#instance_connect_endpoint_id ⇒ String
The ID of the EC2 Instance Connect Endpoint.
-
#ip_address_type ⇒ String
The IP address type of the endpoint.
-
#network_interface_ids ⇒ Array<String>
The ID of the elastic network interface that Amazon EC2 automatically created when creating the EC2 Instance Connect Endpoint.
-
#owner_id ⇒ String
The ID of the Amazon Web Services account that created the EC2 Instance Connect Endpoint.
-
#preserve_client_ip ⇒ Boolean
Indicates whether your client's IP address is preserved as the source when you connect to a resource.
-
#public_dns_names ⇒ Types::InstanceConnectEndpointPublicDnsNames
The public DNS names of the endpoint.
-
#security_group_ids ⇒ Array<String>
The security groups associated with the endpoint.
-
#state ⇒ String
The current state of the EC2 Instance Connect Endpoint.
-
#state_message ⇒ String
The message for the current state of the EC2 Instance Connect Endpoint.
-
#subnet_id ⇒ String
The ID of the subnet in which the EC2 Instance Connect Endpoint was created.
-
#tags ⇒ Array<Types::Tag>
The tags assigned to the EC2 Instance Connect Endpoint.
-
#vpc_id ⇒ String
The ID of the VPC in which the EC2 Instance Connect Endpoint was created.
Instance Attribute Details
#availability_zone ⇒ String
The Availability Zone of the EC2 Instance Connect Endpoint.
41152 41153 41154 41155 41156 41157 41158 41159 41160 41161 41162 41163 41164 41165 41166 41167 41168 41169 41170 41171 41172 41173 |
# File 'lib/aws-sdk-ec2/types.rb', line 41152 class Ec2InstanceConnectEndpoint < Struct.new( :owner_id, :instance_connect_endpoint_id, :instance_connect_endpoint_arn, :state, :state_message, :dns_name, :fips_dns_name, :network_interface_ids, :vpc_id, :availability_zone, :created_at, :subnet_id, :preserve_client_ip, :security_group_ids, :tags, :ip_address_type, :public_dns_names, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
The ID of the Availability Zone of the EC2 Instance Connect Endpoint.
41152 41153 41154 41155 41156 41157 41158 41159 41160 41161 41162 41163 41164 41165 41166 41167 41168 41169 41170 41171 41172 41173 |
# File 'lib/aws-sdk-ec2/types.rb', line 41152 class Ec2InstanceConnectEndpoint < Struct.new( :owner_id, :instance_connect_endpoint_id, :instance_connect_endpoint_arn, :state, :state_message, :dns_name, :fips_dns_name, :network_interface_ids, :vpc_id, :availability_zone, :created_at, :subnet_id, :preserve_client_ip, :security_group_ids, :tags, :ip_address_type, :public_dns_names, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time that the EC2 Instance Connect Endpoint was created.
41152 41153 41154 41155 41156 41157 41158 41159 41160 41161 41162 41163 41164 41165 41166 41167 41168 41169 41170 41171 41172 41173 |
# File 'lib/aws-sdk-ec2/types.rb', line 41152 class Ec2InstanceConnectEndpoint < Struct.new( :owner_id, :instance_connect_endpoint_id, :instance_connect_endpoint_arn, :state, :state_message, :dns_name, :fips_dns_name, :network_interface_ids, :vpc_id, :availability_zone, :created_at, :subnet_id, :preserve_client_ip, :security_group_ids, :tags, :ip_address_type, :public_dns_names, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#dns_name ⇒ String
The DNS name of the EC2 Instance Connect Endpoint.
41152 41153 41154 41155 41156 41157 41158 41159 41160 41161 41162 41163 41164 41165 41166 41167 41168 41169 41170 41171 41172 41173 |
# File 'lib/aws-sdk-ec2/types.rb', line 41152 class Ec2InstanceConnectEndpoint < Struct.new( :owner_id, :instance_connect_endpoint_id, :instance_connect_endpoint_arn, :state, :state_message, :dns_name, :fips_dns_name, :network_interface_ids, :vpc_id, :availability_zone, :created_at, :subnet_id, :preserve_client_ip, :security_group_ids, :tags, :ip_address_type, :public_dns_names, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#fips_dns_name ⇒ String
The Federal Information Processing Standards (FIPS) compliant DNS name of the EC2 Instance Connect Endpoint.
41152 41153 41154 41155 41156 41157 41158 41159 41160 41161 41162 41163 41164 41165 41166 41167 41168 41169 41170 41171 41172 41173 |
# File 'lib/aws-sdk-ec2/types.rb', line 41152 class Ec2InstanceConnectEndpoint < Struct.new( :owner_id, :instance_connect_endpoint_id, :instance_connect_endpoint_arn, :state, :state_message, :dns_name, :fips_dns_name, :network_interface_ids, :vpc_id, :availability_zone, :created_at, :subnet_id, :preserve_client_ip, :security_group_ids, :tags, :ip_address_type, :public_dns_names, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#instance_connect_endpoint_arn ⇒ String
The Amazon Resource Name (ARN) of the EC2 Instance Connect Endpoint.
41152 41153 41154 41155 41156 41157 41158 41159 41160 41161 41162 41163 41164 41165 41166 41167 41168 41169 41170 41171 41172 41173 |
# File 'lib/aws-sdk-ec2/types.rb', line 41152 class Ec2InstanceConnectEndpoint < Struct.new( :owner_id, :instance_connect_endpoint_id, :instance_connect_endpoint_arn, :state, :state_message, :dns_name, :fips_dns_name, :network_interface_ids, :vpc_id, :availability_zone, :created_at, :subnet_id, :preserve_client_ip, :security_group_ids, :tags, :ip_address_type, :public_dns_names, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#instance_connect_endpoint_id ⇒ String
The ID of the EC2 Instance Connect Endpoint.
41152 41153 41154 41155 41156 41157 41158 41159 41160 41161 41162 41163 41164 41165 41166 41167 41168 41169 41170 41171 41172 41173 |
# File 'lib/aws-sdk-ec2/types.rb', line 41152 class Ec2InstanceConnectEndpoint < Struct.new( :owner_id, :instance_connect_endpoint_id, :instance_connect_endpoint_arn, :state, :state_message, :dns_name, :fips_dns_name, :network_interface_ids, :vpc_id, :availability_zone, :created_at, :subnet_id, :preserve_client_ip, :security_group_ids, :tags, :ip_address_type, :public_dns_names, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#ip_address_type ⇒ String
The IP address type of the endpoint.
41152 41153 41154 41155 41156 41157 41158 41159 41160 41161 41162 41163 41164 41165 41166 41167 41168 41169 41170 41171 41172 41173 |
# File 'lib/aws-sdk-ec2/types.rb', line 41152 class Ec2InstanceConnectEndpoint < Struct.new( :owner_id, :instance_connect_endpoint_id, :instance_connect_endpoint_arn, :state, :state_message, :dns_name, :fips_dns_name, :network_interface_ids, :vpc_id, :availability_zone, :created_at, :subnet_id, :preserve_client_ip, :security_group_ids, :tags, :ip_address_type, :public_dns_names, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#network_interface_ids ⇒ Array<String>
The ID of the elastic network interface that Amazon EC2 automatically created when creating the EC2 Instance Connect Endpoint.
41152 41153 41154 41155 41156 41157 41158 41159 41160 41161 41162 41163 41164 41165 41166 41167 41168 41169 41170 41171 41172 41173 |
# File 'lib/aws-sdk-ec2/types.rb', line 41152 class Ec2InstanceConnectEndpoint < Struct.new( :owner_id, :instance_connect_endpoint_id, :instance_connect_endpoint_arn, :state, :state_message, :dns_name, :fips_dns_name, :network_interface_ids, :vpc_id, :availability_zone, :created_at, :subnet_id, :preserve_client_ip, :security_group_ids, :tags, :ip_address_type, :public_dns_names, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
The ID of the Amazon Web Services account that created the EC2 Instance Connect Endpoint.
41152 41153 41154 41155 41156 41157 41158 41159 41160 41161 41162 41163 41164 41165 41166 41167 41168 41169 41170 41171 41172 41173 |
# File 'lib/aws-sdk-ec2/types.rb', line 41152 class Ec2InstanceConnectEndpoint < Struct.new( :owner_id, :instance_connect_endpoint_id, :instance_connect_endpoint_arn, :state, :state_message, :dns_name, :fips_dns_name, :network_interface_ids, :vpc_id, :availability_zone, :created_at, :subnet_id, :preserve_client_ip, :security_group_ids, :tags, :ip_address_type, :public_dns_names, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#preserve_client_ip ⇒ Boolean
Indicates whether your client's IP address is preserved as the source when you connect to a resource. The following are the possible values.
-
true- Use the IP address of the client. Your instance must have an IPv4 address. -
false- Use the IP address of the network interface.
Default: false
41152 41153 41154 41155 41156 41157 41158 41159 41160 41161 41162 41163 41164 41165 41166 41167 41168 41169 41170 41171 41172 41173 |
# File 'lib/aws-sdk-ec2/types.rb', line 41152 class Ec2InstanceConnectEndpoint < Struct.new( :owner_id, :instance_connect_endpoint_id, :instance_connect_endpoint_arn, :state, :state_message, :dns_name, :fips_dns_name, :network_interface_ids, :vpc_id, :availability_zone, :created_at, :subnet_id, :preserve_client_ip, :security_group_ids, :tags, :ip_address_type, :public_dns_names, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#public_dns_names ⇒ Types::InstanceConnectEndpointPublicDnsNames
The public DNS names of the endpoint.
41152 41153 41154 41155 41156 41157 41158 41159 41160 41161 41162 41163 41164 41165 41166 41167 41168 41169 41170 41171 41172 41173 |
# File 'lib/aws-sdk-ec2/types.rb', line 41152 class Ec2InstanceConnectEndpoint < Struct.new( :owner_id, :instance_connect_endpoint_id, :instance_connect_endpoint_arn, :state, :state_message, :dns_name, :fips_dns_name, :network_interface_ids, :vpc_id, :availability_zone, :created_at, :subnet_id, :preserve_client_ip, :security_group_ids, :tags, :ip_address_type, :public_dns_names, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
The security groups associated with the endpoint. If you didn't specify a security group, the default security group for your VPC is associated with the endpoint.
41152 41153 41154 41155 41156 41157 41158 41159 41160 41161 41162 41163 41164 41165 41166 41167 41168 41169 41170 41171 41172 41173 |
# File 'lib/aws-sdk-ec2/types.rb', line 41152 class Ec2InstanceConnectEndpoint < Struct.new( :owner_id, :instance_connect_endpoint_id, :instance_connect_endpoint_arn, :state, :state_message, :dns_name, :fips_dns_name, :network_interface_ids, :vpc_id, :availability_zone, :created_at, :subnet_id, :preserve_client_ip, :security_group_ids, :tags, :ip_address_type, :public_dns_names, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the EC2 Instance Connect Endpoint.
41152 41153 41154 41155 41156 41157 41158 41159 41160 41161 41162 41163 41164 41165 41166 41167 41168 41169 41170 41171 41172 41173 |
# File 'lib/aws-sdk-ec2/types.rb', line 41152 class Ec2InstanceConnectEndpoint < Struct.new( :owner_id, :instance_connect_endpoint_id, :instance_connect_endpoint_arn, :state, :state_message, :dns_name, :fips_dns_name, :network_interface_ids, :vpc_id, :availability_zone, :created_at, :subnet_id, :preserve_client_ip, :security_group_ids, :tags, :ip_address_type, :public_dns_names, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#state_message ⇒ String
The message for the current state of the EC2 Instance Connect Endpoint. Can include a failure message.
41152 41153 41154 41155 41156 41157 41158 41159 41160 41161 41162 41163 41164 41165 41166 41167 41168 41169 41170 41171 41172 41173 |
# File 'lib/aws-sdk-ec2/types.rb', line 41152 class Ec2InstanceConnectEndpoint < Struct.new( :owner_id, :instance_connect_endpoint_id, :instance_connect_endpoint_arn, :state, :state_message, :dns_name, :fips_dns_name, :network_interface_ids, :vpc_id, :availability_zone, :created_at, :subnet_id, :preserve_client_ip, :security_group_ids, :tags, :ip_address_type, :public_dns_names, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#subnet_id ⇒ String
The ID of the subnet in which the EC2 Instance Connect Endpoint was created.
41152 41153 41154 41155 41156 41157 41158 41159 41160 41161 41162 41163 41164 41165 41166 41167 41168 41169 41170 41171 41172 41173 |
# File 'lib/aws-sdk-ec2/types.rb', line 41152 class Ec2InstanceConnectEndpoint < Struct.new( :owner_id, :instance_connect_endpoint_id, :instance_connect_endpoint_arn, :state, :state_message, :dns_name, :fips_dns_name, :network_interface_ids, :vpc_id, :availability_zone, :created_at, :subnet_id, :preserve_client_ip, :security_group_ids, :tags, :ip_address_type, :public_dns_names, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags assigned to the EC2 Instance Connect Endpoint.
41152 41153 41154 41155 41156 41157 41158 41159 41160 41161 41162 41163 41164 41165 41166 41167 41168 41169 41170 41171 41172 41173 |
# File 'lib/aws-sdk-ec2/types.rb', line 41152 class Ec2InstanceConnectEndpoint < Struct.new( :owner_id, :instance_connect_endpoint_id, :instance_connect_endpoint_arn, :state, :state_message, :dns_name, :fips_dns_name, :network_interface_ids, :vpc_id, :availability_zone, :created_at, :subnet_id, :preserve_client_ip, :security_group_ids, :tags, :ip_address_type, :public_dns_names, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC in which the EC2 Instance Connect Endpoint was created.
41152 41153 41154 41155 41156 41157 41158 41159 41160 41161 41162 41163 41164 41165 41166 41167 41168 41169 41170 41171 41172 41173 |
# File 'lib/aws-sdk-ec2/types.rb', line 41152 class Ec2InstanceConnectEndpoint < Struct.new( :owner_id, :instance_connect_endpoint_id, :instance_connect_endpoint_arn, :state, :state_message, :dns_name, :fips_dns_name, :network_interface_ids, :vpc_id, :availability_zone, :created_at, :subnet_id, :preserve_client_ip, :security_group_ids, :tags, :ip_address_type, :public_dns_names, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |