Class: Aws::EC2::Types::EnableFastLaunchRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::EnableFastLaunchRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#image_id ⇒ String
Specify the ID of the image for which to enable Windows fast launch.
-
#launch_template ⇒ Types::FastLaunchLaunchTemplateSpecificationRequest
The launch template to use when launching Windows instances from pre-provisioned snapshots.
-
#max_parallel_launches ⇒ Integer
The maximum number of instances that Amazon EC2 can launch at the same time to create pre-provisioned snapshots for Windows fast launch.
-
#resource_type ⇒ String
The type of resource to use for pre-provisioning the AMI for Windows fast launch.
-
#snapshot_configuration ⇒ Types::FastLaunchSnapshotConfigurationRequest
Configuration settings for creating and managing the snapshots that are used for pre-provisioning the AMI for Windows fast launch.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
40248 40249 40250 40251 40252 40253 40254 40255 40256 40257 |
# File 'lib/aws-sdk-ec2/types.rb', line 40248 class EnableFastLaunchRequest < Struct.new( :image_id, :resource_type, :snapshot_configuration, :launch_template, :max_parallel_launches, :dry_run) SENSITIVE = [] include Aws::Structure end |
#image_id ⇒ String
Specify the ID of the image for which to enable Windows fast launch.
40248 40249 40250 40251 40252 40253 40254 40255 40256 40257 |
# File 'lib/aws-sdk-ec2/types.rb', line 40248 class EnableFastLaunchRequest < Struct.new( :image_id, :resource_type, :snapshot_configuration, :launch_template, :max_parallel_launches, :dry_run) SENSITIVE = [] include Aws::Structure end |
#launch_template ⇒ Types::FastLaunchLaunchTemplateSpecificationRequest
The launch template to use when launching Windows instances from pre-provisioned snapshots. Launch template parameters can include either the name or ID of the launch template, but not both.
40248 40249 40250 40251 40252 40253 40254 40255 40256 40257 |
# File 'lib/aws-sdk-ec2/types.rb', line 40248 class EnableFastLaunchRequest < Struct.new( :image_id, :resource_type, :snapshot_configuration, :launch_template, :max_parallel_launches, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_parallel_launches ⇒ Integer
The maximum number of instances that Amazon EC2 can launch at the
same time to create pre-provisioned snapshots for Windows fast
launch. Value must be 6 or greater.
40248 40249 40250 40251 40252 40253 40254 40255 40256 40257 |
# File 'lib/aws-sdk-ec2/types.rb', line 40248 class EnableFastLaunchRequest < Struct.new( :image_id, :resource_type, :snapshot_configuration, :launch_template, :max_parallel_launches, :dry_run) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of resource to use for pre-provisioning the AMI for Windows
fast launch. Supported values include: snapshot, which is the
default value.
40248 40249 40250 40251 40252 40253 40254 40255 40256 40257 |
# File 'lib/aws-sdk-ec2/types.rb', line 40248 class EnableFastLaunchRequest < Struct.new( :image_id, :resource_type, :snapshot_configuration, :launch_template, :max_parallel_launches, :dry_run) SENSITIVE = [] include Aws::Structure end |
#snapshot_configuration ⇒ Types::FastLaunchSnapshotConfigurationRequest
Configuration settings for creating and managing the snapshots that
are used for pre-provisioning the AMI for Windows fast launch. The
associated ResourceType must be snapshot.
40248 40249 40250 40251 40252 40253 40254 40255 40256 40257 |
# File 'lib/aws-sdk-ec2/types.rb', line 40248 class EnableFastLaunchRequest < Struct.new( :image_id, :resource_type, :snapshot_configuration, :launch_template, :max_parallel_launches, :dry_run) SENSITIVE = [] include Aws::Structure end |