Class: Aws::EC2::Types::EnableFastLaunchResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::EnableFastLaunchResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#image_id ⇒ String
The image ID that identifies the AMI for which Windows fast launch was enabled.
-
#launch_template ⇒ Types::FastLaunchLaunchTemplateSpecificationResponse
The launch template that is used when launching Windows instances from pre-provisioned snapshots.
-
#max_parallel_launches ⇒ Integer
The maximum number of instances that Amazon EC2 can launch at the same time to create pre-provisioned snapshots for Windows fast launch.
-
#owner_id ⇒ String
The owner ID for the AMI for which Windows fast launch was enabled.
-
#resource_type ⇒ String
The type of resource that was defined for pre-provisioning the AMI for Windows fast launch.
-
#snapshot_configuration ⇒ Types::FastLaunchSnapshotConfigurationResponse
Settings to create and manage the pre-provisioned snapshots that Amazon EC2 uses for faster launches from the Windows AMI.
-
#state ⇒ String
The current state of Windows fast launch for the specified AMI.
-
#state_transition_reason ⇒ String
The reason that the state changed for Windows fast launch for the AMI.
-
#state_transition_time ⇒ Time
The time that the state changed for Windows fast launch for the AMI.
Instance Attribute Details
#image_id ⇒ String
The image ID that identifies the AMI for which Windows fast launch was enabled.
41891 41892 41893 41894 41895 41896 41897 41898 41899 41900 41901 41902 41903 |
# File 'lib/aws-sdk-ec2/types.rb', line 41891 class EnableFastLaunchResult < Struct.new( :image_id, :resource_type, :snapshot_configuration, :launch_template, :max_parallel_launches, :owner_id, :state, :state_transition_reason, :state_transition_time) SENSITIVE = [] include Aws::Structure end |
#launch_template ⇒ Types::FastLaunchLaunchTemplateSpecificationResponse
The launch template that is used when launching Windows instances from pre-provisioned snapshots.
41891 41892 41893 41894 41895 41896 41897 41898 41899 41900 41901 41902 41903 |
# File 'lib/aws-sdk-ec2/types.rb', line 41891 class EnableFastLaunchResult < Struct.new( :image_id, :resource_type, :snapshot_configuration, :launch_template, :max_parallel_launches, :owner_id, :state, :state_transition_reason, :state_transition_time) SENSITIVE = [] include Aws::Structure end |
#max_parallel_launches ⇒ Integer
The maximum number of instances that Amazon EC2 can launch at the same time to create pre-provisioned snapshots for Windows fast launch.
41891 41892 41893 41894 41895 41896 41897 41898 41899 41900 41901 41902 41903 |
# File 'lib/aws-sdk-ec2/types.rb', line 41891 class EnableFastLaunchResult < Struct.new( :image_id, :resource_type, :snapshot_configuration, :launch_template, :max_parallel_launches, :owner_id, :state, :state_transition_reason, :state_transition_time) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
The owner ID for the AMI for which Windows fast launch was enabled.
41891 41892 41893 41894 41895 41896 41897 41898 41899 41900 41901 41902 41903 |
# File 'lib/aws-sdk-ec2/types.rb', line 41891 class EnableFastLaunchResult < Struct.new( :image_id, :resource_type, :snapshot_configuration, :launch_template, :max_parallel_launches, :owner_id, :state, :state_transition_reason, :state_transition_time) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of resource that was defined for pre-provisioning the AMI for Windows fast launch.
41891 41892 41893 41894 41895 41896 41897 41898 41899 41900 41901 41902 41903 |
# File 'lib/aws-sdk-ec2/types.rb', line 41891 class EnableFastLaunchResult < Struct.new( :image_id, :resource_type, :snapshot_configuration, :launch_template, :max_parallel_launches, :owner_id, :state, :state_transition_reason, :state_transition_time) SENSITIVE = [] include Aws::Structure end |
#snapshot_configuration ⇒ Types::FastLaunchSnapshotConfigurationResponse
Settings to create and manage the pre-provisioned snapshots that
Amazon EC2 uses for faster launches from the Windows AMI. This
property is returned when the associated resourceType is
snapshot.
41891 41892 41893 41894 41895 41896 41897 41898 41899 41900 41901 41902 41903 |
# File 'lib/aws-sdk-ec2/types.rb', line 41891 class EnableFastLaunchResult < Struct.new( :image_id, :resource_type, :snapshot_configuration, :launch_template, :max_parallel_launches, :owner_id, :state, :state_transition_reason, :state_transition_time) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of Windows fast launch for the specified AMI.
41891 41892 41893 41894 41895 41896 41897 41898 41899 41900 41901 41902 41903 |
# File 'lib/aws-sdk-ec2/types.rb', line 41891 class EnableFastLaunchResult < Struct.new( :image_id, :resource_type, :snapshot_configuration, :launch_template, :max_parallel_launches, :owner_id, :state, :state_transition_reason, :state_transition_time) SENSITIVE = [] include Aws::Structure end |
#state_transition_reason ⇒ String
The reason that the state changed for Windows fast launch for the AMI.
41891 41892 41893 41894 41895 41896 41897 41898 41899 41900 41901 41902 41903 |
# File 'lib/aws-sdk-ec2/types.rb', line 41891 class EnableFastLaunchResult < Struct.new( :image_id, :resource_type, :snapshot_configuration, :launch_template, :max_parallel_launches, :owner_id, :state, :state_transition_reason, :state_transition_time) SENSITIVE = [] include Aws::Structure end |
#state_transition_time ⇒ Time
The time that the state changed for Windows fast launch for the AMI.
41891 41892 41893 41894 41895 41896 41897 41898 41899 41900 41901 41902 41903 |
# File 'lib/aws-sdk-ec2/types.rb', line 41891 class EnableFastLaunchResult < Struct.new( :image_id, :resource_type, :snapshot_configuration, :launch_template, :max_parallel_launches, :owner_id, :state, :state_transition_reason, :state_transition_time) SENSITIVE = [] include Aws::Structure end |