Class: Aws::EC2::Types::EnableSnapshotBlockPublicAccessRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


40653
40654
40655
40656
40657
40658
# File 'lib/aws-sdk-ec2/types.rb', line 40653

class EnableSnapshotBlockPublicAccessRequest < Struct.new(
  :state,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The mode in which to enable block public access for snapshots for the Region. Specify one of the following values:

  • ‘block-all-sharing` - Prevents all public sharing of snapshots in the Region. Users in the account will no longer be able to request new public sharing. Additionally, snapshots that are already publicly shared are treated as private and they are no longer publicly available.

  • ‘block-new-sharing` - Prevents only new public sharing of snapshots in the Region. Users in the account will no longer be able to request new public sharing. However, snapshots that are already publicly shared, remain publicly available.

‘unblocked` is not a valid value for EnableSnapshotBlockPublicAccess.

Returns:

  • (String)


40653
40654
40655
40656
40657
40658
# File 'lib/aws-sdk-ec2/types.rb', line 40653

class EnableSnapshotBlockPublicAccessRequest < Struct.new(
  :state,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end