Class: Aws::EC2::Types::EnableSnapshotBlockPublicAccessResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::EnableSnapshotBlockPublicAccessResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#state ⇒ String
The state of block public access for snapshots for the account and Region.
Instance Attribute Details
#state ⇒ String
The state of block public access for snapshots for the account and
Region. Returns either block-all-sharing or block-new-sharing if
the request succeeds.
40762 40763 40764 40765 40766 |
# File 'lib/aws-sdk-ec2/types.rb', line 40762 class EnableSnapshotBlockPublicAccessResult < Struct.new( :state) SENSITIVE = [] include Aws::Structure end |