Class: Aws::EC2::Types::ExportImageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ExportImageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Token to enable idempotency for export image requests.
-
#description ⇒ String
A description of the image being exported.
-
#disk_image_format ⇒ String
The disk image format.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#image_id ⇒ String
The ID of the image.
-
#role_name ⇒ String
The name of the role that grants VM Import/Export permission to export images to your Amazon S3 bucket.
-
#s3_export_location ⇒ Types::ExportTaskS3LocationRequest
The Amazon S3 bucket for the destination image.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the export image task during creation.
Instance Attribute Details
#client_token ⇒ String
Token to enable idempotency for export image requests.
A suitable default value is auto-generated. You should normally not need to pass this option.
43333 43334 43335 43336 43337 43338 43339 43340 43341 43342 43343 43344 |
# File 'lib/aws-sdk-ec2/types.rb', line 43333 class ExportImageRequest < Struct.new( :client_token, :description, :disk_image_format, :dry_run, :image_id, :s3_export_location, :role_name, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the image being exported. The maximum length is 255 characters.
43333 43334 43335 43336 43337 43338 43339 43340 43341 43342 43343 43344 |
# File 'lib/aws-sdk-ec2/types.rb', line 43333 class ExportImageRequest < Struct.new( :client_token, :description, :disk_image_format, :dry_run, :image_id, :s3_export_location, :role_name, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#disk_image_format ⇒ String
The disk image format.
43333 43334 43335 43336 43337 43338 43339 43340 43341 43342 43343 43344 |
# File 'lib/aws-sdk-ec2/types.rb', line 43333 class ExportImageRequest < Struct.new( :client_token, :description, :disk_image_format, :dry_run, :image_id, :s3_export_location, :role_name, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
43333 43334 43335 43336 43337 43338 43339 43340 43341 43342 43343 43344 |
# File 'lib/aws-sdk-ec2/types.rb', line 43333 class ExportImageRequest < Struct.new( :client_token, :description, :disk_image_format, :dry_run, :image_id, :s3_export_location, :role_name, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#image_id ⇒ String
The ID of the image.
43333 43334 43335 43336 43337 43338 43339 43340 43341 43342 43343 43344 |
# File 'lib/aws-sdk-ec2/types.rb', line 43333 class ExportImageRequest < Struct.new( :client_token, :description, :disk_image_format, :dry_run, :image_id, :s3_export_location, :role_name, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#role_name ⇒ String
The name of the role that grants VM Import/Export permission to export images to your Amazon S3 bucket. If this parameter is not specified, the default role is named 'vmimport'.
43333 43334 43335 43336 43337 43338 43339 43340 43341 43342 43343 43344 |
# File 'lib/aws-sdk-ec2/types.rb', line 43333 class ExportImageRequest < Struct.new( :client_token, :description, :disk_image_format, :dry_run, :image_id, :s3_export_location, :role_name, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#s3_export_location ⇒ Types::ExportTaskS3LocationRequest
The Amazon S3 bucket for the destination image. The destination bucket must exist.
43333 43334 43335 43336 43337 43338 43339 43340 43341 43342 43343 43344 |
# File 'lib/aws-sdk-ec2/types.rb', line 43333 class ExportImageRequest < Struct.new( :client_token, :description, :disk_image_format, :dry_run, :image_id, :s3_export_location, :role_name, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the export image task during creation.
43333 43334 43335 43336 43337 43338 43339 43340 43341 43342 43343 43344 |
# File 'lib/aws-sdk-ec2/types.rb', line 43333 class ExportImageRequest < Struct.new( :client_token, :description, :disk_image_format, :dry_run, :image_id, :s3_export_location, :role_name, :tag_specifications) SENSITIVE = [] include Aws::Structure end |