Class: Aws::EC2::Types::FastLaunchLaunchTemplateSpecificationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Identifies the launch template that the AMI uses for Windows fast launch.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#launch_template_idString

The ID of the launch template that the AMI uses for Windows fast launch.

Returns:

  • (String)


42022
42023
42024
42025
42026
42027
42028
# File 'lib/aws-sdk-ec2/types.rb', line 42022

class FastLaunchLaunchTemplateSpecificationResponse < Struct.new(
  :launch_template_id,
  :launch_template_name,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#launch_template_nameString

The name of the launch template that the AMI uses for Windows fast launch.

Returns:

  • (String)


42022
42023
42024
42025
42026
42027
42028
# File 'lib/aws-sdk-ec2/types.rb', line 42022

class FastLaunchLaunchTemplateSpecificationResponse < Struct.new(
  :launch_template_id,
  :launch_template_name,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#versionString

The version of the launch template that the AMI uses for Windows fast launch.

Returns:

  • (String)


42022
42023
42024
42025
42026
42027
42028
# File 'lib/aws-sdk-ec2/types.rb', line 42022

class FastLaunchLaunchTemplateSpecificationResponse < Struct.new(
  :launch_template_id,
  :launch_template_name,
  :version)
  SENSITIVE = []
  include Aws::Structure
end