Class: Aws::EC2::Types::FleetLaunchTemplateSpecificationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

The Amazon EC2 launch template that can be used by an EC2 Fleet to configure Amazon EC2 instances. You must specify either the ID or name of the launch template in the request, but not both.

For information about launch templates, see Launch an instance from a launch template in the Amazon EC2 User Guide.

Constant Summary collapse

SENSITIVE =
[:launch_template_specification_user_data]

Instance Attribute Summary collapse

Instance Attribute Details

#launch_template_idString

The ID of the launch template.

You must specify the LaunchTemplateId or the LaunchTemplateName, but not both.

Returns:

  • (String)


43648
43649
43650
43651
43652
43653
43654
43655
# File 'lib/aws-sdk-ec2/types.rb', line 43648

class FleetLaunchTemplateSpecificationRequest < Struct.new(
  :launch_template_id,
  :launch_template_name,
  :version,
  :launch_template_specification_user_data)
  SENSITIVE = [:launch_template_specification_user_data]
  include Aws::Structure
end

#launch_template_nameString

The name of the launch template.

You must specify the LaunchTemplateName or the LaunchTemplateId, but not both.

Returns:

  • (String)


43648
43649
43650
43651
43652
43653
43654
43655
# File 'lib/aws-sdk-ec2/types.rb', line 43648

class FleetLaunchTemplateSpecificationRequest < Struct.new(
  :launch_template_id,
  :launch_template_name,
  :version,
  :launch_template_specification_user_data)
  SENSITIVE = [:launch_template_specification_user_data]
  include Aws::Structure
end

#launch_template_specification_user_dataString

The base64-encoded user data for instances launched by the fleet. User data is limited to 16 KB, in raw form, before it is base64-encoded.

Supported only for fleets of type instant.

Returns:

  • (String)


43648
43649
43650
43651
43652
43653
43654
43655
# File 'lib/aws-sdk-ec2/types.rb', line 43648

class FleetLaunchTemplateSpecificationRequest < Struct.new(
  :launch_template_id,
  :launch_template_name,
  :version,
  :launch_template_specification_user_data)
  SENSITIVE = [:launch_template_specification_user_data]
  include Aws::Structure
end

#versionString

The launch template version number, $Latest, or $Default. You must specify a value, otherwise the request fails.

If the value is $Latest, Amazon EC2 uses the latest version of the launch template.

If the value is $Default, Amazon EC2 uses the default version of the launch template.

Returns:

  • (String)


43648
43649
43650
43651
43652
43653
43654
43655
# File 'lib/aws-sdk-ec2/types.rb', line 43648

class FleetLaunchTemplateSpecificationRequest < Struct.new(
  :launch_template_id,
  :launch_template_name,
  :version,
  :launch_template_specification_user_data)
  SENSITIVE = [:launch_template_specification_user_data]
  include Aws::Structure
end