Class: Aws::EC2::Types::FlowLog

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes a flow log.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timeTime

The date and time the flow log was created.

Returns:

  • (Time)


43633
43634
43635
43636
43637
43638
43639
43640
43641
43642
43643
43644
43645
43646
43647
43648
43649
43650
43651
43652
43653
# File 'lib/aws-sdk-ec2/types.rb', line 43633

class FlowLog < Struct.new(
  :creation_time,
  :deliver_logs_error_message,
  :deliver_logs_permission_arn,
  :deliver_cross_account_role,
  :deliver_logs_status,
  :flow_log_id,
  :flow_log_status,
  :log_group_name,
  :resource_id,
  :traffic_type,
  :log_destination_type,
  :log_destination,
  :log_format,
  :tags,
  :max_aggregation_interval,
  :destination_options,
  :tag_field_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#deliver_cross_account_roleString

The ARN of the IAM role that allows the service to publish flow logs across accounts.

Returns:

  • (String)


43633
43634
43635
43636
43637
43638
43639
43640
43641
43642
43643
43644
43645
43646
43647
43648
43649
43650
43651
43652
43653
# File 'lib/aws-sdk-ec2/types.rb', line 43633

class FlowLog < Struct.new(
  :creation_time,
  :deliver_logs_error_message,
  :deliver_logs_permission_arn,
  :deliver_cross_account_role,
  :deliver_logs_status,
  :flow_log_id,
  :flow_log_status,
  :log_group_name,
  :resource_id,
  :traffic_type,
  :log_destination_type,
  :log_destination,
  :log_format,
  :tags,
  :max_aggregation_interval,
  :destination_options,
  :tag_field_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#deliver_logs_error_messageString

Information about the error that occurred. Rate limited indicates that CloudWatch Logs throttling has been applied for one or more network interfaces, or that you've reached the limit on the number of log groups that you can create. Access error indicates that the IAM role associated with the flow log does not have sufficient permissions to publish to CloudWatch Logs. Unknown error indicates an internal error.

Returns:

  • (String)


43633
43634
43635
43636
43637
43638
43639
43640
43641
43642
43643
43644
43645
43646
43647
43648
43649
43650
43651
43652
43653
# File 'lib/aws-sdk-ec2/types.rb', line 43633

class FlowLog < Struct.new(
  :creation_time,
  :deliver_logs_error_message,
  :deliver_logs_permission_arn,
  :deliver_cross_account_role,
  :deliver_logs_status,
  :flow_log_id,
  :flow_log_status,
  :log_group_name,
  :resource_id,
  :traffic_type,
  :log_destination_type,
  :log_destination,
  :log_format,
  :tags,
  :max_aggregation_interval,
  :destination_options,
  :tag_field_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#deliver_logs_permission_arnString

The ARN of the IAM role allows the service to publish logs to CloudWatch Logs.

Returns:

  • (String)


43633
43634
43635
43636
43637
43638
43639
43640
43641
43642
43643
43644
43645
43646
43647
43648
43649
43650
43651
43652
43653
# File 'lib/aws-sdk-ec2/types.rb', line 43633

class FlowLog < Struct.new(
  :creation_time,
  :deliver_logs_error_message,
  :deliver_logs_permission_arn,
  :deliver_cross_account_role,
  :deliver_logs_status,
  :flow_log_id,
  :flow_log_status,
  :log_group_name,
  :resource_id,
  :traffic_type,
  :log_destination_type,
  :log_destination,
  :log_format,
  :tags,
  :max_aggregation_interval,
  :destination_options,
  :tag_field_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#deliver_logs_statusString

The status of the logs delivery (SUCCESS | FAILED).

Returns:

  • (String)


43633
43634
43635
43636
43637
43638
43639
43640
43641
43642
43643
43644
43645
43646
43647
43648
43649
43650
43651
43652
43653
# File 'lib/aws-sdk-ec2/types.rb', line 43633

class FlowLog < Struct.new(
  :creation_time,
  :deliver_logs_error_message,
  :deliver_logs_permission_arn,
  :deliver_cross_account_role,
  :deliver_logs_status,
  :flow_log_id,
  :flow_log_status,
  :log_group_name,
  :resource_id,
  :traffic_type,
  :log_destination_type,
  :log_destination,
  :log_format,
  :tags,
  :max_aggregation_interval,
  :destination_options,
  :tag_field_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#destination_optionsTypes::DestinationOptionsResponse

The destination options.



43633
43634
43635
43636
43637
43638
43639
43640
43641
43642
43643
43644
43645
43646
43647
43648
43649
43650
43651
43652
43653
# File 'lib/aws-sdk-ec2/types.rb', line 43633

class FlowLog < Struct.new(
  :creation_time,
  :deliver_logs_error_message,
  :deliver_logs_permission_arn,
  :deliver_cross_account_role,
  :deliver_logs_status,
  :flow_log_id,
  :flow_log_status,
  :log_group_name,
  :resource_id,
  :traffic_type,
  :log_destination_type,
  :log_destination,
  :log_format,
  :tags,
  :max_aggregation_interval,
  :destination_options,
  :tag_field_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#flow_log_idString

The ID of the flow log.

Returns:

  • (String)


43633
43634
43635
43636
43637
43638
43639
43640
43641
43642
43643
43644
43645
43646
43647
43648
43649
43650
43651
43652
43653
# File 'lib/aws-sdk-ec2/types.rb', line 43633

class FlowLog < Struct.new(
  :creation_time,
  :deliver_logs_error_message,
  :deliver_logs_permission_arn,
  :deliver_cross_account_role,
  :deliver_logs_status,
  :flow_log_id,
  :flow_log_status,
  :log_group_name,
  :resource_id,
  :traffic_type,
  :log_destination_type,
  :log_destination,
  :log_format,
  :tags,
  :max_aggregation_interval,
  :destination_options,
  :tag_field_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#flow_log_statusString

The status of the flow log (ACTIVE).

Returns:

  • (String)


43633
43634
43635
43636
43637
43638
43639
43640
43641
43642
43643
43644
43645
43646
43647
43648
43649
43650
43651
43652
43653
# File 'lib/aws-sdk-ec2/types.rb', line 43633

class FlowLog < Struct.new(
  :creation_time,
  :deliver_logs_error_message,
  :deliver_logs_permission_arn,
  :deliver_cross_account_role,
  :deliver_logs_status,
  :flow_log_id,
  :flow_log_status,
  :log_group_name,
  :resource_id,
  :traffic_type,
  :log_destination_type,
  :log_destination,
  :log_format,
  :tags,
  :max_aggregation_interval,
  :destination_options,
  :tag_field_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#log_destinationString

The Amazon Resource Name (ARN) of the destination for the flow log data.

Returns:

  • (String)


43633
43634
43635
43636
43637
43638
43639
43640
43641
43642
43643
43644
43645
43646
43647
43648
43649
43650
43651
43652
43653
# File 'lib/aws-sdk-ec2/types.rb', line 43633

class FlowLog < Struct.new(
  :creation_time,
  :deliver_logs_error_message,
  :deliver_logs_permission_arn,
  :deliver_cross_account_role,
  :deliver_logs_status,
  :flow_log_id,
  :flow_log_status,
  :log_group_name,
  :resource_id,
  :traffic_type,
  :log_destination_type,
  :log_destination,
  :log_format,
  :tags,
  :max_aggregation_interval,
  :destination_options,
  :tag_field_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#log_destination_typeString

The type of destination for the flow log data.

Returns:

  • (String)


43633
43634
43635
43636
43637
43638
43639
43640
43641
43642
43643
43644
43645
43646
43647
43648
43649
43650
43651
43652
43653
# File 'lib/aws-sdk-ec2/types.rb', line 43633

class FlowLog < Struct.new(
  :creation_time,
  :deliver_logs_error_message,
  :deliver_logs_permission_arn,
  :deliver_cross_account_role,
  :deliver_logs_status,
  :flow_log_id,
  :flow_log_status,
  :log_group_name,
  :resource_id,
  :traffic_type,
  :log_destination_type,
  :log_destination,
  :log_format,
  :tags,
  :max_aggregation_interval,
  :destination_options,
  :tag_field_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#log_formatString

The format of the flow log record.

Returns:

  • (String)


43633
43634
43635
43636
43637
43638
43639
43640
43641
43642
43643
43644
43645
43646
43647
43648
43649
43650
43651
43652
43653
# File 'lib/aws-sdk-ec2/types.rb', line 43633

class FlowLog < Struct.new(
  :creation_time,
  :deliver_logs_error_message,
  :deliver_logs_permission_arn,
  :deliver_cross_account_role,
  :deliver_logs_status,
  :flow_log_id,
  :flow_log_status,
  :log_group_name,
  :resource_id,
  :traffic_type,
  :log_destination_type,
  :log_destination,
  :log_format,
  :tags,
  :max_aggregation_interval,
  :destination_options,
  :tag_field_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#log_group_nameString

The name of the flow log group.

Returns:

  • (String)


43633
43634
43635
43636
43637
43638
43639
43640
43641
43642
43643
43644
43645
43646
43647
43648
43649
43650
43651
43652
43653
# File 'lib/aws-sdk-ec2/types.rb', line 43633

class FlowLog < Struct.new(
  :creation_time,
  :deliver_logs_error_message,
  :deliver_logs_permission_arn,
  :deliver_cross_account_role,
  :deliver_logs_status,
  :flow_log_id,
  :flow_log_status,
  :log_group_name,
  :resource_id,
  :traffic_type,
  :log_destination_type,
  :log_destination,
  :log_format,
  :tags,
  :max_aggregation_interval,
  :destination_options,
  :tag_field_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#max_aggregation_intervalInteger

The maximum interval of time, in seconds, during which a flow of packets is captured and aggregated into a flow log record.

When a network interface is attached to a Nitro-based instance, the aggregation interval is always 60 seconds (1 minute) or less, regardless of the specified value.

Valid Values: 60 | 600

Returns:

  • (Integer)


43633
43634
43635
43636
43637
43638
43639
43640
43641
43642
43643
43644
43645
43646
43647
43648
43649
43650
43651
43652
43653
# File 'lib/aws-sdk-ec2/types.rb', line 43633

class FlowLog < Struct.new(
  :creation_time,
  :deliver_logs_error_message,
  :deliver_logs_permission_arn,
  :deliver_cross_account_role,
  :deliver_logs_status,
  :flow_log_id,
  :flow_log_status,
  :log_group_name,
  :resource_id,
  :traffic_type,
  :log_destination_type,
  :log_destination,
  :log_format,
  :tags,
  :max_aggregation_interval,
  :destination_options,
  :tag_field_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#resource_idString

The ID of the resource being monitored.

Returns:

  • (String)


43633
43634
43635
43636
43637
43638
43639
43640
43641
43642
43643
43644
43645
43646
43647
43648
43649
43650
43651
43652
43653
# File 'lib/aws-sdk-ec2/types.rb', line 43633

class FlowLog < Struct.new(
  :creation_time,
  :deliver_logs_error_message,
  :deliver_logs_permission_arn,
  :deliver_cross_account_role,
  :deliver_logs_status,
  :flow_log_id,
  :flow_log_status,
  :log_group_name,
  :resource_id,
  :traffic_type,
  :log_destination_type,
  :log_destination,
  :log_format,
  :tags,
  :max_aggregation_interval,
  :destination_options,
  :tag_field_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#tag_field_specificationsArray<Types::TagFieldSpecificationResponse>

The tag configuration associated with the Flow Logs Amazon EC2 Tags feature fields in your custom log format.



43633
43634
43635
43636
43637
43638
43639
43640
43641
43642
43643
43644
43645
43646
43647
43648
43649
43650
43651
43652
43653
# File 'lib/aws-sdk-ec2/types.rb', line 43633

class FlowLog < Struct.new(
  :creation_time,
  :deliver_logs_error_message,
  :deliver_logs_permission_arn,
  :deliver_cross_account_role,
  :deliver_logs_status,
  :flow_log_id,
  :flow_log_status,
  :log_group_name,
  :resource_id,
  :traffic_type,
  :log_destination_type,
  :log_destination,
  :log_format,
  :tags,
  :max_aggregation_interval,
  :destination_options,
  :tag_field_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The tags for the flow log.

Returns:



43633
43634
43635
43636
43637
43638
43639
43640
43641
43642
43643
43644
43645
43646
43647
43648
43649
43650
43651
43652
43653
# File 'lib/aws-sdk-ec2/types.rb', line 43633

class FlowLog < Struct.new(
  :creation_time,
  :deliver_logs_error_message,
  :deliver_logs_permission_arn,
  :deliver_cross_account_role,
  :deliver_logs_status,
  :flow_log_id,
  :flow_log_status,
  :log_group_name,
  :resource_id,
  :traffic_type,
  :log_destination_type,
  :log_destination,
  :log_format,
  :tags,
  :max_aggregation_interval,
  :destination_options,
  :tag_field_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#traffic_typeString

The type of traffic captured for the flow log.

Returns:

  • (String)


43633
43634
43635
43636
43637
43638
43639
43640
43641
43642
43643
43644
43645
43646
43647
43648
43649
43650
43651
43652
43653
# File 'lib/aws-sdk-ec2/types.rb', line 43633

class FlowLog < Struct.new(
  :creation_time,
  :deliver_logs_error_message,
  :deliver_logs_permission_arn,
  :deliver_cross_account_role,
  :deliver_logs_status,
  :flow_log_id,
  :flow_log_status,
  :log_group_name,
  :resource_id,
  :traffic_type,
  :log_destination_type,
  :log_destination,
  :log_format,
  :tags,
  :max_aggregation_interval,
  :destination_options,
  :tag_field_specifications)
  SENSITIVE = []
  include Aws::Structure
end