Class: Aws::EC2::Types::GetCapacityManagerMetricDataRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


45986
45987
45988
45989
45990
45991
45992
45993
45994
45995
45996
45997
45998
# File 'lib/aws-sdk-ec2/types.rb', line 45986

class GetCapacityManagerMetricDataRequest < Struct.new(
  :metric_names,
  :start_time,
  :end_time,
  :period,
  :group_by,
  :filter_by,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

The end time for the metric data query, in ISO 8601 format. If the end time is beyond the latest ingested data, it will be automatically adjusted to the latest available data point.

Returns:

  • (Time)


45986
45987
45988
45989
45990
45991
45992
45993
45994
45995
45996
45997
45998
# File 'lib/aws-sdk-ec2/types.rb', line 45986

class GetCapacityManagerMetricDataRequest < Struct.new(
  :metric_names,
  :start_time,
  :end_time,
  :period,
  :group_by,
  :filter_by,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filter_byArray<Types::CapacityManagerCondition>

Conditions to filter the metric data. Each filter specifies a dimension, comparison operator ('equals', 'in'), and values to match against.



45986
45987
45988
45989
45990
45991
45992
45993
45994
45995
45996
45997
45998
# File 'lib/aws-sdk-ec2/types.rb', line 45986

class GetCapacityManagerMetricDataRequest < Struct.new(
  :metric_names,
  :start_time,
  :end_time,
  :period,
  :group_by,
  :filter_by,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#group_byArray<String>

The dimensions by which to group the metric data. This determines how the data is aggregated and returned.

Returns:

  • (Array<String>)


45986
45987
45988
45989
45990
45991
45992
45993
45994
45995
45996
45997
45998
# File 'lib/aws-sdk-ec2/types.rb', line 45986

class GetCapacityManagerMetricDataRequest < Struct.new(
  :metric_names,
  :start_time,
  :end_time,
  :period,
  :group_by,
  :filter_by,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of data points to return. Valid range is 1 to 100,000. Use with NextToken for pagination of large result sets.

Returns:

  • (Integer)


45986
45987
45988
45989
45990
45991
45992
45993
45994
45995
45996
45997
45998
# File 'lib/aws-sdk-ec2/types.rb', line 45986

class GetCapacityManagerMetricDataRequest < Struct.new(
  :metric_names,
  :start_time,
  :end_time,
  :period,
  :group_by,
  :filter_by,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#metric_namesArray<String>

The names of the metrics to retrieve. Maximum of 10 metrics per request.

Returns:

  • (Array<String>)


45986
45987
45988
45989
45990
45991
45992
45993
45994
45995
45996
45997
45998
# File 'lib/aws-sdk-ec2/types.rb', line 45986

class GetCapacityManagerMetricDataRequest < Struct.new(
  :metric_names,
  :start_time,
  :end_time,
  :period,
  :group_by,
  :filter_by,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results. Use this value in a subsequent call to retrieve additional data points.

Returns:

  • (String)


45986
45987
45988
45989
45990
45991
45992
45993
45994
45995
45996
45997
45998
# File 'lib/aws-sdk-ec2/types.rb', line 45986

class GetCapacityManagerMetricDataRequest < Struct.new(
  :metric_names,
  :start_time,
  :end_time,
  :period,
  :group_by,
  :filter_by,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#periodInteger

The granularity, in seconds, of the returned data points.

Returns:

  • (Integer)


45986
45987
45988
45989
45990
45991
45992
45993
45994
45995
45996
45997
45998
# File 'lib/aws-sdk-ec2/types.rb', line 45986

class GetCapacityManagerMetricDataRequest < Struct.new(
  :metric_names,
  :start_time,
  :end_time,
  :period,
  :group_by,
  :filter_by,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The start time for the metric data query, in ISO 8601 format. The time range (end time - start time) must be a multiple of the specified period.

Returns:

  • (Time)


45986
45987
45988
45989
45990
45991
45992
45993
45994
45995
45996
45997
45998
# File 'lib/aws-sdk-ec2/types.rb', line 45986

class GetCapacityManagerMetricDataRequest < Struct.new(
  :metric_names,
  :start_time,
  :end_time,
  :period,
  :group_by,
  :filter_by,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end