Class: Aws::EC2::Types::GetCapacityManagerMetricDimensionsResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#metric_dimension_resultsArray<Types::CapacityManagerDimension>

The available dimension combinations that have data within the specified time range and filters.



42781
42782
42783
42784
42785
42786
# File 'lib/aws-sdk-ec2/types.rb', line 42781

class GetCapacityManagerMetricDimensionsResult < Struct.new(
  :metric_dimension_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to use to retrieve the next page of results. This value is null when there are no more results to return.

Returns:

  • (String)


42781
42782
42783
42784
42785
42786
# File 'lib/aws-sdk-ec2/types.rb', line 42781

class GetCapacityManagerMetricDimensionsResult < Struct.new(
  :metric_dimension_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end