Class: Aws::EC2::Types::GetCoipPoolUsageRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


45892
45893
45894
45895
45896
45897
45898
45899
45900
# File 'lib/aws-sdk-ec2/types.rb', line 45892

class GetCoipPoolUsageRequest < Struct.new(
  :pool_id,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters.

  • coip-address-usage.allocation-id - The allocation ID of the address.

  • coip-address-usage.aws-account-id - The ID of the Amazon Web Services account that is using the customer-owned IP address.

  • coip-address-usage.aws-service - The Amazon Web Services service that is using the customer-owned IP address.

  • coip-address-usage.co-ip - The customer-owned IP address.

Returns:



45892
45893
45894
45895
45896
45897
45898
45899
45900
# File 'lib/aws-sdk-ec2/types.rb', line 45892

class GetCoipPoolUsageRequest < Struct.new(
  :pool_id,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.

Returns:

  • (Integer)


45892
45893
45894
45895
45896
45897
45898
45899
45900
# File 'lib/aws-sdk-ec2/types.rb', line 45892

class GetCoipPoolUsageRequest < Struct.new(
  :pool_id,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


45892
45893
45894
45895
45896
45897
45898
45899
45900
# File 'lib/aws-sdk-ec2/types.rb', line 45892

class GetCoipPoolUsageRequest < Struct.new(
  :pool_id,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#pool_idString

The ID of the address pool.

Returns:

  • (String)


45892
45893
45894
45895
45896
45897
45898
45899
45900
# File 'lib/aws-sdk-ec2/types.rb', line 45892

class GetCoipPoolUsageRequest < Struct.new(
  :pool_id,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end