Class: Aws::EC2::Types::GetDeclarativePoliciesReportSummaryResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetDeclarativePoliciesReportSummaryResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute_summaries ⇒ Array<Types::AttributeSummary>
The attributes described in the report.
-
#end_time ⇒ Time
The time when the report generation ended.
-
#number_of_accounts ⇒ Integer
The total number of accounts associated with the specified
targetId. -
#number_of_failed_accounts ⇒ Integer
The number of accounts where attributes could not be retrieved in any Region.
-
#report_id ⇒ String
The ID of the report.
-
#s3_bucket ⇒ String
The name of the Amazon S3 bucket where the report is located.
-
#s3_prefix ⇒ String
The prefix for your S3 object.
-
#start_time ⇒ Time
The time when the report generation started.
-
#target_id ⇒ String
The root ID, organizational unit ID, or account ID.
Instance Attribute Details
#attribute_summaries ⇒ Array<Types::AttributeSummary>
The attributes described in the report.
46525 46526 46527 46528 46529 46530 46531 46532 46533 46534 46535 46536 46537 |
# File 'lib/aws-sdk-ec2/types.rb', line 46525 class GetDeclarativePoliciesReportSummaryResult < Struct.new( :report_id, :s3_bucket, :s3_prefix, :target_id, :start_time, :end_time, :number_of_accounts, :number_of_failed_accounts, :attribute_summaries) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
The time when the report generation ended.
46525 46526 46527 46528 46529 46530 46531 46532 46533 46534 46535 46536 46537 |
# File 'lib/aws-sdk-ec2/types.rb', line 46525 class GetDeclarativePoliciesReportSummaryResult < Struct.new( :report_id, :s3_bucket, :s3_prefix, :target_id, :start_time, :end_time, :number_of_accounts, :number_of_failed_accounts, :attribute_summaries) SENSITIVE = [] include Aws::Structure end |
#number_of_accounts ⇒ Integer
The total number of accounts associated with the specified
targetId.
46525 46526 46527 46528 46529 46530 46531 46532 46533 46534 46535 46536 46537 |
# File 'lib/aws-sdk-ec2/types.rb', line 46525 class GetDeclarativePoliciesReportSummaryResult < Struct.new( :report_id, :s3_bucket, :s3_prefix, :target_id, :start_time, :end_time, :number_of_accounts, :number_of_failed_accounts, :attribute_summaries) SENSITIVE = [] include Aws::Structure end |
#number_of_failed_accounts ⇒ Integer
The number of accounts where attributes could not be retrieved in any Region.
46525 46526 46527 46528 46529 46530 46531 46532 46533 46534 46535 46536 46537 |
# File 'lib/aws-sdk-ec2/types.rb', line 46525 class GetDeclarativePoliciesReportSummaryResult < Struct.new( :report_id, :s3_bucket, :s3_prefix, :target_id, :start_time, :end_time, :number_of_accounts, :number_of_failed_accounts, :attribute_summaries) SENSITIVE = [] include Aws::Structure end |
#report_id ⇒ String
The ID of the report.
46525 46526 46527 46528 46529 46530 46531 46532 46533 46534 46535 46536 46537 |
# File 'lib/aws-sdk-ec2/types.rb', line 46525 class GetDeclarativePoliciesReportSummaryResult < Struct.new( :report_id, :s3_bucket, :s3_prefix, :target_id, :start_time, :end_time, :number_of_accounts, :number_of_failed_accounts, :attribute_summaries) SENSITIVE = [] include Aws::Structure end |
#s3_bucket ⇒ String
The name of the Amazon S3 bucket where the report is located.
46525 46526 46527 46528 46529 46530 46531 46532 46533 46534 46535 46536 46537 |
# File 'lib/aws-sdk-ec2/types.rb', line 46525 class GetDeclarativePoliciesReportSummaryResult < Struct.new( :report_id, :s3_bucket, :s3_prefix, :target_id, :start_time, :end_time, :number_of_accounts, :number_of_failed_accounts, :attribute_summaries) SENSITIVE = [] include Aws::Structure end |
#s3_prefix ⇒ String
The prefix for your S3 object.
46525 46526 46527 46528 46529 46530 46531 46532 46533 46534 46535 46536 46537 |
# File 'lib/aws-sdk-ec2/types.rb', line 46525 class GetDeclarativePoliciesReportSummaryResult < Struct.new( :report_id, :s3_bucket, :s3_prefix, :target_id, :start_time, :end_time, :number_of_accounts, :number_of_failed_accounts, :attribute_summaries) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The time when the report generation started.
46525 46526 46527 46528 46529 46530 46531 46532 46533 46534 46535 46536 46537 |
# File 'lib/aws-sdk-ec2/types.rb', line 46525 class GetDeclarativePoliciesReportSummaryResult < Struct.new( :report_id, :s3_bucket, :s3_prefix, :target_id, :start_time, :end_time, :number_of_accounts, :number_of_failed_accounts, :attribute_summaries) SENSITIVE = [] include Aws::Structure end |
#target_id ⇒ String
The root ID, organizational unit ID, or account ID.
Format:
-
For root:
r-ab12 -
For OU:
ou-ab12-cdef1234 -
For account:
123456789012
46525 46526 46527 46528 46529 46530 46531 46532 46533 46534 46535 46536 46537 |
# File 'lib/aws-sdk-ec2/types.rb', line 46525 class GetDeclarativePoliciesReportSummaryResult < Struct.new( :report_id, :s3_bucket, :s3_prefix, :target_id, :start_time, :end_time, :number_of_accounts, :number_of_failed_accounts, :attribute_summaries) SENSITIVE = [] include Aws::Structure end |