Class: Aws::EC2::Types::GetEbsDefaultKmsKeyIdRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


46631
46632
46633
46634
46635
# File 'lib/aws-sdk-ec2/types.rb', line 46631

class GetEbsDefaultKmsKeyIdRequest < Struct.new(
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end