Class: Aws::EC2::Types::GetHostReservationPurchasePreviewResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetHostReservationPurchasePreviewResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#currency_code ⇒ String
The currency in which the
totalUpfrontPriceandtotalHourlyPriceamounts are specified. -
#purchase ⇒ Array<Types::Purchase>
The purchase information of the Dedicated Host reservation and the Dedicated Hosts associated with it.
-
#total_hourly_price ⇒ String
The potential total hourly price of the reservation per hour.
-
#total_upfront_price ⇒ String
The potential total upfront price.
Instance Attribute Details
#currency_code ⇒ String
The currency in which the totalUpfrontPrice and totalHourlyPrice
amounts are specified. At this time, the only supported currency is
USD.
45059 45060 45061 45062 45063 45064 45065 45066 |
# File 'lib/aws-sdk-ec2/types.rb', line 45059 class GetHostReservationPurchasePreviewResult < Struct.new( :currency_code, :purchase, :total_hourly_price, :total_upfront_price) SENSITIVE = [] include Aws::Structure end |
#purchase ⇒ Array<Types::Purchase>
The purchase information of the Dedicated Host reservation and the Dedicated Hosts associated with it.
45059 45060 45061 45062 45063 45064 45065 45066 |
# File 'lib/aws-sdk-ec2/types.rb', line 45059 class GetHostReservationPurchasePreviewResult < Struct.new( :currency_code, :purchase, :total_hourly_price, :total_upfront_price) SENSITIVE = [] include Aws::Structure end |
#total_hourly_price ⇒ String
The potential total hourly price of the reservation per hour.
45059 45060 45061 45062 45063 45064 45065 45066 |
# File 'lib/aws-sdk-ec2/types.rb', line 45059 class GetHostReservationPurchasePreviewResult < Struct.new( :currency_code, :purchase, :total_hourly_price, :total_upfront_price) SENSITIVE = [] include Aws::Structure end |
#total_upfront_price ⇒ String
The potential total upfront price. This is billed immediately.
45059 45060 45061 45062 45063 45064 45065 45066 |
# File 'lib/aws-sdk-ec2/types.rb', line 45059 class GetHostReservationPurchasePreviewResult < Struct.new( :currency_code, :purchase, :total_hourly_price, :total_upfront_price) SENSITIVE = [] include Aws::Structure end |