Class: Aws::EC2::Types::GetInstanceTpmEkPubRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Specify this parameter to verify whether the request will succeed, without actually making the request. If the request will succeed, the response is DryRunOperation. Otherwise, the response is UnauthorizedOperation.

Returns:

  • (Boolean)


46513
46514
46515
46516
46517
46518
46519
46520
# File 'lib/aws-sdk-ec2/types.rb', line 46513

class GetInstanceTpmEkPubRequest < Struct.new(
  :instance_id,
  :key_type,
  :key_format,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The ID of the instance for which to get the public endorsement key.

Returns:

  • (String)


46513
46514
46515
46516
46517
46518
46519
46520
# File 'lib/aws-sdk-ec2/types.rb', line 46513

class GetInstanceTpmEkPubRequest < Struct.new(
  :instance_id,
  :key_type,
  :key_format,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#key_formatString

The required public endorsement key format. Specify der for a DER-encoded public key that is compatible with OpenSSL. Specify tpmt for a TPM 2.0 format that is compatible with tpm2-tools. The returned key is base64 encoded.

Returns:

  • (String)


46513
46514
46515
46516
46517
46518
46519
46520
# File 'lib/aws-sdk-ec2/types.rb', line 46513

class GetInstanceTpmEkPubRequest < Struct.new(
  :instance_id,
  :key_type,
  :key_format,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#key_typeString

The required public endorsement key type.

Returns:

  • (String)


46513
46514
46515
46516
46517
46518
46519
46520
# File 'lib/aws-sdk-ec2/types.rb', line 46513

class GetInstanceTpmEkPubRequest < Struct.new(
  :instance_id,
  :key_type,
  :key_format,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end