Class: Aws::EC2::Types::GetInstanceUefiDataRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetInstanceUefiDataRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#instance_id ⇒ String
The ID of the instance from which to retrieve the UEFI data.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
47088 47089 47090 47091 47092 47093 |
# File 'lib/aws-sdk-ec2/types.rb', line 47088 class GetInstanceUefiDataRequest < Struct.new( :instance_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the instance from which to retrieve the UEFI data.
47088 47089 47090 47091 47092 47093 |
# File 'lib/aws-sdk-ec2/types.rb', line 47088 class GetInstanceUefiDataRequest < Struct.new( :instance_id, :dry_run) SENSITIVE = [] include Aws::Structure end |