Class: Aws::EC2::Types::GetInstanceUefiDataResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetInstanceUefiDataResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:uefi_data]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The ID of the instance from which to retrieve the UEFI data.
-
#uefi_data ⇒ String
Base64 representation of the non-volatile UEFI variable store.
Instance Attribute Details
#instance_id ⇒ String
The ID of the instance from which to retrieve the UEFI data.
47105 47106 47107 47108 47109 47110 |
# File 'lib/aws-sdk-ec2/types.rb', line 47105 class GetInstanceUefiDataResult < Struct.new( :instance_id, :uefi_data) SENSITIVE = [:uefi_data] include Aws::Structure end |
#uefi_data ⇒ String
Base64 representation of the non-volatile UEFI variable store.
47105 47106 47107 47108 47109 47110 |
# File 'lib/aws-sdk-ec2/types.rb', line 47105 class GetInstanceUefiDataResult < Struct.new( :instance_id, :uefi_data) SENSITIVE = [:uefi_data] include Aws::Structure end |