Class: Aws::EC2::Types::GetPasswordDataRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetPasswordDataRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#instance_id ⇒ String
The ID of the Windows instance.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
48620 48621 48622 48623 48624 48625 |
# File 'lib/aws-sdk-ec2/types.rb', line 48620 class GetPasswordDataRequest < Struct.new( :instance_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the Windows instance.
48620 48621 48622 48623 48624 48625 |
# File 'lib/aws-sdk-ec2/types.rb', line 48620 class GetPasswordDataRequest < Struct.new( :instance_id, :dry_run) SENSITIVE = [] include Aws::Structure end |