Class: Aws::EC2::Types::GetRouteServerAssociationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetRouteServerAssociationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#route_server_id ⇒ String
The ID of the route server for which to get association information.
Instance Attribute Details
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action
without actually making the request and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
48716 48717 48718 48719 48720 48721 |
# File 'lib/aws-sdk-ec2/types.rb', line 48716 class GetRouteServerAssociationsRequest < Struct.new( :route_server_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#route_server_id ⇒ String
The ID of the route server for which to get association information.
48716 48717 48718 48719 48720 48721 |
# File 'lib/aws-sdk-ec2/types.rb', line 48716 class GetRouteServerAssociationsRequest < Struct.new( :route_server_id, :dry_run) SENSITIVE = [] include Aws::Structure end |