Class: Aws::EC2::Types::GetTransitGatewayAttachmentPropagationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


49266
49267
49268
49269
49270
49271
49272
49273
49274
# File 'lib/aws-sdk-ec2/types.rb', line 49266

class GetTransitGatewayAttachmentPropagationsRequest < Struct.new(
  :transit_gateway_attachment_id,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters. The possible values are:

  • transit-gateway-route-table-id - The ID of the transit gateway route table.

^

Returns:



49266
49267
49268
49269
49270
49271
49272
49273
49274
# File 'lib/aws-sdk-ec2/types.rb', line 49266

class GetTransitGatewayAttachmentPropagationsRequest < Struct.new(
  :transit_gateway_attachment_id,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.

Returns:

  • (Integer)


49266
49267
49268
49269
49270
49271
49272
49273
49274
# File 'lib/aws-sdk-ec2/types.rb', line 49266

class GetTransitGatewayAttachmentPropagationsRequest < Struct.new(
  :transit_gateway_attachment_id,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


49266
49267
49268
49269
49270
49271
49272
49273
49274
# File 'lib/aws-sdk-ec2/types.rb', line 49266

class GetTransitGatewayAttachmentPropagationsRequest < Struct.new(
  :transit_gateway_attachment_id,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_attachment_idString

The ID of the attachment.

Returns:

  • (String)


49266
49267
49268
49269
49270
49271
49272
49273
49274
# File 'lib/aws-sdk-ec2/types.rb', line 49266

class GetTransitGatewayAttachmentPropagationsRequest < Struct.new(
  :transit_gateway_attachment_id,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end