Class: Aws::EC2::Types::GetTransitGatewayMulticastDomainAssociationsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetTransitGatewayMulticastDomainAssociationsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#multicast_domain_associations ⇒ Array<Types::TransitGatewayMulticastDomainAssociation>
Information about the multicast domain associations.
-
#next_token ⇒ String
The token to use to retrieve the next page of results.
Instance Attribute Details
#multicast_domain_associations ⇒ Array<Types::TransitGatewayMulticastDomainAssociation>
Information about the multicast domain associations.
49361 49362 49363 49364 49365 49366 |
# File 'lib/aws-sdk-ec2/types.rb', line 49361 class GetTransitGatewayMulticastDomainAssociationsResult < Struct.new( :multicast_domain_associations, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to retrieve the next page of results. This value is
null when there are no more results to return.
49361 49362 49363 49364 49365 49366 |
# File 'lib/aws-sdk-ec2/types.rb', line 49361 class GetTransitGatewayMulticastDomainAssociationsResult < Struct.new( :multicast_domain_associations, :next_token) SENSITIVE = [] include Aws::Structure end |