Class: Aws::EC2::Types::GetTransitGatewayPolicyTableAssociationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


49446
49447
49448
49449
49450
49451
49452
49453
49454
# File 'lib/aws-sdk-ec2/types.rb', line 49446

class GetTransitGatewayPolicyTableAssociationsRequest < Struct.new(
  :transit_gateway_policy_table_id,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters associated with the transit gateway policy table.

Returns:



49446
49447
49448
49449
49450
49451
49452
49453
49454
# File 'lib/aws-sdk-ec2/types.rb', line 49446

class GetTransitGatewayPolicyTableAssociationsRequest < Struct.new(
  :transit_gateway_policy_table_id,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.

Returns:

  • (Integer)


49446
49447
49448
49449
49450
49451
49452
49453
49454
# File 'lib/aws-sdk-ec2/types.rb', line 49446

class GetTransitGatewayPolicyTableAssociationsRequest < Struct.new(
  :transit_gateway_policy_table_id,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


49446
49447
49448
49449
49450
49451
49452
49453
49454
# File 'lib/aws-sdk-ec2/types.rb', line 49446

class GetTransitGatewayPolicyTableAssociationsRequest < Struct.new(
  :transit_gateway_policy_table_id,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_policy_table_idString

The ID of the transit gateway policy table.

Returns:

  • (String)


49446
49447
49448
49449
49450
49451
49452
49453
49454
# File 'lib/aws-sdk-ec2/types.rb', line 49446

class GetTransitGatewayPolicyTableAssociationsRequest < Struct.new(
  :transit_gateway_policy_table_id,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end