Class: Aws::EC2::Types::GetVpcResourcesBlockingEncryptionEnforcementRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetVpcResourcesBlockingEncryptionEnforcementRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token returned from a previous paginated request.
-
#vpc_id ⇒ String
The ID of the VPC to check for resources blocking encryption enforcement.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
49864 49865 49866 49867 49868 49869 49870 49871 |
# File 'lib/aws-sdk-ec2/types.rb', line 49864 class GetVpcResourcesBlockingEncryptionEnforcementRequest < Struct.new( :vpc_id, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
49864 49865 49866 49867 49868 49869 49870 49871 |
# File 'lib/aws-sdk-ec2/types.rb', line 49864 class GetVpcResourcesBlockingEncryptionEnforcementRequest < Struct.new( :vpc_id, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
49864 49865 49866 49867 49868 49869 49870 49871 |
# File 'lib/aws-sdk-ec2/types.rb', line 49864 class GetVpcResourcesBlockingEncryptionEnforcementRequest < Struct.new( :vpc_id, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC to check for resources blocking encryption enforcement.
49864 49865 49866 49867 49868 49869 49870 49871 |
# File 'lib/aws-sdk-ec2/types.rb', line 49864 class GetVpcResourcesBlockingEncryptionEnforcementRequest < Struct.new( :vpc_id, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |