Class: Aws::EC2::Types::GetVpnConnectionDeviceSampleConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


47988
47989
47990
47991
47992
47993
47994
47995
47996
# File 'lib/aws-sdk-ec2/types.rb', line 47988

class GetVpnConnectionDeviceSampleConfigurationRequest < Struct.new(
  :vpn_connection_id,
  :vpn_connection_device_type_id,
  :internet_key_exchange_version,
  :sample_type,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#internet_key_exchange_versionString

The IKE version to be used in the sample configuration file for your customer gateway device. You can specify one of the following versions: ikev1 or ikev2.

Returns:

  • (String)


47988
47989
47990
47991
47992
47993
47994
47995
47996
# File 'lib/aws-sdk-ec2/types.rb', line 47988

class GetVpnConnectionDeviceSampleConfigurationRequest < Struct.new(
  :vpn_connection_id,
  :vpn_connection_device_type_id,
  :internet_key_exchange_version,
  :sample_type,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#sample_typeString

The type of sample configuration to generate. Valid values are "compatibility" (includes IKEv1) or "recommended" (throws UnsupportedOperationException for IKEv1).

Returns:

  • (String)


47988
47989
47990
47991
47992
47993
47994
47995
47996
# File 'lib/aws-sdk-ec2/types.rb', line 47988

class GetVpnConnectionDeviceSampleConfigurationRequest < Struct.new(
  :vpn_connection_id,
  :vpn_connection_device_type_id,
  :internet_key_exchange_version,
  :sample_type,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpn_connection_device_type_idString

Device identifier provided by the GetVpnConnectionDeviceTypes API.

Returns:

  • (String)


47988
47989
47990
47991
47992
47993
47994
47995
47996
# File 'lib/aws-sdk-ec2/types.rb', line 47988

class GetVpnConnectionDeviceSampleConfigurationRequest < Struct.new(
  :vpn_connection_id,
  :vpn_connection_device_type_id,
  :internet_key_exchange_version,
  :sample_type,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpn_connection_idString

The VpnConnectionId specifies the Site-to-Site VPN connection used for the sample configuration.

Returns:

  • (String)


47988
47989
47990
47991
47992
47993
47994
47995
47996
# File 'lib/aws-sdk-ec2/types.rb', line 47988

class GetVpnConnectionDeviceSampleConfigurationRequest < Struct.new(
  :vpn_connection_id,
  :vpn_connection_device_type_id,
  :internet_key_exchange_version,
  :sample_type,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end