Class: Aws::EC2::Types::HealthCheckPathDestinationRequestObject

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes a destination for a health check path in a request. Destinations can be in a different Availability Zone than the source (cross-AZ) or in a Local Zone (AZ to Local Zone), enabling remote health validation of your application.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#security_group_idString

The ID of the security group for the destination.

Returns:

  • (String)


49316
49317
49318
49319
49320
49321
# File 'lib/aws-sdk-ec2/types.rb', line 49316

class HealthCheckPathDestinationRequestObject < Struct.new(
  :subnet_id,
  :security_group_id)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idString

The ID of the subnet for the destination.

Returns:

  • (String)


49316
49317
49318
49319
49320
49321
# File 'lib/aws-sdk-ec2/types.rb', line 49316

class HealthCheckPathDestinationRequestObject < Struct.new(
  :subnet_id,
  :security_group_id)
  SENSITIVE = []
  include Aws::Structure
end