Class: Aws::EC2::Types::HealthCheckPathSourceRequestObject

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes the source for a health check path in a request. The source defines the subnet and security group where a health check elastic network interface (ENI) is created to originate health check traffic.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#security_group_idString

The ID of the security group for the source.

Returns:

  • (String)


49394
49395
49396
49397
49398
49399
# File 'lib/aws-sdk-ec2/types.rb', line 49394

class HealthCheckPathSourceRequestObject < Struct.new(
  :subnet_id,
  :security_group_id)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idString

The ID of the subnet for the source.

Returns:

  • (String)


49394
49395
49396
49397
49398
49399
# File 'lib/aws-sdk-ec2/types.rb', line 49394

class HealthCheckPathSourceRequestObject < Struct.new(
  :subnet_id,
  :security_group_id)
  SENSITIVE = []
  include Aws::Structure
end