Class: Aws::EC2::Types::HostInstance
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::HostInstance
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes an instance running on a Dedicated Host.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The ID of instance that is running on the Dedicated Host.
-
#instance_type ⇒ String
The instance type (for example,
m3.medium) of the running instance. -
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the instance.
Instance Attribute Details
#instance_id ⇒ String
The ID of instance that is running on the Dedicated Host.
48051 48052 48053 48054 48055 48056 48057 |
# File 'lib/aws-sdk-ec2/types.rb', line 48051 class HostInstance < Struct.new( :instance_id, :instance_type, :owner_id) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The instance type (for example, m3.medium) of the running
instance.
48051 48052 48053 48054 48055 48056 48057 |
# File 'lib/aws-sdk-ec2/types.rb', line 48051 class HostInstance < Struct.new( :instance_id, :instance_type, :owner_id) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the instance.
48051 48052 48053 48054 48055 48056 48057 |
# File 'lib/aws-sdk-ec2/types.rb', line 48051 class HostInstance < Struct.new( :instance_id, :instance_type, :owner_id) SENSITIVE = [] include Aws::Structure end |