Class: Aws::EC2::Types::Image

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes an image.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#architectureString

The architecture of the image.

Returns:

  • (String)


48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#block_device_mappingsArray<Types::BlockDeviceMapping>

Any block device mapping entries.

Returns:



48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#boot_modeString

The boot mode of the image. For more information, see Instance launch behavior with Amazon EC2 boot modes in the Amazon EC2 User Guide.

Returns:

  • (String)


48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#creation_dateString

The date and time the image was created.

Returns:

  • (String)


48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#deprecation_timeString

The date and time to deprecate the AMI, in UTC, in the following format: YYYY-MM-DDTHH:MM:SSZ. If you specified a value for seconds, Amazon EC2 rounds the seconds to the nearest minute.

Returns:

  • (String)


48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#deregistration_protectionString

Indicates whether deregistration protection is enabled for the AMI.

Returns:

  • (String)


48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the AMI that was provided during image creation.

Returns:

  • (String)


48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#ena_supportBoolean

Specifies whether enhanced networking with ENA is enabled.

Returns:

  • (Boolean)


48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#free_tier_eligibleBoolean

Indicates whether the image is eligible for Amazon Web Services Free Tier.

  • If true, the AMI is eligible for Free Tier and can be used to launch instances under the Free Tier limits.

  • If false, the AMI is not eligible for Free Tier.

Returns:

  • (Boolean)


48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#hypervisorString

The hypervisor type of the image. Only xen is supported. ovm is not supported.

Returns:

  • (String)


48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#image_allowedBoolean

If true, the AMI satisfies the criteria for Allowed AMIs and can be discovered and used in the account. If false and Allowed AMIs is set to enabled, the AMI can't be discovered or used in the account. If false and Allowed AMIs is set to audit-mode, the AMI can be discovered and used in the account.

For more information, see Control the discovery and use of AMIs in Amazon EC2 with Allowed AMIs in Amazon EC2 User Guide.

Returns:

  • (Boolean)


48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#image_idString

The ID of the AMI.

Returns:

  • (String)


48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#image_locationString

The location of the AMI.

Returns:

  • (String)


48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#image_owner_aliasString

The owner alias (amazon | aws-backup-vault | aws-marketplace).

Returns:

  • (String)


48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#image_typeString

The type of image.

Returns:

  • (String)


48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#image_watermarksArray<Types::ImageWatermark>

The watermarks attached to the AMI.

Returns:



48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#imds_supportString

If v2.0, it indicates that IMDSv2 is specified in the AMI. Instances launched from this AMI will have HttpTokens automatically set to required so that, by default, the instance requires that IMDSv2 is used when requesting instance metadata. In addition, HttpPutResponseHopLimit is set to 2. For more information, see Configure the AMI in the Amazon EC2 User Guide.

Returns:

  • (String)


48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#kernel_idString

The kernel associated with the image, if any. Only applicable for machine images.

Returns:

  • (String)


48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#last_launched_timeString

The date and time, in ISO 8601 date-time format, when the AMI was last used to launch an EC2 instance. When the AMI is used to launch an instance, there is a 24-hour delay before that usage is reported.

lastLaunchedTime data is available starting April 2017.

Returns:

  • (String)


48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the AMI that was provided during image creation.

Returns:

  • (String)


48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#owner_idString

The ID of the Amazon Web Services account that owns the image.

Returns:

  • (String)


48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#platformString

This value is set to windows for Windows AMIs; otherwise, it is blank.

Returns:

  • (String)


48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#platform_detailsString

The platform details associated with the billing code of the AMI. For more information, see Understand AMI billing information in the Amazon EC2 User Guide.

Returns:

  • (String)


48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#product_codesArray<Types::ProductCode>

Any product codes associated with the AMI.

Returns:



48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#publicBoolean

Indicates whether the image has public launch permissions. The value is true if this image has public launch permissions or false if it has only implicit and explicit launch permissions.

Returns:

  • (Boolean)


48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#public_ssm_parameter_nameString

The name of the public Systems Manager parameter that resolves to this AMI, under the aws/service/ namespace.

Returns:

  • (String)


48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#ramdisk_idString

The RAM disk associated with the image, if any. Only applicable for machine images.

Returns:

  • (String)


48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#root_device_nameString

The device name of the root device volume (for example, /dev/sda1).

Returns:

  • (String)


48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#root_device_typeString

The type of root device used by the AMI. The AMI can use an Amazon EBS volume or an instance store volume.

Returns:

  • (String)


48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#source_image_idString

The ID of the source AMI from which the AMI was created.

Returns:

  • (String)


48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#source_image_regionString

The Region of the source AMI.

Returns:

  • (String)


48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#source_instance_idString

The ID of the instance that the AMI was created from if the AMI was created using CreateImage. This field only appears if the AMI was created using CreateImage.

Returns:

  • (String)


48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#sriov_net_supportString

Specifies whether enhanced networking with the Intel 82599 Virtual Function interface is enabled.

Returns:

  • (String)


48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The current state of the AMI. If the state is available, the image is successfully registered and can be used to launch an instance.

Returns:

  • (String)


48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#state_reasonTypes::StateReason

The reason for the state change.

Returns:



48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Any tags assigned to the image.

Returns:



48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#tpm_supportString

If the image is configured for NitroTPM support, the value is v2.0. For more information, see NitroTPM in the Amazon EC2 User Guide.

Returns:

  • (String)


48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#usage_operationString

The operation of the Amazon EC2 instance and the billing code that is associated with the AMI. usageOperation corresponds to the lineitem/Operation column on your Amazon Web Services Cost and Usage Report and in the Amazon Web Services Price List API. You can view these fields on the Instances or AMIs pages in the Amazon EC2 console, or in the responses that are returned by the DescribeImages command in the Amazon EC2 API, or the describe-images command in the CLI.

Returns:

  • (String)


48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#virtualization_typeString

The type of virtualization of the AMI.

Returns:

  • (String)


48991
48992
48993
48994
48995
48996
48997
48998
48999
49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
49018
49019
49020
49021
49022
49023
49024
49025
49026
49027
49028
49029
49030
49031
49032
49033
# File 'lib/aws-sdk-ec2/types.rb', line 48991

class Image < Struct.new(
  :platform_details,
  :usage_operation,
  :block_device_mappings,
  :description,
  :ena_support,
  :hypervisor,
  :image_owner_alias,
  :name,
  :root_device_name,
  :root_device_type,
  :sriov_net_support,
  :state_reason,
  :tags,
  :virtualization_type,
  :boot_mode,
  :tpm_support,
  :deprecation_time,
  :imds_support,
  :source_instance_id,
  :deregistration_protection,
  :last_launched_time,
  :image_allowed,
  :source_image_id,
  :source_image_region,
  :free_tier_eligible,
  :public_ssm_parameter_name,
  :image_watermarks,
  :image_id,
  :image_location,
  :state,
  :owner_id,
  :creation_date,
  :public,
  :product_codes,
  :architecture,
  :image_type,
  :kernel_id,
  :ramdisk_id,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end