Class: Aws::EC2::Types::ImageUsageReportEntry
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ImageUsageReportEntry
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
A single entry in an image usage report, detailing how an image is being used by a specific Amazon Web Services account and resource type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The ID of the account that uses the image.
-
#image_id ⇒ String
The ID of the image.
-
#report_creation_time ⇒ Time
The date and time the report creation was initiated.
-
#report_id ⇒ String
The ID of the report.
-
#resource_type ⇒ String
The type of resource (‘ec2:Instance` or `ec2:LaunchTemplate`).
-
#usage_count ⇒ Integer
The number of times resources of this type reference this image in the account.
Instance Attribute Details
#account_id ⇒ String
The ID of the account that uses the image.
47684 47685 47686 47687 47688 47689 47690 47691 47692 47693 |
# File 'lib/aws-sdk-ec2/types.rb', line 47684 class ImageUsageReportEntry < Struct.new( :resource_type, :report_id, :usage_count, :account_id, :image_id, :report_creation_time) SENSITIVE = [] include Aws::Structure end |
#image_id ⇒ String
The ID of the image.
47684 47685 47686 47687 47688 47689 47690 47691 47692 47693 |
# File 'lib/aws-sdk-ec2/types.rb', line 47684 class ImageUsageReportEntry < Struct.new( :resource_type, :report_id, :usage_count, :account_id, :image_id, :report_creation_time) SENSITIVE = [] include Aws::Structure end |
#report_creation_time ⇒ Time
The date and time the report creation was initiated.
47684 47685 47686 47687 47688 47689 47690 47691 47692 47693 |
# File 'lib/aws-sdk-ec2/types.rb', line 47684 class ImageUsageReportEntry < Struct.new( :resource_type, :report_id, :usage_count, :account_id, :image_id, :report_creation_time) SENSITIVE = [] include Aws::Structure end |
#report_id ⇒ String
The ID of the report.
47684 47685 47686 47687 47688 47689 47690 47691 47692 47693 |
# File 'lib/aws-sdk-ec2/types.rb', line 47684 class ImageUsageReportEntry < Struct.new( :resource_type, :report_id, :usage_count, :account_id, :image_id, :report_creation_time) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of resource (‘ec2:Instance` or `ec2:LaunchTemplate`).
47684 47685 47686 47687 47688 47689 47690 47691 47692 47693 |
# File 'lib/aws-sdk-ec2/types.rb', line 47684 class ImageUsageReportEntry < Struct.new( :resource_type, :report_id, :usage_count, :account_id, :image_id, :report_creation_time) SENSITIVE = [] include Aws::Structure end |
#usage_count ⇒ Integer
The number of times resources of this type reference this image in the account.
47684 47685 47686 47687 47688 47689 47690 47691 47692 47693 |
# File 'lib/aws-sdk-ec2/types.rb', line 47684 class ImageUsageReportEntry < Struct.new( :resource_type, :report_id, :usage_count, :account_id, :image_id, :report_creation_time) SENSITIVE = [] include Aws::Structure end |