Class: Aws::EC2::Types::ImageUsageResourceType
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ImageUsageResourceType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
A resource type to include in the report. Associated options can also be specified if the resource type is a launch template.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource_type ⇒ String
The resource type.
-
#resource_type_options ⇒ Array<Types::ImageUsageResourceTypeOption>
The options that affect the scope of the report.
Instance Attribute Details
#resource_type ⇒ String
The resource type.
Valid values: ‘ec2:Instance` | `ec2:LaunchTemplate`
47711 47712 47713 47714 47715 47716 |
# File 'lib/aws-sdk-ec2/types.rb', line 47711 class ImageUsageResourceType < Struct.new( :resource_type, :resource_type_options) SENSITIVE = [] include Aws::Structure end |
#resource_type_options ⇒ Array<Types::ImageUsageResourceTypeOption>
The options that affect the scope of the report. Valid only when ‘ResourceType` is `ec2:LaunchTemplate`.
47711 47712 47713 47714 47715 47716 |
# File 'lib/aws-sdk-ec2/types.rb', line 47711 class ImageUsageResourceType < Struct.new( :resource_type, :resource_type_options) SENSITIVE = [] include Aws::Structure end |