Class: Aws::EC2::Types::ImageUsageResourceTypeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

A resource type to include in the report. Associated options can also be specified if the resource type is a launch template.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resource_typeString

The resource type.

Valid values: ‘ec2:Instance` | `ec2:LaunchTemplate`

Returns:

  • (String)


47872
47873
47874
47875
47876
47877
# File 'lib/aws-sdk-ec2/types.rb', line 47872

class ImageUsageResourceTypeRequest < Struct.new(
  :resource_type,
  :resource_type_options)
  SENSITIVE = []
  include Aws::Structure
end

#resource_type_optionsArray<Types::ImageUsageResourceTypeOptionRequest>

The options that affect the scope of the report. Valid only when ‘ResourceType` is `ec2:LaunchTemplate`.



47872
47873
47874
47875
47876
47877
# File 'lib/aws-sdk-ec2/types.rb', line 47872

class ImageUsageResourceTypeRequest < Struct.new(
  :resource_type,
  :resource_type_options)
  SENSITIVE = []
  include Aws::Structure
end