Class: Aws::EC2::Types::ImageWatermark
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ImageWatermark
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a watermark attached to an AMI.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#source_image_creation_time ⇒ Time
The creation date of the source AMI, in the following format: YYYY-MM-*DD*T*HH*:MM:SS.ssssss+HH:MM.
-
#source_image_id ⇒ String
The ID of the AMI to which the watermark was originally attached.
-
#source_image_region ⇒ String
The Region where the watermark was originally attached.
-
#watermark_creation_time ⇒ Time
The date and time the watermark was attached to the AMI, in the following format: YYYY-MM-*DD*T*HH*:MM:SS.ssssss+HH:MM.
-
#watermark_key ⇒ String
The watermark identifier, in ‘accountId:watermarkName` format (for example, `123456789012:approvedAmi`).
Instance Attribute Details
#source_image_creation_time ⇒ Time
The creation date of the source AMI, in the following format: YYYY-MM-*DD*T*HH*:MM:SS.ssssss+HH:MM.
49387 49388 49389 49390 49391 49392 49393 49394 49395 |
# File 'lib/aws-sdk-ec2/types.rb', line 49387 class ImageWatermark < Struct.new( :watermark_key, :source_image_region, :source_image_id, :source_image_creation_time, :watermark_creation_time) SENSITIVE = [] include Aws::Structure end |
#source_image_id ⇒ String
The ID of the AMI to which the watermark was originally attached.
49387 49388 49389 49390 49391 49392 49393 49394 49395 |
# File 'lib/aws-sdk-ec2/types.rb', line 49387 class ImageWatermark < Struct.new( :watermark_key, :source_image_region, :source_image_id, :source_image_creation_time, :watermark_creation_time) SENSITIVE = [] include Aws::Structure end |
#source_image_region ⇒ String
The Region where the watermark was originally attached.
49387 49388 49389 49390 49391 49392 49393 49394 49395 |
# File 'lib/aws-sdk-ec2/types.rb', line 49387 class ImageWatermark < Struct.new( :watermark_key, :source_image_region, :source_image_id, :source_image_creation_time, :watermark_creation_time) SENSITIVE = [] include Aws::Structure end |
#watermark_creation_time ⇒ Time
The date and time the watermark was attached to the AMI, in the following format: YYYY-MM-*DD*T*HH*:MM:SS.ssssss+HH:MM.
49387 49388 49389 49390 49391 49392 49393 49394 49395 |
# File 'lib/aws-sdk-ec2/types.rb', line 49387 class ImageWatermark < Struct.new( :watermark_key, :source_image_region, :source_image_id, :source_image_creation_time, :watermark_creation_time) SENSITIVE = [] include Aws::Structure end |
#watermark_key ⇒ String
The watermark identifier, in ‘accountId:watermarkName` format (for example, `123456789012:approvedAmi`). The `accountId` portion is the Amazon Web Services account ID of the watermark creator. The `watermarkName` portion is customer-provided.
49387 49388 49389 49390 49391 49392 49393 49394 49395 |
# File 'lib/aws-sdk-ec2/types.rb', line 49387 class ImageWatermark < Struct.new( :watermark_key, :source_image_region, :source_image_id, :source_image_creation_time, :watermark_creation_time) SENSITIVE = [] include Aws::Structure end |