Class: Aws::EC2::Types::ImportImageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ImportImageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#architecture ⇒ String
The architecture of the virtual machine.
-
#boot_mode ⇒ String
The boot mode of the virtual machine.
-
#client_data ⇒ Types::ClientData
The client-specific data.
-
#client_token ⇒ String
The token to enable idempotency for VM import requests.
-
#description ⇒ String
A description string for the import image task.
-
#disk_containers ⇒ Array<Types::ImageDiskContainer>
Information about the disk containers.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#encrypted ⇒ Boolean
Specifies whether the destination AMI of the imported image should be encrypted.
-
#hypervisor ⇒ String
The target hypervisor platform.
-
#kms_key_id ⇒ String
An identifier for the symmetric KMS key to use when creating the encrypted AMI.
-
#license_specifications ⇒ Array<Types::ImportImageLicenseConfigurationRequest>
The ARNs of the license configurations.
-
#license_type ⇒ String
The license type to be used for the Amazon Machine Image (AMI) after importing.
-
#platform ⇒ String
The operating system of the virtual machine.
-
#role_name ⇒ String
The name of the role to use when not using the default role, ‘vmimport’.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the import image task during creation.
-
#usage_operation ⇒ String
The usage operation value.
Instance Attribute Details
#architecture ⇒ String
The architecture of the virtual machine.
Valid values: ‘i386` | `x86_64`
48009 48010 48011 48012 48013 48014 48015 48016 48017 48018 48019 48020 48021 48022 48023 48024 48025 48026 48027 48028 |
# File 'lib/aws-sdk-ec2/types.rb', line 48009 class ImportImageRequest < Struct.new( :architecture, :client_data, :client_token, :description, :disk_containers, :dry_run, :encrypted, :hypervisor, :kms_key_id, :license_type, :platform, :role_name, :license_specifications, :tag_specifications, :usage_operation, :boot_mode) SENSITIVE = [] include Aws::Structure end |
#boot_mode ⇒ String
The boot mode of the virtual machine.
<note markdown=“1”> The ‘uefi-preferred` boot mode isn’t supported for importing images. For more information, see [Boot modes] in the *VM Import/Export User Guide*.
</note>
[1]: docs.aws.amazon.com/vm-import/latest/userguide/prerequisites.html#vmimport-boot-modes
48009 48010 48011 48012 48013 48014 48015 48016 48017 48018 48019 48020 48021 48022 48023 48024 48025 48026 48027 48028 |
# File 'lib/aws-sdk-ec2/types.rb', line 48009 class ImportImageRequest < Struct.new( :architecture, :client_data, :client_token, :description, :disk_containers, :dry_run, :encrypted, :hypervisor, :kms_key_id, :license_type, :platform, :role_name, :license_specifications, :tag_specifications, :usage_operation, :boot_mode) SENSITIVE = [] include Aws::Structure end |
#client_data ⇒ Types::ClientData
The client-specific data.
48009 48010 48011 48012 48013 48014 48015 48016 48017 48018 48019 48020 48021 48022 48023 48024 48025 48026 48027 48028 |
# File 'lib/aws-sdk-ec2/types.rb', line 48009 class ImportImageRequest < Struct.new( :architecture, :client_data, :client_token, :description, :disk_containers, :dry_run, :encrypted, :hypervisor, :kms_key_id, :license_type, :platform, :role_name, :license_specifications, :tag_specifications, :usage_operation, :boot_mode) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
The token to enable idempotency for VM import requests.
48009 48010 48011 48012 48013 48014 48015 48016 48017 48018 48019 48020 48021 48022 48023 48024 48025 48026 48027 48028 |
# File 'lib/aws-sdk-ec2/types.rb', line 48009 class ImportImageRequest < Struct.new( :architecture, :client_data, :client_token, :description, :disk_containers, :dry_run, :encrypted, :hypervisor, :kms_key_id, :license_type, :platform, :role_name, :license_specifications, :tag_specifications, :usage_operation, :boot_mode) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description string for the import image task.
48009 48010 48011 48012 48013 48014 48015 48016 48017 48018 48019 48020 48021 48022 48023 48024 48025 48026 48027 48028 |
# File 'lib/aws-sdk-ec2/types.rb', line 48009 class ImportImageRequest < Struct.new( :architecture, :client_data, :client_token, :description, :disk_containers, :dry_run, :encrypted, :hypervisor, :kms_key_id, :license_type, :platform, :role_name, :license_specifications, :tag_specifications, :usage_operation, :boot_mode) SENSITIVE = [] include Aws::Structure end |
#disk_containers ⇒ Array<Types::ImageDiskContainer>
Information about the disk containers.
48009 48010 48011 48012 48013 48014 48015 48016 48017 48018 48019 48020 48021 48022 48023 48024 48025 48026 48027 48028 |
# File 'lib/aws-sdk-ec2/types.rb', line 48009 class ImportImageRequest < Struct.new( :architecture, :client_data, :client_token, :description, :disk_containers, :dry_run, :encrypted, :hypervisor, :kms_key_id, :license_type, :platform, :role_name, :license_specifications, :tag_specifications, :usage_operation, :boot_mode) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
48009 48010 48011 48012 48013 48014 48015 48016 48017 48018 48019 48020 48021 48022 48023 48024 48025 48026 48027 48028 |
# File 'lib/aws-sdk-ec2/types.rb', line 48009 class ImportImageRequest < Struct.new( :architecture, :client_data, :client_token, :description, :disk_containers, :dry_run, :encrypted, :hypervisor, :kms_key_id, :license_type, :platform, :role_name, :license_specifications, :tag_specifications, :usage_operation, :boot_mode) SENSITIVE = [] include Aws::Structure end |
#encrypted ⇒ Boolean
Specifies whether the destination AMI of the imported image should be encrypted. The default KMS key for EBS is used unless you specify a non-default KMS key using ‘KmsKeyId`. For more information, see
- Amazon EBS Encryption][1
-
in the *Amazon Elastic Compute Cloud User
Guide*.
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSEncryption.html
48009 48010 48011 48012 48013 48014 48015 48016 48017 48018 48019 48020 48021 48022 48023 48024 48025 48026 48027 48028 |
# File 'lib/aws-sdk-ec2/types.rb', line 48009 class ImportImageRequest < Struct.new( :architecture, :client_data, :client_token, :description, :disk_containers, :dry_run, :encrypted, :hypervisor, :kms_key_id, :license_type, :platform, :role_name, :license_specifications, :tag_specifications, :usage_operation, :boot_mode) SENSITIVE = [] include Aws::Structure end |
#hypervisor ⇒ String
The target hypervisor platform.
Valid values: ‘xen`
48009 48010 48011 48012 48013 48014 48015 48016 48017 48018 48019 48020 48021 48022 48023 48024 48025 48026 48027 48028 |
# File 'lib/aws-sdk-ec2/types.rb', line 48009 class ImportImageRequest < Struct.new( :architecture, :client_data, :client_token, :description, :disk_containers, :dry_run, :encrypted, :hypervisor, :kms_key_id, :license_type, :platform, :role_name, :license_specifications, :tag_specifications, :usage_operation, :boot_mode) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
An identifier for the symmetric KMS key to use when creating the encrypted AMI. This parameter is only required if you want to use a non-default KMS key; if this parameter is not specified, the default KMS key for EBS is used. If a ‘KmsKeyId` is specified, the `Encrypted` flag must also be set.
The KMS key identifier may be provided in any of the following formats:
-
Key ID
-
Key alias
-
ARN using key ID. The ID ARN contains the ‘arn:aws:kms` namespace, followed by the Region of the key, the Amazon Web Services account ID of the key owner, the `key` namespace, and then the key ID. For example, arn:aws:kms:us-east-1:012345678910:key/abcd1234-a123-456a-a12b-a123b4cd56ef.
-
ARN using key alias. The alias ARN contains the ‘arn:aws:kms` namespace, followed by the Region of the key, the Amazon Web Services account ID of the key owner, the `alias` namespace, and then the key alias. For example, arn:aws:kms:us-east-1:012345678910:alias/ExampleAlias.
Amazon Web Services parses ‘KmsKeyId` asynchronously, meaning that the action you call may appear to complete even though you provided an invalid identifier. This action will eventually report failure.
The specified KMS key must exist in the Region that the AMI is being copied to.
Amazon EBS does not support asymmetric KMS keys.
48009 48010 48011 48012 48013 48014 48015 48016 48017 48018 48019 48020 48021 48022 48023 48024 48025 48026 48027 48028 |
# File 'lib/aws-sdk-ec2/types.rb', line 48009 class ImportImageRequest < Struct.new( :architecture, :client_data, :client_token, :description, :disk_containers, :dry_run, :encrypted, :hypervisor, :kms_key_id, :license_type, :platform, :role_name, :license_specifications, :tag_specifications, :usage_operation, :boot_mode) SENSITIVE = [] include Aws::Structure end |
#license_specifications ⇒ Array<Types::ImportImageLicenseConfigurationRequest>
The ARNs of the license configurations.
48009 48010 48011 48012 48013 48014 48015 48016 48017 48018 48019 48020 48021 48022 48023 48024 48025 48026 48027 48028 |
# File 'lib/aws-sdk-ec2/types.rb', line 48009 class ImportImageRequest < Struct.new( :architecture, :client_data, :client_token, :description, :disk_containers, :dry_run, :encrypted, :hypervisor, :kms_key_id, :license_type, :platform, :role_name, :license_specifications, :tag_specifications, :usage_operation, :boot_mode) SENSITIVE = [] include Aws::Structure end |
#license_type ⇒ String
The license type to be used for the Amazon Machine Image (AMI) after importing.
Specify ‘AWS` to replace the source-system license with an Amazon Web Services license or `BYOL` to retain the source-system license. Leaving this parameter undefined is the same as choosing `AWS` when importing a Windows Server operating system, and the same as choosing `BYOL` when importing a Windows client operating system (such as Windows 10) or a Linux operating system.
To use ‘BYOL`, you must have existing licenses with rights to use these licenses in a third party cloud, such as Amazon Web Services. For more information, see [Prerequisites] in the VM Import/Export User Guide.
[1]: docs.aws.amazon.com/vm-import/latest/userguide/vmimport-image-import.html#prerequisites-image
48009 48010 48011 48012 48013 48014 48015 48016 48017 48018 48019 48020 48021 48022 48023 48024 48025 48026 48027 48028 |
# File 'lib/aws-sdk-ec2/types.rb', line 48009 class ImportImageRequest < Struct.new( :architecture, :client_data, :client_token, :description, :disk_containers, :dry_run, :encrypted, :hypervisor, :kms_key_id, :license_type, :platform, :role_name, :license_specifications, :tag_specifications, :usage_operation, :boot_mode) SENSITIVE = [] include Aws::Structure end |
#platform ⇒ String
The operating system of the virtual machine. If you import a VM that is compatible with Unified Extensible Firmware Interface (UEFI) using an EBS snapshot, you must specify a value for the platform.
Valid values: ‘Windows` | `Linux`
48009 48010 48011 48012 48013 48014 48015 48016 48017 48018 48019 48020 48021 48022 48023 48024 48025 48026 48027 48028 |
# File 'lib/aws-sdk-ec2/types.rb', line 48009 class ImportImageRequest < Struct.new( :architecture, :client_data, :client_token, :description, :disk_containers, :dry_run, :encrypted, :hypervisor, :kms_key_id, :license_type, :platform, :role_name, :license_specifications, :tag_specifications, :usage_operation, :boot_mode) SENSITIVE = [] include Aws::Structure end |
#role_name ⇒ String
The name of the role to use when not using the default role, ‘vmimport’.
48009 48010 48011 48012 48013 48014 48015 48016 48017 48018 48019 48020 48021 48022 48023 48024 48025 48026 48027 48028 |
# File 'lib/aws-sdk-ec2/types.rb', line 48009 class ImportImageRequest < Struct.new( :architecture, :client_data, :client_token, :description, :disk_containers, :dry_run, :encrypted, :hypervisor, :kms_key_id, :license_type, :platform, :role_name, :license_specifications, :tag_specifications, :usage_operation, :boot_mode) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the import image task during creation.
48009 48010 48011 48012 48013 48014 48015 48016 48017 48018 48019 48020 48021 48022 48023 48024 48025 48026 48027 48028 |
# File 'lib/aws-sdk-ec2/types.rb', line 48009 class ImportImageRequest < Struct.new( :architecture, :client_data, :client_token, :description, :disk_containers, :dry_run, :encrypted, :hypervisor, :kms_key_id, :license_type, :platform, :role_name, :license_specifications, :tag_specifications, :usage_operation, :boot_mode) SENSITIVE = [] include Aws::Structure end |
#usage_operation ⇒ String
The usage operation value. For more information, see [Licensing options] in the *VM Import/Export User Guide*.
[1]: docs.aws.amazon.com/vm-import/latest/userguide/vmie_prereqs.html#prerequisites
48009 48010 48011 48012 48013 48014 48015 48016 48017 48018 48019 48020 48021 48022 48023 48024 48025 48026 48027 48028 |
# File 'lib/aws-sdk-ec2/types.rb', line 48009 class ImportImageRequest < Struct.new( :architecture, :client_data, :client_token, :description, :disk_containers, :dry_run, :encrypted, :hypervisor, :kms_key_id, :license_type, :platform, :role_name, :license_specifications, :tag_specifications, :usage_operation, :boot_mode) SENSITIVE = [] include Aws::Structure end |