Class: Aws::EC2::Types::InstanceIpv6Address
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::InstanceIpv6Address
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes an IPv6 address.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ipv_6_address ⇒ String
The IPv6 address.
-
#is_primary_ipv_6 ⇒ Boolean
Determines if an IPv6 address associated with a network interface is the primary IPv6 address.
Instance Attribute Details
#ipv_6_address ⇒ String
The IPv6 address.
54265 54266 54267 54268 54269 54270 |
# File 'lib/aws-sdk-ec2/types.rb', line 54265 class InstanceIpv6Address < Struct.new( :ipv_6_address, :is_primary_ipv_6) SENSITIVE = [] include Aws::Structure end |
#is_primary_ipv_6 ⇒ Boolean
Determines if an IPv6 address associated with a network interface is the primary IPv6 address. When you enable an IPv6 GUA address to be a primary IPv6, the first IPv6 GUA will be made the primary IPv6 address until the instance is terminated or the network interface is detached. For more information, see RunInstances.
54265 54266 54267 54268 54269 54270 |
# File 'lib/aws-sdk-ec2/types.rb', line 54265 class InstanceIpv6Address < Struct.new( :ipv_6_address, :is_primary_ipv_6) SENSITIVE = [] include Aws::Structure end |