Class: Aws::EC2::Types::InstanceMetadataDefaultsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::InstanceMetadataDefaultsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
The default instance metadata service (IMDS) settings that were set at the account level in the specified Amazon Web Services Region.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#http_endpoint ⇒ String
Indicates whether the IMDS endpoint for an instance is enabled or disabled.
-
#http_put_response_hop_limit ⇒ Integer
The maximum number of hops that the metadata token can travel.
-
#http_tokens ⇒ String
Indicates whether IMDSv2 is required.
-
#http_tokens_enforced ⇒ String
Indicates whether to enforce the requirement of IMDSv2 on an instance at the time of launch.
-
#instance_metadata_tags ⇒ String
Indicates whether access to instance tags from the instance metadata is enabled or disabled.
-
#managed_by ⇒ String
The entity that manages the IMDS default settings.
-
#managed_exception_message ⇒ String
The customized exception message that is specified in the declarative policy.
Instance Attribute Details
#http_endpoint ⇒ String
Indicates whether the IMDS endpoint for an instance is enabled or disabled. When disabled, the instance metadata can’t be accessed.
50828 50829 50830 50831 50832 50833 50834 50835 50836 50837 50838 |
# File 'lib/aws-sdk-ec2/types.rb', line 50828 class InstanceMetadataDefaultsResponse < Struct.new( :http_tokens, :http_put_response_hop_limit, :http_endpoint, :instance_metadata_tags, :managed_by, :managed_exception_message, :http_tokens_enforced) SENSITIVE = [] include Aws::Structure end |
#http_put_response_hop_limit ⇒ Integer
The maximum number of hops that the metadata token can travel.
50828 50829 50830 50831 50832 50833 50834 50835 50836 50837 50838 |
# File 'lib/aws-sdk-ec2/types.rb', line 50828 class InstanceMetadataDefaultsResponse < Struct.new( :http_tokens, :http_put_response_hop_limit, :http_endpoint, :instance_metadata_tags, :managed_by, :managed_exception_message, :http_tokens_enforced) SENSITIVE = [] include Aws::Structure end |
#http_tokens ⇒ String
Indicates whether IMDSv2 is required.
-
‘optional` – IMDSv2 is optional, which means that you can use either IMDSv2 or IMDSv1.
-
‘required` – IMDSv2 is required, which means that IMDSv1 is disabled, and you must use IMDSv2.
50828 50829 50830 50831 50832 50833 50834 50835 50836 50837 50838 |
# File 'lib/aws-sdk-ec2/types.rb', line 50828 class InstanceMetadataDefaultsResponse < Struct.new( :http_tokens, :http_put_response_hop_limit, :http_endpoint, :instance_metadata_tags, :managed_by, :managed_exception_message, :http_tokens_enforced) SENSITIVE = [] include Aws::Structure end |
#http_tokens_enforced ⇒ String
Indicates whether to enforce the requirement of IMDSv2 on an instance at the time of launch. When enforcement is enabled, the instance can’t launch unless IMDSv2 (‘HttpTokens`) is set to `required`.
50828 50829 50830 50831 50832 50833 50834 50835 50836 50837 50838 |
# File 'lib/aws-sdk-ec2/types.rb', line 50828 class InstanceMetadataDefaultsResponse < Struct.new( :http_tokens, :http_put_response_hop_limit, :http_endpoint, :instance_metadata_tags, :managed_by, :managed_exception_message, :http_tokens_enforced) SENSITIVE = [] include Aws::Structure end |
#instance_metadata_tags ⇒ String
Indicates whether access to instance tags from the instance metadata is enabled or disabled. For more information, see [View tags for your EC2 instances using instance metadata] in the *Amazon EC2 User Guide*.
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/work-with-tags-in-IMDS.html
50828 50829 50830 50831 50832 50833 50834 50835 50836 50837 50838 |
# File 'lib/aws-sdk-ec2/types.rb', line 50828 class InstanceMetadataDefaultsResponse < Struct.new( :http_tokens, :http_put_response_hop_limit, :http_endpoint, :instance_metadata_tags, :managed_by, :managed_exception_message, :http_tokens_enforced) SENSITIVE = [] include Aws::Structure end |
#managed_by ⇒ String
The entity that manages the IMDS default settings. Possible values include:
-
‘account` - The IMDS default settings are managed by the account.
-
‘declarative-policy` - The IMDS default settings are managed by a declarative policy and can’t be modified by the account.
50828 50829 50830 50831 50832 50833 50834 50835 50836 50837 50838 |
# File 'lib/aws-sdk-ec2/types.rb', line 50828 class InstanceMetadataDefaultsResponse < Struct.new( :http_tokens, :http_put_response_hop_limit, :http_endpoint, :instance_metadata_tags, :managed_by, :managed_exception_message, :http_tokens_enforced) SENSITIVE = [] include Aws::Structure end |
#managed_exception_message ⇒ String
The customized exception message that is specified in the declarative policy.
50828 50829 50830 50831 50832 50833 50834 50835 50836 50837 50838 |
# File 'lib/aws-sdk-ec2/types.rb', line 50828 class InstanceMetadataDefaultsResponse < Struct.new( :http_tokens, :http_put_response_hop_limit, :http_endpoint, :instance_metadata_tags, :managed_by, :managed_exception_message, :http_tokens_enforced) SENSITIVE = [] include Aws::Structure end |