Class: Aws::EC2::Types::InstanceMetadataOptionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::InstanceMetadataOptionsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
The metadata options for the instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#http_endpoint ⇒ String
Indicates whether the HTTP metadata endpoint on your instances is enabled or disabled.
-
#http_protocol_ipv_6 ⇒ String
Indicates whether the IPv6 endpoint for the instance metadata service is enabled or disabled.
-
#http_put_response_hop_limit ⇒ Integer
The maximum number of hops that the metadata token can travel.
-
#http_tokens ⇒ String
Indicates whether IMDSv2 is required.
-
#instance_metadata_tags ⇒ String
Indicates whether access to instance tags from the instance metadata is enabled or disabled.
-
#state ⇒ String
The state of the metadata option changes.
Instance Attribute Details
#http_endpoint ⇒ String
Indicates whether the HTTP metadata endpoint on your instances is enabled or disabled.
If the value is disabled, you cannot access your instance
metadata.
54557 54558 54559 54560 54561 54562 54563 54564 54565 54566 |
# File 'lib/aws-sdk-ec2/types.rb', line 54557 class InstanceMetadataOptionsResponse < Struct.new( :state, :http_tokens, :http_put_response_hop_limit, :http_endpoint, :http_protocol_ipv_6, :instance_metadata_tags) SENSITIVE = [] include Aws::Structure end |
#http_protocol_ipv_6 ⇒ String
Indicates whether the IPv6 endpoint for the instance metadata service is enabled or disabled.
Default: disabled
54557 54558 54559 54560 54561 54562 54563 54564 54565 54566 |
# File 'lib/aws-sdk-ec2/types.rb', line 54557 class InstanceMetadataOptionsResponse < Struct.new( :state, :http_tokens, :http_put_response_hop_limit, :http_endpoint, :http_protocol_ipv_6, :instance_metadata_tags) SENSITIVE = [] include Aws::Structure end |
#http_put_response_hop_limit ⇒ Integer
The maximum number of hops that the metadata token can travel.
Possible values: Integers from 1 to 64
54557 54558 54559 54560 54561 54562 54563 54564 54565 54566 |
# File 'lib/aws-sdk-ec2/types.rb', line 54557 class InstanceMetadataOptionsResponse < Struct.new( :state, :http_tokens, :http_put_response_hop_limit, :http_endpoint, :http_protocol_ipv_6, :instance_metadata_tags) SENSITIVE = [] include Aws::Structure end |
#http_tokens ⇒ String
Indicates whether IMDSv2 is required.
-
optional- IMDSv2 is optional, which means that you can use either IMDSv2 or IMDSv1. -
required- IMDSv2 is required, which means that IMDSv1 is disabled, and you must use IMDSv2.
54557 54558 54559 54560 54561 54562 54563 54564 54565 54566 |
# File 'lib/aws-sdk-ec2/types.rb', line 54557 class InstanceMetadataOptionsResponse < Struct.new( :state, :http_tokens, :http_put_response_hop_limit, :http_endpoint, :http_protocol_ipv_6, :instance_metadata_tags) SENSITIVE = [] include Aws::Structure end |
#instance_metadata_tags ⇒ String
Indicates whether access to instance tags from the instance metadata is enabled or disabled. For more information, see View tags for your EC2 instances using instance metadata.
54557 54558 54559 54560 54561 54562 54563 54564 54565 54566 |
# File 'lib/aws-sdk-ec2/types.rb', line 54557 class InstanceMetadataOptionsResponse < Struct.new( :state, :http_tokens, :http_put_response_hop_limit, :http_endpoint, :http_protocol_ipv_6, :instance_metadata_tags) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the metadata option changes.
pending - The metadata options are being updated and the instance
is not ready to process metadata traffic with the new selection.
applied - The metadata options have been successfully applied on
the instance.
54557 54558 54559 54560 54561 54562 54563 54564 54565 54566 |
# File 'lib/aws-sdk-ec2/types.rb', line 54557 class InstanceMetadataOptionsResponse < Struct.new( :state, :http_tokens, :http_put_response_hop_limit, :http_endpoint, :http_protocol_ipv_6, :instance_metadata_tags) SENSITIVE = [] include Aws::Structure end |