Class: Aws::EC2::Types::InstanceNetworkInterfaceAttachment

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes a network interface attachment.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attach_timeTime

The time stamp when the attachment initiated.

Returns:

  • (Time)


50478
50479
50480
50481
50482
50483
50484
50485
50486
50487
50488
50489
# File 'lib/aws-sdk-ec2/types.rb', line 50478

class InstanceNetworkInterfaceAttachment < Struct.new(
  :attach_time,
  :attachment_id,
  :delete_on_termination,
  :device_index,
  :status,
  :network_card_index,
  :ena_srd_specification,
  :ena_queue_count)
  SENSITIVE = []
  include Aws::Structure
end

#attachment_idString

The ID of the network interface attachment.

Returns:

  • (String)


50478
50479
50480
50481
50482
50483
50484
50485
50486
50487
50488
50489
# File 'lib/aws-sdk-ec2/types.rb', line 50478

class InstanceNetworkInterfaceAttachment < Struct.new(
  :attach_time,
  :attachment_id,
  :delete_on_termination,
  :device_index,
  :status,
  :network_card_index,
  :ena_srd_specification,
  :ena_queue_count)
  SENSITIVE = []
  include Aws::Structure
end

#delete_on_terminationBoolean

Indicates whether the network interface is deleted when the instance is terminated.

Returns:

  • (Boolean)


50478
50479
50480
50481
50482
50483
50484
50485
50486
50487
50488
50489
# File 'lib/aws-sdk-ec2/types.rb', line 50478

class InstanceNetworkInterfaceAttachment < Struct.new(
  :attach_time,
  :attachment_id,
  :delete_on_termination,
  :device_index,
  :status,
  :network_card_index,
  :ena_srd_specification,
  :ena_queue_count)
  SENSITIVE = []
  include Aws::Structure
end

#device_indexInteger

The index of the device on the instance for the network interface attachment.

Returns:

  • (Integer)


50478
50479
50480
50481
50482
50483
50484
50485
50486
50487
50488
50489
# File 'lib/aws-sdk-ec2/types.rb', line 50478

class InstanceNetworkInterfaceAttachment < Struct.new(
  :attach_time,
  :attachment_id,
  :delete_on_termination,
  :device_index,
  :status,
  :network_card_index,
  :ena_srd_specification,
  :ena_queue_count)
  SENSITIVE = []
  include Aws::Structure
end

#ena_queue_countInteger

The number of ENA queues created with the instance.

Returns:

  • (Integer)


50478
50479
50480
50481
50482
50483
50484
50485
50486
50487
50488
50489
# File 'lib/aws-sdk-ec2/types.rb', line 50478

class InstanceNetworkInterfaceAttachment < Struct.new(
  :attach_time,
  :attachment_id,
  :delete_on_termination,
  :device_index,
  :status,
  :network_card_index,
  :ena_srd_specification,
  :ena_queue_count)
  SENSITIVE = []
  include Aws::Structure
end

#ena_srd_specificationTypes::InstanceAttachmentEnaSrdSpecification

Contains the ENA Express settings for the network interface that’s attached to the instance.



50478
50479
50480
50481
50482
50483
50484
50485
50486
50487
50488
50489
# File 'lib/aws-sdk-ec2/types.rb', line 50478

class InstanceNetworkInterfaceAttachment < Struct.new(
  :attach_time,
  :attachment_id,
  :delete_on_termination,
  :device_index,
  :status,
  :network_card_index,
  :ena_srd_specification,
  :ena_queue_count)
  SENSITIVE = []
  include Aws::Structure
end

#network_card_indexInteger

The index of the network card.

Returns:

  • (Integer)


50478
50479
50480
50481
50482
50483
50484
50485
50486
50487
50488
50489
# File 'lib/aws-sdk-ec2/types.rb', line 50478

class InstanceNetworkInterfaceAttachment < Struct.new(
  :attach_time,
  :attachment_id,
  :delete_on_termination,
  :device_index,
  :status,
  :network_card_index,
  :ena_srd_specification,
  :ena_queue_count)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The attachment state.

Returns:

  • (String)


50478
50479
50480
50481
50482
50483
50484
50485
50486
50487
50488
50489
# File 'lib/aws-sdk-ec2/types.rb', line 50478

class InstanceNetworkInterfaceAttachment < Struct.new(
  :attach_time,
  :attachment_id,
  :delete_on_termination,
  :device_index,
  :status,
  :network_card_index,
  :ena_srd_specification,
  :ena_queue_count)
  SENSITIVE = []
  include Aws::Structure
end