Class: Aws::EC2::Types::InstanceSpecification
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::InstanceSpecification
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
The instance details to specify which volumes should be snapshotted.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#exclude_boot_volume ⇒ Boolean
Excludes the root volume from being snapshotted.
-
#exclude_data_volume_ids ⇒ Array<String>
The IDs of the data (non-root) volumes to exclude from the multi-volume snapshot set.
-
#instance_id ⇒ String
The instance to specify which volumes should be snapshotted.
Instance Attribute Details
#exclude_boot_volume ⇒ Boolean
Excludes the root volume from being snapshotted.
55526 55527 55528 55529 55530 55531 55532 |
# File 'lib/aws-sdk-ec2/types.rb', line 55526 class InstanceSpecification < Struct.new( :instance_id, :exclude_boot_volume, :exclude_data_volume_ids) SENSITIVE = [] include Aws::Structure end |
#exclude_data_volume_ids ⇒ Array<String>
The IDs of the data (non-root) volumes to exclude from the multi-volume snapshot set. If you specify the ID of the root volume, the request fails. To exclude the root volume, use ExcludeBootVolume.
You can specify up to 40 volume IDs per request.
55526 55527 55528 55529 55530 55531 55532 |
# File 'lib/aws-sdk-ec2/types.rb', line 55526 class InstanceSpecification < Struct.new( :instance_id, :exclude_boot_volume, :exclude_data_volume_ids) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The instance to specify which volumes should be snapshotted.
55526 55527 55528 55529 55530 55531 55532 |
# File 'lib/aws-sdk-ec2/types.rb', line 55526 class InstanceSpecification < Struct.new( :instance_id, :exclude_boot_volume, :exclude_data_volume_ids) SENSITIVE = [] include Aws::Structure end |