Class: Aws::EC2::Types::InstanceTypeOffering

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

The instance types offered.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_typeString

The instance type. For more information, see Instance types in the Amazon EC2 User Guide.

Returns:

  • (String)


54377
54378
54379
54380
54381
54382
54383
# File 'lib/aws-sdk-ec2/types.rb', line 54377

class InstanceTypeOffering < Struct.new(
  :instance_type,
  :location_type,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#locationString

The identifier for the location. This depends on the location type. For example, if the location type is region, the location is the Region code (for example, us-east-2.)

Returns:

  • (String)


54377
54378
54379
54380
54381
54382
54383
# File 'lib/aws-sdk-ec2/types.rb', line 54377

class InstanceTypeOffering < Struct.new(
  :instance_type,
  :location_type,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#location_typeString

The location type.

Returns:

  • (String)


54377
54378
54379
54380
54381
54382
54383
# File 'lib/aws-sdk-ec2/types.rb', line 54377

class InstanceTypeOffering < Struct.new(
  :instance_type,
  :location_type,
  :location)
  SENSITIVE = []
  include Aws::Structure
end