Class: Aws::EC2::Types::Ipam
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::Ipam
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
IPAM is a VPC feature that you can use to automate your IP address management workflows including assigning, tracking, troubleshooting, and auditing IP addresses across Amazon Web Services Regions and accounts throughout your Amazon Web Services Organization. For more information, see [What is IPAM?] in the *Amazon VPC IPAM User Guide*.
[1]: docs.aws.amazon.com/vpc/latest/ipam/what-is-it-ipam.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#default_resource_discovery_association_id ⇒ String
The IPAM’s default resource discovery association ID.
-
#default_resource_discovery_id ⇒ String
The IPAM’s default resource discovery ID.
-
#description ⇒ String
The description for the IPAM.
-
#enable_private_gua ⇒ Boolean
Enable this option to use your own GUA ranges as private IPv6 addresses.
-
#ipam_arn ⇒ String
The Amazon Resource Name (ARN) of the IPAM.
-
#ipam_id ⇒ String
The ID of the IPAM.
-
#ipam_region ⇒ String
The Amazon Web Services Region of the IPAM.
-
#metered_account ⇒ String
A metered account is an Amazon Web Services account that is charged for active IP addresses managed in IPAM.
-
#operating_regions ⇒ Array<Types::IpamOperatingRegion>
The operating Regions for an IPAM.
-
#owner_id ⇒ String
The Amazon Web Services account ID of the owner of the IPAM.
-
#private_default_scope_id ⇒ String
The ID of the IPAM’s default private scope.
-
#public_default_scope_id ⇒ String
The ID of the IPAM’s default public scope.
-
#resource_discovery_association_count ⇒ Integer
The IPAM’s resource discovery association count.
-
#scope_count ⇒ Integer
The number of scopes in the IPAM.
-
#state ⇒ String
The state of the IPAM.
-
#state_message ⇒ String
The state message.
-
#tags ⇒ Array<Types::Tag>
The key/value combination of a tag assigned to the resource.
-
#tier ⇒ String
IPAM is offered in a Free Tier and an Advanced Tier.
Instance Attribute Details
#default_resource_discovery_association_id ⇒ String
The IPAM’s default resource discovery association ID.
54758 54759 54760 54761 54762 54763 54764 54765 54766 54767 54768 54769 54770 54771 54772 54773 54774 54775 54776 54777 54778 54779 |
# File 'lib/aws-sdk-ec2/types.rb', line 54758 class Ipam < Struct.new( :owner_id, :ipam_id, :ipam_arn, :ipam_region, :public_default_scope_id, :private_default_scope_id, :scope_count, :description, :operating_regions, :state, :tags, :default_resource_discovery_id, :default_resource_discovery_association_id, :resource_discovery_association_count, :state_message, :tier, :enable_private_gua, :metered_account) SENSITIVE = [] include Aws::Structure end |
#default_resource_discovery_id ⇒ String
The IPAM’s default resource discovery ID.
54758 54759 54760 54761 54762 54763 54764 54765 54766 54767 54768 54769 54770 54771 54772 54773 54774 54775 54776 54777 54778 54779 |
# File 'lib/aws-sdk-ec2/types.rb', line 54758 class Ipam < Struct.new( :owner_id, :ipam_id, :ipam_arn, :ipam_region, :public_default_scope_id, :private_default_scope_id, :scope_count, :description, :operating_regions, :state, :tags, :default_resource_discovery_id, :default_resource_discovery_association_id, :resource_discovery_association_count, :state_message, :tier, :enable_private_gua, :metered_account) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description for the IPAM.
54758 54759 54760 54761 54762 54763 54764 54765 54766 54767 54768 54769 54770 54771 54772 54773 54774 54775 54776 54777 54778 54779 |
# File 'lib/aws-sdk-ec2/types.rb', line 54758 class Ipam < Struct.new( :owner_id, :ipam_id, :ipam_arn, :ipam_region, :public_default_scope_id, :private_default_scope_id, :scope_count, :description, :operating_regions, :state, :tags, :default_resource_discovery_id, :default_resource_discovery_association_id, :resource_discovery_association_count, :state_message, :tier, :enable_private_gua, :metered_account) SENSITIVE = [] include Aws::Structure end |
#enable_private_gua ⇒ Boolean
Enable this option to use your own GUA ranges as private IPv6 addresses. This option is disabled by default.
54758 54759 54760 54761 54762 54763 54764 54765 54766 54767 54768 54769 54770 54771 54772 54773 54774 54775 54776 54777 54778 54779 |
# File 'lib/aws-sdk-ec2/types.rb', line 54758 class Ipam < Struct.new( :owner_id, :ipam_id, :ipam_arn, :ipam_region, :public_default_scope_id, :private_default_scope_id, :scope_count, :description, :operating_regions, :state, :tags, :default_resource_discovery_id, :default_resource_discovery_association_id, :resource_discovery_association_count, :state_message, :tier, :enable_private_gua, :metered_account) SENSITIVE = [] include Aws::Structure end |
#ipam_arn ⇒ String
The Amazon Resource Name (ARN) of the IPAM.
54758 54759 54760 54761 54762 54763 54764 54765 54766 54767 54768 54769 54770 54771 54772 54773 54774 54775 54776 54777 54778 54779 |
# File 'lib/aws-sdk-ec2/types.rb', line 54758 class Ipam < Struct.new( :owner_id, :ipam_id, :ipam_arn, :ipam_region, :public_default_scope_id, :private_default_scope_id, :scope_count, :description, :operating_regions, :state, :tags, :default_resource_discovery_id, :default_resource_discovery_association_id, :resource_discovery_association_count, :state_message, :tier, :enable_private_gua, :metered_account) SENSITIVE = [] include Aws::Structure end |
#ipam_id ⇒ String
The ID of the IPAM.
54758 54759 54760 54761 54762 54763 54764 54765 54766 54767 54768 54769 54770 54771 54772 54773 54774 54775 54776 54777 54778 54779 |
# File 'lib/aws-sdk-ec2/types.rb', line 54758 class Ipam < Struct.new( :owner_id, :ipam_id, :ipam_arn, :ipam_region, :public_default_scope_id, :private_default_scope_id, :scope_count, :description, :operating_regions, :state, :tags, :default_resource_discovery_id, :default_resource_discovery_association_id, :resource_discovery_association_count, :state_message, :tier, :enable_private_gua, :metered_account) SENSITIVE = [] include Aws::Structure end |
#ipam_region ⇒ String
The Amazon Web Services Region of the IPAM.
54758 54759 54760 54761 54762 54763 54764 54765 54766 54767 54768 54769 54770 54771 54772 54773 54774 54775 54776 54777 54778 54779 |
# File 'lib/aws-sdk-ec2/types.rb', line 54758 class Ipam < Struct.new( :owner_id, :ipam_id, :ipam_arn, :ipam_region, :public_default_scope_id, :private_default_scope_id, :scope_count, :description, :operating_regions, :state, :tags, :default_resource_discovery_id, :default_resource_discovery_association_id, :resource_discovery_association_count, :state_message, :tier, :enable_private_gua, :metered_account) SENSITIVE = [] include Aws::Structure end |
#metered_account ⇒ String
A metered account is an Amazon Web Services account that is charged for active IP addresses managed in IPAM. For more information, see
- Enable cost distribution][1
-
in the *Amazon VPC IPAM User Guide*.
Possible values:
-
‘ipam-owner` (default): The Amazon Web Services account which owns the IPAM is charged for all active IP addresses managed in IPAM.
-
‘resource-owner`: The Amazon Web Services account that owns the IP address is charged for the active IP address.
[1]: docs.aws.amazon.com/vpc/latest/ipam/ipam-enable-cost-distro.html
54758 54759 54760 54761 54762 54763 54764 54765 54766 54767 54768 54769 54770 54771 54772 54773 54774 54775 54776 54777 54778 54779 |
# File 'lib/aws-sdk-ec2/types.rb', line 54758 class Ipam < Struct.new( :owner_id, :ipam_id, :ipam_arn, :ipam_region, :public_default_scope_id, :private_default_scope_id, :scope_count, :description, :operating_regions, :state, :tags, :default_resource_discovery_id, :default_resource_discovery_association_id, :resource_discovery_association_count, :state_message, :tier, :enable_private_gua, :metered_account) SENSITIVE = [] include Aws::Structure end |
#operating_regions ⇒ Array<Types::IpamOperatingRegion>
The operating Regions for an IPAM. Operating Regions are Amazon Web Services Regions where the IPAM is allowed to manage IP address CIDRs. IPAM only discovers and monitors resources in the Amazon Web Services Regions you select as operating Regions.
For more information about operating Regions, see [Create an IPAM] in the *Amazon VPC IPAM User Guide*.
54758 54759 54760 54761 54762 54763 54764 54765 54766 54767 54768 54769 54770 54771 54772 54773 54774 54775 54776 54777 54778 54779 |
# File 'lib/aws-sdk-ec2/types.rb', line 54758 class Ipam < Struct.new( :owner_id, :ipam_id, :ipam_arn, :ipam_region, :public_default_scope_id, :private_default_scope_id, :scope_count, :description, :operating_regions, :state, :tags, :default_resource_discovery_id, :default_resource_discovery_association_id, :resource_discovery_association_count, :state_message, :tier, :enable_private_gua, :metered_account) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
The Amazon Web Services account ID of the owner of the IPAM.
54758 54759 54760 54761 54762 54763 54764 54765 54766 54767 54768 54769 54770 54771 54772 54773 54774 54775 54776 54777 54778 54779 |
# File 'lib/aws-sdk-ec2/types.rb', line 54758 class Ipam < Struct.new( :owner_id, :ipam_id, :ipam_arn, :ipam_region, :public_default_scope_id, :private_default_scope_id, :scope_count, :description, :operating_regions, :state, :tags, :default_resource_discovery_id, :default_resource_discovery_association_id, :resource_discovery_association_count, :state_message, :tier, :enable_private_gua, :metered_account) SENSITIVE = [] include Aws::Structure end |
#private_default_scope_id ⇒ String
The ID of the IPAM’s default private scope.
54758 54759 54760 54761 54762 54763 54764 54765 54766 54767 54768 54769 54770 54771 54772 54773 54774 54775 54776 54777 54778 54779 |
# File 'lib/aws-sdk-ec2/types.rb', line 54758 class Ipam < Struct.new( :owner_id, :ipam_id, :ipam_arn, :ipam_region, :public_default_scope_id, :private_default_scope_id, :scope_count, :description, :operating_regions, :state, :tags, :default_resource_discovery_id, :default_resource_discovery_association_id, :resource_discovery_association_count, :state_message, :tier, :enable_private_gua, :metered_account) SENSITIVE = [] include Aws::Structure end |
#public_default_scope_id ⇒ String
The ID of the IPAM’s default public scope.
54758 54759 54760 54761 54762 54763 54764 54765 54766 54767 54768 54769 54770 54771 54772 54773 54774 54775 54776 54777 54778 54779 |
# File 'lib/aws-sdk-ec2/types.rb', line 54758 class Ipam < Struct.new( :owner_id, :ipam_id, :ipam_arn, :ipam_region, :public_default_scope_id, :private_default_scope_id, :scope_count, :description, :operating_regions, :state, :tags, :default_resource_discovery_id, :default_resource_discovery_association_id, :resource_discovery_association_count, :state_message, :tier, :enable_private_gua, :metered_account) SENSITIVE = [] include Aws::Structure end |
#resource_discovery_association_count ⇒ Integer
The IPAM’s resource discovery association count.
54758 54759 54760 54761 54762 54763 54764 54765 54766 54767 54768 54769 54770 54771 54772 54773 54774 54775 54776 54777 54778 54779 |
# File 'lib/aws-sdk-ec2/types.rb', line 54758 class Ipam < Struct.new( :owner_id, :ipam_id, :ipam_arn, :ipam_region, :public_default_scope_id, :private_default_scope_id, :scope_count, :description, :operating_regions, :state, :tags, :default_resource_discovery_id, :default_resource_discovery_association_id, :resource_discovery_association_count, :state_message, :tier, :enable_private_gua, :metered_account) SENSITIVE = [] include Aws::Structure end |
#scope_count ⇒ Integer
The number of scopes in the IPAM. The scope quota is 5. For more information on quotas, see [Quotas in IPAM] in the *Amazon VPC IPAM User Guide*.
54758 54759 54760 54761 54762 54763 54764 54765 54766 54767 54768 54769 54770 54771 54772 54773 54774 54775 54776 54777 54778 54779 |
# File 'lib/aws-sdk-ec2/types.rb', line 54758 class Ipam < Struct.new( :owner_id, :ipam_id, :ipam_arn, :ipam_region, :public_default_scope_id, :private_default_scope_id, :scope_count, :description, :operating_regions, :state, :tags, :default_resource_discovery_id, :default_resource_discovery_association_id, :resource_discovery_association_count, :state_message, :tier, :enable_private_gua, :metered_account) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the IPAM.
54758 54759 54760 54761 54762 54763 54764 54765 54766 54767 54768 54769 54770 54771 54772 54773 54774 54775 54776 54777 54778 54779 |
# File 'lib/aws-sdk-ec2/types.rb', line 54758 class Ipam < Struct.new( :owner_id, :ipam_id, :ipam_arn, :ipam_region, :public_default_scope_id, :private_default_scope_id, :scope_count, :description, :operating_regions, :state, :tags, :default_resource_discovery_id, :default_resource_discovery_association_id, :resource_discovery_association_count, :state_message, :tier, :enable_private_gua, :metered_account) SENSITIVE = [] include Aws::Structure end |
#state_message ⇒ String
The state message.
54758 54759 54760 54761 54762 54763 54764 54765 54766 54767 54768 54769 54770 54771 54772 54773 54774 54775 54776 54777 54778 54779 |
# File 'lib/aws-sdk-ec2/types.rb', line 54758 class Ipam < Struct.new( :owner_id, :ipam_id, :ipam_arn, :ipam_region, :public_default_scope_id, :private_default_scope_id, :scope_count, :description, :operating_regions, :state, :tags, :default_resource_discovery_id, :default_resource_discovery_association_id, :resource_discovery_association_count, :state_message, :tier, :enable_private_gua, :metered_account) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key ‘Owner` and the value `TeamA`, specify `tag:Owner` for the filter name and `TeamA` for the filter value.
54758 54759 54760 54761 54762 54763 54764 54765 54766 54767 54768 54769 54770 54771 54772 54773 54774 54775 54776 54777 54778 54779 |
# File 'lib/aws-sdk-ec2/types.rb', line 54758 class Ipam < Struct.new( :owner_id, :ipam_id, :ipam_arn, :ipam_region, :public_default_scope_id, :private_default_scope_id, :scope_count, :description, :operating_regions, :state, :tags, :default_resource_discovery_id, :default_resource_discovery_association_id, :resource_discovery_association_count, :state_message, :tier, :enable_private_gua, :metered_account) SENSITIVE = [] include Aws::Structure end |
#tier ⇒ String
IPAM is offered in a Free Tier and an Advanced Tier. For more information about the features available in each tier and the costs associated with the tiers, see [Amazon VPC pricing > IPAM tab].
54758 54759 54760 54761 54762 54763 54764 54765 54766 54767 54768 54769 54770 54771 54772 54773 54774 54775 54776 54777 54778 54779 |
# File 'lib/aws-sdk-ec2/types.rb', line 54758 class Ipam < Struct.new( :owner_id, :ipam_id, :ipam_arn, :ipam_region, :public_default_scope_id, :private_default_scope_id, :scope_count, :description, :operating_regions, :state, :tags, :default_resource_discovery_id, :default_resource_discovery_association_id, :resource_discovery_association_count, :state_message, :tier, :enable_private_gua, :metered_account) SENSITIVE = [] include Aws::Structure end |