Class: Aws::EC2::Types::IpamExternalResourceVerificationToken

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

A verification token is an Amazon Web Services-generated random value that you can use to prove ownership of an external resource. For example, you can use a verification token to validate that you control a public IP address range when you bring an IP address range to Amazon Web Services (BYOIP).

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ipam_arnString

ARN of the IPAM that created the token.

Returns:

  • (String)


57973
57974
57975
57976
57977
57978
57979
57980
57981
57982
57983
57984
57985
57986
57987
# File 'lib/aws-sdk-ec2/types.rb', line 57973

class IpamExternalResourceVerificationToken < Struct.new(
  :ipam_external_resource_verification_token_id,
  :ipam_external_resource_verification_token_arn,
  :ipam_id,
  :ipam_arn,
  :ipam_region,
  :token_value,
  :token_name,
  :not_after,
  :status,
  :tags,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_external_resource_verification_token_arnString

Token ARN.

Returns:

  • (String)


57973
57974
57975
57976
57977
57978
57979
57980
57981
57982
57983
57984
57985
57986
57987
# File 'lib/aws-sdk-ec2/types.rb', line 57973

class IpamExternalResourceVerificationToken < Struct.new(
  :ipam_external_resource_verification_token_id,
  :ipam_external_resource_verification_token_arn,
  :ipam_id,
  :ipam_arn,
  :ipam_region,
  :token_value,
  :token_name,
  :not_after,
  :status,
  :tags,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_external_resource_verification_token_idString

The ID of the token.

Returns:

  • (String)


57973
57974
57975
57976
57977
57978
57979
57980
57981
57982
57983
57984
57985
57986
57987
# File 'lib/aws-sdk-ec2/types.rb', line 57973

class IpamExternalResourceVerificationToken < Struct.new(
  :ipam_external_resource_verification_token_id,
  :ipam_external_resource_verification_token_arn,
  :ipam_id,
  :ipam_arn,
  :ipam_region,
  :token_value,
  :token_name,
  :not_after,
  :status,
  :tags,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_idString

The ID of the IPAM that created the token.

Returns:

  • (String)


57973
57974
57975
57976
57977
57978
57979
57980
57981
57982
57983
57984
57985
57986
57987
# File 'lib/aws-sdk-ec2/types.rb', line 57973

class IpamExternalResourceVerificationToken < Struct.new(
  :ipam_external_resource_verification_token_id,
  :ipam_external_resource_verification_token_arn,
  :ipam_id,
  :ipam_arn,
  :ipam_region,
  :token_value,
  :token_name,
  :not_after,
  :status,
  :tags,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_regionString

Region of the IPAM that created the token.

Returns:

  • (String)


57973
57974
57975
57976
57977
57978
57979
57980
57981
57982
57983
57984
57985
57986
57987
# File 'lib/aws-sdk-ec2/types.rb', line 57973

class IpamExternalResourceVerificationToken < Struct.new(
  :ipam_external_resource_verification_token_id,
  :ipam_external_resource_verification_token_arn,
  :ipam_id,
  :ipam_arn,
  :ipam_region,
  :token_value,
  :token_name,
  :not_after,
  :status,
  :tags,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#not_afterTime

Token expiration.

Returns:

  • (Time)


57973
57974
57975
57976
57977
57978
57979
57980
57981
57982
57983
57984
57985
57986
57987
# File 'lib/aws-sdk-ec2/types.rb', line 57973

class IpamExternalResourceVerificationToken < Struct.new(
  :ipam_external_resource_verification_token_id,
  :ipam_external_resource_verification_token_arn,
  :ipam_id,
  :ipam_arn,
  :ipam_region,
  :token_value,
  :token_name,
  :not_after,
  :status,
  :tags,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

Token state.

Returns:

  • (String)


57973
57974
57975
57976
57977
57978
57979
57980
57981
57982
57983
57984
57985
57986
57987
# File 'lib/aws-sdk-ec2/types.rb', line 57973

class IpamExternalResourceVerificationToken < Struct.new(
  :ipam_external_resource_verification_token_id,
  :ipam_external_resource_verification_token_arn,
  :ipam_id,
  :ipam_arn,
  :ipam_region,
  :token_value,
  :token_name,
  :not_after,
  :status,
  :tags,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Token status.

Returns:

  • (String)


57973
57974
57975
57976
57977
57978
57979
57980
57981
57982
57983
57984
57985
57986
57987
# File 'lib/aws-sdk-ec2/types.rb', line 57973

class IpamExternalResourceVerificationToken < Struct.new(
  :ipam_external_resource_verification_token_id,
  :ipam_external_resource_verification_token_arn,
  :ipam_id,
  :ipam_arn,
  :ipam_region,
  :token_value,
  :token_name,
  :not_after,
  :status,
  :tags,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Token tags.

Returns:



57973
57974
57975
57976
57977
57978
57979
57980
57981
57982
57983
57984
57985
57986
57987
# File 'lib/aws-sdk-ec2/types.rb', line 57973

class IpamExternalResourceVerificationToken < Struct.new(
  :ipam_external_resource_verification_token_id,
  :ipam_external_resource_verification_token_arn,
  :ipam_id,
  :ipam_arn,
  :ipam_region,
  :token_value,
  :token_name,
  :not_after,
  :status,
  :tags,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#token_nameString

Token name.

Returns:

  • (String)


57973
57974
57975
57976
57977
57978
57979
57980
57981
57982
57983
57984
57985
57986
57987
# File 'lib/aws-sdk-ec2/types.rb', line 57973

class IpamExternalResourceVerificationToken < Struct.new(
  :ipam_external_resource_verification_token_id,
  :ipam_external_resource_verification_token_arn,
  :ipam_id,
  :ipam_arn,
  :ipam_region,
  :token_value,
  :token_name,
  :not_after,
  :status,
  :tags,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#token_valueString

Token value.

Returns:

  • (String)


57973
57974
57975
57976
57977
57978
57979
57980
57981
57982
57983
57984
57985
57986
57987
# File 'lib/aws-sdk-ec2/types.rb', line 57973

class IpamExternalResourceVerificationToken < Struct.new(
  :ipam_external_resource_verification_token_id,
  :ipam_external_resource_verification_token_arn,
  :ipam_id,
  :ipam_arn,
  :ipam_region,
  :token_value,
  :token_name,
  :not_after,
  :status,
  :tags,
  :state)
  SENSITIVE = []
  include Aws::Structure
end