Class: Aws::EC2::Types::IpamInternetRegistryAssociation
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::IpamInternetRegistryAssociation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains information about an association between an IPAM and a Regional Internet Registry (RIR) for delegated RPKI management.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#child_request_xml ⇒ String
The XML content for the child request to be submitted to the internet registry to complete the BPKI setup.
-
#description ⇒ String
The description of the internet registry association.
-
#ipam_id ⇒ String
The ID of the associated IPAM.
-
#ipam_internet_registry_association_arn ⇒ String
The Amazon Resource Name (ARN) of the internet registry association.
-
#ipam_internet_registry_association_id ⇒ String
The ID of the internet registry association.
-
#ipam_region ⇒ String
The Amazon Web Services Region of the IPAM.
-
#organization_handle ⇒ String
The organization handle at the internet registry.
-
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the internet registry association.
-
#rir ⇒ String
The Regional Internet Registry.
-
#state ⇒ String
The state of the internet registry association.
-
#tags ⇒ Array<Types::Tag>
The tags assigned to the internet registry association.
Instance Attribute Details
#child_request_xml ⇒ String
The XML content for the child request to be submitted to the internet registry to complete the BPKI setup.
58022 58023 58024 58025 58026 58027 58028 58029 58030 58031 58032 58033 58034 58035 58036 |
# File 'lib/aws-sdk-ec2/types.rb', line 58022 class IpamInternetRegistryAssociation < Struct.new( :owner_id, :ipam_internet_registry_association_id, :ipam_internet_registry_association_arn, :ipam_id, :ipam_region, :rir, :organization_handle, :description, :state, :child_request_xml, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the internet registry association.
58022 58023 58024 58025 58026 58027 58028 58029 58030 58031 58032 58033 58034 58035 58036 |
# File 'lib/aws-sdk-ec2/types.rb', line 58022 class IpamInternetRegistryAssociation < Struct.new( :owner_id, :ipam_internet_registry_association_id, :ipam_internet_registry_association_arn, :ipam_id, :ipam_region, :rir, :organization_handle, :description, :state, :child_request_xml, :tags) SENSITIVE = [] include Aws::Structure end |
#ipam_id ⇒ String
The ID of the associated IPAM.
58022 58023 58024 58025 58026 58027 58028 58029 58030 58031 58032 58033 58034 58035 58036 |
# File 'lib/aws-sdk-ec2/types.rb', line 58022 class IpamInternetRegistryAssociation < Struct.new( :owner_id, :ipam_internet_registry_association_id, :ipam_internet_registry_association_arn, :ipam_id, :ipam_region, :rir, :organization_handle, :description, :state, :child_request_xml, :tags) SENSITIVE = [] include Aws::Structure end |
#ipam_internet_registry_association_arn ⇒ String
The Amazon Resource Name (ARN) of the internet registry association.
58022 58023 58024 58025 58026 58027 58028 58029 58030 58031 58032 58033 58034 58035 58036 |
# File 'lib/aws-sdk-ec2/types.rb', line 58022 class IpamInternetRegistryAssociation < Struct.new( :owner_id, :ipam_internet_registry_association_id, :ipam_internet_registry_association_arn, :ipam_id, :ipam_region, :rir, :organization_handle, :description, :state, :child_request_xml, :tags) SENSITIVE = [] include Aws::Structure end |
#ipam_internet_registry_association_id ⇒ String
The ID of the internet registry association.
58022 58023 58024 58025 58026 58027 58028 58029 58030 58031 58032 58033 58034 58035 58036 |
# File 'lib/aws-sdk-ec2/types.rb', line 58022 class IpamInternetRegistryAssociation < Struct.new( :owner_id, :ipam_internet_registry_association_id, :ipam_internet_registry_association_arn, :ipam_id, :ipam_region, :rir, :organization_handle, :description, :state, :child_request_xml, :tags) SENSITIVE = [] include Aws::Structure end |
#ipam_region ⇒ String
The Amazon Web Services Region of the IPAM.
58022 58023 58024 58025 58026 58027 58028 58029 58030 58031 58032 58033 58034 58035 58036 |
# File 'lib/aws-sdk-ec2/types.rb', line 58022 class IpamInternetRegistryAssociation < Struct.new( :owner_id, :ipam_internet_registry_association_id, :ipam_internet_registry_association_arn, :ipam_id, :ipam_region, :rir, :organization_handle, :description, :state, :child_request_xml, :tags) SENSITIVE = [] include Aws::Structure end |
#organization_handle ⇒ String
The organization handle at the internet registry.
58022 58023 58024 58025 58026 58027 58028 58029 58030 58031 58032 58033 58034 58035 58036 |
# File 'lib/aws-sdk-ec2/types.rb', line 58022 class IpamInternetRegistryAssociation < Struct.new( :owner_id, :ipam_internet_registry_association_id, :ipam_internet_registry_association_arn, :ipam_id, :ipam_region, :rir, :organization_handle, :description, :state, :child_request_xml, :tags) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the internet registry association.
58022 58023 58024 58025 58026 58027 58028 58029 58030 58031 58032 58033 58034 58035 58036 |
# File 'lib/aws-sdk-ec2/types.rb', line 58022 class IpamInternetRegistryAssociation < Struct.new( :owner_id, :ipam_internet_registry_association_id, :ipam_internet_registry_association_arn, :ipam_id, :ipam_region, :rir, :organization_handle, :description, :state, :child_request_xml, :tags) SENSITIVE = [] include Aws::Structure end |
#rir ⇒ String
The Regional Internet Registry. Possible values:
-
ripe- RIPE NCC (Europe, the Middle East, and Central Asia). -
apnic- APNIC (Asia Pacific). -
arin- ARIN (North America). -
lacnic- LACNIC (Latin America and the Caribbean).
58022 58023 58024 58025 58026 58027 58028 58029 58030 58031 58032 58033 58034 58035 58036 |
# File 'lib/aws-sdk-ec2/types.rb', line 58022 class IpamInternetRegistryAssociation < Struct.new( :owner_id, :ipam_internet_registry_association_id, :ipam_internet_registry_association_arn, :ipam_id, :ipam_region, :rir, :organization_handle, :description, :state, :child_request_xml, :tags) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the internet registry association. Valid values:
pending-activation | pending-enable | create-in-progress |
create-failed | enable-in-progress | enable-complete |
enable-failed | delete-in-progress | delete-complete |
delete-failed.
58022 58023 58024 58025 58026 58027 58028 58029 58030 58031 58032 58033 58034 58035 58036 |
# File 'lib/aws-sdk-ec2/types.rb', line 58022 class IpamInternetRegistryAssociation < Struct.new( :owner_id, :ipam_internet_registry_association_id, :ipam_internet_registry_association_arn, :ipam_id, :ipam_region, :rir, :organization_handle, :description, :state, :child_request_xml, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags assigned to the internet registry association.
58022 58023 58024 58025 58026 58027 58028 58029 58030 58031 58032 58033 58034 58035 58036 |
# File 'lib/aws-sdk-ec2/types.rb', line 58022 class IpamInternetRegistryAssociation < Struct.new( :owner_id, :ipam_internet_registry_association_id, :ipam_internet_registry_association_arn, :ipam_id, :ipam_region, :rir, :organization_handle, :description, :state, :child_request_xml, :tags) SENSITIVE = [] include Aws::Structure end |