Class: Aws::EC2::Types::IpamPolicy

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Information about an IPAM policy.

An IPAM policy is a set of rules that define how public IPv4 addresses from IPAM pools are allocated to Amazon Web Services resources. Each rule maps an Amazon Web Services service to IPAM pools that the service will use to get IP addresses. A single policy can have multiple rules and be applied to multiple Amazon Web Services Regions. If the IPAM pool run out of addresses then the services fallback to Amazon-provided IP addresses. A policy can be applied to an individual Amazon Web Services account or an entity within Amazon Web Services Organizations.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ipam_idString

The ID of the IPAM this policy belongs to.

Returns:

  • (String)


54734
54735
54736
54737
54738
54739
54740
54741
54742
54743
54744
54745
# File 'lib/aws-sdk-ec2/types.rb', line 54734

class IpamPolicy < Struct.new(
  :owner_id,
  :ipam_policy_id,
  :ipam_policy_arn,
  :ipam_policy_region,
  :state,
  :state_message,
  :tags,
  :ipam_id)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_policy_arnString

The Amazon Resource Name (ARN) of the IPAM policy.

Returns:

  • (String)


54734
54735
54736
54737
54738
54739
54740
54741
54742
54743
54744
54745
# File 'lib/aws-sdk-ec2/types.rb', line 54734

class IpamPolicy < Struct.new(
  :owner_id,
  :ipam_policy_id,
  :ipam_policy_arn,
  :ipam_policy_region,
  :state,
  :state_message,
  :tags,
  :ipam_id)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_policy_idString

The ID of the IPAM policy.

Returns:

  • (String)


54734
54735
54736
54737
54738
54739
54740
54741
54742
54743
54744
54745
# File 'lib/aws-sdk-ec2/types.rb', line 54734

class IpamPolicy < Struct.new(
  :owner_id,
  :ipam_policy_id,
  :ipam_policy_arn,
  :ipam_policy_region,
  :state,
  :state_message,
  :tags,
  :ipam_id)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_policy_regionString

The Region of the IPAM policy.

Returns:

  • (String)


54734
54735
54736
54737
54738
54739
54740
54741
54742
54743
54744
54745
# File 'lib/aws-sdk-ec2/types.rb', line 54734

class IpamPolicy < Struct.new(
  :owner_id,
  :ipam_policy_id,
  :ipam_policy_arn,
  :ipam_policy_region,
  :state,
  :state_message,
  :tags,
  :ipam_id)
  SENSITIVE = []
  include Aws::Structure
end

#owner_idString

The account ID that owns the IPAM policy.

Returns:

  • (String)


54734
54735
54736
54737
54738
54739
54740
54741
54742
54743
54744
54745
# File 'lib/aws-sdk-ec2/types.rb', line 54734

class IpamPolicy < Struct.new(
  :owner_id,
  :ipam_policy_id,
  :ipam_policy_arn,
  :ipam_policy_region,
  :state,
  :state_message,
  :tags,
  :ipam_id)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of the IPAM policy.

Returns:

  • (String)


54734
54735
54736
54737
54738
54739
54740
54741
54742
54743
54744
54745
# File 'lib/aws-sdk-ec2/types.rb', line 54734

class IpamPolicy < Struct.new(
  :owner_id,
  :ipam_policy_id,
  :ipam_policy_arn,
  :ipam_policy_region,
  :state,
  :state_message,
  :tags,
  :ipam_id)
  SENSITIVE = []
  include Aws::Structure
end

#state_messageString

A message about the state of the IPAM policy.

Returns:

  • (String)


54734
54735
54736
54737
54738
54739
54740
54741
54742
54743
54744
54745
# File 'lib/aws-sdk-ec2/types.rb', line 54734

class IpamPolicy < Struct.new(
  :owner_id,
  :ipam_policy_id,
  :ipam_policy_arn,
  :ipam_policy_region,
  :state,
  :state_message,
  :tags,
  :ipam_id)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The tags assigned to the IPAM policy.

Returns:



54734
54735
54736
54737
54738
54739
54740
54741
54742
54743
54744
54745
# File 'lib/aws-sdk-ec2/types.rb', line 54734

class IpamPolicy < Struct.new(
  :owner_id,
  :ipam_policy_id,
  :ipam_policy_arn,
  :ipam_policy_region,
  :state,
  :state_message,
  :tags,
  :ipam_id)
  SENSITIVE = []
  include Aws::Structure
end