Class: Aws::EC2::Types::IpamResourceCidr

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

The CIDR for an IPAM resource.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_zone_idString

The Availability Zone ID.

Returns:

  • (String)


56841
56842
56843
56844
56845
56846
56847
56848
56849
56850
56851
56852
56853
56854
56855
56856
56857
56858
56859
56860
# File 'lib/aws-sdk-ec2/types.rb', line 56841

class IpamResourceCidr < Struct.new(
  :ipam_id,
  :ipam_scope_id,
  :ipam_pool_id,
  :resource_region,
  :resource_owner_id,
  :resource_id,
  :resource_name,
  :resource_cidr,
  :resource_type,
  :resource_tags,
  :ip_usage,
  :compliance_status,
  :management_state,
  :overlap_status,
  :vpc_id,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#compliance_statusString

The compliance status of the IPAM resource. For more information on compliance statuses, see Monitor CIDR usage by resource in the Amazon VPC IPAM User Guide.

Returns:

  • (String)


56841
56842
56843
56844
56845
56846
56847
56848
56849
56850
56851
56852
56853
56854
56855
56856
56857
56858
56859
56860
# File 'lib/aws-sdk-ec2/types.rb', line 56841

class IpamResourceCidr < Struct.new(
  :ipam_id,
  :ipam_scope_id,
  :ipam_pool_id,
  :resource_region,
  :resource_owner_id,
  :resource_id,
  :resource_name,
  :resource_cidr,
  :resource_type,
  :resource_tags,
  :ip_usage,
  :compliance_status,
  :management_state,
  :overlap_status,
  :vpc_id,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#ip_usageFloat

The percentage of IP address space in use. To convert the decimal to a percentage, multiply the decimal by 100. Note the following:

  • For resources that are VPCs, this is the percentage of IP address space in the VPC that's taken up by subnet CIDRs.

  • For resources that are subnets, if the subnet has an IPv4 CIDR provisioned to it, this is the percentage of IPv4 address space in the subnet that's in use. If the subnet has an IPv6 CIDR provisioned to it, the percentage of IPv6 address space in use is not represented. The percentage of IPv6 address space in use cannot currently be calculated.

  • For resources that are public IPv4 pools, this is the percentage of IP address space in the pool that's been allocated to Elastic IP addresses (EIPs).

Returns:

  • (Float)


56841
56842
56843
56844
56845
56846
56847
56848
56849
56850
56851
56852
56853
56854
56855
56856
56857
56858
56859
56860
# File 'lib/aws-sdk-ec2/types.rb', line 56841

class IpamResourceCidr < Struct.new(
  :ipam_id,
  :ipam_scope_id,
  :ipam_pool_id,
  :resource_region,
  :resource_owner_id,
  :resource_id,
  :resource_name,
  :resource_cidr,
  :resource_type,
  :resource_tags,
  :ip_usage,
  :compliance_status,
  :management_state,
  :overlap_status,
  :vpc_id,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_idString

The IPAM ID for an IPAM resource.

Returns:

  • (String)


56841
56842
56843
56844
56845
56846
56847
56848
56849
56850
56851
56852
56853
56854
56855
56856
56857
56858
56859
56860
# File 'lib/aws-sdk-ec2/types.rb', line 56841

class IpamResourceCidr < Struct.new(
  :ipam_id,
  :ipam_scope_id,
  :ipam_pool_id,
  :resource_region,
  :resource_owner_id,
  :resource_id,
  :resource_name,
  :resource_cidr,
  :resource_type,
  :resource_tags,
  :ip_usage,
  :compliance_status,
  :management_state,
  :overlap_status,
  :vpc_id,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_pool_idString

The pool ID for an IPAM resource.

Returns:

  • (String)


56841
56842
56843
56844
56845
56846
56847
56848
56849
56850
56851
56852
56853
56854
56855
56856
56857
56858
56859
56860
# File 'lib/aws-sdk-ec2/types.rb', line 56841

class IpamResourceCidr < Struct.new(
  :ipam_id,
  :ipam_scope_id,
  :ipam_pool_id,
  :resource_region,
  :resource_owner_id,
  :resource_id,
  :resource_name,
  :resource_cidr,
  :resource_type,
  :resource_tags,
  :ip_usage,
  :compliance_status,
  :management_state,
  :overlap_status,
  :vpc_id,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_scope_idString

The scope ID for an IPAM resource.

Returns:

  • (String)


56841
56842
56843
56844
56845
56846
56847
56848
56849
56850
56851
56852
56853
56854
56855
56856
56857
56858
56859
56860
# File 'lib/aws-sdk-ec2/types.rb', line 56841

class IpamResourceCidr < Struct.new(
  :ipam_id,
  :ipam_scope_id,
  :ipam_pool_id,
  :resource_region,
  :resource_owner_id,
  :resource_id,
  :resource_name,
  :resource_cidr,
  :resource_type,
  :resource_tags,
  :ip_usage,
  :compliance_status,
  :management_state,
  :overlap_status,
  :vpc_id,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#management_stateString

The management state of the resource. For more information about management states, see Monitor CIDR usage by resource in the Amazon VPC IPAM User Guide.

Returns:

  • (String)


56841
56842
56843
56844
56845
56846
56847
56848
56849
56850
56851
56852
56853
56854
56855
56856
56857
56858
56859
56860
# File 'lib/aws-sdk-ec2/types.rb', line 56841

class IpamResourceCidr < Struct.new(
  :ipam_id,
  :ipam_scope_id,
  :ipam_pool_id,
  :resource_region,
  :resource_owner_id,
  :resource_id,
  :resource_name,
  :resource_cidr,
  :resource_type,
  :resource_tags,
  :ip_usage,
  :compliance_status,
  :management_state,
  :overlap_status,
  :vpc_id,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#overlap_statusString

The overlap status of an IPAM resource. The overlap status tells you if the CIDR for a resource overlaps with another CIDR in the scope. For more information on overlap statuses, see Monitor CIDR usage by resource in the Amazon VPC IPAM User Guide.

Returns:

  • (String)


56841
56842
56843
56844
56845
56846
56847
56848
56849
56850
56851
56852
56853
56854
56855
56856
56857
56858
56859
56860
# File 'lib/aws-sdk-ec2/types.rb', line 56841

class IpamResourceCidr < Struct.new(
  :ipam_id,
  :ipam_scope_id,
  :ipam_pool_id,
  :resource_region,
  :resource_owner_id,
  :resource_id,
  :resource_name,
  :resource_cidr,
  :resource_type,
  :resource_tags,
  :ip_usage,
  :compliance_status,
  :management_state,
  :overlap_status,
  :vpc_id,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#resource_cidrString

The CIDR for an IPAM resource.

Returns:

  • (String)


56841
56842
56843
56844
56845
56846
56847
56848
56849
56850
56851
56852
56853
56854
56855
56856
56857
56858
56859
56860
# File 'lib/aws-sdk-ec2/types.rb', line 56841

class IpamResourceCidr < Struct.new(
  :ipam_id,
  :ipam_scope_id,
  :ipam_pool_id,
  :resource_region,
  :resource_owner_id,
  :resource_id,
  :resource_name,
  :resource_cidr,
  :resource_type,
  :resource_tags,
  :ip_usage,
  :compliance_status,
  :management_state,
  :overlap_status,
  :vpc_id,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#resource_idString

The ID of an IPAM resource.

Returns:

  • (String)


56841
56842
56843
56844
56845
56846
56847
56848
56849
56850
56851
56852
56853
56854
56855
56856
56857
56858
56859
56860
# File 'lib/aws-sdk-ec2/types.rb', line 56841

class IpamResourceCidr < Struct.new(
  :ipam_id,
  :ipam_scope_id,
  :ipam_pool_id,
  :resource_region,
  :resource_owner_id,
  :resource_id,
  :resource_name,
  :resource_cidr,
  :resource_type,
  :resource_tags,
  :ip_usage,
  :compliance_status,
  :management_state,
  :overlap_status,
  :vpc_id,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#resource_nameString

The name of an IPAM resource.

Returns:

  • (String)


56841
56842
56843
56844
56845
56846
56847
56848
56849
56850
56851
56852
56853
56854
56855
56856
56857
56858
56859
56860
# File 'lib/aws-sdk-ec2/types.rb', line 56841

class IpamResourceCidr < Struct.new(
  :ipam_id,
  :ipam_scope_id,
  :ipam_pool_id,
  :resource_region,
  :resource_owner_id,
  :resource_id,
  :resource_name,
  :resource_cidr,
  :resource_type,
  :resource_tags,
  :ip_usage,
  :compliance_status,
  :management_state,
  :overlap_status,
  :vpc_id,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#resource_owner_idString

The Amazon Web Services account number of the owner of an IPAM resource.

Returns:

  • (String)


56841
56842
56843
56844
56845
56846
56847
56848
56849
56850
56851
56852
56853
56854
56855
56856
56857
56858
56859
56860
# File 'lib/aws-sdk-ec2/types.rb', line 56841

class IpamResourceCidr < Struct.new(
  :ipam_id,
  :ipam_scope_id,
  :ipam_pool_id,
  :resource_region,
  :resource_owner_id,
  :resource_id,
  :resource_name,
  :resource_cidr,
  :resource_type,
  :resource_tags,
  :ip_usage,
  :compliance_status,
  :management_state,
  :overlap_status,
  :vpc_id,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#resource_regionString

The Amazon Web Services Region for an IPAM resource.

Returns:

  • (String)


56841
56842
56843
56844
56845
56846
56847
56848
56849
56850
56851
56852
56853
56854
56855
56856
56857
56858
56859
56860
# File 'lib/aws-sdk-ec2/types.rb', line 56841

class IpamResourceCidr < Struct.new(
  :ipam_id,
  :ipam_scope_id,
  :ipam_pool_id,
  :resource_region,
  :resource_owner_id,
  :resource_id,
  :resource_name,
  :resource_cidr,
  :resource_type,
  :resource_tags,
  :ip_usage,
  :compliance_status,
  :management_state,
  :overlap_status,
  :vpc_id,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#resource_tagsArray<Types::IpamResourceTag>

The tags for an IPAM resource.

Returns:



56841
56842
56843
56844
56845
56846
56847
56848
56849
56850
56851
56852
56853
56854
56855
56856
56857
56858
56859
56860
# File 'lib/aws-sdk-ec2/types.rb', line 56841

class IpamResourceCidr < Struct.new(
  :ipam_id,
  :ipam_scope_id,
  :ipam_pool_id,
  :resource_region,
  :resource_owner_id,
  :resource_id,
  :resource_name,
  :resource_cidr,
  :resource_type,
  :resource_tags,
  :ip_usage,
  :compliance_status,
  :management_state,
  :overlap_status,
  :vpc_id,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The type of IPAM resource.

Returns:

  • (String)


56841
56842
56843
56844
56845
56846
56847
56848
56849
56850
56851
56852
56853
56854
56855
56856
56857
56858
56859
56860
# File 'lib/aws-sdk-ec2/types.rb', line 56841

class IpamResourceCidr < Struct.new(
  :ipam_id,
  :ipam_scope_id,
  :ipam_pool_id,
  :resource_region,
  :resource_owner_id,
  :resource_id,
  :resource_name,
  :resource_cidr,
  :resource_type,
  :resource_tags,
  :ip_usage,
  :compliance_status,
  :management_state,
  :overlap_status,
  :vpc_id,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of a VPC.

Returns:

  • (String)


56841
56842
56843
56844
56845
56846
56847
56848
56849
56850
56851
56852
56853
56854
56855
56856
56857
56858
56859
56860
# File 'lib/aws-sdk-ec2/types.rb', line 56841

class IpamResourceCidr < Struct.new(
  :ipam_id,
  :ipam_scope_id,
  :ipam_pool_id,
  :resource_region,
  :resource_owner_id,
  :resource_id,
  :resource_name,
  :resource_cidr,
  :resource_type,
  :resource_tags,
  :ip_usage,
  :compliance_status,
  :management_state,
  :overlap_status,
  :vpc_id,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end