Class: Aws::EC2::Types::IpamResourceDiscoveryAssociation
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::IpamResourceDiscoveryAssociation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
An IPAM resource discovery association. An associated resource discovery is a resource discovery that has been associated with an IPAM. IPAM aggregates the resource CIDRs discovered by the associated resource discovery.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ipam_arn ⇒ String
The IPAM ARN.
-
#ipam_id ⇒ String
The IPAM ID.
-
#ipam_region ⇒ String
The IPAM home Region.
-
#ipam_resource_discovery_association_arn ⇒ String
The resource discovery association Amazon Resource Name (ARN).
-
#ipam_resource_discovery_association_id ⇒ String
The resource discovery association ID.
-
#ipam_resource_discovery_id ⇒ String
The resource discovery ID.
-
#is_default ⇒ Boolean
Defines if the resource discovery is the default.
-
#owner_id ⇒ String
The Amazon Web Services account ID of the resource discovery owner.
-
#resource_discovery_status ⇒ String
The resource discovery status.
-
#state ⇒ String
The lifecycle state of the association when you associate or disassociate a resource discovery.
-
#tags ⇒ Array<Types::Tag>
A tag is a label that you assign to an Amazon Web Services resource.
Instance Attribute Details
#ipam_arn ⇒ String
The IPAM ARN.
57322 57323 57324 57325 57326 57327 57328 57329 57330 57331 57332 57333 57334 57335 57336 |
# File 'lib/aws-sdk-ec2/types.rb', line 57322 class IpamResourceDiscoveryAssociation < Struct.new( :owner_id, :ipam_resource_discovery_association_id, :ipam_resource_discovery_association_arn, :ipam_resource_discovery_id, :ipam_id, :ipam_arn, :ipam_region, :is_default, :resource_discovery_status, :state, :tags) SENSITIVE = [] include Aws::Structure end |
#ipam_id ⇒ String
The IPAM ID.
57322 57323 57324 57325 57326 57327 57328 57329 57330 57331 57332 57333 57334 57335 57336 |
# File 'lib/aws-sdk-ec2/types.rb', line 57322 class IpamResourceDiscoveryAssociation < Struct.new( :owner_id, :ipam_resource_discovery_association_id, :ipam_resource_discovery_association_arn, :ipam_resource_discovery_id, :ipam_id, :ipam_arn, :ipam_region, :is_default, :resource_discovery_status, :state, :tags) SENSITIVE = [] include Aws::Structure end |
#ipam_region ⇒ String
The IPAM home Region.
57322 57323 57324 57325 57326 57327 57328 57329 57330 57331 57332 57333 57334 57335 57336 |
# File 'lib/aws-sdk-ec2/types.rb', line 57322 class IpamResourceDiscoveryAssociation < Struct.new( :owner_id, :ipam_resource_discovery_association_id, :ipam_resource_discovery_association_arn, :ipam_resource_discovery_id, :ipam_id, :ipam_arn, :ipam_region, :is_default, :resource_discovery_status, :state, :tags) SENSITIVE = [] include Aws::Structure end |
#ipam_resource_discovery_association_arn ⇒ String
The resource discovery association Amazon Resource Name (ARN).
57322 57323 57324 57325 57326 57327 57328 57329 57330 57331 57332 57333 57334 57335 57336 |
# File 'lib/aws-sdk-ec2/types.rb', line 57322 class IpamResourceDiscoveryAssociation < Struct.new( :owner_id, :ipam_resource_discovery_association_id, :ipam_resource_discovery_association_arn, :ipam_resource_discovery_id, :ipam_id, :ipam_arn, :ipam_region, :is_default, :resource_discovery_status, :state, :tags) SENSITIVE = [] include Aws::Structure end |
#ipam_resource_discovery_association_id ⇒ String
The resource discovery association ID.
57322 57323 57324 57325 57326 57327 57328 57329 57330 57331 57332 57333 57334 57335 57336 |
# File 'lib/aws-sdk-ec2/types.rb', line 57322 class IpamResourceDiscoveryAssociation < Struct.new( :owner_id, :ipam_resource_discovery_association_id, :ipam_resource_discovery_association_arn, :ipam_resource_discovery_id, :ipam_id, :ipam_arn, :ipam_region, :is_default, :resource_discovery_status, :state, :tags) SENSITIVE = [] include Aws::Structure end |
#ipam_resource_discovery_id ⇒ String
The resource discovery ID.
57322 57323 57324 57325 57326 57327 57328 57329 57330 57331 57332 57333 57334 57335 57336 |
# File 'lib/aws-sdk-ec2/types.rb', line 57322 class IpamResourceDiscoveryAssociation < Struct.new( :owner_id, :ipam_resource_discovery_association_id, :ipam_resource_discovery_association_arn, :ipam_resource_discovery_id, :ipam_id, :ipam_arn, :ipam_region, :is_default, :resource_discovery_status, :state, :tags) SENSITIVE = [] include Aws::Structure end |
#is_default ⇒ Boolean
Defines if the resource discovery is the default. When you create an IPAM, a default resource discovery is created for your IPAM and it's associated with your IPAM.
57322 57323 57324 57325 57326 57327 57328 57329 57330 57331 57332 57333 57334 57335 57336 |
# File 'lib/aws-sdk-ec2/types.rb', line 57322 class IpamResourceDiscoveryAssociation < Struct.new( :owner_id, :ipam_resource_discovery_association_id, :ipam_resource_discovery_association_arn, :ipam_resource_discovery_id, :ipam_id, :ipam_arn, :ipam_region, :is_default, :resource_discovery_status, :state, :tags) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
The Amazon Web Services account ID of the resource discovery owner.
57322 57323 57324 57325 57326 57327 57328 57329 57330 57331 57332 57333 57334 57335 57336 |
# File 'lib/aws-sdk-ec2/types.rb', line 57322 class IpamResourceDiscoveryAssociation < Struct.new( :owner_id, :ipam_resource_discovery_association_id, :ipam_resource_discovery_association_arn, :ipam_resource_discovery_id, :ipam_id, :ipam_arn, :ipam_region, :is_default, :resource_discovery_status, :state, :tags) SENSITIVE = [] include Aws::Structure end |
#resource_discovery_status ⇒ String
The resource discovery status.
-
active- Connection or permissions required to read the results of the resource discovery are intact. -
not-found- Connection or permissions required to read the results of the resource discovery are broken. This may happen if the owner of the resource discovery stopped sharing it or deleted the resource discovery. Verify the resource discovery still exists and the Amazon Web Services RAM resource share is still intact.
57322 57323 57324 57325 57326 57327 57328 57329 57330 57331 57332 57333 57334 57335 57336 |
# File 'lib/aws-sdk-ec2/types.rb', line 57322 class IpamResourceDiscoveryAssociation < Struct.new( :owner_id, :ipam_resource_discovery_association_id, :ipam_resource_discovery_association_arn, :ipam_resource_discovery_id, :ipam_id, :ipam_arn, :ipam_region, :is_default, :resource_discovery_status, :state, :tags) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The lifecycle state of the association when you associate or disassociate a resource discovery.
-
associate-in-progress- Resource discovery is being associated. -
associate-complete- Resource discovery association is complete. -
associate-failed- Resource discovery association has failed. -
disassociate-in-progress- Resource discovery is being disassociated. -
disassociate-complete- Resource discovery disassociation is complete. -
disassociate-failed- Resource discovery disassociation has failed. -
isolate-in-progress- Amazon Web Services account that created the resource discovery association has been removed and the resource discovery association is being isolated. -
isolate-complete- Resource discovery isolation is complete. -
restore-in-progress- Resource discovery is being restored.
57322 57323 57324 57325 57326 57327 57328 57329 57330 57331 57332 57333 57334 57335 57336 |
# File 'lib/aws-sdk-ec2/types.rb', line 57322 class IpamResourceDiscoveryAssociation < Struct.new( :owner_id, :ipam_resource_discovery_association_id, :ipam_resource_discovery_association_arn, :ipam_resource_discovery_id, :ipam_id, :ipam_arn, :ipam_region, :is_default, :resource_discovery_status, :state, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A tag is a label that you assign to an Amazon Web Services resource. Each tag consists of a key and an optional value. You can use tags to search and filter your resources or track your Amazon Web Services costs.
57322 57323 57324 57325 57326 57327 57328 57329 57330 57331 57332 57333 57334 57335 57336 |
# File 'lib/aws-sdk-ec2/types.rb', line 57322 class IpamResourceDiscoveryAssociation < Struct.new( :owner_id, :ipam_resource_discovery_association_id, :ipam_resource_discovery_association_arn, :ipam_resource_discovery_id, :ipam_id, :ipam_arn, :ipam_region, :is_default, :resource_discovery_status, :state, :tags) SENSITIVE = [] include Aws::Structure end |