Class: Aws::EC2::Types::IpamRouteProtectionFinding
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::IpamRouteProtectionFinding
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains information about a route protection finding, including the RPKI validation status of a BYOIP route announcement.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#advertisement_type ⇒ String
The advertisement type.
-
#asn ⇒ String
The Autonomous System Number (ASN) that originates the route.
-
#cidr ⇒ String
The IP address prefix in CIDR notation.
-
#ipam_pool_id ⇒ String
The ID of the IPAM pool associated with the finding.
-
#network_border_group ⇒ String
The network border group.
-
#pool_id ⇒ String
The ID of the BYOIP pool.
-
#resource_owner_id ⇒ String
The ID of the resource owner.
-
#resource_region ⇒ String
The Amazon Web Services Region of the resource.
-
#roa_sample_time ⇒ Time
The time when the ROA data was last sampled.
-
#roas ⇒ Array<Types::IpamRouteOriginAuthorization>
The Route Origin Authorizations (ROAs) that cover the prefix.
-
#route_overlaps ⇒ Array<Types::IpamRouteOverlap>
The overlapping routes detected for this prefix.
-
#rpki_status ⇒ String
The RPKI validation status of the route.
-
#rpki_strength ⇒ String
The RPKI enforcement strength for the route.
-
#sample_time ⇒ Time
The time when the route was last sampled.
-
#state ⇒ String
The state of the BYOIP CIDR.
Instance Attribute Details
#advertisement_type ⇒ String
The advertisement type. Possible values:
-
regional- The IP address is advertised from a single location (regional services such as Amazon EC2). -
global- The IP address is advertised from multiple global locations simultaneously (global services such as Amazon CloudFront).
59896 59897 59898 59899 59900 59901 59902 59903 59904 59905 59906 59907 59908 59909 59910 59911 59912 59913 59914 |
# File 'lib/aws-sdk-ec2/types.rb', line 59896 class IpamRouteProtectionFinding < Struct.new( :resource_owner_id, :resource_region, :ipam_pool_id, :cidr, :state, :advertisement_type, :network_border_group, :pool_id, :asn, :rpki_status, :rpki_strength, :roas, :route_overlaps, :sample_time, :roa_sample_time) SENSITIVE = [] include Aws::Structure end |
#asn ⇒ String
The Autonomous System Number (ASN) that originates the route.
59896 59897 59898 59899 59900 59901 59902 59903 59904 59905 59906 59907 59908 59909 59910 59911 59912 59913 59914 |
# File 'lib/aws-sdk-ec2/types.rb', line 59896 class IpamRouteProtectionFinding < Struct.new( :resource_owner_id, :resource_region, :ipam_pool_id, :cidr, :state, :advertisement_type, :network_border_group, :pool_id, :asn, :rpki_status, :rpki_strength, :roas, :route_overlaps, :sample_time, :roa_sample_time) SENSITIVE = [] include Aws::Structure end |
#cidr ⇒ String
The IP address prefix in CIDR notation.
59896 59897 59898 59899 59900 59901 59902 59903 59904 59905 59906 59907 59908 59909 59910 59911 59912 59913 59914 |
# File 'lib/aws-sdk-ec2/types.rb', line 59896 class IpamRouteProtectionFinding < Struct.new( :resource_owner_id, :resource_region, :ipam_pool_id, :cidr, :state, :advertisement_type, :network_border_group, :pool_id, :asn, :rpki_status, :rpki_strength, :roas, :route_overlaps, :sample_time, :roa_sample_time) SENSITIVE = [] include Aws::Structure end |
#ipam_pool_id ⇒ String
The ID of the IPAM pool associated with the finding.
59896 59897 59898 59899 59900 59901 59902 59903 59904 59905 59906 59907 59908 59909 59910 59911 59912 59913 59914 |
# File 'lib/aws-sdk-ec2/types.rb', line 59896 class IpamRouteProtectionFinding < Struct.new( :resource_owner_id, :resource_region, :ipam_pool_id, :cidr, :state, :advertisement_type, :network_border_group, :pool_id, :asn, :rpki_status, :rpki_strength, :roas, :route_overlaps, :sample_time, :roa_sample_time) SENSITIVE = [] include Aws::Structure end |
#network_border_group ⇒ String
The network border group.
59896 59897 59898 59899 59900 59901 59902 59903 59904 59905 59906 59907 59908 59909 59910 59911 59912 59913 59914 |
# File 'lib/aws-sdk-ec2/types.rb', line 59896 class IpamRouteProtectionFinding < Struct.new( :resource_owner_id, :resource_region, :ipam_pool_id, :cidr, :state, :advertisement_type, :network_border_group, :pool_id, :asn, :rpki_status, :rpki_strength, :roas, :route_overlaps, :sample_time, :roa_sample_time) SENSITIVE = [] include Aws::Structure end |
#pool_id ⇒ String
The ID of the BYOIP pool.
59896 59897 59898 59899 59900 59901 59902 59903 59904 59905 59906 59907 59908 59909 59910 59911 59912 59913 59914 |
# File 'lib/aws-sdk-ec2/types.rb', line 59896 class IpamRouteProtectionFinding < Struct.new( :resource_owner_id, :resource_region, :ipam_pool_id, :cidr, :state, :advertisement_type, :network_border_group, :pool_id, :asn, :rpki_status, :rpki_strength, :roas, :route_overlaps, :sample_time, :roa_sample_time) SENSITIVE = [] include Aws::Structure end |
#resource_owner_id ⇒ String
The ID of the resource owner.
59896 59897 59898 59899 59900 59901 59902 59903 59904 59905 59906 59907 59908 59909 59910 59911 59912 59913 59914 |
# File 'lib/aws-sdk-ec2/types.rb', line 59896 class IpamRouteProtectionFinding < Struct.new( :resource_owner_id, :resource_region, :ipam_pool_id, :cidr, :state, :advertisement_type, :network_border_group, :pool_id, :asn, :rpki_status, :rpki_strength, :roas, :route_overlaps, :sample_time, :roa_sample_time) SENSITIVE = [] include Aws::Structure end |
#resource_region ⇒ String
The Amazon Web Services Region of the resource.
59896 59897 59898 59899 59900 59901 59902 59903 59904 59905 59906 59907 59908 59909 59910 59911 59912 59913 59914 |
# File 'lib/aws-sdk-ec2/types.rb', line 59896 class IpamRouteProtectionFinding < Struct.new( :resource_owner_id, :resource_region, :ipam_pool_id, :cidr, :state, :advertisement_type, :network_border_group, :pool_id, :asn, :rpki_status, :rpki_strength, :roas, :route_overlaps, :sample_time, :roa_sample_time) SENSITIVE = [] include Aws::Structure end |
#roa_sample_time ⇒ Time
The time when the ROA data was last sampled.
59896 59897 59898 59899 59900 59901 59902 59903 59904 59905 59906 59907 59908 59909 59910 59911 59912 59913 59914 |
# File 'lib/aws-sdk-ec2/types.rb', line 59896 class IpamRouteProtectionFinding < Struct.new( :resource_owner_id, :resource_region, :ipam_pool_id, :cidr, :state, :advertisement_type, :network_border_group, :pool_id, :asn, :rpki_status, :rpki_strength, :roas, :route_overlaps, :sample_time, :roa_sample_time) SENSITIVE = [] include Aws::Structure end |
#roas ⇒ Array<Types::IpamRouteOriginAuthorization>
The Route Origin Authorizations (ROAs) that cover the prefix.
59896 59897 59898 59899 59900 59901 59902 59903 59904 59905 59906 59907 59908 59909 59910 59911 59912 59913 59914 |
# File 'lib/aws-sdk-ec2/types.rb', line 59896 class IpamRouteProtectionFinding < Struct.new( :resource_owner_id, :resource_region, :ipam_pool_id, :cidr, :state, :advertisement_type, :network_border_group, :pool_id, :asn, :rpki_status, :rpki_strength, :roas, :route_overlaps, :sample_time, :roa_sample_time) SENSITIVE = [] include Aws::Structure end |
#route_overlaps ⇒ Array<Types::IpamRouteOverlap>
The overlapping routes detected for this prefix.
59896 59897 59898 59899 59900 59901 59902 59903 59904 59905 59906 59907 59908 59909 59910 59911 59912 59913 59914 |
# File 'lib/aws-sdk-ec2/types.rb', line 59896 class IpamRouteProtectionFinding < Struct.new( :resource_owner_id, :resource_region, :ipam_pool_id, :cidr, :state, :advertisement_type, :network_border_group, :pool_id, :asn, :rpki_status, :rpki_strength, :roas, :route_overlaps, :sample_time, :roa_sample_time) SENSITIVE = [] include Aws::Structure end |
#rpki_status ⇒ String
The RPKI validation status of the route. Possible values:
-
valid- The route has a matching ROA that covers the prefix and origin ASN. -
invalid- The route has a ROA for the prefix, but the origin ASN or prefix length does not match. -
unknown- No ROA exists for the prefix, so RPKI validation cannot be performed.
59896 59897 59898 59899 59900 59901 59902 59903 59904 59905 59906 59907 59908 59909 59910 59911 59912 59913 59914 |
# File 'lib/aws-sdk-ec2/types.rb', line 59896 class IpamRouteProtectionFinding < Struct.new( :resource_owner_id, :resource_region, :ipam_pool_id, :cidr, :state, :advertisement_type, :network_border_group, :pool_id, :asn, :rpki_status, :rpki_strength, :roas, :route_overlaps, :sample_time, :roa_sample_time) SENSITIVE = [] include Aws::Structure end |
#rpki_strength ⇒ String
The RPKI enforcement strength for the route. Possible values:
-
strict- Invalid routes are rejected. -
permissive- Invalid routes are accepted but flagged.
59896 59897 59898 59899 59900 59901 59902 59903 59904 59905 59906 59907 59908 59909 59910 59911 59912 59913 59914 |
# File 'lib/aws-sdk-ec2/types.rb', line 59896 class IpamRouteProtectionFinding < Struct.new( :resource_owner_id, :resource_region, :ipam_pool_id, :cidr, :state, :advertisement_type, :network_border_group, :pool_id, :asn, :rpki_status, :rpki_strength, :roas, :route_overlaps, :sample_time, :roa_sample_time) SENSITIVE = [] include Aws::Structure end |
#sample_time ⇒ Time
The time when the route was last sampled.
59896 59897 59898 59899 59900 59901 59902 59903 59904 59905 59906 59907 59908 59909 59910 59911 59912 59913 59914 |
# File 'lib/aws-sdk-ec2/types.rb', line 59896 class IpamRouteProtectionFinding < Struct.new( :resource_owner_id, :resource_region, :ipam_pool_id, :cidr, :state, :advertisement_type, :network_border_group, :pool_id, :asn, :rpki_status, :rpki_strength, :roas, :route_overlaps, :sample_time, :roa_sample_time) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the BYOIP CIDR. Possible values:
-
advertised- The CIDR is being advertised. -
deprovisioned- The CIDR has been deprovisioned. -
failed-deprovision- Deprovisioning failed. -
failed-provision- Provisioning failed. -
pending-deprovision- Deprovisioning is in progress. -
pending-provision- Provisioning is in progress. -
provisioned- The CIDR is provisioned. -
provisioned-not-publicly-advertisable- The CIDR is provisioned but not publicly advertisable.
59896 59897 59898 59899 59900 59901 59902 59903 59904 59905 59906 59907 59908 59909 59910 59911 59912 59913 59914 |
# File 'lib/aws-sdk-ec2/types.rb', line 59896 class IpamRouteProtectionFinding < Struct.new( :resource_owner_id, :resource_region, :ipam_pool_id, :cidr, :state, :advertisement_type, :network_border_group, :pool_id, :asn, :rpki_status, :rpki_strength, :roas, :route_overlaps, :sample_time, :roa_sample_time) SENSITIVE = [] include Aws::Structure end |