Class: Aws::EC2::Types::IpamRoutingPolicyRegistration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains information about a routing policy registration that represents a Route Origin Authorization (ROA) managed through IPAM.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#asnsArray<String>

The Autonomous System Numbers (ASNs) authorized to originate the prefix.

Returns:

  • (Array<String>)


59905
59906
59907
59908
59909
59910
59911
59912
59913
59914
59915
# File 'lib/aws-sdk-ec2/types.rb', line 59905

class IpamRoutingPolicyRegistration < Struct.new(
  :cidr,
  :asns,
  :permit_more_specific_announcements,
  :max_length,
  :description,
  :latest_delta_id,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#cidrString

The IP address prefix in CIDR notation authorized by the ROA.

Returns:

  • (String)


59905
59906
59907
59908
59909
59910
59911
59912
59913
59914
59915
# File 'lib/aws-sdk-ec2/types.rb', line 59905

class IpamRoutingPolicyRegistration < Struct.new(
  :cidr,
  :asns,
  :permit_more_specific_announcements,
  :max_length,
  :description,
  :latest_delta_id,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the routing policy registration.

Returns:

  • (String)


59905
59906
59907
59908
59909
59910
59911
59912
59913
59914
59915
# File 'lib/aws-sdk-ec2/types.rb', line 59905

class IpamRoutingPolicyRegistration < Struct.new(
  :cidr,
  :asns,
  :permit_more_specific_announcements,
  :max_length,
  :description,
  :latest_delta_id,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#latest_delta_idString

The ID of the most recent delta that modified this registration.

Returns:

  • (String)


59905
59906
59907
59908
59909
59910
59911
59912
59913
59914
59915
# File 'lib/aws-sdk-ec2/types.rb', line 59905

class IpamRoutingPolicyRegistration < Struct.new(
  :cidr,
  :asns,
  :permit_more_specific_announcements,
  :max_length,
  :description,
  :latest_delta_id,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#max_lengthInteger

The maximum prefix length that the ASNs are authorized to announce.

Returns:

  • (Integer)


59905
59906
59907
59908
59909
59910
59911
59912
59913
59914
59915
# File 'lib/aws-sdk-ec2/types.rb', line 59905

class IpamRoutingPolicyRegistration < Struct.new(
  :cidr,
  :asns,
  :permit_more_specific_announcements,
  :max_length,
  :description,
  :latest_delta_id,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#permit_more_specific_announcementsBoolean

Specifies whether to permit more specific route announcements than the CIDR prefix. When enabled, ASNs can announce sub-prefixes of the authorized CIDR up to the specified maximum length. Default: false.

Returns:

  • (Boolean)


59905
59906
59907
59908
59909
59910
59911
59912
59913
59914
59915
# File 'lib/aws-sdk-ec2/types.rb', line 59905

class IpamRoutingPolicyRegistration < Struct.new(
  :cidr,
  :asns,
  :permit_more_specific_announcements,
  :max_length,
  :description,
  :latest_delta_id,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of the routing policy registration. Valid values: pending-activate | activate-failed | create-in-progress | create-complete | update-in-progress | update-complete | delete-in-progress | delete-complete.

Returns:

  • (String)


59905
59906
59907
59908
59909
59910
59911
59912
59913
59914
59915
# File 'lib/aws-sdk-ec2/types.rb', line 59905

class IpamRoutingPolicyRegistration < Struct.new(
  :cidr,
  :asns,
  :permit_more_specific_announcements,
  :max_length,
  :description,
  :latest_delta_id,
  :state)
  SENSITIVE = []
  include Aws::Structure
end