Class: Aws::EC2::Types::IpamRoutingPolicyRegistrationDelta
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::IpamRoutingPolicyRegistrationDelta
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains information about a routing policy registration change, including the changes applied and their publication state.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#delta_id ⇒ String
The unique identifier of the delta.
-
#delta_json ⇒ String
The JSON specification describing the changes applied in this delta.
-
#state ⇒ String
The state of the delta.
-
#state_message ⇒ String
A message describing the current state, including error information if the delta failed.
Instance Attribute Details
#delta_id ⇒ String
The unique identifier of the delta.
59961 59962 59963 59964 59965 59966 59967 59968 |
# File 'lib/aws-sdk-ec2/types.rb', line 59961 class IpamRoutingPolicyRegistrationDelta < Struct.new( :delta_id, :delta_json, :state, :state_message) SENSITIVE = [] include Aws::Structure end |
#delta_json ⇒ String
The JSON specification describing the changes applied in this delta.
59961 59962 59963 59964 59965 59966 59967 59968 |
# File 'lib/aws-sdk-ec2/types.rb', line 59961 class IpamRoutingPolicyRegistrationDelta < Struct.new( :delta_id, :delta_json, :state, :state_message) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the delta. Valid values: pending | published |
failed.
59961 59962 59963 59964 59965 59966 59967 59968 |
# File 'lib/aws-sdk-ec2/types.rb', line 59961 class IpamRoutingPolicyRegistrationDelta < Struct.new( :delta_id, :delta_json, :state, :state_message) SENSITIVE = [] include Aws::Structure end |
#state_message ⇒ String
A message describing the current state, including error information if the delta failed.
59961 59962 59963 59964 59965 59966 59967 59968 |
# File 'lib/aws-sdk-ec2/types.rb', line 59961 class IpamRoutingPolicyRegistrationDelta < Struct.new( :delta_id, :delta_json, :state, :state_message) SENSITIVE = [] include Aws::Structure end |