Class: Aws::EC2::Types::IpamScope

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

In IPAM, a scope is the highest-level container within IPAM. An IPAM contains two default scopes. Each scope represents the IP space for a single network. The private scope is intended for all private IP address space. The public scope is intended for all public IP address space. Scopes enable you to reuse IP addresses across multiple unconnected networks without causing IP address overlap or conflict.

For more information, see [How IPAM works] in the *Amazon VPC IPAM User Guide*.

[1]: docs.aws.amazon.com/vpc/latest/ipam/how-it-works-ipam.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description of the scope.

Returns:

  • (String)


55119
55120
55121
55122
55123
55124
55125
55126
55127
55128
55129
55130
55131
55132
55133
55134
# File 'lib/aws-sdk-ec2/types.rb', line 55119

class IpamScope < Struct.new(
  :owner_id,
  :ipam_scope_id,
  :ipam_scope_arn,
  :ipam_arn,
  :ipam_region,
  :ipam_scope_type,
  :is_default,
  :description,
  :pool_count,
  :state,
  :tags,
  :external_authority_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#external_authority_configurationTypes::IpamScopeExternalAuthorityConfiguration

The external authority configuration for this IPAM scope, if configured.

The configuration that links an Amazon VPC IPAM scope to an external authority system. It specifies the type of external system and the external resource identifier that identifies your account or instance in that system.

In IPAM, an external authority is a third-party IP address management system that provides CIDR blocks when you provision address space for top-level IPAM pools. This allows you to use your existing IP management system to control which address ranges are allocated to Amazon Web Services while using Amazon VPC IPAM to manage subnets within those ranges.



55119
55120
55121
55122
55123
55124
55125
55126
55127
55128
55129
55130
55131
55132
55133
55134
# File 'lib/aws-sdk-ec2/types.rb', line 55119

class IpamScope < Struct.new(
  :owner_id,
  :ipam_scope_id,
  :ipam_scope_arn,
  :ipam_arn,
  :ipam_region,
  :ipam_scope_type,
  :is_default,
  :description,
  :pool_count,
  :state,
  :tags,
  :external_authority_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_arnString

The ARN of the IPAM.

Returns:

  • (String)


55119
55120
55121
55122
55123
55124
55125
55126
55127
55128
55129
55130
55131
55132
55133
55134
# File 'lib/aws-sdk-ec2/types.rb', line 55119

class IpamScope < Struct.new(
  :owner_id,
  :ipam_scope_id,
  :ipam_scope_arn,
  :ipam_arn,
  :ipam_region,
  :ipam_scope_type,
  :is_default,
  :description,
  :pool_count,
  :state,
  :tags,
  :external_authority_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_regionString

The Amazon Web Services Region of the IPAM scope.

Returns:

  • (String)


55119
55120
55121
55122
55123
55124
55125
55126
55127
55128
55129
55130
55131
55132
55133
55134
# File 'lib/aws-sdk-ec2/types.rb', line 55119

class IpamScope < Struct.new(
  :owner_id,
  :ipam_scope_id,
  :ipam_scope_arn,
  :ipam_arn,
  :ipam_region,
  :ipam_scope_type,
  :is_default,
  :description,
  :pool_count,
  :state,
  :tags,
  :external_authority_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_scope_arnString

The Amazon Resource Name (ARN) of the scope.

Returns:

  • (String)


55119
55120
55121
55122
55123
55124
55125
55126
55127
55128
55129
55130
55131
55132
55133
55134
# File 'lib/aws-sdk-ec2/types.rb', line 55119

class IpamScope < Struct.new(
  :owner_id,
  :ipam_scope_id,
  :ipam_scope_arn,
  :ipam_arn,
  :ipam_region,
  :ipam_scope_type,
  :is_default,
  :description,
  :pool_count,
  :state,
  :tags,
  :external_authority_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_scope_idString

The ID of the scope.

Returns:

  • (String)


55119
55120
55121
55122
55123
55124
55125
55126
55127
55128
55129
55130
55131
55132
55133
55134
# File 'lib/aws-sdk-ec2/types.rb', line 55119

class IpamScope < Struct.new(
  :owner_id,
  :ipam_scope_id,
  :ipam_scope_arn,
  :ipam_arn,
  :ipam_region,
  :ipam_scope_type,
  :is_default,
  :description,
  :pool_count,
  :state,
  :tags,
  :external_authority_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_scope_typeString

The type of the scope.

Returns:

  • (String)


55119
55120
55121
55122
55123
55124
55125
55126
55127
55128
55129
55130
55131
55132
55133
55134
# File 'lib/aws-sdk-ec2/types.rb', line 55119

class IpamScope < Struct.new(
  :owner_id,
  :ipam_scope_id,
  :ipam_scope_arn,
  :ipam_arn,
  :ipam_region,
  :ipam_scope_type,
  :is_default,
  :description,
  :pool_count,
  :state,
  :tags,
  :external_authority_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#is_defaultBoolean

Defines if the scope is the default scope or not.

Returns:

  • (Boolean)


55119
55120
55121
55122
55123
55124
55125
55126
55127
55128
55129
55130
55131
55132
55133
55134
# File 'lib/aws-sdk-ec2/types.rb', line 55119

class IpamScope < Struct.new(
  :owner_id,
  :ipam_scope_id,
  :ipam_scope_arn,
  :ipam_arn,
  :ipam_region,
  :ipam_scope_type,
  :is_default,
  :description,
  :pool_count,
  :state,
  :tags,
  :external_authority_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#owner_idString

The Amazon Web Services account ID of the owner of the scope.

Returns:

  • (String)


55119
55120
55121
55122
55123
55124
55125
55126
55127
55128
55129
55130
55131
55132
55133
55134
# File 'lib/aws-sdk-ec2/types.rb', line 55119

class IpamScope < Struct.new(
  :owner_id,
  :ipam_scope_id,
  :ipam_scope_arn,
  :ipam_arn,
  :ipam_region,
  :ipam_scope_type,
  :is_default,
  :description,
  :pool_count,
  :state,
  :tags,
  :external_authority_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#pool_countInteger

The number of pools in the scope.

Returns:

  • (Integer)


55119
55120
55121
55122
55123
55124
55125
55126
55127
55128
55129
55130
55131
55132
55133
55134
# File 'lib/aws-sdk-ec2/types.rb', line 55119

class IpamScope < Struct.new(
  :owner_id,
  :ipam_scope_id,
  :ipam_scope_arn,
  :ipam_arn,
  :ipam_region,
  :ipam_scope_type,
  :is_default,
  :description,
  :pool_count,
  :state,
  :tags,
  :external_authority_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of the IPAM scope.

Returns:

  • (String)


55119
55120
55121
55122
55123
55124
55125
55126
55127
55128
55129
55130
55131
55132
55133
55134
# File 'lib/aws-sdk-ec2/types.rb', line 55119

class IpamScope < Struct.new(
  :owner_id,
  :ipam_scope_id,
  :ipam_scope_arn,
  :ipam_arn,
  :ipam_region,
  :ipam_scope_type,
  :is_default,
  :description,
  :pool_count,
  :state,
  :tags,
  :external_authority_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key ‘Owner` and the value `TeamA`, specify `tag:Owner` for the filter name and `TeamA` for the filter value.

Returns:



55119
55120
55121
55122
55123
55124
55125
55126
55127
55128
55129
55130
55131
55132
55133
55134
# File 'lib/aws-sdk-ec2/types.rb', line 55119

class IpamScope < Struct.new(
  :owner_id,
  :ipam_scope_id,
  :ipam_scope_arn,
  :ipam_arn,
  :ipam_region,
  :ipam_scope_type,
  :is_default,
  :description,
  :pool_count,
  :state,
  :tags,
  :external_authority_configuration)
  SENSITIVE = []
  include Aws::Structure
end