Class: Aws::EC2::Types::LaunchTemplateBlockDeviceMappingRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::LaunchTemplateBlockDeviceMappingRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a block device mapping.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#device_name ⇒ String
The device name (for example, /dev/sdh or xvdh).
-
#ebs ⇒ Types::LaunchTemplateEbsBlockDeviceRequest
Parameters used to automatically set up EBS volumes when the instance is launched.
-
#no_device ⇒ String
To omit the device from the block device mapping, specify an empty string.
-
#virtual_name ⇒ String
The virtual device name (ephemeralN).
Instance Attribute Details
#device_name ⇒ String
The device name (for example, /dev/sdh or xvdh).
60684 60685 60686 60687 60688 60689 60690 60691 |
# File 'lib/aws-sdk-ec2/types.rb', line 60684 class LaunchTemplateBlockDeviceMappingRequest < Struct.new( :device_name, :virtual_name, :ebs, :no_device) SENSITIVE = [] include Aws::Structure end |
#ebs ⇒ Types::LaunchTemplateEbsBlockDeviceRequest
Parameters used to automatically set up EBS volumes when the instance is launched.
60684 60685 60686 60687 60688 60689 60690 60691 |
# File 'lib/aws-sdk-ec2/types.rb', line 60684 class LaunchTemplateBlockDeviceMappingRequest < Struct.new( :device_name, :virtual_name, :ebs, :no_device) SENSITIVE = [] include Aws::Structure end |
#no_device ⇒ String
To omit the device from the block device mapping, specify an empty string.
60684 60685 60686 60687 60688 60689 60690 60691 |
# File 'lib/aws-sdk-ec2/types.rb', line 60684 class LaunchTemplateBlockDeviceMappingRequest < Struct.new( :device_name, :virtual_name, :ebs, :no_device) SENSITIVE = [] include Aws::Structure end |
#virtual_name ⇒ String
The virtual device name (ephemeralN). Instance store volumes are numbered starting from 0. An instance type with 2 available instance store volumes can specify mappings for ephemeral0 and ephemeral1. The number of available instance store volumes depends on the instance type. After you connect to the instance, you must mount the volume.
60684 60685 60686 60687 60688 60689 60690 60691 |
# File 'lib/aws-sdk-ec2/types.rb', line 60684 class LaunchTemplateBlockDeviceMappingRequest < Struct.new( :device_name, :virtual_name, :ebs, :no_device) SENSITIVE = [] include Aws::Structure end |