Class: Aws::EC2::Types::LaunchTemplateCpuOptionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::LaunchTemplateCpuOptionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
The CPU options for the instance. Both the core count and threads per core must be specified in the request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#amd_sev_snp ⇒ String
Indicates whether to enable the instance for AMD SEV-SNP.
-
#core_count ⇒ Integer
The number of CPU cores for the instance.
-
#nested_virtualization ⇒ String
Indicates whether to enable the instance for nested virtualization.
-
#threads_per_core ⇒ Integer
The number of threads per CPU core.
Instance Attribute Details
#amd_sev_snp ⇒ String
Indicates whether to enable the instance for AMD SEV-SNP. AMD SEV-SNP is supported with M6a, R6a, and C6a instance types only. For more information, see [AMD SEV-SNP for Amazon EC2 instances].
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/sev-snp.html
57528 57529 57530 57531 57532 57533 57534 57535 |
# File 'lib/aws-sdk-ec2/types.rb', line 57528 class LaunchTemplateCpuOptionsRequest < Struct.new( :core_count, :threads_per_core, :amd_sev_snp, :nested_virtualization) SENSITIVE = [] include Aws::Structure end |
#core_count ⇒ Integer
The number of CPU cores for the instance.
57528 57529 57530 57531 57532 57533 57534 57535 |
# File 'lib/aws-sdk-ec2/types.rb', line 57528 class LaunchTemplateCpuOptionsRequest < Struct.new( :core_count, :threads_per_core, :amd_sev_snp, :nested_virtualization) SENSITIVE = [] include Aws::Structure end |
#nested_virtualization ⇒ String
Indicates whether to enable the instance for nested virtualization. Nested virtualization is supported only on 8th generation Intel-based instance types (c8i, m8i, r8i, and their flex variants). When nested virtualization is enabled, Virtual Secure Mode (VSM) is automatically disabled for the instance.
57528 57529 57530 57531 57532 57533 57534 57535 |
# File 'lib/aws-sdk-ec2/types.rb', line 57528 class LaunchTemplateCpuOptionsRequest < Struct.new( :core_count, :threads_per_core, :amd_sev_snp, :nested_virtualization) SENSITIVE = [] include Aws::Structure end |
#threads_per_core ⇒ Integer
The number of threads per CPU core. To disable multithreading for the instance, specify a value of ‘1`. Otherwise, specify the default value of `2`.
57528 57529 57530 57531 57532 57533 57534 57535 |
# File 'lib/aws-sdk-ec2/types.rb', line 57528 class LaunchTemplateCpuOptionsRequest < Struct.new( :core_count, :threads_per_core, :amd_sev_snp, :nested_virtualization) SENSITIVE = [] include Aws::Structure end |