Class: Aws::EC2::Types::LaunchTemplateEbsBlockDeviceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::LaunchTemplateEbsBlockDeviceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
The parameters for a block device for an EBS volume.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#delete_on_termination ⇒ Boolean
Indicates whether the EBS volume is deleted on instance termination.
-
#ebs_card_index ⇒ Integer
The index of the EBS card.
-
#encrypted ⇒ Boolean
Indicates whether the EBS volume is encrypted.
-
#iops ⇒ Integer
The number of I/O operations per second (IOPS).
-
#kms_key_id ⇒ String
Identifier (key ID, key alias, key ARN, or alias ARN) of the customer managed KMS key to use for EBS encryption.
-
#snapshot_id ⇒ String
The ID of the snapshot.
-
#throughput ⇒ Integer
The throughput to provision for a ‘gp3` volume, with a maximum of 2,000 MiB/s.
-
#volume_initialization_rate ⇒ Integer
Specifies the Amazon EBS Provisioned Rate for Volume Initialization (volume initialization rate), in MiB/s, at which to download the snapshot blocks from Amazon S3 to the volume.
-
#volume_size ⇒ Integer
The size of the volume, in GiBs.
-
#volume_type ⇒ String
The volume type.
Instance Attribute Details
#delete_on_termination ⇒ Boolean
Indicates whether the EBS volume is deleted on instance termination.
56122 56123 56124 56125 56126 56127 56128 56129 56130 56131 56132 56133 56134 56135 |
# File 'lib/aws-sdk-ec2/types.rb', line 56122 class LaunchTemplateEbsBlockDeviceRequest < Struct.new( :encrypted, :delete_on_termination, :iops, :kms_key_id, :snapshot_id, :volume_size, :volume_type, :throughput, :volume_initialization_rate, :ebs_card_index) SENSITIVE = [] include Aws::Structure end |
#ebs_card_index ⇒ Integer
The index of the EBS card. Some instance types support multiple EBS cards. The default EBS card index is 0.
56122 56123 56124 56125 56126 56127 56128 56129 56130 56131 56132 56133 56134 56135 |
# File 'lib/aws-sdk-ec2/types.rb', line 56122 class LaunchTemplateEbsBlockDeviceRequest < Struct.new( :encrypted, :delete_on_termination, :iops, :kms_key_id, :snapshot_id, :volume_size, :volume_type, :throughput, :volume_initialization_rate, :ebs_card_index) SENSITIVE = [] include Aws::Structure end |
#encrypted ⇒ Boolean
Indicates whether the EBS volume is encrypted. Encrypted volumes can only be attached to instances that support Amazon EBS encryption. If you are creating a volume from a snapshot, you can’t specify an encryption value.
56122 56123 56124 56125 56126 56127 56128 56129 56130 56131 56132 56133 56134 56135 |
# File 'lib/aws-sdk-ec2/types.rb', line 56122 class LaunchTemplateEbsBlockDeviceRequest < Struct.new( :encrypted, :delete_on_termination, :iops, :kms_key_id, :snapshot_id, :volume_size, :volume_type, :throughput, :volume_initialization_rate, :ebs_card_index) SENSITIVE = [] include Aws::Structure end |
#iops ⇒ Integer
The number of I/O operations per second (IOPS). For ‘gp3`, `io1`, and `io2` volumes, this represents the number of IOPS that are provisioned for the volume. For `gp2` volumes, this represents the baseline performance of the volume and the rate at which the volume accumulates I/O credits for bursting.
The following are the supported values for each volume type:
-
‘gp3`: 3,000 - 80,000 IOPS
-
‘io1`: 100 - 64,000 IOPS
-
‘io2`: 100 - 256,000 IOPS
For ‘io2` volumes, you can achieve up to 256,000 IOPS on [instances built on the Nitro System]. On other instances, you can achieve performance up to 32,000 IOPS.
This parameter is supported for ‘io1`, `io2`, and `gp3` volumes only.
[1]: docs.aws.amazon.com/ec2/latest/instancetypes/ec2-nitro-instances.html
56122 56123 56124 56125 56126 56127 56128 56129 56130 56131 56132 56133 56134 56135 |
# File 'lib/aws-sdk-ec2/types.rb', line 56122 class LaunchTemplateEbsBlockDeviceRequest < Struct.new( :encrypted, :delete_on_termination, :iops, :kms_key_id, :snapshot_id, :volume_size, :volume_type, :throughput, :volume_initialization_rate, :ebs_card_index) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
Identifier (key ID, key alias, key ARN, or alias ARN) of the customer managed KMS key to use for EBS encryption.
56122 56123 56124 56125 56126 56127 56128 56129 56130 56131 56132 56133 56134 56135 |
# File 'lib/aws-sdk-ec2/types.rb', line 56122 class LaunchTemplateEbsBlockDeviceRequest < Struct.new( :encrypted, :delete_on_termination, :iops, :kms_key_id, :snapshot_id, :volume_size, :volume_type, :throughput, :volume_initialization_rate, :ebs_card_index) SENSITIVE = [] include Aws::Structure end |
#snapshot_id ⇒ String
The ID of the snapshot.
56122 56123 56124 56125 56126 56127 56128 56129 56130 56131 56132 56133 56134 56135 |
# File 'lib/aws-sdk-ec2/types.rb', line 56122 class LaunchTemplateEbsBlockDeviceRequest < Struct.new( :encrypted, :delete_on_termination, :iops, :kms_key_id, :snapshot_id, :volume_size, :volume_type, :throughput, :volume_initialization_rate, :ebs_card_index) SENSITIVE = [] include Aws::Structure end |
#throughput ⇒ Integer
The throughput to provision for a ‘gp3` volume, with a maximum of 2,000 MiB/s.
Valid Range: Minimum value of 125. Maximum value of 2,000.
56122 56123 56124 56125 56126 56127 56128 56129 56130 56131 56132 56133 56134 56135 |
# File 'lib/aws-sdk-ec2/types.rb', line 56122 class LaunchTemplateEbsBlockDeviceRequest < Struct.new( :encrypted, :delete_on_termination, :iops, :kms_key_id, :snapshot_id, :volume_size, :volume_type, :throughput, :volume_initialization_rate, :ebs_card_index) SENSITIVE = [] include Aws::Structure end |
#volume_initialization_rate ⇒ Integer
Specifies the Amazon EBS Provisioned Rate for Volume Initialization (volume initialization rate), in MiB/s, at which to download the snapshot blocks from Amazon S3 to the volume. This is also known as *volume initialization*. Specifying a volume initialization rate ensures that the volume is initialized at a predictable and consistent rate after creation.
This parameter is supported only for volumes created from snapshots. Omit this parameter if:
-
You want to create the volume using fast snapshot restore. You must specify a snapshot that is enabled for fast snapshot restore. In this case, the volume is fully initialized at creation.
<note markdown=“1”> If you specify a snapshot that is enabled for fast snapshot restore and a volume initialization rate, the volume will be initialized at the specified rate instead of fast snapshot restore.
</note> -
You want to create a volume that is initialized at the default rate.
For more information, see [ Initialize Amazon EBS volumes] in the *Amazon EC2 User Guide*.
Valid range: 100 - 300 MiB/s
[1]: docs.aws.amazon.com/ebs/latest/userguide/initalize-volume.html
56122 56123 56124 56125 56126 56127 56128 56129 56130 56131 56132 56133 56134 56135 |
# File 'lib/aws-sdk-ec2/types.rb', line 56122 class LaunchTemplateEbsBlockDeviceRequest < Struct.new( :encrypted, :delete_on_termination, :iops, :kms_key_id, :snapshot_id, :volume_size, :volume_type, :throughput, :volume_initialization_rate, :ebs_card_index) SENSITIVE = [] include Aws::Structure end |
#volume_size ⇒ Integer
The size of the volume, in GiBs. You must specify either a snapshot ID or a volume size. The following are the supported volumes sizes for each volume type:
-
‘gp2`: 1 - 16,384 GiB
-
‘gp3`: 1 - 65,536 GiB
-
‘io1`: 4 - 16,384 GiB
-
‘io2`: 4 - 65,536 GiB
-
‘st1` and `sc1`: 125 - 16,384 GiB
-
‘standard`: 1 - 1024 GiB
56122 56123 56124 56125 56126 56127 56128 56129 56130 56131 56132 56133 56134 56135 |
# File 'lib/aws-sdk-ec2/types.rb', line 56122 class LaunchTemplateEbsBlockDeviceRequest < Struct.new( :encrypted, :delete_on_termination, :iops, :kms_key_id, :snapshot_id, :volume_size, :volume_type, :throughput, :volume_initialization_rate, :ebs_card_index) SENSITIVE = [] include Aws::Structure end |
#volume_type ⇒ String
The volume type. For more information, see [Amazon EBS volume types] in the *Amazon EBS User Guide*.
[1]: docs.aws.amazon.com/ebs/latest/userguide/ebs-volume-types.html
56122 56123 56124 56125 56126 56127 56128 56129 56130 56131 56132 56133 56134 56135 |
# File 'lib/aws-sdk-ec2/types.rb', line 56122 class LaunchTemplateEbsBlockDeviceRequest < Struct.new( :encrypted, :delete_on_termination, :iops, :kms_key_id, :snapshot_id, :volume_size, :volume_type, :throughput, :volume_initialization_rate, :ebs_card_index) SENSITIVE = [] include Aws::Structure end |