Class: Aws::EC2::Types::LaunchTemplateInstanceNetworkInterfaceSpecification
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::LaunchTemplateInstanceNetworkInterfaceSpecification
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a network interface.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#associate_carrier_ip_address ⇒ Boolean
Indicates whether to associate a Carrier IP address with eth0 for a new network interface.
-
#associate_public_ip_address ⇒ Boolean
Indicates whether to associate a public IPv4 address with eth0 for a new network interface.
-
#connection_tracking_specification ⇒ Types::ConnectionTrackingSpecification
A security group connection tracking specification that enables you to set the timeout for connection tracking on an Elastic network interface.
-
#delete_on_termination ⇒ Boolean
Indicates whether the network interface is deleted when the instance is terminated.
-
#description ⇒ String
A description for the network interface.
-
#device_index ⇒ Integer
The device index for the network interface attachment.
-
#ena_queue_count ⇒ Integer
The number of ENA queues created with the instance.
-
#ena_srd_specification ⇒ Types::LaunchTemplateEnaSrdSpecification
Contains the ENA Express settings for instances launched from your launch template.
-
#groups ⇒ Array<String>
The IDs of one or more security groups.
-
#interface_type ⇒ String
The type of network interface.
-
#ipv_4_prefix_count ⇒ Integer
The number of IPv4 prefixes that Amazon Web Services automatically assigned to the network interface.
-
#ipv_4_prefixes ⇒ Array<Types::Ipv4PrefixSpecificationResponse>
One or more IPv4 prefixes assigned to the network interface.
-
#ipv_6_address_count ⇒ Integer
The number of IPv6 addresses for the network interface.
-
#ipv_6_addresses ⇒ Array<Types::InstanceIpv6Address>
The IPv6 addresses for the network interface.
-
#ipv_6_prefix_count ⇒ Integer
The number of IPv6 prefixes that Amazon Web Services automatically assigned to the network interface.
-
#ipv_6_prefixes ⇒ Array<Types::Ipv6PrefixSpecificationResponse>
One or more IPv6 prefixes assigned to the network interface.
-
#network_card_index ⇒ Integer
The index of the network card.
-
#network_interface_id ⇒ String
The ID of the network interface.
-
#primary_ipv_6 ⇒ Boolean
The primary IPv6 address of the network interface.
-
#private_ip_address ⇒ String
The primary private IPv4 address of the network interface.
-
#private_ip_addresses ⇒ Array<Types::PrivateIpAddressSpecification>
One or more private IPv4 addresses.
-
#secondary_private_ip_address_count ⇒ Integer
The number of secondary private IPv4 addresses for the network interface.
-
#subnet_id ⇒ String
The ID of the subnet for the network interface.
Instance Attribute Details
#associate_carrier_ip_address ⇒ Boolean
Indicates whether to associate a Carrier IP address with eth0 for a new network interface.
Use this option when you launch an instance in a Wavelength Zone and want to associate a Carrier IP address with the network interface. For more information about Carrier IP addresses, see Carrier IP address in the Wavelength Developer Guide.
61651 61652 61653 61654 61655 61656 61657 61658 61659 61660 61661 61662 61663 61664 61665 61666 61667 61668 61669 61670 61671 61672 61673 61674 61675 61676 61677 |
# File 'lib/aws-sdk-ec2/types.rb', line 61651 class LaunchTemplateInstanceNetworkInterfaceSpecification < Struct.new( :associate_carrier_ip_address, :associate_public_ip_address, :delete_on_termination, :description, :device_index, :groups, :interface_type, :ipv_6_address_count, :ipv_6_addresses, :network_interface_id, :private_ip_address, :private_ip_addresses, :secondary_private_ip_address_count, :subnet_id, :network_card_index, :ipv_4_prefixes, :ipv_4_prefix_count, :ipv_6_prefixes, :ipv_6_prefix_count, :primary_ipv_6, :ena_srd_specification, :connection_tracking_specification, :ena_queue_count) SENSITIVE = [] include Aws::Structure end |
#associate_public_ip_address ⇒ Boolean
Indicates whether to associate a public IPv4 address with eth0 for a new network interface.
Amazon Web Services charges for all public IPv4 addresses, including public IPv4 addresses associated with running instances and Elastic IP addresses. For more information, see the Public IPv4 Address tab on the Amazon VPC pricing page.
61651 61652 61653 61654 61655 61656 61657 61658 61659 61660 61661 61662 61663 61664 61665 61666 61667 61668 61669 61670 61671 61672 61673 61674 61675 61676 61677 |
# File 'lib/aws-sdk-ec2/types.rb', line 61651 class LaunchTemplateInstanceNetworkInterfaceSpecification < Struct.new( :associate_carrier_ip_address, :associate_public_ip_address, :delete_on_termination, :description, :device_index, :groups, :interface_type, :ipv_6_address_count, :ipv_6_addresses, :network_interface_id, :private_ip_address, :private_ip_addresses, :secondary_private_ip_address_count, :subnet_id, :network_card_index, :ipv_4_prefixes, :ipv_4_prefix_count, :ipv_6_prefixes, :ipv_6_prefix_count, :primary_ipv_6, :ena_srd_specification, :connection_tracking_specification, :ena_queue_count) SENSITIVE = [] include Aws::Structure end |
#connection_tracking_specification ⇒ Types::ConnectionTrackingSpecification
A security group connection tracking specification that enables you to set the timeout for connection tracking on an Elastic network interface. For more information, see Idle connection tracking timeout in the Amazon EC2 User Guide.
61651 61652 61653 61654 61655 61656 61657 61658 61659 61660 61661 61662 61663 61664 61665 61666 61667 61668 61669 61670 61671 61672 61673 61674 61675 61676 61677 |
# File 'lib/aws-sdk-ec2/types.rb', line 61651 class LaunchTemplateInstanceNetworkInterfaceSpecification < Struct.new( :associate_carrier_ip_address, :associate_public_ip_address, :delete_on_termination, :description, :device_index, :groups, :interface_type, :ipv_6_address_count, :ipv_6_addresses, :network_interface_id, :private_ip_address, :private_ip_addresses, :secondary_private_ip_address_count, :subnet_id, :network_card_index, :ipv_4_prefixes, :ipv_4_prefix_count, :ipv_6_prefixes, :ipv_6_prefix_count, :primary_ipv_6, :ena_srd_specification, :connection_tracking_specification, :ena_queue_count) SENSITIVE = [] include Aws::Structure end |
#delete_on_termination ⇒ Boolean
Indicates whether the network interface is deleted when the instance is terminated.
61651 61652 61653 61654 61655 61656 61657 61658 61659 61660 61661 61662 61663 61664 61665 61666 61667 61668 61669 61670 61671 61672 61673 61674 61675 61676 61677 |
# File 'lib/aws-sdk-ec2/types.rb', line 61651 class LaunchTemplateInstanceNetworkInterfaceSpecification < Struct.new( :associate_carrier_ip_address, :associate_public_ip_address, :delete_on_termination, :description, :device_index, :groups, :interface_type, :ipv_6_address_count, :ipv_6_addresses, :network_interface_id, :private_ip_address, :private_ip_addresses, :secondary_private_ip_address_count, :subnet_id, :network_card_index, :ipv_4_prefixes, :ipv_4_prefix_count, :ipv_6_prefixes, :ipv_6_prefix_count, :primary_ipv_6, :ena_srd_specification, :connection_tracking_specification, :ena_queue_count) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description for the network interface.
61651 61652 61653 61654 61655 61656 61657 61658 61659 61660 61661 61662 61663 61664 61665 61666 61667 61668 61669 61670 61671 61672 61673 61674 61675 61676 61677 |
# File 'lib/aws-sdk-ec2/types.rb', line 61651 class LaunchTemplateInstanceNetworkInterfaceSpecification < Struct.new( :associate_carrier_ip_address, :associate_public_ip_address, :delete_on_termination, :description, :device_index, :groups, :interface_type, :ipv_6_address_count, :ipv_6_addresses, :network_interface_id, :private_ip_address, :private_ip_addresses, :secondary_private_ip_address_count, :subnet_id, :network_card_index, :ipv_4_prefixes, :ipv_4_prefix_count, :ipv_6_prefixes, :ipv_6_prefix_count, :primary_ipv_6, :ena_srd_specification, :connection_tracking_specification, :ena_queue_count) SENSITIVE = [] include Aws::Structure end |
#device_index ⇒ Integer
The device index for the network interface attachment.
61651 61652 61653 61654 61655 61656 61657 61658 61659 61660 61661 61662 61663 61664 61665 61666 61667 61668 61669 61670 61671 61672 61673 61674 61675 61676 61677 |
# File 'lib/aws-sdk-ec2/types.rb', line 61651 class LaunchTemplateInstanceNetworkInterfaceSpecification < Struct.new( :associate_carrier_ip_address, :associate_public_ip_address, :delete_on_termination, :description, :device_index, :groups, :interface_type, :ipv_6_address_count, :ipv_6_addresses, :network_interface_id, :private_ip_address, :private_ip_addresses, :secondary_private_ip_address_count, :subnet_id, :network_card_index, :ipv_4_prefixes, :ipv_4_prefix_count, :ipv_6_prefixes, :ipv_6_prefix_count, :primary_ipv_6, :ena_srd_specification, :connection_tracking_specification, :ena_queue_count) SENSITIVE = [] include Aws::Structure end |
#ena_queue_count ⇒ Integer
The number of ENA queues created with the instance.
61651 61652 61653 61654 61655 61656 61657 61658 61659 61660 61661 61662 61663 61664 61665 61666 61667 61668 61669 61670 61671 61672 61673 61674 61675 61676 61677 |
# File 'lib/aws-sdk-ec2/types.rb', line 61651 class LaunchTemplateInstanceNetworkInterfaceSpecification < Struct.new( :associate_carrier_ip_address, :associate_public_ip_address, :delete_on_termination, :description, :device_index, :groups, :interface_type, :ipv_6_address_count, :ipv_6_addresses, :network_interface_id, :private_ip_address, :private_ip_addresses, :secondary_private_ip_address_count, :subnet_id, :network_card_index, :ipv_4_prefixes, :ipv_4_prefix_count, :ipv_6_prefixes, :ipv_6_prefix_count, :primary_ipv_6, :ena_srd_specification, :connection_tracking_specification, :ena_queue_count) SENSITIVE = [] include Aws::Structure end |
#ena_srd_specification ⇒ Types::LaunchTemplateEnaSrdSpecification
Contains the ENA Express settings for instances launched from your launch template.
61651 61652 61653 61654 61655 61656 61657 61658 61659 61660 61661 61662 61663 61664 61665 61666 61667 61668 61669 61670 61671 61672 61673 61674 61675 61676 61677 |
# File 'lib/aws-sdk-ec2/types.rb', line 61651 class LaunchTemplateInstanceNetworkInterfaceSpecification < Struct.new( :associate_carrier_ip_address, :associate_public_ip_address, :delete_on_termination, :description, :device_index, :groups, :interface_type, :ipv_6_address_count, :ipv_6_addresses, :network_interface_id, :private_ip_address, :private_ip_addresses, :secondary_private_ip_address_count, :subnet_id, :network_card_index, :ipv_4_prefixes, :ipv_4_prefix_count, :ipv_6_prefixes, :ipv_6_prefix_count, :primary_ipv_6, :ena_srd_specification, :connection_tracking_specification, :ena_queue_count) SENSITIVE = [] include Aws::Structure end |
#groups ⇒ Array<String>
The IDs of one or more security groups.
61651 61652 61653 61654 61655 61656 61657 61658 61659 61660 61661 61662 61663 61664 61665 61666 61667 61668 61669 61670 61671 61672 61673 61674 61675 61676 61677 |
# File 'lib/aws-sdk-ec2/types.rb', line 61651 class LaunchTemplateInstanceNetworkInterfaceSpecification < Struct.new( :associate_carrier_ip_address, :associate_public_ip_address, :delete_on_termination, :description, :device_index, :groups, :interface_type, :ipv_6_address_count, :ipv_6_addresses, :network_interface_id, :private_ip_address, :private_ip_addresses, :secondary_private_ip_address_count, :subnet_id, :network_card_index, :ipv_4_prefixes, :ipv_4_prefix_count, :ipv_6_prefixes, :ipv_6_prefix_count, :primary_ipv_6, :ena_srd_specification, :connection_tracking_specification, :ena_queue_count) SENSITIVE = [] include Aws::Structure end |
#interface_type ⇒ String
The type of network interface.
61651 61652 61653 61654 61655 61656 61657 61658 61659 61660 61661 61662 61663 61664 61665 61666 61667 61668 61669 61670 61671 61672 61673 61674 61675 61676 61677 |
# File 'lib/aws-sdk-ec2/types.rb', line 61651 class LaunchTemplateInstanceNetworkInterfaceSpecification < Struct.new( :associate_carrier_ip_address, :associate_public_ip_address, :delete_on_termination, :description, :device_index, :groups, :interface_type, :ipv_6_address_count, :ipv_6_addresses, :network_interface_id, :private_ip_address, :private_ip_addresses, :secondary_private_ip_address_count, :subnet_id, :network_card_index, :ipv_4_prefixes, :ipv_4_prefix_count, :ipv_6_prefixes, :ipv_6_prefix_count, :primary_ipv_6, :ena_srd_specification, :connection_tracking_specification, :ena_queue_count) SENSITIVE = [] include Aws::Structure end |
#ipv_4_prefix_count ⇒ Integer
The number of IPv4 prefixes that Amazon Web Services automatically assigned to the network interface.
61651 61652 61653 61654 61655 61656 61657 61658 61659 61660 61661 61662 61663 61664 61665 61666 61667 61668 61669 61670 61671 61672 61673 61674 61675 61676 61677 |
# File 'lib/aws-sdk-ec2/types.rb', line 61651 class LaunchTemplateInstanceNetworkInterfaceSpecification < Struct.new( :associate_carrier_ip_address, :associate_public_ip_address, :delete_on_termination, :description, :device_index, :groups, :interface_type, :ipv_6_address_count, :ipv_6_addresses, :network_interface_id, :private_ip_address, :private_ip_addresses, :secondary_private_ip_address_count, :subnet_id, :network_card_index, :ipv_4_prefixes, :ipv_4_prefix_count, :ipv_6_prefixes, :ipv_6_prefix_count, :primary_ipv_6, :ena_srd_specification, :connection_tracking_specification, :ena_queue_count) SENSITIVE = [] include Aws::Structure end |
#ipv_4_prefixes ⇒ Array<Types::Ipv4PrefixSpecificationResponse>
One or more IPv4 prefixes assigned to the network interface.
61651 61652 61653 61654 61655 61656 61657 61658 61659 61660 61661 61662 61663 61664 61665 61666 61667 61668 61669 61670 61671 61672 61673 61674 61675 61676 61677 |
# File 'lib/aws-sdk-ec2/types.rb', line 61651 class LaunchTemplateInstanceNetworkInterfaceSpecification < Struct.new( :associate_carrier_ip_address, :associate_public_ip_address, :delete_on_termination, :description, :device_index, :groups, :interface_type, :ipv_6_address_count, :ipv_6_addresses, :network_interface_id, :private_ip_address, :private_ip_addresses, :secondary_private_ip_address_count, :subnet_id, :network_card_index, :ipv_4_prefixes, :ipv_4_prefix_count, :ipv_6_prefixes, :ipv_6_prefix_count, :primary_ipv_6, :ena_srd_specification, :connection_tracking_specification, :ena_queue_count) SENSITIVE = [] include Aws::Structure end |
#ipv_6_address_count ⇒ Integer
The number of IPv6 addresses for the network interface.
61651 61652 61653 61654 61655 61656 61657 61658 61659 61660 61661 61662 61663 61664 61665 61666 61667 61668 61669 61670 61671 61672 61673 61674 61675 61676 61677 |
# File 'lib/aws-sdk-ec2/types.rb', line 61651 class LaunchTemplateInstanceNetworkInterfaceSpecification < Struct.new( :associate_carrier_ip_address, :associate_public_ip_address, :delete_on_termination, :description, :device_index, :groups, :interface_type, :ipv_6_address_count, :ipv_6_addresses, :network_interface_id, :private_ip_address, :private_ip_addresses, :secondary_private_ip_address_count, :subnet_id, :network_card_index, :ipv_4_prefixes, :ipv_4_prefix_count, :ipv_6_prefixes, :ipv_6_prefix_count, :primary_ipv_6, :ena_srd_specification, :connection_tracking_specification, :ena_queue_count) SENSITIVE = [] include Aws::Structure end |
#ipv_6_addresses ⇒ Array<Types::InstanceIpv6Address>
The IPv6 addresses for the network interface.
61651 61652 61653 61654 61655 61656 61657 61658 61659 61660 61661 61662 61663 61664 61665 61666 61667 61668 61669 61670 61671 61672 61673 61674 61675 61676 61677 |
# File 'lib/aws-sdk-ec2/types.rb', line 61651 class LaunchTemplateInstanceNetworkInterfaceSpecification < Struct.new( :associate_carrier_ip_address, :associate_public_ip_address, :delete_on_termination, :description, :device_index, :groups, :interface_type, :ipv_6_address_count, :ipv_6_addresses, :network_interface_id, :private_ip_address, :private_ip_addresses, :secondary_private_ip_address_count, :subnet_id, :network_card_index, :ipv_4_prefixes, :ipv_4_prefix_count, :ipv_6_prefixes, :ipv_6_prefix_count, :primary_ipv_6, :ena_srd_specification, :connection_tracking_specification, :ena_queue_count) SENSITIVE = [] include Aws::Structure end |
#ipv_6_prefix_count ⇒ Integer
The number of IPv6 prefixes that Amazon Web Services automatically assigned to the network interface.
61651 61652 61653 61654 61655 61656 61657 61658 61659 61660 61661 61662 61663 61664 61665 61666 61667 61668 61669 61670 61671 61672 61673 61674 61675 61676 61677 |
# File 'lib/aws-sdk-ec2/types.rb', line 61651 class LaunchTemplateInstanceNetworkInterfaceSpecification < Struct.new( :associate_carrier_ip_address, :associate_public_ip_address, :delete_on_termination, :description, :device_index, :groups, :interface_type, :ipv_6_address_count, :ipv_6_addresses, :network_interface_id, :private_ip_address, :private_ip_addresses, :secondary_private_ip_address_count, :subnet_id, :network_card_index, :ipv_4_prefixes, :ipv_4_prefix_count, :ipv_6_prefixes, :ipv_6_prefix_count, :primary_ipv_6, :ena_srd_specification, :connection_tracking_specification, :ena_queue_count) SENSITIVE = [] include Aws::Structure end |
#ipv_6_prefixes ⇒ Array<Types::Ipv6PrefixSpecificationResponse>
One or more IPv6 prefixes assigned to the network interface.
61651 61652 61653 61654 61655 61656 61657 61658 61659 61660 61661 61662 61663 61664 61665 61666 61667 61668 61669 61670 61671 61672 61673 61674 61675 61676 61677 |
# File 'lib/aws-sdk-ec2/types.rb', line 61651 class LaunchTemplateInstanceNetworkInterfaceSpecification < Struct.new( :associate_carrier_ip_address, :associate_public_ip_address, :delete_on_termination, :description, :device_index, :groups, :interface_type, :ipv_6_address_count, :ipv_6_addresses, :network_interface_id, :private_ip_address, :private_ip_addresses, :secondary_private_ip_address_count, :subnet_id, :network_card_index, :ipv_4_prefixes, :ipv_4_prefix_count, :ipv_6_prefixes, :ipv_6_prefix_count, :primary_ipv_6, :ena_srd_specification, :connection_tracking_specification, :ena_queue_count) SENSITIVE = [] include Aws::Structure end |
#network_card_index ⇒ Integer
The index of the network card.
61651 61652 61653 61654 61655 61656 61657 61658 61659 61660 61661 61662 61663 61664 61665 61666 61667 61668 61669 61670 61671 61672 61673 61674 61675 61676 61677 |
# File 'lib/aws-sdk-ec2/types.rb', line 61651 class LaunchTemplateInstanceNetworkInterfaceSpecification < Struct.new( :associate_carrier_ip_address, :associate_public_ip_address, :delete_on_termination, :description, :device_index, :groups, :interface_type, :ipv_6_address_count, :ipv_6_addresses, :network_interface_id, :private_ip_address, :private_ip_addresses, :secondary_private_ip_address_count, :subnet_id, :network_card_index, :ipv_4_prefixes, :ipv_4_prefix_count, :ipv_6_prefixes, :ipv_6_prefix_count, :primary_ipv_6, :ena_srd_specification, :connection_tracking_specification, :ena_queue_count) SENSITIVE = [] include Aws::Structure end |
#network_interface_id ⇒ String
The ID of the network interface.
61651 61652 61653 61654 61655 61656 61657 61658 61659 61660 61661 61662 61663 61664 61665 61666 61667 61668 61669 61670 61671 61672 61673 61674 61675 61676 61677 |
# File 'lib/aws-sdk-ec2/types.rb', line 61651 class LaunchTemplateInstanceNetworkInterfaceSpecification < Struct.new( :associate_carrier_ip_address, :associate_public_ip_address, :delete_on_termination, :description, :device_index, :groups, :interface_type, :ipv_6_address_count, :ipv_6_addresses, :network_interface_id, :private_ip_address, :private_ip_addresses, :secondary_private_ip_address_count, :subnet_id, :network_card_index, :ipv_4_prefixes, :ipv_4_prefix_count, :ipv_6_prefixes, :ipv_6_prefix_count, :primary_ipv_6, :ena_srd_specification, :connection_tracking_specification, :ena_queue_count) SENSITIVE = [] include Aws::Structure end |
#primary_ipv_6 ⇒ Boolean
The primary IPv6 address of the network interface. When you enable an IPv6 GUA address to be a primary IPv6, the first IPv6 GUA will be made the primary IPv6 address until the instance is terminated or the network interface is detached. For more information about primary IPv6 addresses, see RunInstances.
61651 61652 61653 61654 61655 61656 61657 61658 61659 61660 61661 61662 61663 61664 61665 61666 61667 61668 61669 61670 61671 61672 61673 61674 61675 61676 61677 |
# File 'lib/aws-sdk-ec2/types.rb', line 61651 class LaunchTemplateInstanceNetworkInterfaceSpecification < Struct.new( :associate_carrier_ip_address, :associate_public_ip_address, :delete_on_termination, :description, :device_index, :groups, :interface_type, :ipv_6_address_count, :ipv_6_addresses, :network_interface_id, :private_ip_address, :private_ip_addresses, :secondary_private_ip_address_count, :subnet_id, :network_card_index, :ipv_4_prefixes, :ipv_4_prefix_count, :ipv_6_prefixes, :ipv_6_prefix_count, :primary_ipv_6, :ena_srd_specification, :connection_tracking_specification, :ena_queue_count) SENSITIVE = [] include Aws::Structure end |
#private_ip_address ⇒ String
The primary private IPv4 address of the network interface.
61651 61652 61653 61654 61655 61656 61657 61658 61659 61660 61661 61662 61663 61664 61665 61666 61667 61668 61669 61670 61671 61672 61673 61674 61675 61676 61677 |
# File 'lib/aws-sdk-ec2/types.rb', line 61651 class LaunchTemplateInstanceNetworkInterfaceSpecification < Struct.new( :associate_carrier_ip_address, :associate_public_ip_address, :delete_on_termination, :description, :device_index, :groups, :interface_type, :ipv_6_address_count, :ipv_6_addresses, :network_interface_id, :private_ip_address, :private_ip_addresses, :secondary_private_ip_address_count, :subnet_id, :network_card_index, :ipv_4_prefixes, :ipv_4_prefix_count, :ipv_6_prefixes, :ipv_6_prefix_count, :primary_ipv_6, :ena_srd_specification, :connection_tracking_specification, :ena_queue_count) SENSITIVE = [] include Aws::Structure end |
#private_ip_addresses ⇒ Array<Types::PrivateIpAddressSpecification>
One or more private IPv4 addresses.
61651 61652 61653 61654 61655 61656 61657 61658 61659 61660 61661 61662 61663 61664 61665 61666 61667 61668 61669 61670 61671 61672 61673 61674 61675 61676 61677 |
# File 'lib/aws-sdk-ec2/types.rb', line 61651 class LaunchTemplateInstanceNetworkInterfaceSpecification < Struct.new( :associate_carrier_ip_address, :associate_public_ip_address, :delete_on_termination, :description, :device_index, :groups, :interface_type, :ipv_6_address_count, :ipv_6_addresses, :network_interface_id, :private_ip_address, :private_ip_addresses, :secondary_private_ip_address_count, :subnet_id, :network_card_index, :ipv_4_prefixes, :ipv_4_prefix_count, :ipv_6_prefixes, :ipv_6_prefix_count, :primary_ipv_6, :ena_srd_specification, :connection_tracking_specification, :ena_queue_count) SENSITIVE = [] include Aws::Structure end |
#secondary_private_ip_address_count ⇒ Integer
The number of secondary private IPv4 addresses for the network interface.
61651 61652 61653 61654 61655 61656 61657 61658 61659 61660 61661 61662 61663 61664 61665 61666 61667 61668 61669 61670 61671 61672 61673 61674 61675 61676 61677 |
# File 'lib/aws-sdk-ec2/types.rb', line 61651 class LaunchTemplateInstanceNetworkInterfaceSpecification < Struct.new( :associate_carrier_ip_address, :associate_public_ip_address, :delete_on_termination, :description, :device_index, :groups, :interface_type, :ipv_6_address_count, :ipv_6_addresses, :network_interface_id, :private_ip_address, :private_ip_addresses, :secondary_private_ip_address_count, :subnet_id, :network_card_index, :ipv_4_prefixes, :ipv_4_prefix_count, :ipv_6_prefixes, :ipv_6_prefix_count, :primary_ipv_6, :ena_srd_specification, :connection_tracking_specification, :ena_queue_count) SENSITIVE = [] include Aws::Structure end |
#subnet_id ⇒ String
The ID of the subnet for the network interface.
61651 61652 61653 61654 61655 61656 61657 61658 61659 61660 61661 61662 61663 61664 61665 61666 61667 61668 61669 61670 61671 61672 61673 61674 61675 61676 61677 |
# File 'lib/aws-sdk-ec2/types.rb', line 61651 class LaunchTemplateInstanceNetworkInterfaceSpecification < Struct.new( :associate_carrier_ip_address, :associate_public_ip_address, :delete_on_termination, :description, :device_index, :groups, :interface_type, :ipv_6_address_count, :ipv_6_addresses, :network_interface_id, :private_ip_address, :private_ip_addresses, :secondary_private_ip_address_count, :subnet_id, :network_card_index, :ipv_4_prefixes, :ipv_4_prefix_count, :ipv_6_prefixes, :ipv_6_prefix_count, :primary_ipv_6, :ena_srd_specification, :connection_tracking_specification, :ena_queue_count) SENSITIVE = [] include Aws::Structure end |