Class: Aws::EC2::Types::LaunchTemplateSpecification
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::LaunchTemplateSpecification
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the launch template to use.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#launch_template_id ⇒ String
The ID of the launch template.
-
#launch_template_name ⇒ String
The name of the launch template.
-
#version ⇒ String
The launch template version number,
$Latest, or$Default.
Instance Attribute Details
#launch_template_id ⇒ String
The ID of the launch template.
You must specify either the launch template ID or the launch template name, but not both.
59299 59300 59301 59302 59303 59304 59305 |
# File 'lib/aws-sdk-ec2/types.rb', line 59299 class LaunchTemplateSpecification < Struct.new( :launch_template_id, :launch_template_name, :version) SENSITIVE = [] include Aws::Structure end |
#launch_template_name ⇒ String
The name of the launch template.
You must specify either the launch template ID or the launch template name, but not both.
59299 59300 59301 59302 59303 59304 59305 |
# File 'lib/aws-sdk-ec2/types.rb', line 59299 class LaunchTemplateSpecification < Struct.new( :launch_template_id, :launch_template_name, :version) SENSITIVE = [] include Aws::Structure end |
#version ⇒ String
The launch template version number, $Latest, or $Default.
A value of $Latest uses the latest version of the launch template.
A value of $Default uses the default version of the launch
template.
Default: The default version of the launch template.
59299 59300 59301 59302 59303 59304 59305 |
# File 'lib/aws-sdk-ec2/types.rb', line 59299 class LaunchTemplateSpecification < Struct.new( :launch_template_id, :launch_template_name, :version) SENSITIVE = [] include Aws::Structure end |