Class: Aws::EC2::Types::LocalGatewayVirtualInterface
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::LocalGatewayVirtualInterface
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a local gateway virtual interface.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration_state ⇒ String
The current state of the local gateway virtual interface.
-
#local_address ⇒ String
The local address.
-
#local_bgp_asn ⇒ Integer
The Border Gateway Protocol (BGP) Autonomous System Number (ASN) of the local gateway.
-
#local_gateway_id ⇒ String
The ID of the local gateway.
-
#local_gateway_virtual_interface_arn ⇒ String
The Amazon Resource Number (ARN) of the local gateway virtual interface.
-
#local_gateway_virtual_interface_group_id ⇒ String
The ID of the local gateway virtual interface group.
-
#local_gateway_virtual_interface_id ⇒ String
The ID of the virtual interface.
-
#outpost_lag_id ⇒ String
The Outpost LAG ID.
-
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the local gateway virtual interface.
-
#peer_address ⇒ String
The peer address.
-
#peer_bgp_asn ⇒ Integer
The peer BGP ASN.
-
#peer_bgp_asn_extended ⇒ Integer
The extended 32-bit ASN of the BGP peer for use with larger ASN values.
-
#tags ⇒ Array<Types::Tag>
The tags assigned to the virtual interface.
-
#vlan ⇒ Integer
The ID of the VLAN.
Instance Attribute Details
#configuration_state ⇒ String
The current state of the local gateway virtual interface.
63228 63229 63230 63231 63232 63233 63234 63235 63236 63237 63238 63239 63240 63241 63242 63243 63244 63245 |
# File 'lib/aws-sdk-ec2/types.rb', line 63228 class LocalGatewayVirtualInterface < Struct.new( :local_gateway_virtual_interface_id, :local_gateway_id, :local_gateway_virtual_interface_group_id, :local_gateway_virtual_interface_arn, :outpost_lag_id, :vlan, :local_address, :peer_address, :local_bgp_asn, :peer_bgp_asn, :peer_bgp_asn_extended, :owner_id, :tags, :configuration_state) SENSITIVE = [] include Aws::Structure end |
#local_address ⇒ String
The local address.
63228 63229 63230 63231 63232 63233 63234 63235 63236 63237 63238 63239 63240 63241 63242 63243 63244 63245 |
# File 'lib/aws-sdk-ec2/types.rb', line 63228 class LocalGatewayVirtualInterface < Struct.new( :local_gateway_virtual_interface_id, :local_gateway_id, :local_gateway_virtual_interface_group_id, :local_gateway_virtual_interface_arn, :outpost_lag_id, :vlan, :local_address, :peer_address, :local_bgp_asn, :peer_bgp_asn, :peer_bgp_asn_extended, :owner_id, :tags, :configuration_state) SENSITIVE = [] include Aws::Structure end |
#local_bgp_asn ⇒ Integer
The Border Gateway Protocol (BGP) Autonomous System Number (ASN) of the local gateway.
63228 63229 63230 63231 63232 63233 63234 63235 63236 63237 63238 63239 63240 63241 63242 63243 63244 63245 |
# File 'lib/aws-sdk-ec2/types.rb', line 63228 class LocalGatewayVirtualInterface < Struct.new( :local_gateway_virtual_interface_id, :local_gateway_id, :local_gateway_virtual_interface_group_id, :local_gateway_virtual_interface_arn, :outpost_lag_id, :vlan, :local_address, :peer_address, :local_bgp_asn, :peer_bgp_asn, :peer_bgp_asn_extended, :owner_id, :tags, :configuration_state) SENSITIVE = [] include Aws::Structure end |
#local_gateway_id ⇒ String
The ID of the local gateway.
63228 63229 63230 63231 63232 63233 63234 63235 63236 63237 63238 63239 63240 63241 63242 63243 63244 63245 |
# File 'lib/aws-sdk-ec2/types.rb', line 63228 class LocalGatewayVirtualInterface < Struct.new( :local_gateway_virtual_interface_id, :local_gateway_id, :local_gateway_virtual_interface_group_id, :local_gateway_virtual_interface_arn, :outpost_lag_id, :vlan, :local_address, :peer_address, :local_bgp_asn, :peer_bgp_asn, :peer_bgp_asn_extended, :owner_id, :tags, :configuration_state) SENSITIVE = [] include Aws::Structure end |
#local_gateway_virtual_interface_arn ⇒ String
The Amazon Resource Number (ARN) of the local gateway virtual interface.
63228 63229 63230 63231 63232 63233 63234 63235 63236 63237 63238 63239 63240 63241 63242 63243 63244 63245 |
# File 'lib/aws-sdk-ec2/types.rb', line 63228 class LocalGatewayVirtualInterface < Struct.new( :local_gateway_virtual_interface_id, :local_gateway_id, :local_gateway_virtual_interface_group_id, :local_gateway_virtual_interface_arn, :outpost_lag_id, :vlan, :local_address, :peer_address, :local_bgp_asn, :peer_bgp_asn, :peer_bgp_asn_extended, :owner_id, :tags, :configuration_state) SENSITIVE = [] include Aws::Structure end |
#local_gateway_virtual_interface_group_id ⇒ String
The ID of the local gateway virtual interface group.
63228 63229 63230 63231 63232 63233 63234 63235 63236 63237 63238 63239 63240 63241 63242 63243 63244 63245 |
# File 'lib/aws-sdk-ec2/types.rb', line 63228 class LocalGatewayVirtualInterface < Struct.new( :local_gateway_virtual_interface_id, :local_gateway_id, :local_gateway_virtual_interface_group_id, :local_gateway_virtual_interface_arn, :outpost_lag_id, :vlan, :local_address, :peer_address, :local_bgp_asn, :peer_bgp_asn, :peer_bgp_asn_extended, :owner_id, :tags, :configuration_state) SENSITIVE = [] include Aws::Structure end |
#local_gateway_virtual_interface_id ⇒ String
The ID of the virtual interface.
63228 63229 63230 63231 63232 63233 63234 63235 63236 63237 63238 63239 63240 63241 63242 63243 63244 63245 |
# File 'lib/aws-sdk-ec2/types.rb', line 63228 class LocalGatewayVirtualInterface < Struct.new( :local_gateway_virtual_interface_id, :local_gateway_id, :local_gateway_virtual_interface_group_id, :local_gateway_virtual_interface_arn, :outpost_lag_id, :vlan, :local_address, :peer_address, :local_bgp_asn, :peer_bgp_asn, :peer_bgp_asn_extended, :owner_id, :tags, :configuration_state) SENSITIVE = [] include Aws::Structure end |
#outpost_lag_id ⇒ String
The Outpost LAG ID.
63228 63229 63230 63231 63232 63233 63234 63235 63236 63237 63238 63239 63240 63241 63242 63243 63244 63245 |
# File 'lib/aws-sdk-ec2/types.rb', line 63228 class LocalGatewayVirtualInterface < Struct.new( :local_gateway_virtual_interface_id, :local_gateway_id, :local_gateway_virtual_interface_group_id, :local_gateway_virtual_interface_arn, :outpost_lag_id, :vlan, :local_address, :peer_address, :local_bgp_asn, :peer_bgp_asn, :peer_bgp_asn_extended, :owner_id, :tags, :configuration_state) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the local gateway virtual interface.
63228 63229 63230 63231 63232 63233 63234 63235 63236 63237 63238 63239 63240 63241 63242 63243 63244 63245 |
# File 'lib/aws-sdk-ec2/types.rb', line 63228 class LocalGatewayVirtualInterface < Struct.new( :local_gateway_virtual_interface_id, :local_gateway_id, :local_gateway_virtual_interface_group_id, :local_gateway_virtual_interface_arn, :outpost_lag_id, :vlan, :local_address, :peer_address, :local_bgp_asn, :peer_bgp_asn, :peer_bgp_asn_extended, :owner_id, :tags, :configuration_state) SENSITIVE = [] include Aws::Structure end |
#peer_address ⇒ String
The peer address.
63228 63229 63230 63231 63232 63233 63234 63235 63236 63237 63238 63239 63240 63241 63242 63243 63244 63245 |
# File 'lib/aws-sdk-ec2/types.rb', line 63228 class LocalGatewayVirtualInterface < Struct.new( :local_gateway_virtual_interface_id, :local_gateway_id, :local_gateway_virtual_interface_group_id, :local_gateway_virtual_interface_arn, :outpost_lag_id, :vlan, :local_address, :peer_address, :local_bgp_asn, :peer_bgp_asn, :peer_bgp_asn_extended, :owner_id, :tags, :configuration_state) SENSITIVE = [] include Aws::Structure end |
#peer_bgp_asn ⇒ Integer
The peer BGP ASN.
63228 63229 63230 63231 63232 63233 63234 63235 63236 63237 63238 63239 63240 63241 63242 63243 63244 63245 |
# File 'lib/aws-sdk-ec2/types.rb', line 63228 class LocalGatewayVirtualInterface < Struct.new( :local_gateway_virtual_interface_id, :local_gateway_id, :local_gateway_virtual_interface_group_id, :local_gateway_virtual_interface_arn, :outpost_lag_id, :vlan, :local_address, :peer_address, :local_bgp_asn, :peer_bgp_asn, :peer_bgp_asn_extended, :owner_id, :tags, :configuration_state) SENSITIVE = [] include Aws::Structure end |
#peer_bgp_asn_extended ⇒ Integer
The extended 32-bit ASN of the BGP peer for use with larger ASN values.
63228 63229 63230 63231 63232 63233 63234 63235 63236 63237 63238 63239 63240 63241 63242 63243 63244 63245 |
# File 'lib/aws-sdk-ec2/types.rb', line 63228 class LocalGatewayVirtualInterface < Struct.new( :local_gateway_virtual_interface_id, :local_gateway_id, :local_gateway_virtual_interface_group_id, :local_gateway_virtual_interface_arn, :outpost_lag_id, :vlan, :local_address, :peer_address, :local_bgp_asn, :peer_bgp_asn, :peer_bgp_asn_extended, :owner_id, :tags, :configuration_state) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags assigned to the virtual interface.
63228 63229 63230 63231 63232 63233 63234 63235 63236 63237 63238 63239 63240 63241 63242 63243 63244 63245 |
# File 'lib/aws-sdk-ec2/types.rb', line 63228 class LocalGatewayVirtualInterface < Struct.new( :local_gateway_virtual_interface_id, :local_gateway_id, :local_gateway_virtual_interface_group_id, :local_gateway_virtual_interface_arn, :outpost_lag_id, :vlan, :local_address, :peer_address, :local_bgp_asn, :peer_bgp_asn, :peer_bgp_asn_extended, :owner_id, :tags, :configuration_state) SENSITIVE = [] include Aws::Structure end |
#vlan ⇒ Integer
The ID of the VLAN.
63228 63229 63230 63231 63232 63233 63234 63235 63236 63237 63238 63239 63240 63241 63242 63243 63244 63245 |
# File 'lib/aws-sdk-ec2/types.rb', line 63228 class LocalGatewayVirtualInterface < Struct.new( :local_gateway_virtual_interface_id, :local_gateway_id, :local_gateway_virtual_interface_group_id, :local_gateway_virtual_interface_arn, :outpost_lag_id, :vlan, :local_address, :peer_address, :local_bgp_asn, :peer_bgp_asn, :peer_bgp_asn_extended, :owner_id, :tags, :configuration_state) SENSITIVE = [] include Aws::Structure end |