Class: Aws::EC2::Types::LockedSnapshotsInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::LockedSnapshotsInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Information about a locked snapshot.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cool_off_period ⇒ Integer
The compliance mode cooling-off period, in hours.
-
#cool_off_period_expires_on ⇒ Time
The date and time at which the compliance mode cooling-off period expires, in the UTC time zone (
YYYY-MM-DDThh:mm:ss.sssZ). -
#lock_created_on ⇒ Time
The date and time at which the snapshot was locked, in the UTC time zone (
YYYY-MM-DDThh:mm:ss.sssZ). -
#lock_duration ⇒ Integer
The period of time for which the snapshot is locked, in days.
-
#lock_duration_start_time ⇒ Time
The date and time at which the lock duration started, in the UTC time zone (
YYYY-MM-DDThh:mm:ss.sssZ). -
#lock_expires_on ⇒ Time
The date and time at which the lock will expire, in the UTC time zone (
YYYY-MM-DDThh:mm:ss.sssZ). -
#lock_state ⇒ String
The state of the snapshot lock.
-
#owner_id ⇒ String
The account ID of the Amazon Web Services account that owns the snapshot.
-
#snapshot_id ⇒ String
The ID of the snapshot.
Instance Attribute Details
#cool_off_period ⇒ Integer
The compliance mode cooling-off period, in hours.
62179 62180 62181 62182 62183 62184 62185 62186 62187 62188 62189 62190 62191 |
# File 'lib/aws-sdk-ec2/types.rb', line 62179 class LockedSnapshotsInfo < Struct.new( :owner_id, :snapshot_id, :lock_state, :lock_duration, :cool_off_period, :cool_off_period_expires_on, :lock_created_on, :lock_duration_start_time, :lock_expires_on) SENSITIVE = [] include Aws::Structure end |
#cool_off_period_expires_on ⇒ Time
The date and time at which the compliance mode cooling-off period
expires, in the UTC time zone (YYYY-MM-DDThh:mm:ss.sssZ).
62179 62180 62181 62182 62183 62184 62185 62186 62187 62188 62189 62190 62191 |
# File 'lib/aws-sdk-ec2/types.rb', line 62179 class LockedSnapshotsInfo < Struct.new( :owner_id, :snapshot_id, :lock_state, :lock_duration, :cool_off_period, :cool_off_period_expires_on, :lock_created_on, :lock_duration_start_time, :lock_expires_on) SENSITIVE = [] include Aws::Structure end |
#lock_created_on ⇒ Time
The date and time at which the snapshot was locked, in the UTC time
zone (YYYY-MM-DDThh:mm:ss.sssZ).
62179 62180 62181 62182 62183 62184 62185 62186 62187 62188 62189 62190 62191 |
# File 'lib/aws-sdk-ec2/types.rb', line 62179 class LockedSnapshotsInfo < Struct.new( :owner_id, :snapshot_id, :lock_state, :lock_duration, :cool_off_period, :cool_off_period_expires_on, :lock_created_on, :lock_duration_start_time, :lock_expires_on) SENSITIVE = [] include Aws::Structure end |
#lock_duration ⇒ Integer
The period of time for which the snapshot is locked, in days.
62179 62180 62181 62182 62183 62184 62185 62186 62187 62188 62189 62190 62191 |
# File 'lib/aws-sdk-ec2/types.rb', line 62179 class LockedSnapshotsInfo < Struct.new( :owner_id, :snapshot_id, :lock_state, :lock_duration, :cool_off_period, :cool_off_period_expires_on, :lock_created_on, :lock_duration_start_time, :lock_expires_on) SENSITIVE = [] include Aws::Structure end |
#lock_duration_start_time ⇒ Time
The date and time at which the lock duration started, in the UTC
time zone (YYYY-MM-DDThh:mm:ss.sssZ).
If you lock a snapshot that is in the pending state, the lock
duration starts only once the snapshot enters the completed state.
62179 62180 62181 62182 62183 62184 62185 62186 62187 62188 62189 62190 62191 |
# File 'lib/aws-sdk-ec2/types.rb', line 62179 class LockedSnapshotsInfo < Struct.new( :owner_id, :snapshot_id, :lock_state, :lock_duration, :cool_off_period, :cool_off_period_expires_on, :lock_created_on, :lock_duration_start_time, :lock_expires_on) SENSITIVE = [] include Aws::Structure end |
#lock_expires_on ⇒ Time
The date and time at which the lock will expire, in the UTC time
zone (YYYY-MM-DDThh:mm:ss.sssZ).
62179 62180 62181 62182 62183 62184 62185 62186 62187 62188 62189 62190 62191 |
# File 'lib/aws-sdk-ec2/types.rb', line 62179 class LockedSnapshotsInfo < Struct.new( :owner_id, :snapshot_id, :lock_state, :lock_duration, :cool_off_period, :cool_off_period_expires_on, :lock_created_on, :lock_duration_start_time, :lock_expires_on) SENSITIVE = [] include Aws::Structure end |
#lock_state ⇒ String
The state of the snapshot lock. Valid states include:
-
compliance-cooloff- The snapshot has been locked in compliance mode but it is still within the cooling-off period. The snapshot can't be deleted, but it can be unlocked and the lock settings can be modified by users with appropriate permissions. -
governance- The snapshot is locked in governance mode. The snapshot can't be deleted, but it can be unlocked and the lock settings can be modified by users with appropriate permissions. -
compliance- The snapshot is locked in compliance mode and the cooling-off period has expired. The snapshot can't be unlocked or deleted. The lock duration can only be increased by users with appropriate permissions. -
expired- The snapshot was locked in compliance or governance mode but the lock duration has expired. The snapshot is not locked and can be deleted.
62179 62180 62181 62182 62183 62184 62185 62186 62187 62188 62189 62190 62191 |
# File 'lib/aws-sdk-ec2/types.rb', line 62179 class LockedSnapshotsInfo < Struct.new( :owner_id, :snapshot_id, :lock_state, :lock_duration, :cool_off_period, :cool_off_period_expires_on, :lock_created_on, :lock_duration_start_time, :lock_expires_on) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
The account ID of the Amazon Web Services account that owns the snapshot.
62179 62180 62181 62182 62183 62184 62185 62186 62187 62188 62189 62190 62191 |
# File 'lib/aws-sdk-ec2/types.rb', line 62179 class LockedSnapshotsInfo < Struct.new( :owner_id, :snapshot_id, :lock_state, :lock_duration, :cool_off_period, :cool_off_period_expires_on, :lock_created_on, :lock_duration_start_time, :lock_expires_on) SENSITIVE = [] include Aws::Structure end |
#snapshot_id ⇒ String
The ID of the snapshot.
62179 62180 62181 62182 62183 62184 62185 62186 62187 62188 62189 62190 62191 |
# File 'lib/aws-sdk-ec2/types.rb', line 62179 class LockedSnapshotsInfo < Struct.new( :owner_id, :snapshot_id, :lock_state, :lock_duration, :cool_off_period, :cool_off_period_expires_on, :lock_created_on, :lock_duration_start_time, :lock_expires_on) SENSITIVE = [] include Aws::Structure end |