Class: Aws::EC2::Types::MacSystemIntegrityProtectionConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::MacSystemIntegrityProtectionConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the configuration for a System Integrity Protection (SIP) modification task.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#apple_internal ⇒ String
Indicates whether Apple Internal was enabled or disabled by the task.
-
#base_system ⇒ String
Indicates whether Base System was enabled or disabled by the task.
-
#d_trace_restrictions ⇒ String
Indicates whether Dtrace Restrictions was enabled or disabled by the task.
-
#debugging_restrictions ⇒ String
Indicates whether Debugging Restrictions was enabled or disabled by the task.
-
#filesystem_protections ⇒ String
Indicates whether Filesystem Protections was enabled or disabled by the task.
-
#kext_signing ⇒ String
Indicates whether Kext Signing was enabled or disabled by the task.
-
#nvram_protections ⇒ String
Indicates whether NVRAM Protections was enabled or disabled by the task.
-
#status ⇒ String
Indicates SIP was enabled or disabled by the task.
Instance Attribute Details
#apple_internal ⇒ String
Indicates whether Apple Internal was enabled or disabled by the task.
59957 59958 59959 59960 59961 59962 59963 59964 59965 59966 59967 59968 |
# File 'lib/aws-sdk-ec2/types.rb', line 59957 class MacSystemIntegrityProtectionConfiguration < Struct.new( :apple_internal, :base_system, :debugging_restrictions, :d_trace_restrictions, :filesystem_protections, :kext_signing, :nvram_protections, :status) SENSITIVE = [] include Aws::Structure end |
#base_system ⇒ String
Indicates whether Base System was enabled or disabled by the task.
59957 59958 59959 59960 59961 59962 59963 59964 59965 59966 59967 59968 |
# File 'lib/aws-sdk-ec2/types.rb', line 59957 class MacSystemIntegrityProtectionConfiguration < Struct.new( :apple_internal, :base_system, :debugging_restrictions, :d_trace_restrictions, :filesystem_protections, :kext_signing, :nvram_protections, :status) SENSITIVE = [] include Aws::Structure end |
#d_trace_restrictions ⇒ String
Indicates whether Dtrace Restrictions was enabled or disabled by the task.
59957 59958 59959 59960 59961 59962 59963 59964 59965 59966 59967 59968 |
# File 'lib/aws-sdk-ec2/types.rb', line 59957 class MacSystemIntegrityProtectionConfiguration < Struct.new( :apple_internal, :base_system, :debugging_restrictions, :d_trace_restrictions, :filesystem_protections, :kext_signing, :nvram_protections, :status) SENSITIVE = [] include Aws::Structure end |
#debugging_restrictions ⇒ String
Indicates whether Debugging Restrictions was enabled or disabled by the task.
59957 59958 59959 59960 59961 59962 59963 59964 59965 59966 59967 59968 |
# File 'lib/aws-sdk-ec2/types.rb', line 59957 class MacSystemIntegrityProtectionConfiguration < Struct.new( :apple_internal, :base_system, :debugging_restrictions, :d_trace_restrictions, :filesystem_protections, :kext_signing, :nvram_protections, :status) SENSITIVE = [] include Aws::Structure end |
#filesystem_protections ⇒ String
Indicates whether Filesystem Protections was enabled or disabled by the task.
59957 59958 59959 59960 59961 59962 59963 59964 59965 59966 59967 59968 |
# File 'lib/aws-sdk-ec2/types.rb', line 59957 class MacSystemIntegrityProtectionConfiguration < Struct.new( :apple_internal, :base_system, :debugging_restrictions, :d_trace_restrictions, :filesystem_protections, :kext_signing, :nvram_protections, :status) SENSITIVE = [] include Aws::Structure end |
#kext_signing ⇒ String
Indicates whether Kext Signing was enabled or disabled by the task.
59957 59958 59959 59960 59961 59962 59963 59964 59965 59966 59967 59968 |
# File 'lib/aws-sdk-ec2/types.rb', line 59957 class MacSystemIntegrityProtectionConfiguration < Struct.new( :apple_internal, :base_system, :debugging_restrictions, :d_trace_restrictions, :filesystem_protections, :kext_signing, :nvram_protections, :status) SENSITIVE = [] include Aws::Structure end |
#nvram_protections ⇒ String
Indicates whether NVRAM Protections was enabled or disabled by the task.
59957 59958 59959 59960 59961 59962 59963 59964 59965 59966 59967 59968 |
# File 'lib/aws-sdk-ec2/types.rb', line 59957 class MacSystemIntegrityProtectionConfiguration < Struct.new( :apple_internal, :base_system, :debugging_restrictions, :d_trace_restrictions, :filesystem_protections, :kext_signing, :nvram_protections, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Indicates SIP was enabled or disabled by the task.
59957 59958 59959 59960 59961 59962 59963 59964 59965 59966 59967 59968 |
# File 'lib/aws-sdk-ec2/types.rb', line 59957 class MacSystemIntegrityProtectionConfiguration < Struct.new( :apple_internal, :base_system, :debugging_restrictions, :d_trace_restrictions, :filesystem_protections, :kext_signing, :nvram_protections, :status) SENSITIVE = [] include Aws::Structure end |