Class: Aws::EC2::Types::MediaDeviceInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::MediaDeviceInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the media accelerators for the instance type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#count ⇒ Integer
The number of media accelerators for the instance type.
-
#manufacturer ⇒ String
The manufacturer of the media accelerator.
-
#memory_info ⇒ Types::MediaDeviceMemoryInfo
Describes the memory available to the media accelerator.
-
#name ⇒ String
The name of the media accelerator.
Instance Attribute Details
#count ⇒ Integer
The number of media accelerators for the instance type.
60164 60165 60166 60167 60168 60169 60170 60171 |
# File 'lib/aws-sdk-ec2/types.rb', line 60164 class MediaDeviceInfo < Struct.new( :count, :name, :manufacturer, :memory_info) SENSITIVE = [] include Aws::Structure end |
#manufacturer ⇒ String
The manufacturer of the media accelerator.
60164 60165 60166 60167 60168 60169 60170 60171 |
# File 'lib/aws-sdk-ec2/types.rb', line 60164 class MediaDeviceInfo < Struct.new( :count, :name, :manufacturer, :memory_info) SENSITIVE = [] include Aws::Structure end |
#memory_info ⇒ Types::MediaDeviceMemoryInfo
Describes the memory available to the media accelerator.
60164 60165 60166 60167 60168 60169 60170 60171 |
# File 'lib/aws-sdk-ec2/types.rb', line 60164 class MediaDeviceInfo < Struct.new( :count, :name, :manufacturer, :memory_info) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the media accelerator.
60164 60165 60166 60167 60168 60169 60170 60171 |
# File 'lib/aws-sdk-ec2/types.rb', line 60164 class MediaDeviceInfo < Struct.new( :count, :name, :manufacturer, :memory_info) SENSITIVE = [] include Aws::Structure end |