Class: Aws::EC2::Types::MetricValue

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Represents a single metric value with its associated statistic, such as the sum or average of unused capacity hours.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#metricString

The name of the metric.

Returns:

  • (String)


59030
59031
59032
59033
59034
59035
# File 'lib/aws-sdk-ec2/types.rb', line 59030

class MetricValue < Struct.new(
  :metric,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#valueFloat

The numerical value of the metric for the specified statistic and time period.

Returns:

  • (Float)


59030
59031
59032
59033
59034
59035
# File 'lib/aws-sdk-ec2/types.rb', line 59030

class MetricValue < Struct.new(
  :metric,
  :value)
  SENSITIVE = []
  include Aws::Structure
end