Class: Aws::EC2::Types::ModifyApplicationStatusCheckRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyApplicationStatusCheckRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aggregation ⇒ String
The aggregation setting for the application status check.
-
#application_status_check_id ⇒ String
The ID of the application status check to modify.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure that the operation completes no more than one time.
-
#device_index ⇒ Integer
The index of the network device to use for the health check.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#failure_threshold ⇒ Integer
The number of consecutive failed health checks before the application status is considered impaired.
-
#health_check_paths ⇒ Array<Types::HealthCheckPathRequestObject>
The health check paths to use for the application status check.
-
#initialization_grace_period_seconds ⇒ Integer
The number of seconds to wait before starting health checks after an instance is launched.
-
#interval ⇒ Integer
The interval, in seconds, between health checks.
-
#ip_scope ⇒ String
The IP scope to use for the health check.
-
#ip_version ⇒ String
The IP version to use for the health check.
-
#path ⇒ String
The URL path to use for the health check HTTP request (for example,
/healthor/status). -
#port ⇒ Integer
The port to use for the health check.
-
#protocol ⇒ String
The protocol to use for the health check.
-
#status_code_matcher ⇒ String
The HTTP status codes that indicate a successful health check response.
-
#success_threshold ⇒ Integer
The number of consecutive successful health checks before the application status is considered healthy.
-
#timeout ⇒ Integer
The amount of time, in seconds, to wait for a health check response before considering it failed.
Instance Attribute Details
#aggregation ⇒ String
The aggregation setting for the application status check. When set
to included, the result of this check contributes to the
instance-level application status reported by
DescribeApplicationStatus. When set to excluded, the check runs
independently and does not affect the instance-level status. Valid
values: included | excluded.
64356 64357 64358 64359 64360 64361 64362 64363 64364 64365 64366 64367 64368 64369 64370 64371 64372 64373 64374 64375 64376 |
# File 'lib/aws-sdk-ec2/types.rb', line 64356 class ModifyApplicationStatusCheckRequest < Struct.new( :application_status_check_id, :aggregation, :health_check_paths, :protocol, :port, :path, :device_index, :ip_version, :ip_scope, :interval, :timeout, :failure_threshold, :success_threshold, :status_code_matcher, :initialization_grace_period_seconds, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#application_status_check_id ⇒ String
The ID of the application status check to modify.
64356 64357 64358 64359 64360 64361 64362 64363 64364 64365 64366 64367 64368 64369 64370 64371 64372 64373 64374 64375 64376 |
# File 'lib/aws-sdk-ec2/types.rb', line 64356 class ModifyApplicationStatusCheckRequest < Struct.new( :application_status_check_id, :aggregation, :health_check_paths, :protocol, :port, :path, :device_index, :ip_version, :ip_scope, :interval, :timeout, :failure_threshold, :success_threshold, :status_code_matcher, :initialization_grace_period_seconds, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure that the operation completes no more than one time. If you retry a request with the same token, the service ignores the request but does not return an error. For more information, see Ensuring idempotency.
A suitable default value is auto-generated. You should normally not need to pass this option.
64356 64357 64358 64359 64360 64361 64362 64363 64364 64365 64366 64367 64368 64369 64370 64371 64372 64373 64374 64375 64376 |
# File 'lib/aws-sdk-ec2/types.rb', line 64356 class ModifyApplicationStatusCheckRequest < Struct.new( :application_status_check_id, :aggregation, :health_check_paths, :protocol, :port, :path, :device_index, :ip_version, :ip_scope, :interval, :timeout, :failure_threshold, :success_threshold, :status_code_matcher, :initialization_grace_period_seconds, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#device_index ⇒ Integer
The index of the network device to use for the health check. The value must be greater than or equal to 0.
64356 64357 64358 64359 64360 64361 64362 64363 64364 64365 64366 64367 64368 64369 64370 64371 64372 64373 64374 64375 64376 |
# File 'lib/aws-sdk-ec2/types.rb', line 64356 class ModifyApplicationStatusCheckRequest < Struct.new( :application_status_check_id, :aggregation, :health_check_paths, :protocol, :port, :path, :device_index, :ip_version, :ip_scope, :interval, :timeout, :failure_threshold, :success_threshold, :status_code_matcher, :initialization_grace_period_seconds, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
64356 64357 64358 64359 64360 64361 64362 64363 64364 64365 64366 64367 64368 64369 64370 64371 64372 64373 64374 64375 64376 |
# File 'lib/aws-sdk-ec2/types.rb', line 64356 class ModifyApplicationStatusCheckRequest < Struct.new( :application_status_check_id, :aggregation, :health_check_paths, :protocol, :port, :path, :device_index, :ip_version, :ip_scope, :interval, :timeout, :failure_threshold, :success_threshold, :status_code_matcher, :initialization_grace_period_seconds, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#failure_threshold ⇒ Integer
The number of consecutive failed health checks before the application status is considered impaired. The value must be greater than 0.
64356 64357 64358 64359 64360 64361 64362 64363 64364 64365 64366 64367 64368 64369 64370 64371 64372 64373 64374 64375 64376 |
# File 'lib/aws-sdk-ec2/types.rb', line 64356 class ModifyApplicationStatusCheckRequest < Struct.new( :application_status_check_id, :aggregation, :health_check_paths, :protocol, :port, :path, :device_index, :ip_version, :ip_scope, :interval, :timeout, :failure_threshold, :success_threshold, :status_code_matcher, :initialization_grace_period_seconds, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#health_check_paths ⇒ Array<Types::HealthCheckPathRequestObject>
The health check paths to use for the application status check.
64356 64357 64358 64359 64360 64361 64362 64363 64364 64365 64366 64367 64368 64369 64370 64371 64372 64373 64374 64375 64376 |
# File 'lib/aws-sdk-ec2/types.rb', line 64356 class ModifyApplicationStatusCheckRequest < Struct.new( :application_status_check_id, :aggregation, :health_check_paths, :protocol, :port, :path, :device_index, :ip_version, :ip_scope, :interval, :timeout, :failure_threshold, :success_threshold, :status_code_matcher, :initialization_grace_period_seconds, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#initialization_grace_period_seconds ⇒ Integer
The number of seconds to wait before starting health checks after an instance is launched. Valid values: 1 to 600.
64356 64357 64358 64359 64360 64361 64362 64363 64364 64365 64366 64367 64368 64369 64370 64371 64372 64373 64374 64375 64376 |
# File 'lib/aws-sdk-ec2/types.rb', line 64356 class ModifyApplicationStatusCheckRequest < Struct.new( :application_status_check_id, :aggregation, :health_check_paths, :protocol, :port, :path, :device_index, :ip_version, :ip_scope, :interval, :timeout, :failure_threshold, :success_threshold, :status_code_matcher, :initialization_grace_period_seconds, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#interval ⇒ Integer
The interval, in seconds, between health checks. Valid value: 60.
64356 64357 64358 64359 64360 64361 64362 64363 64364 64365 64366 64367 64368 64369 64370 64371 64372 64373 64374 64375 64376 |
# File 'lib/aws-sdk-ec2/types.rb', line 64356 class ModifyApplicationStatusCheckRequest < Struct.new( :application_status_check_id, :aggregation, :health_check_paths, :protocol, :port, :path, :device_index, :ip_version, :ip_scope, :interval, :timeout, :failure_threshold, :success_threshold, :status_code_matcher, :initialization_grace_period_seconds, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#ip_scope ⇒ String
The IP scope to use for the health check. Valid value: private.
64356 64357 64358 64359 64360 64361 64362 64363 64364 64365 64366 64367 64368 64369 64370 64371 64372 64373 64374 64375 64376 |
# File 'lib/aws-sdk-ec2/types.rb', line 64356 class ModifyApplicationStatusCheckRequest < Struct.new( :application_status_check_id, :aggregation, :health_check_paths, :protocol, :port, :path, :device_index, :ip_version, :ip_scope, :interval, :timeout, :failure_threshold, :success_threshold, :status_code_matcher, :initialization_grace_period_seconds, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#ip_version ⇒ String
The IP version to use for the health check. Valid values: ipv4 and
ipv6.
64356 64357 64358 64359 64360 64361 64362 64363 64364 64365 64366 64367 64368 64369 64370 64371 64372 64373 64374 64375 64376 |
# File 'lib/aws-sdk-ec2/types.rb', line 64356 class ModifyApplicationStatusCheckRequest < Struct.new( :application_status_check_id, :aggregation, :health_check_paths, :protocol, :port, :path, :device_index, :ip_version, :ip_scope, :interval, :timeout, :failure_threshold, :success_threshold, :status_code_matcher, :initialization_grace_period_seconds, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#path ⇒ String
The URL path to use for the health check HTTP request (for example,
/health or /status).
64356 64357 64358 64359 64360 64361 64362 64363 64364 64365 64366 64367 64368 64369 64370 64371 64372 64373 64374 64375 64376 |
# File 'lib/aws-sdk-ec2/types.rb', line 64356 class ModifyApplicationStatusCheckRequest < Struct.new( :application_status_check_id, :aggregation, :health_check_paths, :protocol, :port, :path, :device_index, :ip_version, :ip_scope, :interval, :timeout, :failure_threshold, :success_threshold, :status_code_matcher, :initialization_grace_period_seconds, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
The port to use for the health check. Valid values: 1 to 65535.
64356 64357 64358 64359 64360 64361 64362 64363 64364 64365 64366 64367 64368 64369 64370 64371 64372 64373 64374 64375 64376 |
# File 'lib/aws-sdk-ec2/types.rb', line 64356 class ModifyApplicationStatusCheckRequest < Struct.new( :application_status_check_id, :aggregation, :health_check_paths, :protocol, :port, :path, :device_index, :ip_version, :ip_scope, :interval, :timeout, :failure_threshold, :success_threshold, :status_code_matcher, :initialization_grace_period_seconds, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#protocol ⇒ String
The protocol to use for the health check. Valid values: http |
https.
64356 64357 64358 64359 64360 64361 64362 64363 64364 64365 64366 64367 64368 64369 64370 64371 64372 64373 64374 64375 64376 |
# File 'lib/aws-sdk-ec2/types.rb', line 64356 class ModifyApplicationStatusCheckRequest < Struct.new( :application_status_check_id, :aggregation, :health_check_paths, :protocol, :port, :path, :device_index, :ip_version, :ip_scope, :interval, :timeout, :failure_threshold, :success_threshold, :status_code_matcher, :initialization_grace_period_seconds, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#status_code_matcher ⇒ String
The HTTP status codes that indicate a successful health check
response. Specify a comma-separated list of individual status codes
or ranges, for example, 200,202,300-399. For a range, the first
value must be less than the second value. Maximum length: 64
characters.
64356 64357 64358 64359 64360 64361 64362 64363 64364 64365 64366 64367 64368 64369 64370 64371 64372 64373 64374 64375 64376 |
# File 'lib/aws-sdk-ec2/types.rb', line 64356 class ModifyApplicationStatusCheckRequest < Struct.new( :application_status_check_id, :aggregation, :health_check_paths, :protocol, :port, :path, :device_index, :ip_version, :ip_scope, :interval, :timeout, :failure_threshold, :success_threshold, :status_code_matcher, :initialization_grace_period_seconds, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#success_threshold ⇒ Integer
The number of consecutive successful health checks before the application status is considered healthy. The value must be greater than 0.
64356 64357 64358 64359 64360 64361 64362 64363 64364 64365 64366 64367 64368 64369 64370 64371 64372 64373 64374 64375 64376 |
# File 'lib/aws-sdk-ec2/types.rb', line 64356 class ModifyApplicationStatusCheckRequest < Struct.new( :application_status_check_id, :aggregation, :health_check_paths, :protocol, :port, :path, :device_index, :ip_version, :ip_scope, :interval, :timeout, :failure_threshold, :success_threshold, :status_code_matcher, :initialization_grace_period_seconds, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#timeout ⇒ Integer
The amount of time, in seconds, to wait for a health check response
before considering it failed. Valid values: 1 to 30. The value must
be less than Interval.
64356 64357 64358 64359 64360 64361 64362 64363 64364 64365 64366 64367 64368 64369 64370 64371 64372 64373 64374 64375 64376 |
# File 'lib/aws-sdk-ec2/types.rb', line 64356 class ModifyApplicationStatusCheckRequest < Struct.new( :application_status_check_id, :aggregation, :health_check_paths, :protocol, :port, :path, :device_index, :ip_version, :ip_scope, :interval, :timeout, :failure_threshold, :success_threshold, :status_code_matcher, :initialization_grace_period_seconds, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |