Class: Aws::EC2::Types::ModifyFleetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contextString

Reserved.

Returns:

  • (String)


64841
64842
64843
64844
64845
64846
64847
64848
64849
64850
# File 'lib/aws-sdk-ec2/types.rb', line 64841

class ModifyFleetRequest < Struct.new(
  :dry_run,
  :excess_capacity_termination_policy,
  :launch_template_configs,
  :fleet_id,
  :target_capacity_specification,
  :context)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


64841
64842
64843
64844
64845
64846
64847
64848
64849
64850
# File 'lib/aws-sdk-ec2/types.rb', line 64841

class ModifyFleetRequest < Struct.new(
  :dry_run,
  :excess_capacity_termination_policy,
  :launch_template_configs,
  :fleet_id,
  :target_capacity_specification,
  :context)
  SENSITIVE = []
  include Aws::Structure
end

#excess_capacity_termination_policyString

Indicates whether running instances should be terminated if the total target capacity of the EC2 Fleet is decreased below the current size of the EC2 Fleet.

Supported only for fleets of type maintain.

Returns:

  • (String)


64841
64842
64843
64844
64845
64846
64847
64848
64849
64850
# File 'lib/aws-sdk-ec2/types.rb', line 64841

class ModifyFleetRequest < Struct.new(
  :dry_run,
  :excess_capacity_termination_policy,
  :launch_template_configs,
  :fleet_id,
  :target_capacity_specification,
  :context)
  SENSITIVE = []
  include Aws::Structure
end

#fleet_idString

The ID of the EC2 Fleet.

Returns:

  • (String)


64841
64842
64843
64844
64845
64846
64847
64848
64849
64850
# File 'lib/aws-sdk-ec2/types.rb', line 64841

class ModifyFleetRequest < Struct.new(
  :dry_run,
  :excess_capacity_termination_policy,
  :launch_template_configs,
  :fleet_id,
  :target_capacity_specification,
  :context)
  SENSITIVE = []
  include Aws::Structure
end

#launch_template_configsArray<Types::FleetLaunchTemplateConfigRequest>

The launch template and overrides.



64841
64842
64843
64844
64845
64846
64847
64848
64849
64850
# File 'lib/aws-sdk-ec2/types.rb', line 64841

class ModifyFleetRequest < Struct.new(
  :dry_run,
  :excess_capacity_termination_policy,
  :launch_template_configs,
  :fleet_id,
  :target_capacity_specification,
  :context)
  SENSITIVE = []
  include Aws::Structure
end

#target_capacity_specificationTypes::TargetCapacitySpecificationRequest

The size of the EC2 Fleet.



64841
64842
64843
64844
64845
64846
64847
64848
64849
64850
# File 'lib/aws-sdk-ec2/types.rb', line 64841

class ModifyFleetRequest < Struct.new(
  :dry_run,
  :excess_capacity_termination_policy,
  :launch_template_configs,
  :fleet_id,
  :target_capacity_specification,
  :context)
  SENSITIVE = []
  include Aws::Structure
end