Class: Aws::EC2::Types::ModifyHostsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyHostsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_placement ⇒ String
Specify whether to enable or disable auto-placement.
-
#host_ids ⇒ Array<String>
The IDs of the Dedicated Hosts to modify.
-
#host_maintenance ⇒ String
Indicates whether to enable or disable host maintenance for the Dedicated Host.
-
#host_recovery ⇒ String
Indicates whether to enable or disable host recovery for the Dedicated Host.
-
#instance_family ⇒ String
Specifies the instance family to be supported by the Dedicated Host.
-
#instance_type ⇒ String
Specifies the instance type to be supported by the Dedicated Host.
Instance Attribute Details
#auto_placement ⇒ String
Specify whether to enable or disable auto-placement.
63630 63631 63632 63633 63634 63635 63636 63637 63638 63639 |
# File 'lib/aws-sdk-ec2/types.rb', line 63630 class ModifyHostsRequest < Struct.new( :host_recovery, :instance_type, :instance_family, :host_maintenance, :host_ids, :auto_placement) SENSITIVE = [] include Aws::Structure end |
#host_ids ⇒ Array<String>
The IDs of the Dedicated Hosts to modify.
63630 63631 63632 63633 63634 63635 63636 63637 63638 63639 |
# File 'lib/aws-sdk-ec2/types.rb', line 63630 class ModifyHostsRequest < Struct.new( :host_recovery, :instance_type, :instance_family, :host_maintenance, :host_ids, :auto_placement) SENSITIVE = [] include Aws::Structure end |
#host_maintenance ⇒ String
Indicates whether to enable or disable host maintenance for the Dedicated Host. For more information, see Host maintenance in the Amazon EC2 User Guide.
63630 63631 63632 63633 63634 63635 63636 63637 63638 63639 |
# File 'lib/aws-sdk-ec2/types.rb', line 63630 class ModifyHostsRequest < Struct.new( :host_recovery, :instance_type, :instance_family, :host_maintenance, :host_ids, :auto_placement) SENSITIVE = [] include Aws::Structure end |
#host_recovery ⇒ String
Indicates whether to enable or disable host recovery for the Dedicated Host. For more information, see Host recovery in the Amazon EC2 User Guide.
63630 63631 63632 63633 63634 63635 63636 63637 63638 63639 |
# File 'lib/aws-sdk-ec2/types.rb', line 63630 class ModifyHostsRequest < Struct.new( :host_recovery, :instance_type, :instance_family, :host_maintenance, :host_ids, :auto_placement) SENSITIVE = [] include Aws::Structure end |
#instance_family ⇒ String
Specifies the instance family to be supported by the Dedicated Host. Specify this parameter to modify a Dedicated Host to support multiple instance types within its current instance family.
If you want to modify a Dedicated Host to support a specific instance type only, omit this parameter and specify InstanceType instead. You cannot specify InstanceFamily and InstanceType in the same request.
63630 63631 63632 63633 63634 63635 63636 63637 63638 63639 |
# File 'lib/aws-sdk-ec2/types.rb', line 63630 class ModifyHostsRequest < Struct.new( :host_recovery, :instance_type, :instance_family, :host_maintenance, :host_ids, :auto_placement) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
Specifies the instance type to be supported by the Dedicated Host. Specify this parameter to modify a Dedicated Host to support only a specific instance type.
If you want to modify a Dedicated Host to support multiple instance types in its current instance family, omit this parameter and specify InstanceFamily instead. You cannot specify InstanceType and InstanceFamily in the same request.
63630 63631 63632 63633 63634 63635 63636 63637 63638 63639 |
# File 'lib/aws-sdk-ec2/types.rb', line 63630 class ModifyHostsRequest < Struct.new( :host_recovery, :instance_type, :instance_family, :host_maintenance, :host_ids, :auto_placement) SENSITIVE = [] include Aws::Structure end |