Class: Aws::EC2::Types::ModifyInstanceConnectEndpointRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyInstanceConnectEndpointRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#instance_connect_endpoint_id ⇒ String
The ID of the EC2 Instance Connect Endpoint to modify.
-
#ip_address_type ⇒ String
The new IP address type for the EC2 Instance Connect Endpoint.
-
#preserve_client_ip ⇒ Boolean
Indicates whether the client IP address is preserved as the source when you connect to a resource.
-
#security_group_ids ⇒ Array<String>
Changes the security groups for the EC2 Instance Connect Endpoint.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
62754 62755 62756 62757 62758 62759 62760 62761 62762 |
# File 'lib/aws-sdk-ec2/types.rb', line 62754 class ModifyInstanceConnectEndpointRequest < Struct.new( :dry_run, :instance_connect_endpoint_id, :ip_address_type, :security_group_ids, :preserve_client_ip) SENSITIVE = [] include Aws::Structure end |
#instance_connect_endpoint_id ⇒ String
The ID of the EC2 Instance Connect Endpoint to modify.
62754 62755 62756 62757 62758 62759 62760 62761 62762 |
# File 'lib/aws-sdk-ec2/types.rb', line 62754 class ModifyInstanceConnectEndpointRequest < Struct.new( :dry_run, :instance_connect_endpoint_id, :ip_address_type, :security_group_ids, :preserve_client_ip) SENSITIVE = [] include Aws::Structure end |
#ip_address_type ⇒ String
The new IP address type for the EC2 Instance Connect Endpoint.
PreserveClientIp is only supported on IPv4 EC2 Instance Connect
Endpoints. To use PreserveClientIp, the value for IpAddressType
must be ipv4.
62754 62755 62756 62757 62758 62759 62760 62761 62762 |
# File 'lib/aws-sdk-ec2/types.rb', line 62754 class ModifyInstanceConnectEndpointRequest < Struct.new( :dry_run, :instance_connect_endpoint_id, :ip_address_type, :security_group_ids, :preserve_client_ip) SENSITIVE = [] include Aws::Structure end |
#preserve_client_ip ⇒ Boolean
Indicates whether the client IP address is preserved as the source when you connect to a resource. The following are the possible values.
-
true- Use the IP address of the client. Your instance must have an IPv4 address. -
false- Use the IP address of the network interface.
62754 62755 62756 62757 62758 62759 62760 62761 62762 |
# File 'lib/aws-sdk-ec2/types.rb', line 62754 class ModifyInstanceConnectEndpointRequest < Struct.new( :dry_run, :instance_connect_endpoint_id, :ip_address_type, :security_group_ids, :preserve_client_ip) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
Changes the security groups for the EC2 Instance Connect Endpoint. The new set of groups you specify replaces the current set. You must specify at least one group, even if it's just the default security group in the VPC. You must specify the ID of the security group, not the name.
62754 62755 62756 62757 62758 62759 62760 62761 62762 |
# File 'lib/aws-sdk-ec2/types.rb', line 62754 class ModifyInstanceConnectEndpointRequest < Struct.new( :dry_run, :instance_connect_endpoint_id, :ip_address_type, :security_group_ids, :preserve_client_ip) SENSITIVE = [] include Aws::Structure end |