Class: Aws::EC2::Types::ModifyInstanceCpuOptionsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyInstanceCpuOptionsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#core_count ⇒ Integer
The number of CPU cores that are running for the specified instance after the update.
-
#instance_id ⇒ String
The ID of the instance that was updated.
-
#nested_virtualization ⇒ String
Indicates whether nested virtualization has been enabled or disabled.
-
#threads_per_core ⇒ Integer
The number of threads that are running per CPU core for the specified instance after the update.
Instance Attribute Details
#core_count ⇒ Integer
The number of CPU cores that are running for the specified instance after the update.
61186 61187 61188 61189 61190 61191 61192 61193 |
# File 'lib/aws-sdk-ec2/types.rb', line 61186 class ModifyInstanceCpuOptionsResult < Struct.new( :instance_id, :core_count, :threads_per_core, :nested_virtualization) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the instance that was updated.
61186 61187 61188 61189 61190 61191 61192 61193 |
# File 'lib/aws-sdk-ec2/types.rb', line 61186 class ModifyInstanceCpuOptionsResult < Struct.new( :instance_id, :core_count, :threads_per_core, :nested_virtualization) SENSITIVE = [] include Aws::Structure end |
#nested_virtualization ⇒ String
Indicates whether nested virtualization has been enabled or disabled.
61186 61187 61188 61189 61190 61191 61192 61193 |
# File 'lib/aws-sdk-ec2/types.rb', line 61186 class ModifyInstanceCpuOptionsResult < Struct.new( :instance_id, :core_count, :threads_per_core, :nested_virtualization) SENSITIVE = [] include Aws::Structure end |
#threads_per_core ⇒ Integer
The number of threads that are running per CPU core for the specified instance after the update.
61186 61187 61188 61189 61190 61191 61192 61193 |
# File 'lib/aws-sdk-ec2/types.rb', line 61186 class ModifyInstanceCpuOptionsResult < Struct.new( :instance_id, :core_count, :threads_per_core, :nested_virtualization) SENSITIVE = [] include Aws::Structure end |