Class: Aws::EC2::Types::ModifyInstanceEventWindowRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cron_expressionString

The cron expression of the event window, for example, `* 0-4,20-23 *

  • 1,5`.

Constraints:

  • Only hour and day of the week values are supported.

  • For day of the week values, you can specify either integers 0 through 6, or alternative single values SUN through SAT.

  • The minute, month, and year must be specified by *.

  • The hour value must be one or a multiple range, for example, 0-4 or 0-4,20-23.

  • Each hour range must be >= 2 hours, for example, 0-2 or 20-23.

  • The event window must be >= 4 hours. The combined total time ranges in the event window must be >= 4 hours.

For more information about cron expressions, see cron on the Wikipedia website.

Returns:

  • (String)


62986
62987
62988
62989
62990
62991
62992
62993
62994
# File 'lib/aws-sdk-ec2/types.rb', line 62986

class ModifyInstanceEventWindowRequest < Struct.new(
  :dry_run,
  :name,
  :instance_event_window_id,
  :time_ranges,
  :cron_expression)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


62986
62987
62988
62989
62990
62991
62992
62993
62994
# File 'lib/aws-sdk-ec2/types.rb', line 62986

class ModifyInstanceEventWindowRequest < Struct.new(
  :dry_run,
  :name,
  :instance_event_window_id,
  :time_ranges,
  :cron_expression)
  SENSITIVE = []
  include Aws::Structure
end

#instance_event_window_idString

The ID of the event window.

Returns:

  • (String)


62986
62987
62988
62989
62990
62991
62992
62993
62994
# File 'lib/aws-sdk-ec2/types.rb', line 62986

class ModifyInstanceEventWindowRequest < Struct.new(
  :dry_run,
  :name,
  :instance_event_window_id,
  :time_ranges,
  :cron_expression)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the event window.

Returns:

  • (String)


62986
62987
62988
62989
62990
62991
62992
62993
62994
# File 'lib/aws-sdk-ec2/types.rb', line 62986

class ModifyInstanceEventWindowRequest < Struct.new(
  :dry_run,
  :name,
  :instance_event_window_id,
  :time_ranges,
  :cron_expression)
  SENSITIVE = []
  include Aws::Structure
end

#time_rangesArray<Types::InstanceEventWindowTimeRangeRequest>

The time ranges of the event window.



62986
62987
62988
62989
62990
62991
62992
62993
62994
# File 'lib/aws-sdk-ec2/types.rb', line 62986

class ModifyInstanceEventWindowRequest < Struct.new(
  :dry_run,
  :name,
  :instance_event_window_id,
  :time_ranges,
  :cron_expression)
  SENSITIVE = []
  include Aws::Structure
end