Class: Aws::EC2::Types::ModifyInstanceMaintenanceOptionsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyInstanceMaintenanceOptionsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_recovery ⇒ String
Provides information on the current automatic recovery behavior of your instance.
-
#instance_id ⇒ String
The ID of the instance.
-
#reboot_migration ⇒ String
Specifies whether to attempt reboot migration during a user-initiated reboot of an instance that has a scheduled
system-rebootevent:.
Instance Attribute Details
#auto_recovery ⇒ String
Provides information on the current automatic recovery behavior of your instance.
62513 62514 62515 62516 62517 62518 62519 |
# File 'lib/aws-sdk-ec2/types.rb', line 62513 class ModifyInstanceMaintenanceOptionsResult < Struct.new( :instance_id, :auto_recovery, :reboot_migration) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the instance.
62513 62514 62515 62516 62517 62518 62519 |
# File 'lib/aws-sdk-ec2/types.rb', line 62513 class ModifyInstanceMaintenanceOptionsResult < Struct.new( :instance_id, :auto_recovery, :reboot_migration) SENSITIVE = [] include Aws::Structure end |
#reboot_migration ⇒ String
Specifies whether to attempt reboot migration during a
user-initiated reboot of an instance that has a scheduled
system-reboot event:
-
default- Amazon EC2 attempts to migrate the instance to new hardware (reboot migration). If successful, thesystem-rebootevent is cleared. If unsuccessful, an in-place reboot occurs and the event remains scheduled. -
disabled- Amazon EC2 keeps the instance on the same hardware (in-place reboot). Thesystem-rebootevent remains scheduled.
This setting only applies to supported instances that have a scheduled reboot event. For more information, see Enable or disable reboot migration in the Amazon EC2 User Guide.
62513 62514 62515 62516 62517 62518 62519 |
# File 'lib/aws-sdk-ec2/types.rb', line 62513 class ModifyInstanceMaintenanceOptionsResult < Struct.new( :instance_id, :auto_recovery, :reboot_migration) SENSITIVE = [] include Aws::Structure end |