Class: Aws::EC2::Types::ModifyInstancePlacementRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyInstancePlacementRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#affinity ⇒ String
The affinity setting for the instance.
-
#group_id ⇒ String
The Group Id of a placement group.
-
#group_name ⇒ String
The name of the placement group in which to place the instance.
-
#host_id ⇒ String
The ID of the Dedicated Host with which to associate the instance.
-
#host_resource_group_arn ⇒ String
The ARN of the host resource group in which to place the instance.
-
#instance_id ⇒ String
The ID of the instance that you are modifying.
-
#partition_number ⇒ Integer
The number of the partition in which to place the instance.
-
#tenancy ⇒ String
The tenancy for the instance.
Instance Attribute Details
#affinity ⇒ String
The affinity setting for the instance. For more information, see Host affinity in the Amazon EC2 User Guide.
66179 66180 66181 66182 66183 66184 66185 66186 66187 66188 66189 66190 |
# File 'lib/aws-sdk-ec2/types.rb', line 66179 class ModifyInstancePlacementRequest < Struct.new( :group_name, :partition_number, :host_resource_group_arn, :group_id, :instance_id, :tenancy, :affinity, :host_id) SENSITIVE = [] include Aws::Structure end |
#group_id ⇒ String
The Group Id of a placement group. You must specify the Placement Group Group Id to launch an instance in a shared placement group.
66179 66180 66181 66182 66183 66184 66185 66186 66187 66188 66189 66190 |
# File 'lib/aws-sdk-ec2/types.rb', line 66179 class ModifyInstancePlacementRequest < Struct.new( :group_name, :partition_number, :host_resource_group_arn, :group_id, :instance_id, :tenancy, :affinity, :host_id) SENSITIVE = [] include Aws::Structure end |
#group_name ⇒ String
The name of the placement group in which to place the instance. For
spread placement groups, the instance must have a tenancy of
default. For cluster and partition placement groups, the instance
must have a tenancy of default or dedicated.
To remove an instance from a placement group, specify an empty string ("").
66179 66180 66181 66182 66183 66184 66185 66186 66187 66188 66189 66190 |
# File 'lib/aws-sdk-ec2/types.rb', line 66179 class ModifyInstancePlacementRequest < Struct.new( :group_name, :partition_number, :host_resource_group_arn, :group_id, :instance_id, :tenancy, :affinity, :host_id) SENSITIVE = [] include Aws::Structure end |
#host_id ⇒ String
The ID of the Dedicated Host with which to associate the instance.
66179 66180 66181 66182 66183 66184 66185 66186 66187 66188 66189 66190 |
# File 'lib/aws-sdk-ec2/types.rb', line 66179 class ModifyInstancePlacementRequest < Struct.new( :group_name, :partition_number, :host_resource_group_arn, :group_id, :instance_id, :tenancy, :affinity, :host_id) SENSITIVE = [] include Aws::Structure end |
#host_resource_group_arn ⇒ String
The ARN of the host resource group in which to place the instance.
The instance must have a tenancy of host to specify this
parameter.
66179 66180 66181 66182 66183 66184 66185 66186 66187 66188 66189 66190 |
# File 'lib/aws-sdk-ec2/types.rb', line 66179 class ModifyInstancePlacementRequest < Struct.new( :group_name, :partition_number, :host_resource_group_arn, :group_id, :instance_id, :tenancy, :affinity, :host_id) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the instance that you are modifying.
66179 66180 66181 66182 66183 66184 66185 66186 66187 66188 66189 66190 |
# File 'lib/aws-sdk-ec2/types.rb', line 66179 class ModifyInstancePlacementRequest < Struct.new( :group_name, :partition_number, :host_resource_group_arn, :group_id, :instance_id, :tenancy, :affinity, :host_id) SENSITIVE = [] include Aws::Structure end |
#partition_number ⇒ Integer
The number of the partition in which to place the instance. Valid
only if the placement group strategy is set to partition.
66179 66180 66181 66182 66183 66184 66185 66186 66187 66188 66189 66190 |
# File 'lib/aws-sdk-ec2/types.rb', line 66179 class ModifyInstancePlacementRequest < Struct.new( :group_name, :partition_number, :host_resource_group_arn, :group_id, :instance_id, :tenancy, :affinity, :host_id) SENSITIVE = [] include Aws::Structure end |
#tenancy ⇒ String
The tenancy for the instance.
host. You can't change the tenancy from
host to dedicated or default. Attempting to make one of these
unsupported tenancy changes results in an InvalidRequest error
code.
66179 66180 66181 66182 66183 66184 66185 66186 66187 66188 66189 66190 |
# File 'lib/aws-sdk-ec2/types.rb', line 66179 class ModifyInstancePlacementRequest < Struct.new( :group_name, :partition_number, :host_resource_group_arn, :group_id, :instance_id, :tenancy, :affinity, :host_id) SENSITIVE = [] include Aws::Structure end |