Class: Aws::EC2::Types::ModifyIpamRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#add_operating_regionsArray<Types::AddIpamOperatingRegion>

Choose the operating Regions for the IPAM. Operating Regions are Amazon Web Services Regions where the IPAM is allowed to manage IP address CIDRs. IPAM only discovers and monitors resources in the Amazon Web Services Regions you select as operating Regions.

For more information about operating Regions, see Create an IPAM in the Amazon VPC IPAM User Guide.

Returns:



65168
65169
65170
65171
65172
65173
65174
65175
65176
65177
65178
65179
# File 'lib/aws-sdk-ec2/types.rb', line 65168

class ModifyIpamRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :description,
  :add_operating_regions,
  :remove_operating_regions,
  :tier,
  :enable_private_gua,
  :metered_account)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the IPAM you want to modify.

Returns:

  • (String)


65168
65169
65170
65171
65172
65173
65174
65175
65176
65177
65178
65179
# File 'lib/aws-sdk-ec2/types.rb', line 65168

class ModifyIpamRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :description,
  :add_operating_regions,
  :remove_operating_regions,
  :tier,
  :enable_private_gua,
  :metered_account)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


65168
65169
65170
65171
65172
65173
65174
65175
65176
65177
65178
65179
# File 'lib/aws-sdk-ec2/types.rb', line 65168

class ModifyIpamRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :description,
  :add_operating_regions,
  :remove_operating_regions,
  :tier,
  :enable_private_gua,
  :metered_account)
  SENSITIVE = []
  include Aws::Structure
end

#enable_private_guaBoolean

Enable this option to use your own GUA ranges as private IPv6 addresses. This option is disabled by default.

Returns:

  • (Boolean)


65168
65169
65170
65171
65172
65173
65174
65175
65176
65177
65178
65179
# File 'lib/aws-sdk-ec2/types.rb', line 65168

class ModifyIpamRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :description,
  :add_operating_regions,
  :remove_operating_regions,
  :tier,
  :enable_private_gua,
  :metered_account)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_idString

The ID of the IPAM you want to modify.

Returns:

  • (String)


65168
65169
65170
65171
65172
65173
65174
65175
65176
65177
65178
65179
# File 'lib/aws-sdk-ec2/types.rb', line 65168

class ModifyIpamRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :description,
  :add_operating_regions,
  :remove_operating_regions,
  :tier,
  :enable_private_gua,
  :metered_account)
  SENSITIVE = []
  include Aws::Structure
end

#metered_accountString

A metered account is an Amazon Web Services account that is charged for active IP addresses managed in IPAM. For more information, see Enable cost distribution in the Amazon VPC IPAM User Guide.

Possible values:

  • ipam-owner (default): The Amazon Web Services account which owns the IPAM is charged for all active IP addresses managed in IPAM.

  • resource-owner: The Amazon Web Services account that owns the IP address is charged for the active IP address.

Returns:

  • (String)


65168
65169
65170
65171
65172
65173
65174
65175
65176
65177
65178
65179
# File 'lib/aws-sdk-ec2/types.rb', line 65168

class ModifyIpamRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :description,
  :add_operating_regions,
  :remove_operating_regions,
  :tier,
  :enable_private_gua,
  :metered_account)
  SENSITIVE = []
  include Aws::Structure
end

#remove_operating_regionsArray<Types::RemoveIpamOperatingRegion>

The operating Regions to remove.



65168
65169
65170
65171
65172
65173
65174
65175
65176
65177
65178
65179
# File 'lib/aws-sdk-ec2/types.rb', line 65168

class ModifyIpamRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :description,
  :add_operating_regions,
  :remove_operating_regions,
  :tier,
  :enable_private_gua,
  :metered_account)
  SENSITIVE = []
  include Aws::Structure
end

#tierString

IPAM is offered in a Free Tier and an Advanced Tier. For more information about the features available in each tier and the costs associated with the tiers, see Amazon VPC pricing > IPAM tab.

Returns:

  • (String)


65168
65169
65170
65171
65172
65173
65174
65175
65176
65177
65178
65179
# File 'lib/aws-sdk-ec2/types.rb', line 65168

class ModifyIpamRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :description,
  :add_operating_regions,
  :remove_operating_regions,
  :tier,
  :enable_private_gua,
  :metered_account)
  SENSITIVE = []
  include Aws::Structure
end