Class: Aws::EC2::Types::ModifyIpamResourceCidrRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#current_ipam_scope_idString

The ID of the current scope that the resource CIDR is in.

Returns:

  • (String)


66624
66625
66626
66627
66628
66629
66630
66631
66632
66633
66634
# File 'lib/aws-sdk-ec2/types.rb', line 66624

class ModifyIpamResourceCidrRequest < Struct.new(
  :dry_run,
  :resource_id,
  :resource_cidr,
  :resource_region,
  :current_ipam_scope_id,
  :destination_ipam_scope_id,
  :monitored)
  SENSITIVE = []
  include Aws::Structure
end

#destination_ipam_scope_idString

The ID of the scope you want to transfer the resource CIDR to.

Returns:

  • (String)


66624
66625
66626
66627
66628
66629
66630
66631
66632
66633
66634
# File 'lib/aws-sdk-ec2/types.rb', line 66624

class ModifyIpamResourceCidrRequest < Struct.new(
  :dry_run,
  :resource_id,
  :resource_cidr,
  :resource_region,
  :current_ipam_scope_id,
  :destination_ipam_scope_id,
  :monitored)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


66624
66625
66626
66627
66628
66629
66630
66631
66632
66633
66634
# File 'lib/aws-sdk-ec2/types.rb', line 66624

class ModifyIpamResourceCidrRequest < Struct.new(
  :dry_run,
  :resource_id,
  :resource_cidr,
  :resource_region,
  :current_ipam_scope_id,
  :destination_ipam_scope_id,
  :monitored)
  SENSITIVE = []
  include Aws::Structure
end

#monitoredBoolean

Determines if the resource is monitored by IPAM. If a resource is monitored, the resource is discovered by IPAM and you can view details about the resource’s CIDR.

Returns:

  • (Boolean)


66624
66625
66626
66627
66628
66629
66630
66631
66632
66633
66634
# File 'lib/aws-sdk-ec2/types.rb', line 66624

class ModifyIpamResourceCidrRequest < Struct.new(
  :dry_run,
  :resource_id,
  :resource_cidr,
  :resource_region,
  :current_ipam_scope_id,
  :destination_ipam_scope_id,
  :monitored)
  SENSITIVE = []
  include Aws::Structure
end

#resource_cidrString

The CIDR of the resource you want to modify.

Returns:

  • (String)


66624
66625
66626
66627
66628
66629
66630
66631
66632
66633
66634
# File 'lib/aws-sdk-ec2/types.rb', line 66624

class ModifyIpamResourceCidrRequest < Struct.new(
  :dry_run,
  :resource_id,
  :resource_cidr,
  :resource_region,
  :current_ipam_scope_id,
  :destination_ipam_scope_id,
  :monitored)
  SENSITIVE = []
  include Aws::Structure
end

#resource_idString

The ID of the resource you want to modify.

Returns:

  • (String)


66624
66625
66626
66627
66628
66629
66630
66631
66632
66633
66634
# File 'lib/aws-sdk-ec2/types.rb', line 66624

class ModifyIpamResourceCidrRequest < Struct.new(
  :dry_run,
  :resource_id,
  :resource_cidr,
  :resource_region,
  :current_ipam_scope_id,
  :destination_ipam_scope_id,
  :monitored)
  SENSITIVE = []
  include Aws::Structure
end

#resource_regionString

The Amazon Web Services Region of the resource you want to modify.

Returns:

  • (String)


66624
66625
66626
66627
66628
66629
66630
66631
66632
66633
66634
# File 'lib/aws-sdk-ec2/types.rb', line 66624

class ModifyIpamResourceCidrRequest < Struct.new(
  :dry_run,
  :resource_id,
  :resource_cidr,
  :resource_region,
  :current_ipam_scope_id,
  :destination_ipam_scope_id,
  :monitored)
  SENSITIVE = []
  include Aws::Structure
end