Class: Aws::EC2::Types::ModifyIpamResourceDiscoveryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#add_operating_regionsArray<Types::AddIpamOperatingRegion>

Add operating Regions to the resource discovery. Operating Regions are Amazon Web Services Regions where the IPAM is allowed to manage IP address CIDRs. IPAM only discovers and monitors resources in the Amazon Web Services Regions you select as operating Regions.

Returns:



61200
61201
61202
61203
61204
61205
61206
61207
61208
61209
61210
# File 'lib/aws-sdk-ec2/types.rb', line 61200

class ModifyIpamResourceDiscoveryRequest < Struct.new(
  :dry_run,
  :ipam_resource_discovery_id,
  :description,
  :add_operating_regions,
  :remove_operating_regions,
  :add_organizational_unit_exclusions,
  :remove_organizational_unit_exclusions)
  SENSITIVE = []
  include Aws::Structure
end

#add_organizational_unit_exclusionsArray<Types::AddIpamOrganizationalUnitExclusion>

Add an Organizational Unit (OU) exclusion to your IPAM. If your IPAM is integrated with Amazon Web Services Organizations and you add an organizational unit (OU) exclusion, IPAM will not manage the IP addresses in accounts in that OU exclusion. There is a limit on the number of exclusions you can create. For more information, see

Quotas for your IPAM][1

in the *Amazon VPC IPAM User Guide*.

<note markdown=“1”> The resulting set of exclusions must not result in “overlap”, meaning two or more OU exclusions must not exclude the same OU. For more information and examples, see the Amazon Web Services CLI request process in [Add or remove OU exclusions ][2] in the *Amazon VPC User Guide*.

</note>

[1]: docs.aws.amazon.com/vpc/latest/ipam/quotas-ipam.html [2]: docs.aws.amazon.com/vpc/latest/ipam/exclude-ous.html#exclude-ous-create-delete



61200
61201
61202
61203
61204
61205
61206
61207
61208
61209
61210
# File 'lib/aws-sdk-ec2/types.rb', line 61200

class ModifyIpamResourceDiscoveryRequest < Struct.new(
  :dry_run,
  :ipam_resource_discovery_id,
  :description,
  :add_operating_regions,
  :remove_operating_regions,
  :add_organizational_unit_exclusions,
  :remove_organizational_unit_exclusions)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A resource discovery description.

Returns:

  • (String)


61200
61201
61202
61203
61204
61205
61206
61207
61208
61209
61210
# File 'lib/aws-sdk-ec2/types.rb', line 61200

class ModifyIpamResourceDiscoveryRequest < Struct.new(
  :dry_run,
  :ipam_resource_discovery_id,
  :description,
  :add_operating_regions,
  :remove_operating_regions,
  :add_organizational_unit_exclusions,
  :remove_organizational_unit_exclusions)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


61200
61201
61202
61203
61204
61205
61206
61207
61208
61209
61210
# File 'lib/aws-sdk-ec2/types.rb', line 61200

class ModifyIpamResourceDiscoveryRequest < Struct.new(
  :dry_run,
  :ipam_resource_discovery_id,
  :description,
  :add_operating_regions,
  :remove_operating_regions,
  :add_organizational_unit_exclusions,
  :remove_organizational_unit_exclusions)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_resource_discovery_idString

A resource discovery ID.

Returns:

  • (String)


61200
61201
61202
61203
61204
61205
61206
61207
61208
61209
61210
# File 'lib/aws-sdk-ec2/types.rb', line 61200

class ModifyIpamResourceDiscoveryRequest < Struct.new(
  :dry_run,
  :ipam_resource_discovery_id,
  :description,
  :add_operating_regions,
  :remove_operating_regions,
  :add_organizational_unit_exclusions,
  :remove_organizational_unit_exclusions)
  SENSITIVE = []
  include Aws::Structure
end

#remove_operating_regionsArray<Types::RemoveIpamOperatingRegion>

Remove operating Regions.



61200
61201
61202
61203
61204
61205
61206
61207
61208
61209
61210
# File 'lib/aws-sdk-ec2/types.rb', line 61200

class ModifyIpamResourceDiscoveryRequest < Struct.new(
  :dry_run,
  :ipam_resource_discovery_id,
  :description,
  :add_operating_regions,
  :remove_operating_regions,
  :add_organizational_unit_exclusions,
  :remove_organizational_unit_exclusions)
  SENSITIVE = []
  include Aws::Structure
end

#remove_organizational_unit_exclusionsArray<Types::RemoveIpamOrganizationalUnitExclusion>

Remove an Organizational Unit (OU) exclusion to your IPAM. If your IPAM is integrated with Amazon Web Services Organizations and you add an organizational unit (OU) exclusion, IPAM will not manage the IP addresses in accounts in that OU exclusion. There is a limit on the number of exclusions you can create. For more information, see

Quotas for your IPAM][1

in the *Amazon VPC IPAM User Guide*.

<note markdown=“1”> The resulting set of exclusions must not result in “overlap”, meaning two or more OU exclusions must not exclude the same OU. For more information and examples, see the Amazon Web Services CLI request process in [Add or remove OU exclusions ][2] in the *Amazon VPC User Guide*.

</note>

[1]: docs.aws.amazon.com/vpc/latest/ipam/quotas-ipam.html [2]: docs.aws.amazon.com/vpc/latest/ipam/exclude-ous.html#exclude-ous-create-delete



61200
61201
61202
61203
61204
61205
61206
61207
61208
61209
61210
# File 'lib/aws-sdk-ec2/types.rb', line 61200

class ModifyIpamResourceDiscoveryRequest < Struct.new(
  :dry_run,
  :ipam_resource_discovery_id,
  :description,
  :add_operating_regions,
  :remove_operating_regions,
  :add_organizational_unit_exclusions,
  :remove_organizational_unit_exclusions)
  SENSITIVE = []
  include Aws::Structure
end