Class: Aws::EC2::Types::ModifyIpamScopeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyIpamScopeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the scope you want to modify.
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#external_authority_configuration ⇒ Types::ExternalAuthorityConfiguration
The configuration that links an Amazon VPC IPAM scope to an external authority system.
-
#ipam_scope_id ⇒ String
The ID of the scope you want to modify.
-
#remove_external_authority_configuration ⇒ Boolean
Remove the external authority configuration.
Instance Attribute Details
#description ⇒ String
The description of the scope you want to modify.
64016 64017 64018 64019 64020 64021 64022 64023 64024 |
# File 'lib/aws-sdk-ec2/types.rb', line 64016 class ModifyIpamScopeRequest < Struct.new( :dry_run, :ipam_scope_id, :description, :external_authority_configuration, :remove_external_authority_configuration) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action
without actually making the request and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
64016 64017 64018 64019 64020 64021 64022 64023 64024 |
# File 'lib/aws-sdk-ec2/types.rb', line 64016 class ModifyIpamScopeRequest < Struct.new( :dry_run, :ipam_scope_id, :description, :external_authority_configuration, :remove_external_authority_configuration) SENSITIVE = [] include Aws::Structure end |
#external_authority_configuration ⇒ Types::ExternalAuthorityConfiguration
The configuration that links an Amazon VPC IPAM scope to an external authority system. It specifies the type of external system and the external resource identifier that identifies your account or instance in that system.
In IPAM, an external authority is a third-party IP address management system that provides CIDR blocks when you provision address space for top-level IPAM pools. This allows you to use your existing IP management system to control which address ranges are allocated to Amazon Web Services while using Amazon VPC IPAM to manage subnets within those ranges.
64016 64017 64018 64019 64020 64021 64022 64023 64024 |
# File 'lib/aws-sdk-ec2/types.rb', line 64016 class ModifyIpamScopeRequest < Struct.new( :dry_run, :ipam_scope_id, :description, :external_authority_configuration, :remove_external_authority_configuration) SENSITIVE = [] include Aws::Structure end |
#ipam_scope_id ⇒ String
The ID of the scope you want to modify.
64016 64017 64018 64019 64020 64021 64022 64023 64024 |
# File 'lib/aws-sdk-ec2/types.rb', line 64016 class ModifyIpamScopeRequest < Struct.new( :dry_run, :ipam_scope_id, :description, :external_authority_configuration, :remove_external_authority_configuration) SENSITIVE = [] include Aws::Structure end |
#remove_external_authority_configuration ⇒ Boolean
Remove the external authority configuration. true to remove.
64016 64017 64018 64019 64020 64021 64022 64023 64024 |
# File 'lib/aws-sdk-ec2/types.rb', line 64016 class ModifyIpamScopeRequest < Struct.new( :dry_run, :ipam_scope_id, :description, :external_authority_configuration, :remove_external_authority_configuration) SENSITIVE = [] include Aws::Structure end |