Class: Aws::EC2::Types::ModifyLaunchTemplateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyLaunchTemplateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier you provide to ensure the idempotency of the request.
-
#default_version ⇒ String
The version number of the launch template to set as the default version.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#launch_template_id ⇒ String
The ID of the launch template.
-
#launch_template_name ⇒ String
The name of the launch template.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier you provide to ensure the idempotency of the request. If a client token isn't specified, a randomly generated token is used in the request to ensure idempotency.
For more information, see Ensuring idempotency.
Constraint: Maximum 128 ASCII characters.
A suitable default value is auto-generated. You should normally not need to pass this option.
66939 66940 66941 66942 66943 66944 66945 66946 66947 |
# File 'lib/aws-sdk-ec2/types.rb', line 66939 class ModifyLaunchTemplateRequest < Struct.new( :dry_run, :client_token, :launch_template_id, :launch_template_name, :default_version) SENSITIVE = [] include Aws::Structure end |
#default_version ⇒ String
The version number of the launch template to set as the default version.
66939 66940 66941 66942 66943 66944 66945 66946 66947 |
# File 'lib/aws-sdk-ec2/types.rb', line 66939 class ModifyLaunchTemplateRequest < Struct.new( :dry_run, :client_token, :launch_template_id, :launch_template_name, :default_version) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
66939 66940 66941 66942 66943 66944 66945 66946 66947 |
# File 'lib/aws-sdk-ec2/types.rb', line 66939 class ModifyLaunchTemplateRequest < Struct.new( :dry_run, :client_token, :launch_template_id, :launch_template_name, :default_version) SENSITIVE = [] include Aws::Structure end |
#launch_template_id ⇒ String
The ID of the launch template.
You must specify either the launch template ID or the launch template name, but not both.
66939 66940 66941 66942 66943 66944 66945 66946 66947 |
# File 'lib/aws-sdk-ec2/types.rb', line 66939 class ModifyLaunchTemplateRequest < Struct.new( :dry_run, :client_token, :launch_template_id, :launch_template_name, :default_version) SENSITIVE = [] include Aws::Structure end |
#launch_template_name ⇒ String
The name of the launch template.
You must specify either the launch template ID or the launch template name, but not both.
66939 66940 66941 66942 66943 66944 66945 66946 66947 |
# File 'lib/aws-sdk-ec2/types.rb', line 66939 class ModifyLaunchTemplateRequest < Struct.new( :dry_run, :client_token, :launch_template_id, :launch_template_name, :default_version) SENSITIVE = [] include Aws::Structure end |