Class: Aws::EC2::Types::ModifyNetworkInterfaceAttributeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyNetworkInterfaceAttributeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for ModifyNetworkInterfaceAttribute.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#associate_public_ip_address ⇒ Boolean
Indicates whether to assign a public IPv4 address to a network interface.
-
#associated_subnet_ids ⇒ Array<String>
A list of subnet IDs to associate with the network interface.
-
#attachment ⇒ Types::NetworkInterfaceAttachmentChanges
Information about the interface attachment.
-
#connection_tracking_specification ⇒ Types::ConnectionTrackingSpecificationRequest
A connection tracking specification.
-
#description ⇒ Types::AttributeValue
A description for the network interface.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#ena_srd_specification ⇒ Types::EnaSrdSpecification
Updates the ENA Express configuration for the network interface that’s attached to the instance.
-
#enable_primary_ipv_6 ⇒ Boolean
If you’re modifying a network interface in a dual-stack or IPv6-only subnet, you have the option to assign a primary IPv6 IP address.
-
#groups ⇒ Array<String>
Changes the security groups for the network interface.
-
#network_interface_id ⇒ String
The ID of the network interface.
-
#source_dest_check ⇒ Types::AttributeBooleanValue
Enable or disable source/destination checks, which ensure that the instance is either the source or the destination of any traffic that it receives.
Instance Attribute Details
#associate_public_ip_address ⇒ Boolean
Indicates whether to assign a public IPv4 address to a network interface. This option can be enabled for any network interface but will only apply to the primary network interface (eth0).
61567 61568 61569 61570 61571 61572 61573 61574 61575 61576 61577 61578 61579 61580 61581 |
# File 'lib/aws-sdk-ec2/types.rb', line 61567 class ModifyNetworkInterfaceAttributeRequest < Struct.new( :ena_srd_specification, :enable_primary_ipv_6, :connection_tracking_specification, :associate_public_ip_address, :associated_subnet_ids, :dry_run, :network_interface_id, :description, :source_dest_check, :groups, :attachment) SENSITIVE = [] include Aws::Structure end |
#associated_subnet_ids ⇒ Array<String>
A list of subnet IDs to associate with the network interface.
61567 61568 61569 61570 61571 61572 61573 61574 61575 61576 61577 61578 61579 61580 61581 |
# File 'lib/aws-sdk-ec2/types.rb', line 61567 class ModifyNetworkInterfaceAttributeRequest < Struct.new( :ena_srd_specification, :enable_primary_ipv_6, :connection_tracking_specification, :associate_public_ip_address, :associated_subnet_ids, :dry_run, :network_interface_id, :description, :source_dest_check, :groups, :attachment) SENSITIVE = [] include Aws::Structure end |
#attachment ⇒ Types::NetworkInterfaceAttachmentChanges
Information about the interface attachment. If modifying the ‘delete on termination` attribute, you must specify the ID of the interface attachment.
61567 61568 61569 61570 61571 61572 61573 61574 61575 61576 61577 61578 61579 61580 61581 |
# File 'lib/aws-sdk-ec2/types.rb', line 61567 class ModifyNetworkInterfaceAttributeRequest < Struct.new( :ena_srd_specification, :enable_primary_ipv_6, :connection_tracking_specification, :associate_public_ip_address, :associated_subnet_ids, :dry_run, :network_interface_id, :description, :source_dest_check, :groups, :attachment) SENSITIVE = [] include Aws::Structure end |
#connection_tracking_specification ⇒ Types::ConnectionTrackingSpecificationRequest
A connection tracking specification.
61567 61568 61569 61570 61571 61572 61573 61574 61575 61576 61577 61578 61579 61580 61581 |
# File 'lib/aws-sdk-ec2/types.rb', line 61567 class ModifyNetworkInterfaceAttributeRequest < Struct.new( :ena_srd_specification, :enable_primary_ipv_6, :connection_tracking_specification, :associate_public_ip_address, :associated_subnet_ids, :dry_run, :network_interface_id, :description, :source_dest_check, :groups, :attachment) SENSITIVE = [] include Aws::Structure end |
#description ⇒ Types::AttributeValue
A description for the network interface.
61567 61568 61569 61570 61571 61572 61573 61574 61575 61576 61577 61578 61579 61580 61581 |
# File 'lib/aws-sdk-ec2/types.rb', line 61567 class ModifyNetworkInterfaceAttributeRequest < Struct.new( :ena_srd_specification, :enable_primary_ipv_6, :connection_tracking_specification, :associate_public_ip_address, :associated_subnet_ids, :dry_run, :network_interface_id, :description, :source_dest_check, :groups, :attachment) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
61567 61568 61569 61570 61571 61572 61573 61574 61575 61576 61577 61578 61579 61580 61581 |
# File 'lib/aws-sdk-ec2/types.rb', line 61567 class ModifyNetworkInterfaceAttributeRequest < Struct.new( :ena_srd_specification, :enable_primary_ipv_6, :connection_tracking_specification, :associate_public_ip_address, :associated_subnet_ids, :dry_run, :network_interface_id, :description, :source_dest_check, :groups, :attachment) SENSITIVE = [] include Aws::Structure end |
#ena_srd_specification ⇒ Types::EnaSrdSpecification
Updates the ENA Express configuration for the network interface that’s attached to the instance.
61567 61568 61569 61570 61571 61572 61573 61574 61575 61576 61577 61578 61579 61580 61581 |
# File 'lib/aws-sdk-ec2/types.rb', line 61567 class ModifyNetworkInterfaceAttributeRequest < Struct.new( :ena_srd_specification, :enable_primary_ipv_6, :connection_tracking_specification, :associate_public_ip_address, :associated_subnet_ids, :dry_run, :network_interface_id, :description, :source_dest_check, :groups, :attachment) SENSITIVE = [] include Aws::Structure end |
#enable_primary_ipv_6 ⇒ Boolean
If you’re modifying a network interface in a dual-stack or IPv6-only subnet, you have the option to assign a primary IPv6 IP address. A primary IPv6 address is an IPv6 GUA address associated with an ENI that you have enabled to use a primary IPv6 address. Use this option if the instance that this ENI will be attached to relies on its IPv6 address not changing. Amazon Web Services will automatically assign an IPv6 address associated with the ENI attached to your instance to be the primary IPv6 address. Once you enable an IPv6 GUA address to be a primary IPv6, you cannot disable it. When you enable an IPv6 GUA address to be a primary IPv6, the first IPv6 GUA will be made the primary IPv6 address until the instance is terminated or the network interface is detached. If you have multiple IPv6 addresses associated with an ENI attached to your instance and you enable a primary IPv6 address, the first IPv6 GUA address associated with the ENI becomes the primary IPv6 address.
61567 61568 61569 61570 61571 61572 61573 61574 61575 61576 61577 61578 61579 61580 61581 |
# File 'lib/aws-sdk-ec2/types.rb', line 61567 class ModifyNetworkInterfaceAttributeRequest < Struct.new( :ena_srd_specification, :enable_primary_ipv_6, :connection_tracking_specification, :associate_public_ip_address, :associated_subnet_ids, :dry_run, :network_interface_id, :description, :source_dest_check, :groups, :attachment) SENSITIVE = [] include Aws::Structure end |
#groups ⇒ Array<String>
Changes the security groups for the network interface. The new set of groups you specify replaces the current set. You must specify at least one group, even if it’s just the default security group in the VPC. You must specify the ID of the security group, not the name.
61567 61568 61569 61570 61571 61572 61573 61574 61575 61576 61577 61578 61579 61580 61581 |
# File 'lib/aws-sdk-ec2/types.rb', line 61567 class ModifyNetworkInterfaceAttributeRequest < Struct.new( :ena_srd_specification, :enable_primary_ipv_6, :connection_tracking_specification, :associate_public_ip_address, :associated_subnet_ids, :dry_run, :network_interface_id, :description, :source_dest_check, :groups, :attachment) SENSITIVE = [] include Aws::Structure end |
#network_interface_id ⇒ String
The ID of the network interface.
61567 61568 61569 61570 61571 61572 61573 61574 61575 61576 61577 61578 61579 61580 61581 |
# File 'lib/aws-sdk-ec2/types.rb', line 61567 class ModifyNetworkInterfaceAttributeRequest < Struct.new( :ena_srd_specification, :enable_primary_ipv_6, :connection_tracking_specification, :associate_public_ip_address, :associated_subnet_ids, :dry_run, :network_interface_id, :description, :source_dest_check, :groups, :attachment) SENSITIVE = [] include Aws::Structure end |
#source_dest_check ⇒ Types::AttributeBooleanValue
Enable or disable source/destination checks, which ensure that the instance is either the source or the destination of any traffic that it receives. If the value is ‘true`, source/destination checks are enabled; otherwise, they are disabled. The default value is `true`. You must disable source/destination checks if the instance runs services such as network address translation, routing, or firewalls.
61567 61568 61569 61570 61571 61572 61573 61574 61575 61576 61577 61578 61579 61580 61581 |
# File 'lib/aws-sdk-ec2/types.rb', line 61567 class ModifyNetworkInterfaceAttributeRequest < Struct.new( :ena_srd_specification, :enable_primary_ipv_6, :connection_tracking_specification, :associate_public_ip_address, :associated_subnet_ids, :dry_run, :network_interface_id, :description, :source_dest_check, :groups, :attachment) SENSITIVE = [] include Aws::Structure end |