Class: Aws::EC2::Types::ModifySubnetAttributeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#assign_ipv_6_address_on_creationTypes::AttributeBooleanValue

Specify ‘true` to indicate that network interfaces created in the specified subnet should be assigned an IPv6 address. This includes a network interface that’s created when launching an instance into the subnet (the instance therefore receives an IPv6 address).

If you enable the IPv6 addressing feature for your subnet, your network interface or instance only receives an IPv6 address if it’s created using version ‘2016-11-15` or later of the Amazon EC2 API.



63151
63152
63153
63154
63155
63156
63157
63158
63159
63160
63161
63162
63163
63164
63165
# File 'lib/aws-sdk-ec2/types.rb', line 63151

class ModifySubnetAttributeRequest < Struct.new(
  :assign_ipv_6_address_on_creation,
  :map_public_ip_on_launch,
  :subnet_id,
  :map_customer_owned_ip_on_launch,
  :customer_owned_ipv_4_pool,
  :enable_dns_64,
  :private_dns_hostname_type_on_launch,
  :enable_resource_name_dns_a_record_on_launch,
  :enable_resource_name_dns_aaaa_record_on_launch,
  :enable_lni_at_device_index,
  :disable_lni_at_device_index)
  SENSITIVE = []
  include Aws::Structure
end

#customer_owned_ipv_4_poolString

The customer-owned IPv4 address pool associated with the subnet.

You must set this value when you specify ‘true` for `MapCustomerOwnedIpOnLaunch`.

Returns:

  • (String)


63151
63152
63153
63154
63155
63156
63157
63158
63159
63160
63161
63162
63163
63164
63165
# File 'lib/aws-sdk-ec2/types.rb', line 63151

class ModifySubnetAttributeRequest < Struct.new(
  :assign_ipv_6_address_on_creation,
  :map_public_ip_on_launch,
  :subnet_id,
  :map_customer_owned_ip_on_launch,
  :customer_owned_ipv_4_pool,
  :enable_dns_64,
  :private_dns_hostname_type_on_launch,
  :enable_resource_name_dns_a_record_on_launch,
  :enable_resource_name_dns_aaaa_record_on_launch,
  :enable_lni_at_device_index,
  :disable_lni_at_device_index)
  SENSITIVE = []
  include Aws::Structure
end

#disable_lni_at_device_indexTypes::AttributeBooleanValue

Specify ‘true` to indicate that local network interfaces at the current position should be disabled.



63151
63152
63153
63154
63155
63156
63157
63158
63159
63160
63161
63162
63163
63164
63165
# File 'lib/aws-sdk-ec2/types.rb', line 63151

class ModifySubnetAttributeRequest < Struct.new(
  :assign_ipv_6_address_on_creation,
  :map_public_ip_on_launch,
  :subnet_id,
  :map_customer_owned_ip_on_launch,
  :customer_owned_ipv_4_pool,
  :enable_dns_64,
  :private_dns_hostname_type_on_launch,
  :enable_resource_name_dns_a_record_on_launch,
  :enable_resource_name_dns_aaaa_record_on_launch,
  :enable_lni_at_device_index,
  :disable_lni_at_device_index)
  SENSITIVE = []
  include Aws::Structure
end

#enable_dns_64Types::AttributeBooleanValue

Indicates whether DNS queries made to the Amazon-provided DNS Resolver in this subnet should return synthetic IPv6 addresses for IPv4-only destinations.

You must first configure a NAT gateway in a public subnet (separate from the subnet containing the IPv6-only workloads). For example, the subnet containing the NAT gateway should have a ‘0.0.0.0/0` route pointing to the internet gateway. For more information, see

Configure DNS64 and NAT64][1

in the *Amazon VPC User Guide*.

[1]: docs.aws.amazon.com/vpc/latest/userguide/nat-gateway-nat64-dns64.html#nat-gateway-nat64-dns64-walkthrough



63151
63152
63153
63154
63155
63156
63157
63158
63159
63160
63161
63162
63163
63164
63165
# File 'lib/aws-sdk-ec2/types.rb', line 63151

class ModifySubnetAttributeRequest < Struct.new(
  :assign_ipv_6_address_on_creation,
  :map_public_ip_on_launch,
  :subnet_id,
  :map_customer_owned_ip_on_launch,
  :customer_owned_ipv_4_pool,
  :enable_dns_64,
  :private_dns_hostname_type_on_launch,
  :enable_resource_name_dns_a_record_on_launch,
  :enable_resource_name_dns_aaaa_record_on_launch,
  :enable_lni_at_device_index,
  :disable_lni_at_device_index)
  SENSITIVE = []
  include Aws::Structure
end

#enable_lni_at_device_indexInteger

Indicates the device position for local network interfaces in this subnet. For example, ‘1` indicates local network interfaces in this subnet are the secondary network interface (eth1). A local network interface cannot be the primary network interface (eth0).

Returns:

  • (Integer)


63151
63152
63153
63154
63155
63156
63157
63158
63159
63160
63161
63162
63163
63164
63165
# File 'lib/aws-sdk-ec2/types.rb', line 63151

class ModifySubnetAttributeRequest < Struct.new(
  :assign_ipv_6_address_on_creation,
  :map_public_ip_on_launch,
  :subnet_id,
  :map_customer_owned_ip_on_launch,
  :customer_owned_ipv_4_pool,
  :enable_dns_64,
  :private_dns_hostname_type_on_launch,
  :enable_resource_name_dns_a_record_on_launch,
  :enable_resource_name_dns_aaaa_record_on_launch,
  :enable_lni_at_device_index,
  :disable_lni_at_device_index)
  SENSITIVE = []
  include Aws::Structure
end

#enable_resource_name_dns_a_record_on_launchTypes::AttributeBooleanValue

Indicates whether to respond to DNS queries for instance hostnames with DNS A records.



63151
63152
63153
63154
63155
63156
63157
63158
63159
63160
63161
63162
63163
63164
63165
# File 'lib/aws-sdk-ec2/types.rb', line 63151

class ModifySubnetAttributeRequest < Struct.new(
  :assign_ipv_6_address_on_creation,
  :map_public_ip_on_launch,
  :subnet_id,
  :map_customer_owned_ip_on_launch,
  :customer_owned_ipv_4_pool,
  :enable_dns_64,
  :private_dns_hostname_type_on_launch,
  :enable_resource_name_dns_a_record_on_launch,
  :enable_resource_name_dns_aaaa_record_on_launch,
  :enable_lni_at_device_index,
  :disable_lni_at_device_index)
  SENSITIVE = []
  include Aws::Structure
end

#enable_resource_name_dns_aaaa_record_on_launchTypes::AttributeBooleanValue

Indicates whether to respond to DNS queries for instance hostnames with DNS AAAA records.



63151
63152
63153
63154
63155
63156
63157
63158
63159
63160
63161
63162
63163
63164
63165
# File 'lib/aws-sdk-ec2/types.rb', line 63151

class ModifySubnetAttributeRequest < Struct.new(
  :assign_ipv_6_address_on_creation,
  :map_public_ip_on_launch,
  :subnet_id,
  :map_customer_owned_ip_on_launch,
  :customer_owned_ipv_4_pool,
  :enable_dns_64,
  :private_dns_hostname_type_on_launch,
  :enable_resource_name_dns_a_record_on_launch,
  :enable_resource_name_dns_aaaa_record_on_launch,
  :enable_lni_at_device_index,
  :disable_lni_at_device_index)
  SENSITIVE = []
  include Aws::Structure
end

#map_customer_owned_ip_on_launchTypes::AttributeBooleanValue

Specify ‘true` to indicate that network interfaces attached to instances created in the specified subnet should be assigned a customer-owned IPv4 address.

When this value is ‘true`, you must specify the customer-owned IP pool using `CustomerOwnedIpv4Pool`.



63151
63152
63153
63154
63155
63156
63157
63158
63159
63160
63161
63162
63163
63164
63165
# File 'lib/aws-sdk-ec2/types.rb', line 63151

class ModifySubnetAttributeRequest < Struct.new(
  :assign_ipv_6_address_on_creation,
  :map_public_ip_on_launch,
  :subnet_id,
  :map_customer_owned_ip_on_launch,
  :customer_owned_ipv_4_pool,
  :enable_dns_64,
  :private_dns_hostname_type_on_launch,
  :enable_resource_name_dns_a_record_on_launch,
  :enable_resource_name_dns_aaaa_record_on_launch,
  :enable_lni_at_device_index,
  :disable_lni_at_device_index)
  SENSITIVE = []
  include Aws::Structure
end

#map_public_ip_on_launchTypes::AttributeBooleanValue

Specify ‘true` to indicate that network interfaces attached to instances created in the specified subnet should be assigned a public IPv4 address.

Amazon Web Services charges for all public IPv4 addresses, including public IPv4 addresses associated with running instances and Elastic IP addresses. For more information, see the *Public IPv4 Address* tab on the [Amazon VPC pricing page].

[1]: aws.amazon.com/vpc/pricing/



63151
63152
63153
63154
63155
63156
63157
63158
63159
63160
63161
63162
63163
63164
63165
# File 'lib/aws-sdk-ec2/types.rb', line 63151

class ModifySubnetAttributeRequest < Struct.new(
  :assign_ipv_6_address_on_creation,
  :map_public_ip_on_launch,
  :subnet_id,
  :map_customer_owned_ip_on_launch,
  :customer_owned_ipv_4_pool,
  :enable_dns_64,
  :private_dns_hostname_type_on_launch,
  :enable_resource_name_dns_a_record_on_launch,
  :enable_resource_name_dns_aaaa_record_on_launch,
  :enable_lni_at_device_index,
  :disable_lni_at_device_index)
  SENSITIVE = []
  include Aws::Structure
end

#private_dns_hostname_type_on_launchString

The type of hostname to assign to instances in the subnet at launch. For IPv4-only and dual-stack (IPv4 and IPv6) subnets, an instance DNS name can be based on the instance IPv4 address (ip-name) or the instance ID (resource-name). For IPv6 only subnets, an instance DNS name must be based on the instance ID (resource-name).

Returns:

  • (String)


63151
63152
63153
63154
63155
63156
63157
63158
63159
63160
63161
63162
63163
63164
63165
# File 'lib/aws-sdk-ec2/types.rb', line 63151

class ModifySubnetAttributeRequest < Struct.new(
  :assign_ipv_6_address_on_creation,
  :map_public_ip_on_launch,
  :subnet_id,
  :map_customer_owned_ip_on_launch,
  :customer_owned_ipv_4_pool,
  :enable_dns_64,
  :private_dns_hostname_type_on_launch,
  :enable_resource_name_dns_a_record_on_launch,
  :enable_resource_name_dns_aaaa_record_on_launch,
  :enable_lni_at_device_index,
  :disable_lni_at_device_index)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idString

The ID of the subnet.

Returns:

  • (String)


63151
63152
63153
63154
63155
63156
63157
63158
63159
63160
63161
63162
63163
63164
63165
# File 'lib/aws-sdk-ec2/types.rb', line 63151

class ModifySubnetAttributeRequest < Struct.new(
  :assign_ipv_6_address_on_creation,
  :map_public_ip_on_launch,
  :subnet_id,
  :map_customer_owned_ip_on_launch,
  :customer_owned_ipv_4_pool,
  :enable_dns_64,
  :private_dns_hostname_type_on_launch,
  :enable_resource_name_dns_a_record_on_launch,
  :enable_resource_name_dns_aaaa_record_on_launch,
  :enable_lni_at_device_index,
  :disable_lni_at_device_index)
  SENSITIVE = []
  include Aws::Structure
end