Class: Aws::EC2::Types::ModifyTransitGatewayOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

The transit gateway options.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#add_transit_gateway_cidr_blocksArray<String>

Adds IPv4 or IPv6 CIDR blocks for the transit gateway. Must be a size /24 CIDR block or larger for IPv4, or a size /64 CIDR block or larger for IPv6.

Returns:

  • (Array<String>)


64968
64969
64970
64971
64972
64973
64974
64975
64976
64977
64978
64979
64980
64981
64982
64983
# File 'lib/aws-sdk-ec2/types.rb', line 64968

class ModifyTransitGatewayOptions < Struct.new(
  :add_transit_gateway_cidr_blocks,
  :remove_transit_gateway_cidr_blocks,
  :vpn_ecmp_support,
  :dns_support,
  :security_group_referencing_support,
  :auto_accept_shared_attachments,
  :default_route_table_association,
  :association_default_route_table_id,
  :default_route_table_propagation,
  :propagation_default_route_table_id,
  :amazon_side_asn,
  :encryption_support)
  SENSITIVE = []
  include Aws::Structure
end

#amazon_side_asnInteger

A private Autonomous System Number (ASN) for the Amazon side of a BGP session. The range is 64512 to 65534 for 16-bit ASNs and 4200000000 to 4294967294 for 32-bit ASNs.

The modify ASN operation is not allowed on a transit gateway if it has the following attachments:

  • Dynamic VPN

  • Static VPN

  • Direct Connect Gateway

  • Connect

  • VPN Concentrator

  • Client VPN

You must first delete all transit gateway attachments configured prior to modifying the ASN on the transit gateway.

Returns:

  • (Integer)


64968
64969
64970
64971
64972
64973
64974
64975
64976
64977
64978
64979
64980
64981
64982
64983
# File 'lib/aws-sdk-ec2/types.rb', line 64968

class ModifyTransitGatewayOptions < Struct.new(
  :add_transit_gateway_cidr_blocks,
  :remove_transit_gateway_cidr_blocks,
  :vpn_ecmp_support,
  :dns_support,
  :security_group_referencing_support,
  :auto_accept_shared_attachments,
  :default_route_table_association,
  :association_default_route_table_id,
  :default_route_table_propagation,
  :propagation_default_route_table_id,
  :amazon_side_asn,
  :encryption_support)
  SENSITIVE = []
  include Aws::Structure
end

#association_default_route_table_idString

The ID of the default association route table.

Returns:

  • (String)


64968
64969
64970
64971
64972
64973
64974
64975
64976
64977
64978
64979
64980
64981
64982
64983
# File 'lib/aws-sdk-ec2/types.rb', line 64968

class ModifyTransitGatewayOptions < Struct.new(
  :add_transit_gateway_cidr_blocks,
  :remove_transit_gateway_cidr_blocks,
  :vpn_ecmp_support,
  :dns_support,
  :security_group_referencing_support,
  :auto_accept_shared_attachments,
  :default_route_table_association,
  :association_default_route_table_id,
  :default_route_table_propagation,
  :propagation_default_route_table_id,
  :amazon_side_asn,
  :encryption_support)
  SENSITIVE = []
  include Aws::Structure
end

#auto_accept_shared_attachmentsString

Enable or disable automatic acceptance of attachment requests.

Returns:

  • (String)


64968
64969
64970
64971
64972
64973
64974
64975
64976
64977
64978
64979
64980
64981
64982
64983
# File 'lib/aws-sdk-ec2/types.rb', line 64968

class ModifyTransitGatewayOptions < Struct.new(
  :add_transit_gateway_cidr_blocks,
  :remove_transit_gateway_cidr_blocks,
  :vpn_ecmp_support,
  :dns_support,
  :security_group_referencing_support,
  :auto_accept_shared_attachments,
  :default_route_table_association,
  :association_default_route_table_id,
  :default_route_table_propagation,
  :propagation_default_route_table_id,
  :amazon_side_asn,
  :encryption_support)
  SENSITIVE = []
  include Aws::Structure
end

#default_route_table_associationString

Enable or disable automatic association with the default association route table.

Returns:

  • (String)


64968
64969
64970
64971
64972
64973
64974
64975
64976
64977
64978
64979
64980
64981
64982
64983
# File 'lib/aws-sdk-ec2/types.rb', line 64968

class ModifyTransitGatewayOptions < Struct.new(
  :add_transit_gateway_cidr_blocks,
  :remove_transit_gateway_cidr_blocks,
  :vpn_ecmp_support,
  :dns_support,
  :security_group_referencing_support,
  :auto_accept_shared_attachments,
  :default_route_table_association,
  :association_default_route_table_id,
  :default_route_table_propagation,
  :propagation_default_route_table_id,
  :amazon_side_asn,
  :encryption_support)
  SENSITIVE = []
  include Aws::Structure
end

#default_route_table_propagationString

Indicates whether resource attachments automatically propagate routes to the default propagation route table. Enabled by default. If defaultRouteTablePropagation is set to enable, Amazon Web Services Transit Gateway will create the default transit gateway route table.

Returns:

  • (String)


64968
64969
64970
64971
64972
64973
64974
64975
64976
64977
64978
64979
64980
64981
64982
64983
# File 'lib/aws-sdk-ec2/types.rb', line 64968

class ModifyTransitGatewayOptions < Struct.new(
  :add_transit_gateway_cidr_blocks,
  :remove_transit_gateway_cidr_blocks,
  :vpn_ecmp_support,
  :dns_support,
  :security_group_referencing_support,
  :auto_accept_shared_attachments,
  :default_route_table_association,
  :association_default_route_table_id,
  :default_route_table_propagation,
  :propagation_default_route_table_id,
  :amazon_side_asn,
  :encryption_support)
  SENSITIVE = []
  include Aws::Structure
end

#dns_supportString

Enable or disable DNS support.

Returns:

  • (String)


64968
64969
64970
64971
64972
64973
64974
64975
64976
64977
64978
64979
64980
64981
64982
64983
# File 'lib/aws-sdk-ec2/types.rb', line 64968

class ModifyTransitGatewayOptions < Struct.new(
  :add_transit_gateway_cidr_blocks,
  :remove_transit_gateway_cidr_blocks,
  :vpn_ecmp_support,
  :dns_support,
  :security_group_referencing_support,
  :auto_accept_shared_attachments,
  :default_route_table_association,
  :association_default_route_table_id,
  :default_route_table_propagation,
  :propagation_default_route_table_id,
  :amazon_side_asn,
  :encryption_support)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_supportString

Enable or disable encryption support for VPC Encryption Control.

Returns:

  • (String)


64968
64969
64970
64971
64972
64973
64974
64975
64976
64977
64978
64979
64980
64981
64982
64983
# File 'lib/aws-sdk-ec2/types.rb', line 64968

class ModifyTransitGatewayOptions < Struct.new(
  :add_transit_gateway_cidr_blocks,
  :remove_transit_gateway_cidr_blocks,
  :vpn_ecmp_support,
  :dns_support,
  :security_group_referencing_support,
  :auto_accept_shared_attachments,
  :default_route_table_association,
  :association_default_route_table_id,
  :default_route_table_propagation,
  :propagation_default_route_table_id,
  :amazon_side_asn,
  :encryption_support)
  SENSITIVE = []
  include Aws::Structure
end

#propagation_default_route_table_idString

The ID of the default propagation route table.

Returns:

  • (String)


64968
64969
64970
64971
64972
64973
64974
64975
64976
64977
64978
64979
64980
64981
64982
64983
# File 'lib/aws-sdk-ec2/types.rb', line 64968

class ModifyTransitGatewayOptions < Struct.new(
  :add_transit_gateway_cidr_blocks,
  :remove_transit_gateway_cidr_blocks,
  :vpn_ecmp_support,
  :dns_support,
  :security_group_referencing_support,
  :auto_accept_shared_attachments,
  :default_route_table_association,
  :association_default_route_table_id,
  :default_route_table_propagation,
  :propagation_default_route_table_id,
  :amazon_side_asn,
  :encryption_support)
  SENSITIVE = []
  include Aws::Structure
end

#remove_transit_gateway_cidr_blocksArray<String>

Removes CIDR blocks for the transit gateway.

Returns:

  • (Array<String>)


64968
64969
64970
64971
64972
64973
64974
64975
64976
64977
64978
64979
64980
64981
64982
64983
# File 'lib/aws-sdk-ec2/types.rb', line 64968

class ModifyTransitGatewayOptions < Struct.new(
  :add_transit_gateway_cidr_blocks,
  :remove_transit_gateway_cidr_blocks,
  :vpn_ecmp_support,
  :dns_support,
  :security_group_referencing_support,
  :auto_accept_shared_attachments,
  :default_route_table_association,
  :association_default_route_table_id,
  :default_route_table_propagation,
  :propagation_default_route_table_id,
  :amazon_side_asn,
  :encryption_support)
  SENSITIVE = []
  include Aws::Structure
end

#security_group_referencing_supportString

Enables you to reference a security group across VPCs attached to a transit gateway to simplify security group management.

This option is disabled by default.

For more information about security group referencing, see Security group referencing in the Amazon Web Services Transit Gateways Guide.

Returns:

  • (String)


64968
64969
64970
64971
64972
64973
64974
64975
64976
64977
64978
64979
64980
64981
64982
64983
# File 'lib/aws-sdk-ec2/types.rb', line 64968

class ModifyTransitGatewayOptions < Struct.new(
  :add_transit_gateway_cidr_blocks,
  :remove_transit_gateway_cidr_blocks,
  :vpn_ecmp_support,
  :dns_support,
  :security_group_referencing_support,
  :auto_accept_shared_attachments,
  :default_route_table_association,
  :association_default_route_table_id,
  :default_route_table_propagation,
  :propagation_default_route_table_id,
  :amazon_side_asn,
  :encryption_support)
  SENSITIVE = []
  include Aws::Structure
end

#vpn_ecmp_supportString

Enable or disable Equal Cost Multipath Protocol support.

Returns:

  • (String)


64968
64969
64970
64971
64972
64973
64974
64975
64976
64977
64978
64979
64980
64981
64982
64983
# File 'lib/aws-sdk-ec2/types.rb', line 64968

class ModifyTransitGatewayOptions < Struct.new(
  :add_transit_gateway_cidr_blocks,
  :remove_transit_gateway_cidr_blocks,
  :vpn_ecmp_support,
  :dns_support,
  :security_group_referencing_support,
  :auto_accept_shared_attachments,
  :default_route_table_association,
  :association_default_route_table_id,
  :default_route_table_propagation,
  :propagation_default_route_table_id,
  :amazon_side_asn,
  :encryption_support)
  SENSITIVE = []
  include Aws::Structure
end