Class: Aws::EC2::Types::ModifyVerifiedAccessGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


68669
68670
68671
68672
68673
68674
68675
68676
68677
# File 'lib/aws-sdk-ec2/types.rb', line 68669

class ModifyVerifiedAccessGroupRequest < Struct.new(
  :verified_access_group_id,
  :verified_access_instance_id,
  :description,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description for the Verified Access group.

Returns:

  • (String)


68669
68670
68671
68672
68673
68674
68675
68676
68677
# File 'lib/aws-sdk-ec2/types.rb', line 68669

class ModifyVerifiedAccessGroupRequest < Struct.new(
  :verified_access_group_id,
  :verified_access_instance_id,
  :description,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


68669
68670
68671
68672
68673
68674
68675
68676
68677
# File 'lib/aws-sdk-ec2/types.rb', line 68669

class ModifyVerifiedAccessGroupRequest < Struct.new(
  :verified_access_group_id,
  :verified_access_instance_id,
  :description,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#verified_access_group_idString

The ID of the Verified Access group.

Returns:

  • (String)


68669
68670
68671
68672
68673
68674
68675
68676
68677
# File 'lib/aws-sdk-ec2/types.rb', line 68669

class ModifyVerifiedAccessGroupRequest < Struct.new(
  :verified_access_group_id,
  :verified_access_instance_id,
  :description,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#verified_access_instance_idString

The ID of the Verified Access instance.

Returns:

  • (String)


68669
68670
68671
68672
68673
68674
68675
68676
68677
# File 'lib/aws-sdk-ec2/types.rb', line 68669

class ModifyVerifiedAccessGroupRequest < Struct.new(
  :verified_access_group_id,
  :verified_access_instance_id,
  :description,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end