Class: Aws::EC2::Types::ModifyVerifiedAccessInstanceLoggingConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyVerifiedAccessInstanceLoggingConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_logs ⇒ Types::VerifiedAccessLogOptions
The configuration options for Verified Access instances.
-
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#verified_access_instance_id ⇒ String
The ID of the Verified Access instance.
Instance Attribute Details
#access_logs ⇒ Types::VerifiedAccessLogOptions
The configuration options for Verified Access instances.
67277 67278 67279 67280 67281 67282 67283 67284 |
# File 'lib/aws-sdk-ec2/types.rb', line 67277 class ModifyVerifiedAccessInstanceLoggingConfigurationRequest < Struct.new( :verified_access_instance_id, :access_logs, :dry_run, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring idempotency.
A suitable default value is auto-generated. You should normally not need to pass this option.
67277 67278 67279 67280 67281 67282 67283 67284 |
# File 'lib/aws-sdk-ec2/types.rb', line 67277 class ModifyVerifiedAccessInstanceLoggingConfigurationRequest < Struct.new( :verified_access_instance_id, :access_logs, :dry_run, :client_token) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
67277 67278 67279 67280 67281 67282 67283 67284 |
# File 'lib/aws-sdk-ec2/types.rb', line 67277 class ModifyVerifiedAccessInstanceLoggingConfigurationRequest < Struct.new( :verified_access_instance_id, :access_logs, :dry_run, :client_token) SENSITIVE = [] include Aws::Structure end |
#verified_access_instance_id ⇒ String
The ID of the Verified Access instance.
67277 67278 67279 67280 67281 67282 67283 67284 |
# File 'lib/aws-sdk-ec2/types.rb', line 67277 class ModifyVerifiedAccessInstanceLoggingConfigurationRequest < Struct.new( :verified_access_instance_id, :access_logs, :dry_run, :client_token) SENSITIVE = [] include Aws::Structure end |