Class: Aws::EC2::Types::ModifyVpcAttributeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyVpcAttributeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enable_dns_hostnames ⇒ Types::AttributeBooleanValue
Indicates whether the instances launched in the VPC get DNS hostnames.
-
#enable_dns_support ⇒ Types::AttributeBooleanValue
Indicates whether the DNS resolution is supported for the VPC.
-
#enable_network_address_usage_metrics ⇒ Types::AttributeBooleanValue
Indicates whether Network Address Usage metrics are enabled for your VPC.
-
#vpc_id ⇒ String
The ID of the VPC.
Instance Attribute Details
#enable_dns_hostnames ⇒ Types::AttributeBooleanValue
Indicates whether the instances launched in the VPC get DNS hostnames. If enabled, instances in the VPC get DNS hostnames; otherwise, they do not.
You cannot modify the DNS resolution and DNS hostnames attributes in the same request. Use separate requests for each attribute. You can only enable DNS hostnames if you’ve enabled DNS support.
63512 63513 63514 63515 63516 63517 63518 63519 |
# File 'lib/aws-sdk-ec2/types.rb', line 63512 class ModifyVpcAttributeRequest < Struct.new( :enable_dns_hostnames, :enable_dns_support, :vpc_id, :enable_network_address_usage_metrics) SENSITIVE = [] include Aws::Structure end |
#enable_dns_support ⇒ Types::AttributeBooleanValue
Indicates whether the DNS resolution is supported for the VPC. If enabled, queries to the Amazon provided DNS server at the 169.254.169.253 IP address, or the reserved IP address at the base of the VPC network range “plus two” succeed. If disabled, the Amazon provided DNS service in the VPC that resolves public DNS hostnames to IP addresses is not enabled.
You cannot modify the DNS resolution and DNS hostnames attributes in the same request. Use separate requests for each attribute.
63512 63513 63514 63515 63516 63517 63518 63519 |
# File 'lib/aws-sdk-ec2/types.rb', line 63512 class ModifyVpcAttributeRequest < Struct.new( :enable_dns_hostnames, :enable_dns_support, :vpc_id, :enable_network_address_usage_metrics) SENSITIVE = [] include Aws::Structure end |
#enable_network_address_usage_metrics ⇒ Types::AttributeBooleanValue
Indicates whether Network Address Usage metrics are enabled for your VPC.
63512 63513 63514 63515 63516 63517 63518 63519 |
# File 'lib/aws-sdk-ec2/types.rb', line 63512 class ModifyVpcAttributeRequest < Struct.new( :enable_dns_hostnames, :enable_dns_support, :vpc_id, :enable_network_address_usage_metrics) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC.
63512 63513 63514 63515 63516 63517 63518 63519 |
# File 'lib/aws-sdk-ec2/types.rb', line 63512 class ModifyVpcAttributeRequest < Struct.new( :enable_dns_hostnames, :enable_dns_support, :vpc_id, :enable_network_address_usage_metrics) SENSITIVE = [] include Aws::Structure end |