Class: Aws::EC2::Types::ModifyVpcBlockPublicAccessExclusionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


66068
66069
66070
66071
66072
66073
66074
# File 'lib/aws-sdk-ec2/types.rb', line 66068

class ModifyVpcBlockPublicAccessExclusionRequest < Struct.new(
  :dry_run,
  :exclusion_id,
  :internet_gateway_exclusion_mode)
  SENSITIVE = []
  include Aws::Structure
end

#exclusion_idString

The ID of an exclusion.

Returns:

  • (String)


66068
66069
66070
66071
66072
66073
66074
# File 'lib/aws-sdk-ec2/types.rb', line 66068

class ModifyVpcBlockPublicAccessExclusionRequest < Struct.new(
  :dry_run,
  :exclusion_id,
  :internet_gateway_exclusion_mode)
  SENSITIVE = []
  include Aws::Structure
end

#internet_gateway_exclusion_modeString

The exclusion mode for internet gateway traffic.

  • allow-bidirectional: Allow all internet traffic to and from the excluded VPCs and subnets.

  • allow-egress: Allow outbound internet traffic from the excluded VPCs and subnets. Block inbound internet traffic to the excluded VPCs and subnets. Only applies when VPC Block Public Access is set to Bidirectional.

Returns:

  • (String)


66068
66069
66070
66071
66072
66073
66074
# File 'lib/aws-sdk-ec2/types.rb', line 66068

class ModifyVpcBlockPublicAccessExclusionRequest < Struct.new(
  :dry_run,
  :exclusion_id,
  :internet_gateway_exclusion_mode)
  SENSITIVE = []
  include Aws::Structure
end