Class: Aws::EC2::Types::NetworkBandwidthGbps
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::NetworkBandwidthGbps
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
The minimum and maximum amount of network bandwidth, in gigabits per second (Gbps).
<note markdown=“1”> Setting the minimum bandwidth does not guarantee that your instance will achieve the minimum bandwidth. Amazon EC2 will identify instance types that support the specified minimum bandwidth, but the actual bandwidth of your instance might go below the specified minimum at times. For more information, see [Available instance bandwidth] in the *Amazon EC2 User Guide*.
</note>
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max ⇒ Float
The maximum amount of network bandwidth, in Gbps.
-
#min ⇒ Float
The minimum amount of network bandwidth, in Gbps.
Instance Attribute Details
#max ⇒ Float
The maximum amount of network bandwidth, in Gbps. If this parameter is not specified, there is no maximum limit.
66614 66615 66616 66617 66618 66619 |
# File 'lib/aws-sdk-ec2/types.rb', line 66614 class NetworkBandwidthGbps < Struct.new( :min, :max) SENSITIVE = [] include Aws::Structure end |
#min ⇒ Float
The minimum amount of network bandwidth, in Gbps. If this parameter is not specified, there is no minimum limit.
66614 66615 66616 66617 66618 66619 |
# File 'lib/aws-sdk-ec2/types.rb', line 66614 class NetworkBandwidthGbps < Struct.new( :min, :max) SENSITIVE = [] include Aws::Structure end |