Class: Aws::EC2::Types::NetworkBandwidthGbpsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::NetworkBandwidthGbpsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
The minimum and maximum amount of network bandwidth, in gigabits per second (Gbps).
<note markdown=“1”> Setting the minimum bandwidth does not guarantee that your instance will achieve the minimum bandwidth. Amazon EC2 will identify instance types that support the specified minimum bandwidth, but the actual bandwidth of your instance might go below the specified minimum at times. For more information, see [Available instance bandwidth] in the *Amazon EC2 User Guide*.
</note>
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max ⇒ Float
The maximum amount of network bandwidth, in Gbps.
-
#min ⇒ Float
The minimum amount of network bandwidth, in Gbps.
Instance Attribute Details
#max ⇒ Float
The maximum amount of network bandwidth, in Gbps. To specify no maximum limit, omit this parameter.
66802 66803 66804 66805 66806 66807 |
# File 'lib/aws-sdk-ec2/types.rb', line 66802 class NetworkBandwidthGbpsRequest < Struct.new( :min, :max) SENSITIVE = [] include Aws::Structure end |
#min ⇒ Float
The minimum amount of network bandwidth, in Gbps. To specify no minimum limit, omit this parameter.
66802 66803 66804 66805 66806 66807 |
# File 'lib/aws-sdk-ec2/types.rb', line 66802 class NetworkBandwidthGbpsRequest < Struct.new( :min, :max) SENSITIVE = [] include Aws::Structure end |