Class: Aws::EC2::Types::NetworkInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::NetworkInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the networking features of the instance type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bandwidth_weightings ⇒ Array<String>
A list of valid settings for configurable bandwidth weighting for the instance type, if supported.
-
#connection_tracking_configuration ⇒ Types::DefaultConnectionTrackingConfiguration
Indicates conntrack information for the instance type.
-
#default_network_card_index ⇒ Integer
The index of the default network card, starting at 0.
-
#efa_info ⇒ Types::EfaInfo
Describes the Elastic Fabric Adapters for the instance type.
-
#efa_supported ⇒ Boolean
Indicates whether Elastic Fabric Adapter (EFA) is supported.
-
#ena_srd_supported ⇒ Boolean
Indicates whether the instance type supports ENA Express.
-
#ena_support ⇒ String
Indicates whether Elastic Network Adapter (ENA) is supported.
-
#encryption_in_transit_supported ⇒ Boolean
Indicates whether the instance type automatically encrypts in-transit traffic between instances.
-
#flexible_ena_queues_support ⇒ String
Indicates whether changing the number of ENA queues is supported.
-
#ipv_4_addresses_per_interface ⇒ Integer
The maximum number of IPv4 addresses per network interface.
-
#ipv_4_addresses_per_secondary_interface ⇒ Integer
The maximum number of IPv4 addresses per secondary interface.
-
#ipv_6_addresses_per_interface ⇒ Integer
The maximum number of IPv6 addresses per network interface.
-
#ipv_6_supported ⇒ Boolean
Indicates whether IPv6 is supported.
-
#maximum_network_cards ⇒ Integer
The maximum number of physical network cards that can be allocated to the instance.
-
#maximum_network_interfaces ⇒ Integer
The maximum number of network interfaces for the instance type.
-
#maximum_secondary_network_interfaces ⇒ Integer
The maximum number of secondary interfaces for the instance type.
-
#network_cards ⇒ Array<Types::NetworkCardInfo>
Describes the network cards for the instance type.
-
#network_performance ⇒ String
The network performance.
-
#secondary_network_supported ⇒ Boolean
Indicates whether secondary interface attachments from secondary network are supported.
Instance Attribute Details
#bandwidth_weightings ⇒ Array<String>
A list of valid settings for configurable bandwidth weighting for the instance type, if supported.
71182 71183 71184 71185 71186 71187 71188 71189 71190 71191 71192 71193 71194 71195 71196 71197 71198 71199 71200 71201 71202 71203 71204 |
# File 'lib/aws-sdk-ec2/types.rb', line 71182 class NetworkInfo < Struct.new( :network_performance, :maximum_network_interfaces, :maximum_network_cards, :default_network_card_index, :network_cards, :ipv_4_addresses_per_interface, :ipv_6_addresses_per_interface, :ipv_6_supported, :ena_support, :efa_supported, :efa_info, :encryption_in_transit_supported, :ena_srd_supported, :bandwidth_weightings, :flexible_ena_queues_support, :connection_tracking_configuration, :secondary_network_supported, :maximum_secondary_network_interfaces, :ipv_4_addresses_per_secondary_interface) SENSITIVE = [] include Aws::Structure end |
#connection_tracking_configuration ⇒ Types::DefaultConnectionTrackingConfiguration
Indicates conntrack information for the instance type
71182 71183 71184 71185 71186 71187 71188 71189 71190 71191 71192 71193 71194 71195 71196 71197 71198 71199 71200 71201 71202 71203 71204 |
# File 'lib/aws-sdk-ec2/types.rb', line 71182 class NetworkInfo < Struct.new( :network_performance, :maximum_network_interfaces, :maximum_network_cards, :default_network_card_index, :network_cards, :ipv_4_addresses_per_interface, :ipv_6_addresses_per_interface, :ipv_6_supported, :ena_support, :efa_supported, :efa_info, :encryption_in_transit_supported, :ena_srd_supported, :bandwidth_weightings, :flexible_ena_queues_support, :connection_tracking_configuration, :secondary_network_supported, :maximum_secondary_network_interfaces, :ipv_4_addresses_per_secondary_interface) SENSITIVE = [] include Aws::Structure end |
#default_network_card_index ⇒ Integer
The index of the default network card, starting at 0.
71182 71183 71184 71185 71186 71187 71188 71189 71190 71191 71192 71193 71194 71195 71196 71197 71198 71199 71200 71201 71202 71203 71204 |
# File 'lib/aws-sdk-ec2/types.rb', line 71182 class NetworkInfo < Struct.new( :network_performance, :maximum_network_interfaces, :maximum_network_cards, :default_network_card_index, :network_cards, :ipv_4_addresses_per_interface, :ipv_6_addresses_per_interface, :ipv_6_supported, :ena_support, :efa_supported, :efa_info, :encryption_in_transit_supported, :ena_srd_supported, :bandwidth_weightings, :flexible_ena_queues_support, :connection_tracking_configuration, :secondary_network_supported, :maximum_secondary_network_interfaces, :ipv_4_addresses_per_secondary_interface) SENSITIVE = [] include Aws::Structure end |
#efa_info ⇒ Types::EfaInfo
Describes the Elastic Fabric Adapters for the instance type.
71182 71183 71184 71185 71186 71187 71188 71189 71190 71191 71192 71193 71194 71195 71196 71197 71198 71199 71200 71201 71202 71203 71204 |
# File 'lib/aws-sdk-ec2/types.rb', line 71182 class NetworkInfo < Struct.new( :network_performance, :maximum_network_interfaces, :maximum_network_cards, :default_network_card_index, :network_cards, :ipv_4_addresses_per_interface, :ipv_6_addresses_per_interface, :ipv_6_supported, :ena_support, :efa_supported, :efa_info, :encryption_in_transit_supported, :ena_srd_supported, :bandwidth_weightings, :flexible_ena_queues_support, :connection_tracking_configuration, :secondary_network_supported, :maximum_secondary_network_interfaces, :ipv_4_addresses_per_secondary_interface) SENSITIVE = [] include Aws::Structure end |
#efa_supported ⇒ Boolean
Indicates whether Elastic Fabric Adapter (EFA) is supported.
71182 71183 71184 71185 71186 71187 71188 71189 71190 71191 71192 71193 71194 71195 71196 71197 71198 71199 71200 71201 71202 71203 71204 |
# File 'lib/aws-sdk-ec2/types.rb', line 71182 class NetworkInfo < Struct.new( :network_performance, :maximum_network_interfaces, :maximum_network_cards, :default_network_card_index, :network_cards, :ipv_4_addresses_per_interface, :ipv_6_addresses_per_interface, :ipv_6_supported, :ena_support, :efa_supported, :efa_info, :encryption_in_transit_supported, :ena_srd_supported, :bandwidth_weightings, :flexible_ena_queues_support, :connection_tracking_configuration, :secondary_network_supported, :maximum_secondary_network_interfaces, :ipv_4_addresses_per_secondary_interface) SENSITIVE = [] include Aws::Structure end |
#ena_srd_supported ⇒ Boolean
Indicates whether the instance type supports ENA Express. ENA Express uses Amazon Web Services Scalable Reliable Datagram (SRD) technology to increase the maximum bandwidth used per stream and minimize tail latency of network traffic between EC2 instances.
71182 71183 71184 71185 71186 71187 71188 71189 71190 71191 71192 71193 71194 71195 71196 71197 71198 71199 71200 71201 71202 71203 71204 |
# File 'lib/aws-sdk-ec2/types.rb', line 71182 class NetworkInfo < Struct.new( :network_performance, :maximum_network_interfaces, :maximum_network_cards, :default_network_card_index, :network_cards, :ipv_4_addresses_per_interface, :ipv_6_addresses_per_interface, :ipv_6_supported, :ena_support, :efa_supported, :efa_info, :encryption_in_transit_supported, :ena_srd_supported, :bandwidth_weightings, :flexible_ena_queues_support, :connection_tracking_configuration, :secondary_network_supported, :maximum_secondary_network_interfaces, :ipv_4_addresses_per_secondary_interface) SENSITIVE = [] include Aws::Structure end |
#ena_support ⇒ String
Indicates whether Elastic Network Adapter (ENA) is supported.
71182 71183 71184 71185 71186 71187 71188 71189 71190 71191 71192 71193 71194 71195 71196 71197 71198 71199 71200 71201 71202 71203 71204 |
# File 'lib/aws-sdk-ec2/types.rb', line 71182 class NetworkInfo < Struct.new( :network_performance, :maximum_network_interfaces, :maximum_network_cards, :default_network_card_index, :network_cards, :ipv_4_addresses_per_interface, :ipv_6_addresses_per_interface, :ipv_6_supported, :ena_support, :efa_supported, :efa_info, :encryption_in_transit_supported, :ena_srd_supported, :bandwidth_weightings, :flexible_ena_queues_support, :connection_tracking_configuration, :secondary_network_supported, :maximum_secondary_network_interfaces, :ipv_4_addresses_per_secondary_interface) SENSITIVE = [] include Aws::Structure end |
#encryption_in_transit_supported ⇒ Boolean
Indicates whether the instance type automatically encrypts in-transit traffic between instances.
71182 71183 71184 71185 71186 71187 71188 71189 71190 71191 71192 71193 71194 71195 71196 71197 71198 71199 71200 71201 71202 71203 71204 |
# File 'lib/aws-sdk-ec2/types.rb', line 71182 class NetworkInfo < Struct.new( :network_performance, :maximum_network_interfaces, :maximum_network_cards, :default_network_card_index, :network_cards, :ipv_4_addresses_per_interface, :ipv_6_addresses_per_interface, :ipv_6_supported, :ena_support, :efa_supported, :efa_info, :encryption_in_transit_supported, :ena_srd_supported, :bandwidth_weightings, :flexible_ena_queues_support, :connection_tracking_configuration, :secondary_network_supported, :maximum_secondary_network_interfaces, :ipv_4_addresses_per_secondary_interface) SENSITIVE = [] include Aws::Structure end |
#flexible_ena_queues_support ⇒ String
Indicates whether changing the number of ENA queues is supported.
71182 71183 71184 71185 71186 71187 71188 71189 71190 71191 71192 71193 71194 71195 71196 71197 71198 71199 71200 71201 71202 71203 71204 |
# File 'lib/aws-sdk-ec2/types.rb', line 71182 class NetworkInfo < Struct.new( :network_performance, :maximum_network_interfaces, :maximum_network_cards, :default_network_card_index, :network_cards, :ipv_4_addresses_per_interface, :ipv_6_addresses_per_interface, :ipv_6_supported, :ena_support, :efa_supported, :efa_info, :encryption_in_transit_supported, :ena_srd_supported, :bandwidth_weightings, :flexible_ena_queues_support, :connection_tracking_configuration, :secondary_network_supported, :maximum_secondary_network_interfaces, :ipv_4_addresses_per_secondary_interface) SENSITIVE = [] include Aws::Structure end |
#ipv_4_addresses_per_interface ⇒ Integer
The maximum number of IPv4 addresses per network interface.
71182 71183 71184 71185 71186 71187 71188 71189 71190 71191 71192 71193 71194 71195 71196 71197 71198 71199 71200 71201 71202 71203 71204 |
# File 'lib/aws-sdk-ec2/types.rb', line 71182 class NetworkInfo < Struct.new( :network_performance, :maximum_network_interfaces, :maximum_network_cards, :default_network_card_index, :network_cards, :ipv_4_addresses_per_interface, :ipv_6_addresses_per_interface, :ipv_6_supported, :ena_support, :efa_supported, :efa_info, :encryption_in_transit_supported, :ena_srd_supported, :bandwidth_weightings, :flexible_ena_queues_support, :connection_tracking_configuration, :secondary_network_supported, :maximum_secondary_network_interfaces, :ipv_4_addresses_per_secondary_interface) SENSITIVE = [] include Aws::Structure end |
#ipv_4_addresses_per_secondary_interface ⇒ Integer
The maximum number of IPv4 addresses per secondary interface.
71182 71183 71184 71185 71186 71187 71188 71189 71190 71191 71192 71193 71194 71195 71196 71197 71198 71199 71200 71201 71202 71203 71204 |
# File 'lib/aws-sdk-ec2/types.rb', line 71182 class NetworkInfo < Struct.new( :network_performance, :maximum_network_interfaces, :maximum_network_cards, :default_network_card_index, :network_cards, :ipv_4_addresses_per_interface, :ipv_6_addresses_per_interface, :ipv_6_supported, :ena_support, :efa_supported, :efa_info, :encryption_in_transit_supported, :ena_srd_supported, :bandwidth_weightings, :flexible_ena_queues_support, :connection_tracking_configuration, :secondary_network_supported, :maximum_secondary_network_interfaces, :ipv_4_addresses_per_secondary_interface) SENSITIVE = [] include Aws::Structure end |
#ipv_6_addresses_per_interface ⇒ Integer
The maximum number of IPv6 addresses per network interface.
71182 71183 71184 71185 71186 71187 71188 71189 71190 71191 71192 71193 71194 71195 71196 71197 71198 71199 71200 71201 71202 71203 71204 |
# File 'lib/aws-sdk-ec2/types.rb', line 71182 class NetworkInfo < Struct.new( :network_performance, :maximum_network_interfaces, :maximum_network_cards, :default_network_card_index, :network_cards, :ipv_4_addresses_per_interface, :ipv_6_addresses_per_interface, :ipv_6_supported, :ena_support, :efa_supported, :efa_info, :encryption_in_transit_supported, :ena_srd_supported, :bandwidth_weightings, :flexible_ena_queues_support, :connection_tracking_configuration, :secondary_network_supported, :maximum_secondary_network_interfaces, :ipv_4_addresses_per_secondary_interface) SENSITIVE = [] include Aws::Structure end |
#ipv_6_supported ⇒ Boolean
Indicates whether IPv6 is supported.
71182 71183 71184 71185 71186 71187 71188 71189 71190 71191 71192 71193 71194 71195 71196 71197 71198 71199 71200 71201 71202 71203 71204 |
# File 'lib/aws-sdk-ec2/types.rb', line 71182 class NetworkInfo < Struct.new( :network_performance, :maximum_network_interfaces, :maximum_network_cards, :default_network_card_index, :network_cards, :ipv_4_addresses_per_interface, :ipv_6_addresses_per_interface, :ipv_6_supported, :ena_support, :efa_supported, :efa_info, :encryption_in_transit_supported, :ena_srd_supported, :bandwidth_weightings, :flexible_ena_queues_support, :connection_tracking_configuration, :secondary_network_supported, :maximum_secondary_network_interfaces, :ipv_4_addresses_per_secondary_interface) SENSITIVE = [] include Aws::Structure end |
#maximum_network_cards ⇒ Integer
The maximum number of physical network cards that can be allocated to the instance.
71182 71183 71184 71185 71186 71187 71188 71189 71190 71191 71192 71193 71194 71195 71196 71197 71198 71199 71200 71201 71202 71203 71204 |
# File 'lib/aws-sdk-ec2/types.rb', line 71182 class NetworkInfo < Struct.new( :network_performance, :maximum_network_interfaces, :maximum_network_cards, :default_network_card_index, :network_cards, :ipv_4_addresses_per_interface, :ipv_6_addresses_per_interface, :ipv_6_supported, :ena_support, :efa_supported, :efa_info, :encryption_in_transit_supported, :ena_srd_supported, :bandwidth_weightings, :flexible_ena_queues_support, :connection_tracking_configuration, :secondary_network_supported, :maximum_secondary_network_interfaces, :ipv_4_addresses_per_secondary_interface) SENSITIVE = [] include Aws::Structure end |
#maximum_network_interfaces ⇒ Integer
The maximum number of network interfaces for the instance type.
71182 71183 71184 71185 71186 71187 71188 71189 71190 71191 71192 71193 71194 71195 71196 71197 71198 71199 71200 71201 71202 71203 71204 |
# File 'lib/aws-sdk-ec2/types.rb', line 71182 class NetworkInfo < Struct.new( :network_performance, :maximum_network_interfaces, :maximum_network_cards, :default_network_card_index, :network_cards, :ipv_4_addresses_per_interface, :ipv_6_addresses_per_interface, :ipv_6_supported, :ena_support, :efa_supported, :efa_info, :encryption_in_transit_supported, :ena_srd_supported, :bandwidth_weightings, :flexible_ena_queues_support, :connection_tracking_configuration, :secondary_network_supported, :maximum_secondary_network_interfaces, :ipv_4_addresses_per_secondary_interface) SENSITIVE = [] include Aws::Structure end |
#maximum_secondary_network_interfaces ⇒ Integer
The maximum number of secondary interfaces for the instance type.
71182 71183 71184 71185 71186 71187 71188 71189 71190 71191 71192 71193 71194 71195 71196 71197 71198 71199 71200 71201 71202 71203 71204 |
# File 'lib/aws-sdk-ec2/types.rb', line 71182 class NetworkInfo < Struct.new( :network_performance, :maximum_network_interfaces, :maximum_network_cards, :default_network_card_index, :network_cards, :ipv_4_addresses_per_interface, :ipv_6_addresses_per_interface, :ipv_6_supported, :ena_support, :efa_supported, :efa_info, :encryption_in_transit_supported, :ena_srd_supported, :bandwidth_weightings, :flexible_ena_queues_support, :connection_tracking_configuration, :secondary_network_supported, :maximum_secondary_network_interfaces, :ipv_4_addresses_per_secondary_interface) SENSITIVE = [] include Aws::Structure end |
#network_cards ⇒ Array<Types::NetworkCardInfo>
Describes the network cards for the instance type.
71182 71183 71184 71185 71186 71187 71188 71189 71190 71191 71192 71193 71194 71195 71196 71197 71198 71199 71200 71201 71202 71203 71204 |
# File 'lib/aws-sdk-ec2/types.rb', line 71182 class NetworkInfo < Struct.new( :network_performance, :maximum_network_interfaces, :maximum_network_cards, :default_network_card_index, :network_cards, :ipv_4_addresses_per_interface, :ipv_6_addresses_per_interface, :ipv_6_supported, :ena_support, :efa_supported, :efa_info, :encryption_in_transit_supported, :ena_srd_supported, :bandwidth_weightings, :flexible_ena_queues_support, :connection_tracking_configuration, :secondary_network_supported, :maximum_secondary_network_interfaces, :ipv_4_addresses_per_secondary_interface) SENSITIVE = [] include Aws::Structure end |
#network_performance ⇒ String
The network performance.
71182 71183 71184 71185 71186 71187 71188 71189 71190 71191 71192 71193 71194 71195 71196 71197 71198 71199 71200 71201 71202 71203 71204 |
# File 'lib/aws-sdk-ec2/types.rb', line 71182 class NetworkInfo < Struct.new( :network_performance, :maximum_network_interfaces, :maximum_network_cards, :default_network_card_index, :network_cards, :ipv_4_addresses_per_interface, :ipv_6_addresses_per_interface, :ipv_6_supported, :ena_support, :efa_supported, :efa_info, :encryption_in_transit_supported, :ena_srd_supported, :bandwidth_weightings, :flexible_ena_queues_support, :connection_tracking_configuration, :secondary_network_supported, :maximum_secondary_network_interfaces, :ipv_4_addresses_per_secondary_interface) SENSITIVE = [] include Aws::Structure end |
#secondary_network_supported ⇒ Boolean
Indicates whether secondary interface attachments from secondary network are supported.
71182 71183 71184 71185 71186 71187 71188 71189 71190 71191 71192 71193 71194 71195 71196 71197 71198 71199 71200 71201 71202 71203 71204 |
# File 'lib/aws-sdk-ec2/types.rb', line 71182 class NetworkInfo < Struct.new( :network_performance, :maximum_network_interfaces, :maximum_network_cards, :default_network_card_index, :network_cards, :ipv_4_addresses_per_interface, :ipv_6_addresses_per_interface, :ipv_6_supported, :ena_support, :efa_supported, :efa_info, :encryption_in_transit_supported, :ena_srd_supported, :bandwidth_weightings, :flexible_ena_queues_support, :connection_tracking_configuration, :secondary_network_supported, :maximum_secondary_network_interfaces, :ipv_4_addresses_per_secondary_interface) SENSITIVE = [] include Aws::Structure end |