Class: Aws::EC2::Types::NetworkInterfaceIpv6Address
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::NetworkInterfaceIpv6Address
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes an IPv6 address associated with a network interface.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ipv_6_address ⇒ String
The IPv6 address.
-
#is_primary_ipv_6 ⇒ Boolean
Determines if an IPv6 address associated with a network interface is the primary IPv6 address.
-
#public_ipv_6_dns_name ⇒ String
An IPv6-enabled public hostname for a network interface.
Instance Attribute Details
#ipv_6_address ⇒ String
The IPv6 address.
66149 66150 66151 66152 66153 66154 66155 |
# File 'lib/aws-sdk-ec2/types.rb', line 66149 class NetworkInterfaceIpv6Address < Struct.new( :ipv_6_address, :public_ipv_6_dns_name, :is_primary_ipv_6) SENSITIVE = [] include Aws::Structure end |
#is_primary_ipv_6 ⇒ Boolean
Determines if an IPv6 address associated with a network interface is the primary IPv6 address. When you enable an IPv6 GUA address to be a primary IPv6, the first IPv6 GUA will be made the primary IPv6 address until the instance is terminated or the network interface is detached. For more information, see [ModifyNetworkInterfaceAttribute].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyNetworkInterfaceAttribute.html
66149 66150 66151 66152 66153 66154 66155 |
# File 'lib/aws-sdk-ec2/types.rb', line 66149 class NetworkInterfaceIpv6Address < Struct.new( :ipv_6_address, :public_ipv_6_dns_name, :is_primary_ipv_6) SENSITIVE = [] include Aws::Structure end |
#public_ipv_6_dns_name ⇒ String
An IPv6-enabled public hostname for a network interface. Requests from within the VPC or from the internet resolve to the IPv6 GUA of the network interface. For more information, see [EC2 instance hostnames, DNS names, and domains] in the *Amazon EC2 User Guide*.
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-instance-naming.html
66149 66150 66151 66152 66153 66154 66155 |
# File 'lib/aws-sdk-ec2/types.rb', line 66149 class NetworkInterfaceIpv6Address < Struct.new( :ipv_6_address, :public_ipv_6_dns_name, :is_primary_ipv_6) SENSITIVE = [] include Aws::Structure end |