Class: Aws::EC2::Types::Placement
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::Placement
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the placement of an instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#affinity ⇒ String
The affinity setting for the instance on the Dedicated Host.
-
#availability_zone ⇒ String
The Availability Zone of the instance.
-
#availability_zone_id ⇒ String
The ID of the Availability Zone of the instance.
-
#group_id ⇒ String
The ID of the placement group that the instance is in.
-
#group_name ⇒ String
The name of the placement group that the instance is in.
-
#host_id ⇒ String
The ID of the Dedicated Host on which the instance resides.
-
#host_resource_group_arn ⇒ String
The ARN of the host resource group in which to launch the instances.
-
#partition_number ⇒ Integer
The number of the partition that the instance is in.
-
#spread_domain ⇒ String
Reserved for future use.
-
#tenancy ⇒ String
The tenancy of the instance.
Instance Attribute Details
#affinity ⇒ String
The affinity setting for the instance on the Dedicated Host.
This parameter is not supported for [CreateFleet] or [ImportInstance].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateFleet [2]: docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ImportInstance.html
69738 69739 69740 69741 69742 69743 69744 69745 69746 69747 69748 69749 69750 69751 |
# File 'lib/aws-sdk-ec2/types.rb', line 69738 class Placement < Struct.new( :availability_zone_id, :affinity, :group_name, :partition_number, :host_id, :tenancy, :spread_domain, :host_resource_group_arn, :group_id, :availability_zone) SENSITIVE = [] include Aws::Structure end |
#availability_zone ⇒ String
The Availability Zone of the instance.
On input, you can specify ‘AvailabilityZone` or `AvailabilityZoneId`, but not both. If you specify neither one, Amazon EC2 automatically selects an Availability Zone for you.
This parameter is not supported for [CreateFleet].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateFleet
69738 69739 69740 69741 69742 69743 69744 69745 69746 69747 69748 69749 69750 69751 |
# File 'lib/aws-sdk-ec2/types.rb', line 69738 class Placement < Struct.new( :availability_zone_id, :affinity, :group_name, :partition_number, :host_id, :tenancy, :spread_domain, :host_resource_group_arn, :group_id, :availability_zone) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
The ID of the Availability Zone of the instance.
On input, you can specify ‘AvailabilityZone` or `AvailabilityZoneId`, but not both. If you specify neither one, Amazon EC2 automatically selects an Availability Zone for you.
This parameter is not supported for [CreateFleet].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateFleet
69738 69739 69740 69741 69742 69743 69744 69745 69746 69747 69748 69749 69750 69751 |
# File 'lib/aws-sdk-ec2/types.rb', line 69738 class Placement < Struct.new( :availability_zone_id, :affinity, :group_name, :partition_number, :host_id, :tenancy, :spread_domain, :host_resource_group_arn, :group_id, :availability_zone) SENSITIVE = [] include Aws::Structure end |
#group_id ⇒ String
The ID of the placement group that the instance is in.
On input, you can specify ‘GroupId` or `GroupName`, but not both.
69738 69739 69740 69741 69742 69743 69744 69745 69746 69747 69748 69749 69750 69751 |
# File 'lib/aws-sdk-ec2/types.rb', line 69738 class Placement < Struct.new( :availability_zone_id, :affinity, :group_name, :partition_number, :host_id, :tenancy, :spread_domain, :host_resource_group_arn, :group_id, :availability_zone) SENSITIVE = [] include Aws::Structure end |
#group_name ⇒ String
The name of the placement group that the instance is in.
On input, you can specify ‘GroupId` or `GroupName`, but not both.
69738 69739 69740 69741 69742 69743 69744 69745 69746 69747 69748 69749 69750 69751 |
# File 'lib/aws-sdk-ec2/types.rb', line 69738 class Placement < Struct.new( :availability_zone_id, :affinity, :group_name, :partition_number, :host_id, :tenancy, :spread_domain, :host_resource_group_arn, :group_id, :availability_zone) SENSITIVE = [] include Aws::Structure end |
#host_id ⇒ String
The ID of the Dedicated Host on which the instance resides.
This parameter is not supported for [CreateFleet] or [ImportInstance].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateFleet [2]: docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ImportInstance.html
69738 69739 69740 69741 69742 69743 69744 69745 69746 69747 69748 69749 69750 69751 |
# File 'lib/aws-sdk-ec2/types.rb', line 69738 class Placement < Struct.new( :availability_zone_id, :affinity, :group_name, :partition_number, :host_id, :tenancy, :spread_domain, :host_resource_group_arn, :group_id, :availability_zone) SENSITIVE = [] include Aws::Structure end |
#host_resource_group_arn ⇒ String
The ARN of the host resource group in which to launch the instances.
On input, if you specify this parameter, either omit the Tenancy parameter or set it to ‘host`.
This parameter is not supported for [CreateFleet].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateFleet
69738 69739 69740 69741 69742 69743 69744 69745 69746 69747 69748 69749 69750 69751 |
# File 'lib/aws-sdk-ec2/types.rb', line 69738 class Placement < Struct.new( :availability_zone_id, :affinity, :group_name, :partition_number, :host_id, :tenancy, :spread_domain, :host_resource_group_arn, :group_id, :availability_zone) SENSITIVE = [] include Aws::Structure end |
#partition_number ⇒ Integer
The number of the partition that the instance is in. Valid only if the placement group strategy is set to ‘partition`.
This parameter is not supported for [CreateFleet].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateFleet
69738 69739 69740 69741 69742 69743 69744 69745 69746 69747 69748 69749 69750 69751 |
# File 'lib/aws-sdk-ec2/types.rb', line 69738 class Placement < Struct.new( :availability_zone_id, :affinity, :group_name, :partition_number, :host_id, :tenancy, :spread_domain, :host_resource_group_arn, :group_id, :availability_zone) SENSITIVE = [] include Aws::Structure end |
#spread_domain ⇒ String
Reserved for future use.
69738 69739 69740 69741 69742 69743 69744 69745 69746 69747 69748 69749 69750 69751 |
# File 'lib/aws-sdk-ec2/types.rb', line 69738 class Placement < Struct.new( :availability_zone_id, :affinity, :group_name, :partition_number, :host_id, :tenancy, :spread_domain, :host_resource_group_arn, :group_id, :availability_zone) SENSITIVE = [] include Aws::Structure end |
#tenancy ⇒ String
The tenancy of the instance. An instance with a tenancy of ‘dedicated` runs on single-tenant hardware.
This parameter is not supported for [CreateFleet]. The ‘host` tenancy is not supported for [ImportInstance] or for T3 instances that are configured for the `unlimited` CPU credit option.
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateFleet [2]: docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ImportInstance.html
69738 69739 69740 69741 69742 69743 69744 69745 69746 69747 69748 69749 69750 69751 |
# File 'lib/aws-sdk-ec2/types.rb', line 69738 class Placement < Struct.new( :availability_zone_id, :affinity, :group_name, :partition_number, :host_id, :tenancy, :spread_domain, :host_resource_group_arn, :group_id, :availability_zone) SENSITIVE = [] include Aws::Structure end |