Class: Aws::EC2::Types::PriceSchedule
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::PriceSchedule
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the price for a Reserved Instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#active ⇒ Boolean
The current price schedule, as determined by the term remaining for the Reserved Instance in the listing.
-
#currency_code ⇒ String
The currency for transacting the Reserved Instance resale.
-
#price ⇒ Float
The fixed price for the term.
-
#term ⇒ Integer
The number of months remaining in the reservation.
Instance Attribute Details
#active ⇒ Boolean
The current price schedule, as determined by the term remaining for the Reserved Instance in the listing.
A specific price schedule is always in effect, but only one price schedule can be active at any time. Take, for example, a Reserved Instance listing that has five months remaining in its term. When you specify price schedules for five months and two months, this means that schedule 1, covering the first three months of the remaining term, will be active during months 5, 4, and 3. Then schedule 2, covering the last two months of the term, will be active for months 2 and 1.
69310 69311 69312 69313 69314 69315 69316 69317 |
# File 'lib/aws-sdk-ec2/types.rb', line 69310 class PriceSchedule < Struct.new( :active, :currency_code, :price, :term) SENSITIVE = [] include Aws::Structure end |
#currency_code ⇒ String
The currency for transacting the Reserved Instance resale. At this time, the only supported currency is ‘USD`.
69310 69311 69312 69313 69314 69315 69316 69317 |
# File 'lib/aws-sdk-ec2/types.rb', line 69310 class PriceSchedule < Struct.new( :active, :currency_code, :price, :term) SENSITIVE = [] include Aws::Structure end |
#price ⇒ Float
The fixed price for the term.
69310 69311 69312 69313 69314 69315 69316 69317 |
# File 'lib/aws-sdk-ec2/types.rb', line 69310 class PriceSchedule < Struct.new( :active, :currency_code, :price, :term) SENSITIVE = [] include Aws::Structure end |
#term ⇒ Integer
The number of months remaining in the reservation. For example, 2 is the second to the last month before the capacity reservation expires.
69310 69311 69312 69313 69314 69315 69316 69317 |
# File 'lib/aws-sdk-ec2/types.rb', line 69310 class PriceSchedule < Struct.new( :active, :currency_code, :price, :term) SENSITIVE = [] include Aws::Structure end |