Class: Aws::EC2::Types::PrivateDnsNameConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::PrivateDnsNameConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Information about the private DNS name for the service endpoint.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the record subdomain the service provider needs to create.
-
#state ⇒ String
The verification state of the VPC endpoint service.
-
#type ⇒ String
The endpoint service verification type, for example TXT.
-
#value ⇒ String
The value the service provider adds to the private DNS name domain record before verification.
Instance Attribute Details
#name ⇒ String
The name of the record subdomain the service provider needs to
create. The service provider adds the value text to the name.
73623 73624 73625 73626 73627 73628 73629 73630 |
# File 'lib/aws-sdk-ec2/types.rb', line 73623 class PrivateDnsNameConfiguration < Struct.new( :state, :type, :value, :name) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The verification state of the VPC endpoint service.
Consumers of the endpoint service can use the private name only when
the state is verified.
73623 73624 73625 73626 73627 73628 73629 73630 |
# File 'lib/aws-sdk-ec2/types.rb', line 73623 class PrivateDnsNameConfiguration < Struct.new( :state, :type, :value, :name) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The endpoint service verification type, for example TXT.
73623 73624 73625 73626 73627 73628 73629 73630 |
# File 'lib/aws-sdk-ec2/types.rb', line 73623 class PrivateDnsNameConfiguration < Struct.new( :state, :type, :value, :name) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
The value the service provider adds to the private DNS name domain record before verification.
73623 73624 73625 73626 73627 73628 73629 73630 |
# File 'lib/aws-sdk-ec2/types.rb', line 73623 class PrivateDnsNameConfiguration < Struct.new( :state, :type, :value, :name) SENSITIVE = [] include Aws::Structure end |