Class: Aws::EC2::Types::PrivateDnsNameOptionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes the options for instance hostnames.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enable_resource_name_dns_a_recordBoolean

Indicates whether to respond to DNS queries for instance hostnames with DNS A records.

Returns:

  • (Boolean)


70568
70569
70570
70571
70572
70573
70574
# File 'lib/aws-sdk-ec2/types.rb', line 70568

class PrivateDnsNameOptionsRequest < Struct.new(
  :hostname_type,
  :enable_resource_name_dns_a_record,
  :enable_resource_name_dns_aaaa_record)
  SENSITIVE = []
  include Aws::Structure
end

#enable_resource_name_dns_aaaa_recordBoolean

Indicates whether to respond to DNS queries for instance hostnames with DNS AAAA records.

Returns:

  • (Boolean)


70568
70569
70570
70571
70572
70573
70574
# File 'lib/aws-sdk-ec2/types.rb', line 70568

class PrivateDnsNameOptionsRequest < Struct.new(
  :hostname_type,
  :enable_resource_name_dns_a_record,
  :enable_resource_name_dns_aaaa_record)
  SENSITIVE = []
  include Aws::Structure
end

#hostname_typeString

The type of hostname for EC2 instances. For IPv4 only subnets, an instance DNS name must be based on the instance IPv4 address. For IPv6 only subnets, an instance DNS name must be based on the instance ID. For dual-stack subnets, you can specify whether DNS names use the instance IPv4 address or the instance ID.

Returns:

  • (String)


70568
70569
70570
70571
70572
70573
70574
# File 'lib/aws-sdk-ec2/types.rb', line 70568

class PrivateDnsNameOptionsRequest < Struct.new(
  :hostname_type,
  :enable_resource_name_dns_a_record,
  :enable_resource_name_dns_aaaa_record)
  SENSITIVE = []
  include Aws::Structure
end