Class: Aws::EC2::Types::ProvisionPublicIpv4PoolCidrRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


74112
74113
74114
74115
74116
74117
74118
74119
74120
# File 'lib/aws-sdk-ec2/types.rb', line 74112

class ProvisionPublicIpv4PoolCidrRequest < Struct.new(
  :dry_run,
  :ipam_pool_id,
  :pool_id,
  :netmask_length,
  :network_border_group)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_pool_idString

The ID of the IPAM pool you would like to use to allocate this CIDR.

Returns:

  • (String)


74112
74113
74114
74115
74116
74117
74118
74119
74120
# File 'lib/aws-sdk-ec2/types.rb', line 74112

class ProvisionPublicIpv4PoolCidrRequest < Struct.new(
  :dry_run,
  :ipam_pool_id,
  :pool_id,
  :netmask_length,
  :network_border_group)
  SENSITIVE = []
  include Aws::Structure
end

#netmask_lengthInteger

The netmask length of the CIDR you would like to allocate to the public IPv4 pool. The least specific netmask length you can define is 24.

Returns:

  • (Integer)


74112
74113
74114
74115
74116
74117
74118
74119
74120
# File 'lib/aws-sdk-ec2/types.rb', line 74112

class ProvisionPublicIpv4PoolCidrRequest < Struct.new(
  :dry_run,
  :ipam_pool_id,
  :pool_id,
  :netmask_length,
  :network_border_group)
  SENSITIVE = []
  include Aws::Structure
end

#network_border_groupString

The Availability Zone (AZ) or Local Zone (LZ) network border group that the resource that the IP address is assigned to is in. Defaults to an AZ network border group. For more information on available Local Zones, see Local Zone availability in the Amazon EC2 User Guide.

Returns:

  • (String)


74112
74113
74114
74115
74116
74117
74118
74119
74120
# File 'lib/aws-sdk-ec2/types.rb', line 74112

class ProvisionPublicIpv4PoolCidrRequest < Struct.new(
  :dry_run,
  :ipam_pool_id,
  :pool_id,
  :netmask_length,
  :network_border_group)
  SENSITIVE = []
  include Aws::Structure
end

#pool_idString

The ID of the public IPv4 pool you would like to use for this CIDR.

Returns:

  • (String)


74112
74113
74114
74115
74116
74117
74118
74119
74120
# File 'lib/aws-sdk-ec2/types.rb', line 74112

class ProvisionPublicIpv4PoolCidrRequest < Struct.new(
  :dry_run,
  :ipam_pool_id,
  :pool_id,
  :netmask_length,
  :network_border_group)
  SENSITIVE = []
  include Aws::Structure
end