Class: Aws::EC2::Types::ProvisionPublicIpv4PoolCidrResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ProvisionPublicIpv4PoolCidrResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#pool_address_range ⇒ Types::PublicIpv4PoolRange
Information about the address range of the public IPv4 pool.
-
#pool_id ⇒ String
The ID of the pool that you want to provision the CIDR to.
Instance Attribute Details
#pool_address_range ⇒ Types::PublicIpv4PoolRange
Information about the address range of the public IPv4 pool.
69892 69893 69894 69895 69896 69897 |
# File 'lib/aws-sdk-ec2/types.rb', line 69892 class ProvisionPublicIpv4PoolCidrResult < Struct.new( :pool_id, :pool_address_range) SENSITIVE = [] include Aws::Structure end |
#pool_id ⇒ String
The ID of the pool that you want to provision the CIDR to.
69892 69893 69894 69895 69896 69897 |
# File 'lib/aws-sdk-ec2/types.rb', line 69892 class ProvisionPublicIpv4PoolCidrResult < Struct.new( :pool_id, :pool_address_range) SENSITIVE = [] include Aws::Structure end |