Class: Aws::EC2::Types::Purchase
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::Purchase
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the result of the purchase.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#currency_code ⇒ String
The currency in which the
UpfrontPriceandHourlyPriceamounts are specified. -
#duration ⇒ Integer
The duration of the reservation's term in seconds.
-
#host_id_set ⇒ Array<String>
The IDs of the Dedicated Hosts associated with the reservation.
-
#host_reservation_id ⇒ String
The ID of the reservation.
-
#hourly_price ⇒ String
The hourly price of the reservation per hour.
-
#instance_family ⇒ String
The instance family on the Dedicated Host that the reservation can be associated with.
-
#payment_option ⇒ String
The payment option for the reservation.
-
#upfront_price ⇒ String
The upfront price of the reservation.
Instance Attribute Details
#currency_code ⇒ String
The currency in which the UpfrontPrice and HourlyPrice amounts
are specified. At this time, the only supported currency is USD.
74366 74367 74368 74369 74370 74371 74372 74373 74374 74375 74376 74377 |
# File 'lib/aws-sdk-ec2/types.rb', line 74366 class Purchase < Struct.new( :currency_code, :duration, :host_id_set, :host_reservation_id, :hourly_price, :instance_family, :payment_option, :upfront_price) SENSITIVE = [] include Aws::Structure end |
#duration ⇒ Integer
The duration of the reservation's term in seconds.
74366 74367 74368 74369 74370 74371 74372 74373 74374 74375 74376 74377 |
# File 'lib/aws-sdk-ec2/types.rb', line 74366 class Purchase < Struct.new( :currency_code, :duration, :host_id_set, :host_reservation_id, :hourly_price, :instance_family, :payment_option, :upfront_price) SENSITIVE = [] include Aws::Structure end |
#host_id_set ⇒ Array<String>
The IDs of the Dedicated Hosts associated with the reservation.
74366 74367 74368 74369 74370 74371 74372 74373 74374 74375 74376 74377 |
# File 'lib/aws-sdk-ec2/types.rb', line 74366 class Purchase < Struct.new( :currency_code, :duration, :host_id_set, :host_reservation_id, :hourly_price, :instance_family, :payment_option, :upfront_price) SENSITIVE = [] include Aws::Structure end |
#host_reservation_id ⇒ String
The ID of the reservation.
74366 74367 74368 74369 74370 74371 74372 74373 74374 74375 74376 74377 |
# File 'lib/aws-sdk-ec2/types.rb', line 74366 class Purchase < Struct.new( :currency_code, :duration, :host_id_set, :host_reservation_id, :hourly_price, :instance_family, :payment_option, :upfront_price) SENSITIVE = [] include Aws::Structure end |
#hourly_price ⇒ String
The hourly price of the reservation per hour.
74366 74367 74368 74369 74370 74371 74372 74373 74374 74375 74376 74377 |
# File 'lib/aws-sdk-ec2/types.rb', line 74366 class Purchase < Struct.new( :currency_code, :duration, :host_id_set, :host_reservation_id, :hourly_price, :instance_family, :payment_option, :upfront_price) SENSITIVE = [] include Aws::Structure end |
#instance_family ⇒ String
The instance family on the Dedicated Host that the reservation can be associated with.
74366 74367 74368 74369 74370 74371 74372 74373 74374 74375 74376 74377 |
# File 'lib/aws-sdk-ec2/types.rb', line 74366 class Purchase < Struct.new( :currency_code, :duration, :host_id_set, :host_reservation_id, :hourly_price, :instance_family, :payment_option, :upfront_price) SENSITIVE = [] include Aws::Structure end |
#payment_option ⇒ String
The payment option for the reservation.
74366 74367 74368 74369 74370 74371 74372 74373 74374 74375 74376 74377 |
# File 'lib/aws-sdk-ec2/types.rb', line 74366 class Purchase < Struct.new( :currency_code, :duration, :host_id_set, :host_reservation_id, :hourly_price, :instance_family, :payment_option, :upfront_price) SENSITIVE = [] include Aws::Structure end |
#upfront_price ⇒ String
The upfront price of the reservation.
74366 74367 74368 74369 74370 74371 74372 74373 74374 74375 74376 74377 |
# File 'lib/aws-sdk-ec2/types.rb', line 74366 class Purchase < Struct.new( :currency_code, :duration, :host_id_set, :host_reservation_id, :hourly_price, :instance_family, :payment_option, :upfront_price) SENSITIVE = [] include Aws::Structure end |