Class: Aws::EC2::Types::PurchaseReservedInstancesOfferingRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::PurchaseReservedInstancesOfferingRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for PurchaseReservedInstancesOffering.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#instance_count ⇒ Integer
The number of Reserved Instances to purchase.
-
#limit_price ⇒ Types::ReservedInstanceLimitPrice
Specified for Reserved Instance Marketplace offerings to limit the total order and ensure that the Reserved Instances are not purchased at unexpected prices.
-
#purchase_time ⇒ Time
The time at which to purchase the Reserved Instance, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ).
-
#reserved_instances_offering_id ⇒ String
The ID of the Reserved Instance offering to purchase.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
74575 74576 74577 74578 74579 74580 74581 74582 74583 |
# File 'lib/aws-sdk-ec2/types.rb', line 74575 class PurchaseReservedInstancesOfferingRequest < Struct.new( :instance_count, :reserved_instances_offering_id, :purchase_time, :dry_run, :limit_price) SENSITIVE = [] include Aws::Structure end |
#instance_count ⇒ Integer
The number of Reserved Instances to purchase.
74575 74576 74577 74578 74579 74580 74581 74582 74583 |
# File 'lib/aws-sdk-ec2/types.rb', line 74575 class PurchaseReservedInstancesOfferingRequest < Struct.new( :instance_count, :reserved_instances_offering_id, :purchase_time, :dry_run, :limit_price) SENSITIVE = [] include Aws::Structure end |
#limit_price ⇒ Types::ReservedInstanceLimitPrice
Specified for Reserved Instance Marketplace offerings to limit the total order and ensure that the Reserved Instances are not purchased at unexpected prices.
74575 74576 74577 74578 74579 74580 74581 74582 74583 |
# File 'lib/aws-sdk-ec2/types.rb', line 74575 class PurchaseReservedInstancesOfferingRequest < Struct.new( :instance_count, :reserved_instances_offering_id, :purchase_time, :dry_run, :limit_price) SENSITIVE = [] include Aws::Structure end |
#purchase_time ⇒ Time
The time at which to purchase the Reserved Instance, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ).
74575 74576 74577 74578 74579 74580 74581 74582 74583 |
# File 'lib/aws-sdk-ec2/types.rb', line 74575 class PurchaseReservedInstancesOfferingRequest < Struct.new( :instance_count, :reserved_instances_offering_id, :purchase_time, :dry_run, :limit_price) SENSITIVE = [] include Aws::Structure end |
#reserved_instances_offering_id ⇒ String
The ID of the Reserved Instance offering to purchase.
74575 74576 74577 74578 74579 74580 74581 74582 74583 |
# File 'lib/aws-sdk-ec2/types.rb', line 74575 class PurchaseReservedInstancesOfferingRequest < Struct.new( :instance_count, :reserved_instances_offering_id, :purchase_time, :dry_run, :limit_price) SENSITIVE = [] include Aws::Structure end |