Class: Aws::EC2::Types::RejectVpcEndpointConnectionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


75459
75460
75461
75462
75463
75464
75465
# File 'lib/aws-sdk-ec2/types.rb', line 75459

class RejectVpcEndpointConnectionsRequest < Struct.new(
  :dry_run,
  :service_id,
  :vpc_endpoint_ids)
  SENSITIVE = []
  include Aws::Structure
end

#service_idString

The ID of the service.

Returns:

  • (String)


75459
75460
75461
75462
75463
75464
75465
# File 'lib/aws-sdk-ec2/types.rb', line 75459

class RejectVpcEndpointConnectionsRequest < Struct.new(
  :dry_run,
  :service_id,
  :vpc_endpoint_ids)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_endpoint_idsArray<String>

The IDs of the VPC endpoints.

Returns:

  • (Array<String>)


75459
75460
75461
75462
75463
75464
75465
# File 'lib/aws-sdk-ec2/types.rb', line 75459

class RejectVpcEndpointConnectionsRequest < Struct.new(
  :dry_run,
  :service_id,
  :vpc_endpoint_ids)
  SENSITIVE = []
  include Aws::Structure
end