Class: Aws::EC2::Types::ReplaceRootVolumeTask
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ReplaceRootVolumeTask
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Information about a root volume replacement task.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#complete_time ⇒ String
The time the task completed.
-
#delete_replaced_root_volume ⇒ Boolean
Indicates whether the original root volume is to be deleted after the root volume replacement task completes.
-
#image_id ⇒ String
The ID of the AMI used to create the replacement root volume.
-
#instance_id ⇒ String
The ID of the instance for which the root volume replacement task was created.
-
#replace_root_volume_task_id ⇒ String
The ID of the root volume replacement task.
-
#snapshot_id ⇒ String
The ID of the snapshot used to create the replacement root volume.
-
#start_time ⇒ String
The time the task was started.
-
#tags ⇒ Array<Types::Tag>
The tags assigned to the task.
-
#task_state ⇒ String
The state of the task.
Instance Attribute Details
#complete_time ⇒ String
The time the task completed.
72767 72768 72769 72770 72771 72772 72773 72774 72775 72776 72777 72778 72779 |
# File 'lib/aws-sdk-ec2/types.rb', line 72767 class ReplaceRootVolumeTask < Struct.new( :replace_root_volume_task_id, :instance_id, :task_state, :start_time, :complete_time, :tags, :image_id, :snapshot_id, :delete_replaced_root_volume) SENSITIVE = [] include Aws::Structure end |
#delete_replaced_root_volume ⇒ Boolean
Indicates whether the original root volume is to be deleted after the root volume replacement task completes.
72767 72768 72769 72770 72771 72772 72773 72774 72775 72776 72777 72778 72779 |
# File 'lib/aws-sdk-ec2/types.rb', line 72767 class ReplaceRootVolumeTask < Struct.new( :replace_root_volume_task_id, :instance_id, :task_state, :start_time, :complete_time, :tags, :image_id, :snapshot_id, :delete_replaced_root_volume) SENSITIVE = [] include Aws::Structure end |
#image_id ⇒ String
The ID of the AMI used to create the replacement root volume.
72767 72768 72769 72770 72771 72772 72773 72774 72775 72776 72777 72778 72779 |
# File 'lib/aws-sdk-ec2/types.rb', line 72767 class ReplaceRootVolumeTask < Struct.new( :replace_root_volume_task_id, :instance_id, :task_state, :start_time, :complete_time, :tags, :image_id, :snapshot_id, :delete_replaced_root_volume) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the instance for which the root volume replacement task was created.
72767 72768 72769 72770 72771 72772 72773 72774 72775 72776 72777 72778 72779 |
# File 'lib/aws-sdk-ec2/types.rb', line 72767 class ReplaceRootVolumeTask < Struct.new( :replace_root_volume_task_id, :instance_id, :task_state, :start_time, :complete_time, :tags, :image_id, :snapshot_id, :delete_replaced_root_volume) SENSITIVE = [] include Aws::Structure end |
#replace_root_volume_task_id ⇒ String
The ID of the root volume replacement task.
72767 72768 72769 72770 72771 72772 72773 72774 72775 72776 72777 72778 72779 |
# File 'lib/aws-sdk-ec2/types.rb', line 72767 class ReplaceRootVolumeTask < Struct.new( :replace_root_volume_task_id, :instance_id, :task_state, :start_time, :complete_time, :tags, :image_id, :snapshot_id, :delete_replaced_root_volume) SENSITIVE = [] include Aws::Structure end |
#snapshot_id ⇒ String
The ID of the snapshot used to create the replacement root volume.
72767 72768 72769 72770 72771 72772 72773 72774 72775 72776 72777 72778 72779 |
# File 'lib/aws-sdk-ec2/types.rb', line 72767 class ReplaceRootVolumeTask < Struct.new( :replace_root_volume_task_id, :instance_id, :task_state, :start_time, :complete_time, :tags, :image_id, :snapshot_id, :delete_replaced_root_volume) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ String
The time the task was started.
72767 72768 72769 72770 72771 72772 72773 72774 72775 72776 72777 72778 72779 |
# File 'lib/aws-sdk-ec2/types.rb', line 72767 class ReplaceRootVolumeTask < Struct.new( :replace_root_volume_task_id, :instance_id, :task_state, :start_time, :complete_time, :tags, :image_id, :snapshot_id, :delete_replaced_root_volume) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags assigned to the task.
72767 72768 72769 72770 72771 72772 72773 72774 72775 72776 72777 72778 72779 |
# File 'lib/aws-sdk-ec2/types.rb', line 72767 class ReplaceRootVolumeTask < Struct.new( :replace_root_volume_task_id, :instance_id, :task_state, :start_time, :complete_time, :tags, :image_id, :snapshot_id, :delete_replaced_root_volume) SENSITIVE = [] include Aws::Structure end |
#task_state ⇒ String
The state of the task. The task can be in one of the following states:
-
pending- the replacement volume is being created. -
in-progress- the original volume is being detached and the replacement volume is being attached. -
succeeded- the replacement volume has been successfully attached to the instance and the instance is available. -
failing- the replacement task is in the process of failing. -
failed- the replacement task has failed but the original root volume is still attached. -
failing-detached- the replacement task is in the process of failing. The instance might have no root volume attached. -
failed-detached- the replacement task has failed and the instance has no root volume attached.
72767 72768 72769 72770 72771 72772 72773 72774 72775 72776 72777 72778 72779 |
# File 'lib/aws-sdk-ec2/types.rb', line 72767 class ReplaceRootVolumeTask < Struct.new( :replace_root_volume_task_id, :instance_id, :task_state, :start_time, :complete_time, :tags, :image_id, :snapshot_id, :delete_replaced_root_volume) SENSITIVE = [] include Aws::Structure end |