Class: Aws::EC2::Types::ReportInstanceStatusRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

Descriptive text about the health state of your instance.

Returns:

  • (String)


76260
76261
76262
76263
76264
76265
76266
76267
76268
76269
76270
# File 'lib/aws-sdk-ec2/types.rb', line 76260

class ReportInstanceStatusRequest < Struct.new(
  :dry_run,
  :instances,
  :status,
  :start_time,
  :end_time,
  :reason_codes,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


76260
76261
76262
76263
76264
76265
76266
76267
76268
76269
76270
# File 'lib/aws-sdk-ec2/types.rb', line 76260

class ReportInstanceStatusRequest < Struct.new(
  :dry_run,
  :instances,
  :status,
  :start_time,
  :end_time,
  :reason_codes,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#end_timeTime

The time at which the reported instance health state ended.

Returns:

  • (Time)


76260
76261
76262
76263
76264
76265
76266
76267
76268
76269
76270
# File 'lib/aws-sdk-ec2/types.rb', line 76260

class ReportInstanceStatusRequest < Struct.new(
  :dry_run,
  :instances,
  :status,
  :start_time,
  :end_time,
  :reason_codes,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#instancesArray<String>

The instances.

Returns:

  • (Array<String>)


76260
76261
76262
76263
76264
76265
76266
76267
76268
76269
76270
# File 'lib/aws-sdk-ec2/types.rb', line 76260

class ReportInstanceStatusRequest < Struct.new(
  :dry_run,
  :instances,
  :status,
  :start_time,
  :end_time,
  :reason_codes,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#reason_codesArray<String>

The reason codes that describe the health state of your instance.

  • instance-stuck-in-state: My instance is stuck in a state.

  • unresponsive: My instance is unresponsive.

  • not-accepting-credentials: My instance is not accepting my credentials.

  • password-not-available: A password is not available for my instance.

  • performance-network: My instance is experiencing performance problems that I believe are network related.

  • performance-instance-store: My instance is experiencing performance problems that I believe are related to the instance stores.

  • performance-ebs-volume: My instance is experiencing performance problems that I believe are related to an EBS volume.

  • performance-other: My instance is experiencing performance problems.

  • other: [explain using the description parameter]

Returns:

  • (Array<String>)


76260
76261
76262
76263
76264
76265
76266
76267
76268
76269
76270
# File 'lib/aws-sdk-ec2/types.rb', line 76260

class ReportInstanceStatusRequest < Struct.new(
  :dry_run,
  :instances,
  :status,
  :start_time,
  :end_time,
  :reason_codes,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#start_timeTime

The time at which the reported instance health state began.

Returns:

  • (Time)


76260
76261
76262
76263
76264
76265
76266
76267
76268
76269
76270
# File 'lib/aws-sdk-ec2/types.rb', line 76260

class ReportInstanceStatusRequest < Struct.new(
  :dry_run,
  :instances,
  :status,
  :start_time,
  :end_time,
  :reason_codes,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#statusString

The status of all instances listed.

Returns:

  • (String)


76260
76261
76262
76263
76264
76265
76266
76267
76268
76269
76270
# File 'lib/aws-sdk-ec2/types.rb', line 76260

class ReportInstanceStatusRequest < Struct.new(
  :dry_run,
  :instances,
  :status,
  :start_time,
  :end_time,
  :reason_codes,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end