Class: Aws::EC2::Types::ReservedCapacityFallbackOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes the fallback behavior for an EC2 Fleet that uses reserved capacity when the reserved capacity is not enough to meet the target capacity. If you don't specify fallback options, EC2 Fleet does not fall back to any other market type after the specified reservation types are exhausted.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#market_typesArray<String>

The instance purchasing options to fall back to when the reserved capacity is not enough to meet the target capacity. The only supported value is on-demand, which launches On-Demand Instances to fulfill the remaining target capacity.

Returns:

  • (Array<String>)


77170
77171
77172
77173
77174
# File 'lib/aws-sdk-ec2/types.rb', line 77170

class ReservedCapacityFallbackOptions < Struct.new(
  :market_types)
  SENSITIVE = []
  include Aws::Structure
end