Class: Aws::EC2::Types::ReservedCapacityOptionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Defines EC2 Fleet preferences for utilizing reserved capacity when DefaultTargetCapacityType is set to reserved-capacity. EC2 Fleet can fulfill reserved capacity using On-Demand Capacity Reservations, Capacity Blocks for ML, and interruptible Capacity Reservations.

This configuration can only be used if the EC2 Fleet is of type instant.

When you specify ReservedCapacityOptions, you must also set DefaultTargetCapacityType to reserved-capacity in the TargetCapacitySpecification.

For more information about interruptible Capacity Reservations, see Launch instances into an interruptible Capacity Reservation in the Amazon EC2 User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allocation_strategyString

The strategy that determines the order in which EC2 Fleet launches instances across the reservation types that you specify. The only supported value is prioritized, which launches instances in the priority order that you specify in your launch template overrides. If you don't specify an allocation strategy, instances are launched in a random order.

Returns:

  • (String)


77286
77287
77288
77289
77290
77291
77292
77293
# File 'lib/aws-sdk-ec2/types.rb', line 77286

class ReservedCapacityOptionsRequest < Struct.new(
  :allocation_strategy,
  :reservation_types,
  :capacity_reservation_target,
  :reserved_capacity_fallback_options)
  SENSITIVE = []
  include Aws::Structure
end

#capacity_reservation_targetTypes::FleetCapacityReservationTargetRequest

The Capacity Reservations or Capacity Reservation Resource Groups to use for fulfilling the EC2 Fleet request. You can specify Capacity Reservation IDs or a Capacity Reservation Resource Group ARN, but not both.



77286
77287
77288
77289
77290
77291
77292
77293
# File 'lib/aws-sdk-ec2/types.rb', line 77286

class ReservedCapacityOptionsRequest < Struct.new(
  :allocation_strategy,
  :reservation_types,
  :capacity_reservation_target,
  :reserved_capacity_fallback_options)
  SENSITIVE = []
  include Aws::Structure
end

#reservation_typesArray<String>

The types of Capacity Reservations to use for fulfilling the EC2 Fleet request. This is an ordered list: EC2 Fleet attempts to launch instances into each Capacity Reservation type in the order that you specify them before moving on to the next type.

Returns:

  • (Array<String>)


77286
77287
77288
77289
77290
77291
77292
77293
# File 'lib/aws-sdk-ec2/types.rb', line 77286

class ReservedCapacityOptionsRequest < Struct.new(
  :allocation_strategy,
  :reservation_types,
  :capacity_reservation_target,
  :reserved_capacity_fallback_options)
  SENSITIVE = []
  include Aws::Structure
end

#reserved_capacity_fallback_optionsTypes::ReservedCapacityFallbackOptionsRequest

The fallback behavior for the EC2 Fleet when there is not enough reserved capacity available to meet the target capacity. This member takes a ReservedCapacityFallbackOptionsRequest structure, in which you set MarketTypes to the instance purchasing options to fall back to.



77286
77287
77288
77289
77290
77291
77292
77293
# File 'lib/aws-sdk-ec2/types.rb', line 77286

class ReservedCapacityOptionsRequest < Struct.new(
  :allocation_strategy,
  :reservation_types,
  :capacity_reservation_target,
  :reserved_capacity_fallback_options)
  SENSITIVE = []
  include Aws::Structure
end