Class: Aws::EC2::Types::ReservedInstanceLimitPrice
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ReservedInstanceLimitPrice
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the limit price of a Reserved Instance offering.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#amount ⇒ Float
Used for Reserved Instance Marketplace offerings.
-
#currency_code ⇒ String
The currency in which the
limitPriceamount is specified.
Instance Attribute Details
#amount ⇒ Float
Used for Reserved Instance Marketplace offerings. Specifies the limit price on the total order (instanceCount * price).
74035 74036 74037 74038 74039 74040 |
# File 'lib/aws-sdk-ec2/types.rb', line 74035 class ReservedInstanceLimitPrice < Struct.new( :amount, :currency_code) SENSITIVE = [] include Aws::Structure end |
#currency_code ⇒ String
The currency in which the limitPrice amount is specified. At this
time, the only supported currency is USD.
74035 74036 74037 74038 74039 74040 |
# File 'lib/aws-sdk-ec2/types.rb', line 74035 class ReservedInstanceLimitPrice < Struct.new( :amount, :currency_code) SENSITIVE = [] include Aws::Structure end |