Class: Aws::EC2::Types::ResourceTypeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

A resource type to check for image references. Associated options can also be specified if the resource type is an EC2 instance or launch template.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resource_typeString

The resource type.

Returns:

  • (String)


72037
72038
72039
72040
72041
72042
# File 'lib/aws-sdk-ec2/types.rb', line 72037

class ResourceTypeRequest < Struct.new(
  :resource_type,
  :resource_type_options)
  SENSITIVE = []
  include Aws::Structure
end

#resource_type_optionsArray<Types::ResourceTypeOption>

The options that affect the scope of the response. Valid only when ‘ResourceType` is `ec2:Instance` or `ec2:LaunchTemplate`.

Returns:



72037
72038
72039
72040
72041
72042
# File 'lib/aws-sdk-ec2/types.rb', line 72037

class ResourceTypeRequest < Struct.new(
  :resource_type,
  :resource_type_options)
  SENSITIVE = []
  include Aws::Structure
end