Class: Aws::EC2::Types::RestoreSnapshotTierRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


78416
78417
78418
78419
78420
78421
78422
78423
# File 'lib/aws-sdk-ec2/types.rb', line 78416

class RestoreSnapshotTierRequest < Struct.new(
  :snapshot_id,
  :temporary_restore_days,
  :permanent_restore,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#permanent_restoreBoolean

Indicates whether to permanently restore an archived snapshot. To permanently restore an archived snapshot, specify true and omit the RestoreSnapshotTierRequest$TemporaryRestoreDays parameter.

Returns:

  • (Boolean)


78416
78417
78418
78419
78420
78421
78422
78423
# File 'lib/aws-sdk-ec2/types.rb', line 78416

class RestoreSnapshotTierRequest < Struct.new(
  :snapshot_id,
  :temporary_restore_days,
  :permanent_restore,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_idString

The ID of the snapshot to restore.

Returns:

  • (String)


78416
78417
78418
78419
78420
78421
78422
78423
# File 'lib/aws-sdk-ec2/types.rb', line 78416

class RestoreSnapshotTierRequest < Struct.new(
  :snapshot_id,
  :temporary_restore_days,
  :permanent_restore,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#temporary_restore_daysInteger

Specifies the number of days for which to temporarily restore an archived snapshot. Required for temporary restores only. The snapshot will be automatically re-archived after this period.

To temporarily restore an archived snapshot, specify the number of days and omit the PermanentRestore parameter or set it to false.

Returns:

  • (Integer)


78416
78417
78418
78419
78420
78421
78422
78423
# File 'lib/aws-sdk-ec2/types.rb', line 78416

class RestoreSnapshotTierRequest < Struct.new(
  :snapshot_id,
  :temporary_restore_days,
  :permanent_restore,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end