Class: Aws::EC2::Types::RevokeSecurityGroupIngressRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cidr_ipString

The CIDR IP address range. You can't specify this parameter when specifying a source security group.

Returns:

  • (String)


75581
75582
75583
75584
75585
75586
75587
75588
75589
75590
75591
75592
75593
75594
75595
# File 'lib/aws-sdk-ec2/types.rb', line 75581

class RevokeSecurityGroupIngressRequest < Struct.new(
  :cidr_ip,
  :from_port,
  :group_id,
  :group_name,
  :ip_permissions,
  :ip_protocol,
  :source_security_group_name,
  :source_security_group_owner_id,
  :to_port,
  :security_group_rule_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


75581
75582
75583
75584
75585
75586
75587
75588
75589
75590
75591
75592
75593
75594
75595
# File 'lib/aws-sdk-ec2/types.rb', line 75581

class RevokeSecurityGroupIngressRequest < Struct.new(
  :cidr_ip,
  :from_port,
  :group_id,
  :group_name,
  :ip_permissions,
  :ip_protocol,
  :source_security_group_name,
  :source_security_group_owner_id,
  :to_port,
  :security_group_rule_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#from_portInteger

If the protocol is TCP or UDP, this is the start of the port range. If the protocol is ICMP, this is the ICMP type or -1 (all ICMP types).

Returns:

  • (Integer)


75581
75582
75583
75584
75585
75586
75587
75588
75589
75590
75591
75592
75593
75594
75595
# File 'lib/aws-sdk-ec2/types.rb', line 75581

class RevokeSecurityGroupIngressRequest < Struct.new(
  :cidr_ip,
  :from_port,
  :group_id,
  :group_name,
  :ip_permissions,
  :ip_protocol,
  :source_security_group_name,
  :source_security_group_owner_id,
  :to_port,
  :security_group_rule_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#group_idString

The ID of the security group.

Returns:

  • (String)


75581
75582
75583
75584
75585
75586
75587
75588
75589
75590
75591
75592
75593
75594
75595
# File 'lib/aws-sdk-ec2/types.rb', line 75581

class RevokeSecurityGroupIngressRequest < Struct.new(
  :cidr_ip,
  :from_port,
  :group_id,
  :group_name,
  :ip_permissions,
  :ip_protocol,
  :source_security_group_name,
  :source_security_group_owner_id,
  :to_port,
  :security_group_rule_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#group_nameString

[Default VPC] The name of the security group. You must specify either the security group ID or the security group name in the request. For security groups in a nondefault VPC, you must specify the security group ID.

Returns:

  • (String)


75581
75582
75583
75584
75585
75586
75587
75588
75589
75590
75591
75592
75593
75594
75595
# File 'lib/aws-sdk-ec2/types.rb', line 75581

class RevokeSecurityGroupIngressRequest < Struct.new(
  :cidr_ip,
  :from_port,
  :group_id,
  :group_name,
  :ip_permissions,
  :ip_protocol,
  :source_security_group_name,
  :source_security_group_owner_id,
  :to_port,
  :security_group_rule_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#ip_permissionsArray<Types::IpPermission>

The sets of IP permissions. You can't specify a source security group and a CIDR IP address range in the same set of permissions.

Returns:



75581
75582
75583
75584
75585
75586
75587
75588
75589
75590
75591
75592
75593
75594
75595
# File 'lib/aws-sdk-ec2/types.rb', line 75581

class RevokeSecurityGroupIngressRequest < Struct.new(
  :cidr_ip,
  :from_port,
  :group_id,
  :group_name,
  :ip_permissions,
  :ip_protocol,
  :source_security_group_name,
  :source_security_group_owner_id,
  :to_port,
  :security_group_rule_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#ip_protocolString

The IP protocol name (tcp, udp, icmp) or number (see Protocol Numbers). Use -1 to specify all.

Returns:

  • (String)


75581
75582
75583
75584
75585
75586
75587
75588
75589
75590
75591
75592
75593
75594
75595
# File 'lib/aws-sdk-ec2/types.rb', line 75581

class RevokeSecurityGroupIngressRequest < Struct.new(
  :cidr_ip,
  :from_port,
  :group_id,
  :group_name,
  :ip_permissions,
  :ip_protocol,
  :source_security_group_name,
  :source_security_group_owner_id,
  :to_port,
  :security_group_rule_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#security_group_rule_idsArray<String>

The IDs of the security group rules.

Returns:

  • (Array<String>)


75581
75582
75583
75584
75585
75586
75587
75588
75589
75590
75591
75592
75593
75594
75595
# File 'lib/aws-sdk-ec2/types.rb', line 75581

class RevokeSecurityGroupIngressRequest < Struct.new(
  :cidr_ip,
  :from_port,
  :group_id,
  :group_name,
  :ip_permissions,
  :ip_protocol,
  :source_security_group_name,
  :source_security_group_owner_id,
  :to_port,
  :security_group_rule_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#source_security_group_nameString

[Default VPC] The name of the source security group. You can't specify this parameter in combination with the following parameters: the CIDR IP address range, the start of the port range, the IP protocol, and the end of the port range. The source security group must be in the same VPC. To revoke a specific rule for an IP protocol and port range, use a set of IP permissions instead.

Returns:

  • (String)


75581
75582
75583
75584
75585
75586
75587
75588
75589
75590
75591
75592
75593
75594
75595
# File 'lib/aws-sdk-ec2/types.rb', line 75581

class RevokeSecurityGroupIngressRequest < Struct.new(
  :cidr_ip,
  :from_port,
  :group_id,
  :group_name,
  :ip_permissions,
  :ip_protocol,
  :source_security_group_name,
  :source_security_group_owner_id,
  :to_port,
  :security_group_rule_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#source_security_group_owner_idString

Not supported.

Returns:

  • (String)


75581
75582
75583
75584
75585
75586
75587
75588
75589
75590
75591
75592
75593
75594
75595
# File 'lib/aws-sdk-ec2/types.rb', line 75581

class RevokeSecurityGroupIngressRequest < Struct.new(
  :cidr_ip,
  :from_port,
  :group_id,
  :group_name,
  :ip_permissions,
  :ip_protocol,
  :source_security_group_name,
  :source_security_group_owner_id,
  :to_port,
  :security_group_rule_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#to_portInteger

If the protocol is TCP or UDP, this is the end of the port range. If the protocol is ICMP, this is the ICMP code or -1 (all ICMP codes).

Returns:

  • (Integer)


75581
75582
75583
75584
75585
75586
75587
75588
75589
75590
75591
75592
75593
75594
75595
# File 'lib/aws-sdk-ec2/types.rb', line 75581

class RevokeSecurityGroupIngressRequest < Struct.new(
  :cidr_ip,
  :from_port,
  :group_id,
  :group_name,
  :ip_permissions,
  :ip_protocol,
  :source_security_group_name,
  :source_security_group_owner_id,
  :to_port,
  :security_group_rule_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end