Class: Aws::EC2::Types::RouteServerBgpOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::RouteServerBgpOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
The BGP configuration options for a route server peer.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#peer_asn ⇒ Integer
The Border Gateway Protocol (BGP) Autonomous System Number (ASN) for the appliance.
-
#peer_liveness_detection ⇒ String
The liveness detection protocol used for the BGP peer.
Instance Attribute Details
#peer_asn ⇒ Integer
The Border Gateway Protocol (BGP) Autonomous System Number (ASN) for the appliance. Valid values are from 1 to 4294967295. We recommend using a private ASN in the 64512–65534 (16-bit ASN) or 4200000000–4294967294 (32-bit ASN) range.
75580 75581 75582 75583 75584 75585 |
# File 'lib/aws-sdk-ec2/types.rb', line 75580 class RouteServerBgpOptions < Struct.new( :peer_asn, :peer_liveness_detection) SENSITIVE = [] include Aws::Structure end |
#peer_liveness_detection ⇒ String
The liveness detection protocol used for the BGP peer.
The requested liveness detection protocol for the BGP peer.
-
bgp-keepalive: The standard BGP keep alive mechanism (RFC4271) that is stable but may take longer to fail-over in cases of network impact or router failure. -
bfd: An additional Bidirectional Forwarding Detection (BFD) protocol (RFC5880) that enables fast failover by using more sensitive liveness detection.
Defaults to bgp-keepalive.
75580 75581 75582 75583 75584 75585 |
# File 'lib/aws-sdk-ec2/types.rb', line 75580 class RouteServerBgpOptions < Struct.new( :peer_asn, :peer_liveness_detection) SENSITIVE = [] include Aws::Structure end |