Class: Aws::EC2::Types::RouteServerPeer
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::RouteServerPeer
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a BGP peer configuration for a route server endpoint.
A route server peer is a session between a route server endpoint and the device deployed in Amazon Web Services (such as a firewall appliance or other network security function running on an EC2 instance). The device must meet these requirements:
-
Have an elastic network interface in the VPC
-
Support BGP (Border Gateway Protocol)
-
Can initiate BGP sessions
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bfd_status ⇒ Types::RouteServerBfdStatus
The current status of the BFD session with this peer.
-
#bgp_options ⇒ Types::RouteServerBgpOptions
The BGP configuration options for this peer, including ASN (Autonomous System Number) and BFD (Bidrectional Forwarding Detection) settings.
-
#bgp_status ⇒ Types::RouteServerBgpStatus
The current status of the BGP session with this peer.
-
#endpoint_eni_address ⇒ String
The IP address of the Elastic network interface for the route server endpoint.
-
#endpoint_eni_id ⇒ String
The ID of the Elastic network interface for the route server endpoint.
-
#failure_reason ⇒ String
The reason for any failure in peer creation or operation.
-
#peer_address ⇒ String
The IPv4 address of the peer device.
-
#route_server_endpoint_id ⇒ String
The ID of the route server endpoint associated with this peer.
-
#route_server_id ⇒ String
The ID of the route server associated with this peer.
-
#route_server_peer_id ⇒ String
The unique identifier of the route server peer.
-
#state ⇒ String
The current state of the route server peer.
-
#subnet_id ⇒ String
The ID of the subnet containing the route server peer.
-
#tags ⇒ Array<Types::Tag>
Any tags assigned to the route server peer.
-
#vpc_id ⇒ String
The ID of the VPC containing the route server peer.
Instance Attribute Details
#bfd_status ⇒ Types::RouteServerBfdStatus
The current status of the BFD session with this peer.
76481 76482 76483 76484 76485 76486 76487 76488 76489 76490 76491 76492 76493 76494 76495 76496 76497 76498 |
# File 'lib/aws-sdk-ec2/types.rb', line 76481 class RouteServerPeer < Struct.new( :route_server_peer_id, :route_server_endpoint_id, :route_server_id, :vpc_id, :subnet_id, :state, :failure_reason, :endpoint_eni_id, :endpoint_eni_address, :peer_address, :bgp_options, :bgp_status, :bfd_status, :tags) SENSITIVE = [] include Aws::Structure end |
#bgp_options ⇒ Types::RouteServerBgpOptions
The BGP configuration options for this peer, including ASN (Autonomous System Number) and BFD (Bidrectional Forwarding Detection) settings.
76481 76482 76483 76484 76485 76486 76487 76488 76489 76490 76491 76492 76493 76494 76495 76496 76497 76498 |
# File 'lib/aws-sdk-ec2/types.rb', line 76481 class RouteServerPeer < Struct.new( :route_server_peer_id, :route_server_endpoint_id, :route_server_id, :vpc_id, :subnet_id, :state, :failure_reason, :endpoint_eni_id, :endpoint_eni_address, :peer_address, :bgp_options, :bgp_status, :bfd_status, :tags) SENSITIVE = [] include Aws::Structure end |
#bgp_status ⇒ Types::RouteServerBgpStatus
The current status of the BGP session with this peer.
76481 76482 76483 76484 76485 76486 76487 76488 76489 76490 76491 76492 76493 76494 76495 76496 76497 76498 |
# File 'lib/aws-sdk-ec2/types.rb', line 76481 class RouteServerPeer < Struct.new( :route_server_peer_id, :route_server_endpoint_id, :route_server_id, :vpc_id, :subnet_id, :state, :failure_reason, :endpoint_eni_id, :endpoint_eni_address, :peer_address, :bgp_options, :bgp_status, :bfd_status, :tags) SENSITIVE = [] include Aws::Structure end |
#endpoint_eni_address ⇒ String
The IP address of the Elastic network interface for the route server endpoint.
76481 76482 76483 76484 76485 76486 76487 76488 76489 76490 76491 76492 76493 76494 76495 76496 76497 76498 |
# File 'lib/aws-sdk-ec2/types.rb', line 76481 class RouteServerPeer < Struct.new( :route_server_peer_id, :route_server_endpoint_id, :route_server_id, :vpc_id, :subnet_id, :state, :failure_reason, :endpoint_eni_id, :endpoint_eni_address, :peer_address, :bgp_options, :bgp_status, :bfd_status, :tags) SENSITIVE = [] include Aws::Structure end |
#endpoint_eni_id ⇒ String
The ID of the Elastic network interface for the route server endpoint.
76481 76482 76483 76484 76485 76486 76487 76488 76489 76490 76491 76492 76493 76494 76495 76496 76497 76498 |
# File 'lib/aws-sdk-ec2/types.rb', line 76481 class RouteServerPeer < Struct.new( :route_server_peer_id, :route_server_endpoint_id, :route_server_id, :vpc_id, :subnet_id, :state, :failure_reason, :endpoint_eni_id, :endpoint_eni_address, :peer_address, :bgp_options, :bgp_status, :bfd_status, :tags) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
The reason for any failure in peer creation or operation.
76481 76482 76483 76484 76485 76486 76487 76488 76489 76490 76491 76492 76493 76494 76495 76496 76497 76498 |
# File 'lib/aws-sdk-ec2/types.rb', line 76481 class RouteServerPeer < Struct.new( :route_server_peer_id, :route_server_endpoint_id, :route_server_id, :vpc_id, :subnet_id, :state, :failure_reason, :endpoint_eni_id, :endpoint_eni_address, :peer_address, :bgp_options, :bgp_status, :bfd_status, :tags) SENSITIVE = [] include Aws::Structure end |
#peer_address ⇒ String
The IPv4 address of the peer device.
76481 76482 76483 76484 76485 76486 76487 76488 76489 76490 76491 76492 76493 76494 76495 76496 76497 76498 |
# File 'lib/aws-sdk-ec2/types.rb', line 76481 class RouteServerPeer < Struct.new( :route_server_peer_id, :route_server_endpoint_id, :route_server_id, :vpc_id, :subnet_id, :state, :failure_reason, :endpoint_eni_id, :endpoint_eni_address, :peer_address, :bgp_options, :bgp_status, :bfd_status, :tags) SENSITIVE = [] include Aws::Structure end |
#route_server_endpoint_id ⇒ String
The ID of the route server endpoint associated with this peer.
76481 76482 76483 76484 76485 76486 76487 76488 76489 76490 76491 76492 76493 76494 76495 76496 76497 76498 |
# File 'lib/aws-sdk-ec2/types.rb', line 76481 class RouteServerPeer < Struct.new( :route_server_peer_id, :route_server_endpoint_id, :route_server_id, :vpc_id, :subnet_id, :state, :failure_reason, :endpoint_eni_id, :endpoint_eni_address, :peer_address, :bgp_options, :bgp_status, :bfd_status, :tags) SENSITIVE = [] include Aws::Structure end |
#route_server_id ⇒ String
The ID of the route server associated with this peer.
76481 76482 76483 76484 76485 76486 76487 76488 76489 76490 76491 76492 76493 76494 76495 76496 76497 76498 |
# File 'lib/aws-sdk-ec2/types.rb', line 76481 class RouteServerPeer < Struct.new( :route_server_peer_id, :route_server_endpoint_id, :route_server_id, :vpc_id, :subnet_id, :state, :failure_reason, :endpoint_eni_id, :endpoint_eni_address, :peer_address, :bgp_options, :bgp_status, :bfd_status, :tags) SENSITIVE = [] include Aws::Structure end |
#route_server_peer_id ⇒ String
The unique identifier of the route server peer.
76481 76482 76483 76484 76485 76486 76487 76488 76489 76490 76491 76492 76493 76494 76495 76496 76497 76498 |
# File 'lib/aws-sdk-ec2/types.rb', line 76481 class RouteServerPeer < Struct.new( :route_server_peer_id, :route_server_endpoint_id, :route_server_id, :vpc_id, :subnet_id, :state, :failure_reason, :endpoint_eni_id, :endpoint_eni_address, :peer_address, :bgp_options, :bgp_status, :bfd_status, :tags) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the route server peer.
76481 76482 76483 76484 76485 76486 76487 76488 76489 76490 76491 76492 76493 76494 76495 76496 76497 76498 |
# File 'lib/aws-sdk-ec2/types.rb', line 76481 class RouteServerPeer < Struct.new( :route_server_peer_id, :route_server_endpoint_id, :route_server_id, :vpc_id, :subnet_id, :state, :failure_reason, :endpoint_eni_id, :endpoint_eni_address, :peer_address, :bgp_options, :bgp_status, :bfd_status, :tags) SENSITIVE = [] include Aws::Structure end |
#subnet_id ⇒ String
The ID of the subnet containing the route server peer.
76481 76482 76483 76484 76485 76486 76487 76488 76489 76490 76491 76492 76493 76494 76495 76496 76497 76498 |
# File 'lib/aws-sdk-ec2/types.rb', line 76481 class RouteServerPeer < Struct.new( :route_server_peer_id, :route_server_endpoint_id, :route_server_id, :vpc_id, :subnet_id, :state, :failure_reason, :endpoint_eni_id, :endpoint_eni_address, :peer_address, :bgp_options, :bgp_status, :bfd_status, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Any tags assigned to the route server peer.
76481 76482 76483 76484 76485 76486 76487 76488 76489 76490 76491 76492 76493 76494 76495 76496 76497 76498 |
# File 'lib/aws-sdk-ec2/types.rb', line 76481 class RouteServerPeer < Struct.new( :route_server_peer_id, :route_server_endpoint_id, :route_server_id, :vpc_id, :subnet_id, :state, :failure_reason, :endpoint_eni_id, :endpoint_eni_address, :peer_address, :bgp_options, :bgp_status, :bfd_status, :tags) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC containing the route server peer.
76481 76482 76483 76484 76485 76486 76487 76488 76489 76490 76491 76492 76493 76494 76495 76496 76497 76498 |
# File 'lib/aws-sdk-ec2/types.rb', line 76481 class RouteServerPeer < Struct.new( :route_server_peer_id, :route_server_endpoint_id, :route_server_id, :vpc_id, :subnet_id, :state, :failure_reason, :endpoint_eni_id, :endpoint_eni_address, :peer_address, :bgp_options, :bgp_status, :bfd_status, :tags) SENSITIVE = [] include Aws::Structure end |