Class: Aws::EC2::Types::RouteServerPropagation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes the route propagation configuration between a route server and a route table.

When enabled, route server propagation installs the routes in the FIB on the route table you've specified. Route server supports IPv4 and IPv6 route propagation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#route_server_idString

The ID of the route server configured for route propagation.

Returns:

  • (String)


76344
76345
76346
76347
76348
76349
76350
# File 'lib/aws-sdk-ec2/types.rb', line 76344

class RouteServerPropagation < Struct.new(
  :route_server_id,
  :route_table_id,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#route_table_idString

The ID of the route table configured for route server propagation.

Returns:

  • (String)


76344
76345
76346
76347
76348
76349
76350
# File 'lib/aws-sdk-ec2/types.rb', line 76344

class RouteServerPropagation < Struct.new(
  :route_server_id,
  :route_table_id,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The current state of route propagation.

Returns:

  • (String)


76344
76345
76346
76347
76348
76349
76350
# File 'lib/aws-sdk-ec2/types.rb', line 76344

class RouteServerPropagation < Struct.new(
  :route_server_id,
  :route_table_id,
  :state)
  SENSITIVE = []
  include Aws::Structure
end