Class: Aws::EC2::Types::RouteServerRoute

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes a route in the route server's routing database.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#as_pathsArray<String>

The AS path attributes of the BGP route.

Returns:

  • (Array<String>)


76409
76410
76411
76412
76413
76414
76415
76416
76417
76418
76419
76420
# File 'lib/aws-sdk-ec2/types.rb', line 76409

class RouteServerRoute < Struct.new(
  :route_server_endpoint_id,
  :route_server_peer_id,
  :route_installation_details,
  :route_status,
  :prefix,
  :as_paths,
  :med,
  :next_hop_ip)
  SENSITIVE = []
  include Aws::Structure
end

#medInteger

The Multi-Exit Discriminator (MED) value of the BGP route.

Returns:

  • (Integer)


76409
76410
76411
76412
76413
76414
76415
76416
76417
76418
76419
76420
# File 'lib/aws-sdk-ec2/types.rb', line 76409

class RouteServerRoute < Struct.new(
  :route_server_endpoint_id,
  :route_server_peer_id,
  :route_installation_details,
  :route_status,
  :prefix,
  :as_paths,
  :med,
  :next_hop_ip)
  SENSITIVE = []
  include Aws::Structure
end

#next_hop_ipString

The IP address for the next hop.

Returns:

  • (String)


76409
76410
76411
76412
76413
76414
76415
76416
76417
76418
76419
76420
# File 'lib/aws-sdk-ec2/types.rb', line 76409

class RouteServerRoute < Struct.new(
  :route_server_endpoint_id,
  :route_server_peer_id,
  :route_installation_details,
  :route_status,
  :prefix,
  :as_paths,
  :med,
  :next_hop_ip)
  SENSITIVE = []
  include Aws::Structure
end

#prefixString

The destination CIDR block of the route.

Returns:

  • (String)


76409
76410
76411
76412
76413
76414
76415
76416
76417
76418
76419
76420
# File 'lib/aws-sdk-ec2/types.rb', line 76409

class RouteServerRoute < Struct.new(
  :route_server_endpoint_id,
  :route_server_peer_id,
  :route_installation_details,
  :route_status,
  :prefix,
  :as_paths,
  :med,
  :next_hop_ip)
  SENSITIVE = []
  include Aws::Structure
end

#route_installation_detailsArray<Types::RouteServerRouteInstallationDetail>

Details about the installation status of this route in route tables.



76409
76410
76411
76412
76413
76414
76415
76416
76417
76418
76419
76420
# File 'lib/aws-sdk-ec2/types.rb', line 76409

class RouteServerRoute < Struct.new(
  :route_server_endpoint_id,
  :route_server_peer_id,
  :route_installation_details,
  :route_status,
  :prefix,
  :as_paths,
  :med,
  :next_hop_ip)
  SENSITIVE = []
  include Aws::Structure
end

#route_server_endpoint_idString

The ID of the route server endpoint that received this route.

Returns:

  • (String)


76409
76410
76411
76412
76413
76414
76415
76416
76417
76418
76419
76420
# File 'lib/aws-sdk-ec2/types.rb', line 76409

class RouteServerRoute < Struct.new(
  :route_server_endpoint_id,
  :route_server_peer_id,
  :route_installation_details,
  :route_status,
  :prefix,
  :as_paths,
  :med,
  :next_hop_ip)
  SENSITIVE = []
  include Aws::Structure
end

#route_server_peer_idString

The ID of the route server peer that advertised this route.

Returns:

  • (String)


76409
76410
76411
76412
76413
76414
76415
76416
76417
76418
76419
76420
# File 'lib/aws-sdk-ec2/types.rb', line 76409

class RouteServerRoute < Struct.new(
  :route_server_endpoint_id,
  :route_server_peer_id,
  :route_installation_details,
  :route_status,
  :prefix,
  :as_paths,
  :med,
  :next_hop_ip)
  SENSITIVE = []
  include Aws::Structure
end

#route_statusString

The current status of the route in the routing database. Values are in-rib or in-fib depending on if the routes are in the RIB or the FIB database.

The Routing Information Base (RIB) serves as a database that stores all the routing information and network topology data collected by a router or routing system, such as routes learned from BGP peers. The RIB is constantly updated as new routing information is received or existing routes change. This ensures that the route server always has the most current view of the network topology and can make optimal routing decisions.

The Forwarding Information Base (FIB) serves as a forwarding table for what route server has determined are the best-path routes in the RIB after evaluating all available routing information and policies. The FIB routes are installed on the route tables. The FIB is recomputed whenever there are changes to the RIB.

Returns:

  • (String)


76409
76410
76411
76412
76413
76414
76415
76416
76417
76418
76419
76420
# File 'lib/aws-sdk-ec2/types.rb', line 76409

class RouteServerRoute < Struct.new(
  :route_server_endpoint_id,
  :route_server_peer_id,
  :route_installation_details,
  :route_status,
  :prefix,
  :as_paths,
  :med,
  :next_hop_ip)
  SENSITIVE = []
  include Aws::Structure
end