Class: Aws::EC2::Types::RouteTableAssociation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes an association between a route table and a subnet or gateway.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#association_stateTypes::RouteTableAssociationState

The state of the association.



74747
74748
74749
74750
74751
74752
74753
74754
74755
74756
74757
# File 'lib/aws-sdk-ec2/types.rb', line 74747

class RouteTableAssociation < Struct.new(
  :main,
  :route_table_association_id,
  :route_table_id,
  :subnet_id,
  :gateway_id,
  :public_ipv_4_pool,
  :association_state)
  SENSITIVE = []
  include Aws::Structure
end

#gateway_idString

The ID of the internet gateway or virtual private gateway.

Returns:

  • (String)


74747
74748
74749
74750
74751
74752
74753
74754
74755
74756
74757
# File 'lib/aws-sdk-ec2/types.rb', line 74747

class RouteTableAssociation < Struct.new(
  :main,
  :route_table_association_id,
  :route_table_id,
  :subnet_id,
  :gateway_id,
  :public_ipv_4_pool,
  :association_state)
  SENSITIVE = []
  include Aws::Structure
end

#mainBoolean

Indicates whether this is the main route table.

Returns:

  • (Boolean)


74747
74748
74749
74750
74751
74752
74753
74754
74755
74756
74757
# File 'lib/aws-sdk-ec2/types.rb', line 74747

class RouteTableAssociation < Struct.new(
  :main,
  :route_table_association_id,
  :route_table_id,
  :subnet_id,
  :gateway_id,
  :public_ipv_4_pool,
  :association_state)
  SENSITIVE = []
  include Aws::Structure
end

#public_ipv_4_poolString

The ID of a public IPv4 pool. A public IPv4 pool is a pool of IPv4 addresses that you’ve brought to Amazon Web Services with BYOIP.

Returns:

  • (String)


74747
74748
74749
74750
74751
74752
74753
74754
74755
74756
74757
# File 'lib/aws-sdk-ec2/types.rb', line 74747

class RouteTableAssociation < Struct.new(
  :main,
  :route_table_association_id,
  :route_table_id,
  :subnet_id,
  :gateway_id,
  :public_ipv_4_pool,
  :association_state)
  SENSITIVE = []
  include Aws::Structure
end

#route_table_association_idString

The ID of the association.

Returns:

  • (String)


74747
74748
74749
74750
74751
74752
74753
74754
74755
74756
74757
# File 'lib/aws-sdk-ec2/types.rb', line 74747

class RouteTableAssociation < Struct.new(
  :main,
  :route_table_association_id,
  :route_table_id,
  :subnet_id,
  :gateway_id,
  :public_ipv_4_pool,
  :association_state)
  SENSITIVE = []
  include Aws::Structure
end

#route_table_idString

The ID of the route table.

Returns:

  • (String)


74747
74748
74749
74750
74751
74752
74753
74754
74755
74756
74757
# File 'lib/aws-sdk-ec2/types.rb', line 74747

class RouteTableAssociation < Struct.new(
  :main,
  :route_table_association_id,
  :route_table_id,
  :subnet_id,
  :gateway_id,
  :public_ipv_4_pool,
  :association_state)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idString

The ID of the subnet. A subnet ID is not returned for an implicit association.

Returns:

  • (String)


74747
74748
74749
74750
74751
74752
74753
74754
74755
74756
74757
# File 'lib/aws-sdk-ec2/types.rb', line 74747

class RouteTableAssociation < Struct.new(
  :main,
  :route_table_association_id,
  :route_table_id,
  :subnet_id,
  :gateway_id,
  :public_ipv_4_pool,
  :association_state)
  SENSITIVE = []
  include Aws::Structure
end