Class: Aws::EC2::Types::RunScheduledInstancesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::RunScheduledInstancesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for RunScheduledInstances.
Constant Summary collapse
- SENSITIVE =
[:launch_specification]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier that ensures the idempotency of the request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#instance_count ⇒ Integer
The number of instances.
-
#launch_specification ⇒ Types::ScheduledInstancesLaunchSpecification
The launch specification.
-
#scheduled_instance_id ⇒ String
The Scheduled Instance ID.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier that ensures the idempotency of the request. For more information, see Ensuring Idempotency.
A suitable default value is auto-generated. You should normally not need to pass this option.
76613 76614 76615 76616 76617 76618 76619 76620 76621 |
# File 'lib/aws-sdk-ec2/types.rb', line 76613 class RunScheduledInstancesRequest < Struct.new( :client_token, :dry_run, :instance_count, :launch_specification, :scheduled_instance_id) SENSITIVE = [:launch_specification] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
76613 76614 76615 76616 76617 76618 76619 76620 76621 |
# File 'lib/aws-sdk-ec2/types.rb', line 76613 class RunScheduledInstancesRequest < Struct.new( :client_token, :dry_run, :instance_count, :launch_specification, :scheduled_instance_id) SENSITIVE = [:launch_specification] include Aws::Structure end |
#instance_count ⇒ Integer
The number of instances.
Default: 1
76613 76614 76615 76616 76617 76618 76619 76620 76621 |
# File 'lib/aws-sdk-ec2/types.rb', line 76613 class RunScheduledInstancesRequest < Struct.new( :client_token, :dry_run, :instance_count, :launch_specification, :scheduled_instance_id) SENSITIVE = [:launch_specification] include Aws::Structure end |
#launch_specification ⇒ Types::ScheduledInstancesLaunchSpecification
The launch specification. You must match the instance type, Availability Zone, network, and platform of the schedule that you purchased.
76613 76614 76615 76616 76617 76618 76619 76620 76621 |
# File 'lib/aws-sdk-ec2/types.rb', line 76613 class RunScheduledInstancesRequest < Struct.new( :client_token, :dry_run, :instance_count, :launch_specification, :scheduled_instance_id) SENSITIVE = [:launch_specification] include Aws::Structure end |
#scheduled_instance_id ⇒ String
The Scheduled Instance ID.
76613 76614 76615 76616 76617 76618 76619 76620 76621 |
# File 'lib/aws-sdk-ec2/types.rb', line 76613 class RunScheduledInstancesRequest < Struct.new( :client_token, :dry_run, :instance_count, :launch_specification, :scheduled_instance_id) SENSITIVE = [:launch_specification] include Aws::Structure end |