Class: Aws::EC2::Types::S3Storage
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::S3Storage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the storage parameters for Amazon S3 and Amazon S3 buckets for an instance store-backed AMI.
Constant Summary collapse
- SENSITIVE =
[:upload_policy, :upload_policy_signature]
Instance Attribute Summary collapse
-
#aws_access_key_id ⇒ String
The access key ID of the owner of the bucket.
-
#bucket ⇒ String
The bucket in which to store the AMI.
-
#prefix ⇒ String
The beginning of the file name of the AMI.
-
#upload_policy ⇒ String
An Amazon S3 upload policy that gives Amazon EC2 permission to upload items into Amazon S3 on your behalf.
-
#upload_policy_signature ⇒ String
The signature of the JSON document.
Instance Attribute Details
#aws_access_key_id ⇒ String
The access key ID of the owner of the bucket. Before you specify a value for your access key ID, review and follow the guidance in Best Practices for Amazon Web Services accounts in the Account ManagementReference Guide.
80210 80211 80212 80213 80214 80215 80216 80217 80218 |
# File 'lib/aws-sdk-ec2/types.rb', line 80210 class S3Storage < Struct.new( :aws_access_key_id, :bucket, :prefix, :upload_policy, :upload_policy_signature) SENSITIVE = [:upload_policy, :upload_policy_signature] include Aws::Structure end |
#bucket ⇒ String
The bucket in which to store the AMI. You can specify a bucket that you already own or a new bucket that Amazon EC2 creates on your behalf. If you specify a bucket that belongs to someone else, Amazon EC2 returns an error.
80210 80211 80212 80213 80214 80215 80216 80217 80218 |
# File 'lib/aws-sdk-ec2/types.rb', line 80210 class S3Storage < Struct.new( :aws_access_key_id, :bucket, :prefix, :upload_policy, :upload_policy_signature) SENSITIVE = [:upload_policy, :upload_policy_signature] include Aws::Structure end |
#prefix ⇒ String
The beginning of the file name of the AMI.
80210 80211 80212 80213 80214 80215 80216 80217 80218 |
# File 'lib/aws-sdk-ec2/types.rb', line 80210 class S3Storage < Struct.new( :aws_access_key_id, :bucket, :prefix, :upload_policy, :upload_policy_signature) SENSITIVE = [:upload_policy, :upload_policy_signature] include Aws::Structure end |
#upload_policy ⇒ String
An Amazon S3 upload policy that gives Amazon EC2 permission to upload items into Amazon S3 on your behalf.
80210 80211 80212 80213 80214 80215 80216 80217 80218 |
# File 'lib/aws-sdk-ec2/types.rb', line 80210 class S3Storage < Struct.new( :aws_access_key_id, :bucket, :prefix, :upload_policy, :upload_policy_signature) SENSITIVE = [:upload_policy, :upload_policy_signature] include Aws::Structure end |
#upload_policy_signature ⇒ String
The signature of the JSON document.
80210 80211 80212 80213 80214 80215 80216 80217 80218 |
# File 'lib/aws-sdk-ec2/types.rb', line 80210 class S3Storage < Struct.new( :aws_access_key_id, :bucket, :prefix, :upload_policy, :upload_policy_signature) SENSITIVE = [:upload_policy, :upload_policy_signature] include Aws::Structure end |