Class: Aws::EC2::Types::ScheduledInstancesBlockDeviceMapping

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes a block device mapping for a Scheduled Instance.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#device_nameString

The device name (for example, /dev/sdh or xvdh).

Returns:

  • (String)


76987
76988
76989
76990
76991
76992
76993
76994
# File 'lib/aws-sdk-ec2/types.rb', line 76987

class ScheduledInstancesBlockDeviceMapping < Struct.new(
  :device_name,
  :ebs,
  :no_device,
  :virtual_name)
  SENSITIVE = []
  include Aws::Structure
end

#ebsTypes::ScheduledInstancesEbs

Parameters used to set up EBS volumes automatically when the instance is launched.



76987
76988
76989
76990
76991
76992
76993
76994
# File 'lib/aws-sdk-ec2/types.rb', line 76987

class ScheduledInstancesBlockDeviceMapping < Struct.new(
  :device_name,
  :ebs,
  :no_device,
  :virtual_name)
  SENSITIVE = []
  include Aws::Structure
end

#no_deviceString

To omit the device from the block device mapping, specify an empty string.

Returns:

  • (String)


76987
76988
76989
76990
76991
76992
76993
76994
# File 'lib/aws-sdk-ec2/types.rb', line 76987

class ScheduledInstancesBlockDeviceMapping < Struct.new(
  :device_name,
  :ebs,
  :no_device,
  :virtual_name)
  SENSITIVE = []
  include Aws::Structure
end

#virtual_nameString

The virtual device name (ephemeralN). Instance store volumes are numbered starting from 0. An instance type with two available instance store volumes can specify mappings for ephemeral0 and ephemeral1. The number of available instance store volumes depends on the instance type. After you connect to the instance, you must mount the volume.

Constraints: For M3 instances, you must specify instance store volumes in the block device mapping for the instance. When you launch an M3 instance, we ignore any instance store volumes specified in the block device mapping for the AMI.

Returns:

  • (String)


76987
76988
76989
76990
76991
76992
76993
76994
# File 'lib/aws-sdk-ec2/types.rb', line 76987

class ScheduledInstancesBlockDeviceMapping < Struct.new(
  :device_name,
  :ebs,
  :no_device,
  :virtual_name)
  SENSITIVE = []
  include Aws::Structure
end