Class: Aws::EC2::Types::SecondaryNetwork

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes a secondary network.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ipv_4_cidr_block_associationsArray<Types::SecondaryNetworkIpv4CidrBlockAssociation>

Information about the IPv4 CIDR blocks associated with the secondary network.



76516
76517
76518
76519
76520
76521
76522
76523
76524
76525
76526
76527
# File 'lib/aws-sdk-ec2/types.rb', line 76516

class SecondaryNetwork < Struct.new(
  :secondary_network_id,
  :secondary_network_arn,
  :owner_id,
  :type,
  :state,
  :state_reason,
  :ipv_4_cidr_block_associations,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#owner_idString

The ID of the Amazon Web Services account that owns the secondary network.

Returns:

  • (String)


76516
76517
76518
76519
76520
76521
76522
76523
76524
76525
76526
76527
# File 'lib/aws-sdk-ec2/types.rb', line 76516

class SecondaryNetwork < Struct.new(
  :secondary_network_id,
  :secondary_network_arn,
  :owner_id,
  :type,
  :state,
  :state_reason,
  :ipv_4_cidr_block_associations,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#secondary_network_arnString

The Amazon Resource Name (ARN) of the secondary network.

Returns:

  • (String)


76516
76517
76518
76519
76520
76521
76522
76523
76524
76525
76526
76527
# File 'lib/aws-sdk-ec2/types.rb', line 76516

class SecondaryNetwork < Struct.new(
  :secondary_network_id,
  :secondary_network_arn,
  :owner_id,
  :type,
  :state,
  :state_reason,
  :ipv_4_cidr_block_associations,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#secondary_network_idString

The ID of the secondary network.

Returns:

  • (String)


76516
76517
76518
76519
76520
76521
76522
76523
76524
76525
76526
76527
# File 'lib/aws-sdk-ec2/types.rb', line 76516

class SecondaryNetwork < Struct.new(
  :secondary_network_id,
  :secondary_network_arn,
  :owner_id,
  :type,
  :state,
  :state_reason,
  :ipv_4_cidr_block_associations,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of the secondary network.

Returns:

  • (String)


76516
76517
76518
76519
76520
76521
76522
76523
76524
76525
76526
76527
# File 'lib/aws-sdk-ec2/types.rb', line 76516

class SecondaryNetwork < Struct.new(
  :secondary_network_id,
  :secondary_network_arn,
  :owner_id,
  :type,
  :state,
  :state_reason,
  :ipv_4_cidr_block_associations,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#state_reasonString

The reason for the current state of the secondary network.

Returns:

  • (String)


76516
76517
76518
76519
76520
76521
76522
76523
76524
76525
76526
76527
# File 'lib/aws-sdk-ec2/types.rb', line 76516

class SecondaryNetwork < Struct.new(
  :secondary_network_id,
  :secondary_network_arn,
  :owner_id,
  :type,
  :state,
  :state_reason,
  :ipv_4_cidr_block_associations,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The tags assigned to the secondary network.

Returns:



76516
76517
76518
76519
76520
76521
76522
76523
76524
76525
76526
76527
# File 'lib/aws-sdk-ec2/types.rb', line 76516

class SecondaryNetwork < Struct.new(
  :secondary_network_id,
  :secondary_network_arn,
  :owner_id,
  :type,
  :state,
  :state_reason,
  :ipv_4_cidr_block_associations,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the secondary network.

Returns:

  • (String)


76516
76517
76518
76519
76520
76521
76522
76523
76524
76525
76526
76527
# File 'lib/aws-sdk-ec2/types.rb', line 76516

class SecondaryNetwork < Struct.new(
  :secondary_network_id,
  :secondary_network_arn,
  :owner_id,
  :type,
  :state,
  :state_reason,
  :ipv_4_cidr_block_associations,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end