Class: Aws::EC2::Types::SecondaryNetworkIpv4CidrBlockAssociation
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::SecondaryNetworkIpv4CidrBlockAssociation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes an IPv4 CIDR block associated with a secondary network.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#association_id ⇒ String
The association ID for the IPv4 CIDR block.
-
#cidr_block ⇒ String
The IPv4 CIDR block.
-
#state ⇒ String
The state of the CIDR block association.
-
#state_reason ⇒ String
The reason for the current state of the CIDR block association.
Instance Attribute Details
#association_id ⇒ String
The association ID for the IPv4 CIDR block.
76549 76550 76551 76552 76553 76554 76555 76556 |
# File 'lib/aws-sdk-ec2/types.rb', line 76549 class SecondaryNetworkIpv4CidrBlockAssociation < Struct.new( :association_id, :cidr_block, :state, :state_reason) SENSITIVE = [] include Aws::Structure end |
#cidr_block ⇒ String
The IPv4 CIDR block.
76549 76550 76551 76552 76553 76554 76555 76556 |
# File 'lib/aws-sdk-ec2/types.rb', line 76549 class SecondaryNetworkIpv4CidrBlockAssociation < Struct.new( :association_id, :cidr_block, :state, :state_reason) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the CIDR block association.
76549 76550 76551 76552 76553 76554 76555 76556 |
# File 'lib/aws-sdk-ec2/types.rb', line 76549 class SecondaryNetworkIpv4CidrBlockAssociation < Struct.new( :association_id, :cidr_block, :state, :state_reason) SENSITIVE = [] include Aws::Structure end |
#state_reason ⇒ String
The reason for the current state of the CIDR block association.
76549 76550 76551 76552 76553 76554 76555 76556 |
# File 'lib/aws-sdk-ec2/types.rb', line 76549 class SecondaryNetworkIpv4CidrBlockAssociation < Struct.new( :association_id, :cidr_block, :state, :state_reason) SENSITIVE = [] include Aws::Structure end |