Class: Aws::EC2::Types::SecondarySubnet

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes a secondary subnet.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_zoneString

The Availability Zone of the secondary subnet.

Returns:

  • (String)


76608
76609
76610
76611
76612
76613
76614
76615
76616
76617
76618
76619
76620
76621
76622
# File 'lib/aws-sdk-ec2/types.rb', line 76608

class SecondarySubnet < Struct.new(
  :secondary_subnet_id,
  :secondary_subnet_arn,
  :secondary_network_id,
  :secondary_network_type,
  :owner_id,
  :availability_zone_id,
  :availability_zone,
  :ipv_4_cidr_block_associations,
  :state,
  :state_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zone_idString

The ID of the Availability Zone of the secondary subnet.

Returns:

  • (String)


76608
76609
76610
76611
76612
76613
76614
76615
76616
76617
76618
76619
76620
76621
76622
# File 'lib/aws-sdk-ec2/types.rb', line 76608

class SecondarySubnet < Struct.new(
  :secondary_subnet_id,
  :secondary_subnet_arn,
  :secondary_network_id,
  :secondary_network_type,
  :owner_id,
  :availability_zone_id,
  :availability_zone,
  :ipv_4_cidr_block_associations,
  :state,
  :state_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#ipv_4_cidr_block_associationsArray<Types::SecondarySubnetIpv4CidrBlockAssociation>

Information about the IPv4 CIDR blocks associated with the secondary subnet.



76608
76609
76610
76611
76612
76613
76614
76615
76616
76617
76618
76619
76620
76621
76622
# File 'lib/aws-sdk-ec2/types.rb', line 76608

class SecondarySubnet < Struct.new(
  :secondary_subnet_id,
  :secondary_subnet_arn,
  :secondary_network_id,
  :secondary_network_type,
  :owner_id,
  :availability_zone_id,
  :availability_zone,
  :ipv_4_cidr_block_associations,
  :state,
  :state_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#owner_idString

The ID of the Amazon Web Services account that owns the secondary subnet.

Returns:

  • (String)


76608
76609
76610
76611
76612
76613
76614
76615
76616
76617
76618
76619
76620
76621
76622
# File 'lib/aws-sdk-ec2/types.rb', line 76608

class SecondarySubnet < Struct.new(
  :secondary_subnet_id,
  :secondary_subnet_arn,
  :secondary_network_id,
  :secondary_network_type,
  :owner_id,
  :availability_zone_id,
  :availability_zone,
  :ipv_4_cidr_block_associations,
  :state,
  :state_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#secondary_network_idString

The ID of the secondary network.

Returns:

  • (String)


76608
76609
76610
76611
76612
76613
76614
76615
76616
76617
76618
76619
76620
76621
76622
# File 'lib/aws-sdk-ec2/types.rb', line 76608

class SecondarySubnet < Struct.new(
  :secondary_subnet_id,
  :secondary_subnet_arn,
  :secondary_network_id,
  :secondary_network_type,
  :owner_id,
  :availability_zone_id,
  :availability_zone,
  :ipv_4_cidr_block_associations,
  :state,
  :state_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#secondary_network_typeString

The type of the secondary network.

Returns:

  • (String)


76608
76609
76610
76611
76612
76613
76614
76615
76616
76617
76618
76619
76620
76621
76622
# File 'lib/aws-sdk-ec2/types.rb', line 76608

class SecondarySubnet < Struct.new(
  :secondary_subnet_id,
  :secondary_subnet_arn,
  :secondary_network_id,
  :secondary_network_type,
  :owner_id,
  :availability_zone_id,
  :availability_zone,
  :ipv_4_cidr_block_associations,
  :state,
  :state_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#secondary_subnet_arnString

The Amazon Resource Name (ARN) of the secondary subnet.

Returns:

  • (String)


76608
76609
76610
76611
76612
76613
76614
76615
76616
76617
76618
76619
76620
76621
76622
# File 'lib/aws-sdk-ec2/types.rb', line 76608

class SecondarySubnet < Struct.new(
  :secondary_subnet_id,
  :secondary_subnet_arn,
  :secondary_network_id,
  :secondary_network_type,
  :owner_id,
  :availability_zone_id,
  :availability_zone,
  :ipv_4_cidr_block_associations,
  :state,
  :state_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#secondary_subnet_idString

The ID of the secondary subnet.

Returns:

  • (String)


76608
76609
76610
76611
76612
76613
76614
76615
76616
76617
76618
76619
76620
76621
76622
# File 'lib/aws-sdk-ec2/types.rb', line 76608

class SecondarySubnet < Struct.new(
  :secondary_subnet_id,
  :secondary_subnet_arn,
  :secondary_network_id,
  :secondary_network_type,
  :owner_id,
  :availability_zone_id,
  :availability_zone,
  :ipv_4_cidr_block_associations,
  :state,
  :state_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of the secondary subnet.

Returns:

  • (String)


76608
76609
76610
76611
76612
76613
76614
76615
76616
76617
76618
76619
76620
76621
76622
# File 'lib/aws-sdk-ec2/types.rb', line 76608

class SecondarySubnet < Struct.new(
  :secondary_subnet_id,
  :secondary_subnet_arn,
  :secondary_network_id,
  :secondary_network_type,
  :owner_id,
  :availability_zone_id,
  :availability_zone,
  :ipv_4_cidr_block_associations,
  :state,
  :state_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#state_reasonString

The reason for the current state of the secondary subnet.

Returns:

  • (String)


76608
76609
76610
76611
76612
76613
76614
76615
76616
76617
76618
76619
76620
76621
76622
# File 'lib/aws-sdk-ec2/types.rb', line 76608

class SecondarySubnet < Struct.new(
  :secondary_subnet_id,
  :secondary_subnet_arn,
  :secondary_network_id,
  :secondary_network_type,
  :owner_id,
  :availability_zone_id,
  :availability_zone,
  :ipv_4_cidr_block_associations,
  :state,
  :state_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The tags assigned to the secondary subnet.

Returns:



76608
76609
76610
76611
76612
76613
76614
76615
76616
76617
76618
76619
76620
76621
76622
# File 'lib/aws-sdk-ec2/types.rb', line 76608

class SecondarySubnet < Struct.new(
  :secondary_subnet_id,
  :secondary_subnet_arn,
  :secondary_network_id,
  :secondary_network_type,
  :owner_id,
  :availability_zone_id,
  :availability_zone,
  :ipv_4_cidr_block_associations,
  :state,
  :state_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end