Class: Aws::EC2::Types::Snapshot
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::Snapshot
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a snapshot.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone ⇒ String
The Availability Zone or Local Zone of the snapshot.
-
#completion_duration_minutes ⇒ Integer
Only for snapshot copies created with time-based snapshot copy operations. -
#completion_time ⇒ Time
The time stamp when the snapshot was completed.
-
#data_encryption_key_id ⇒ String
The data encryption key identifier for the snapshot.
-
#description ⇒ String
The description for the snapshot.
-
#encrypted ⇒ Boolean
Indicates whether the snapshot is encrypted.
-
#full_snapshot_size_in_bytes ⇒ Integer
The full size of the snapshot, in bytes.
-
#kms_key_id ⇒ String
The Amazon Resource Name (ARN) of the KMS key that was used to protect the volume encryption key for the parent volume.
-
#outpost_arn ⇒ String
The ARN of the Outpost on which the snapshot is stored.
-
#owner_alias ⇒ String
The Amazon Web Services owner alias, from an Amazon-maintained list (
amazon). -
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the EBS snapshot.
-
#progress ⇒ String
The progress of the snapshot, as a percentage.
-
#restore_expiry_time ⇒ Time
Only for archived snapshots that are temporarily restored.
-
#snapshot_id ⇒ String
The ID of the snapshot.
-
#sse_type ⇒ String
Reserved for future use.
-
#start_time ⇒ Time
The time stamp when the snapshot was initiated.
-
#state ⇒ String
The snapshot state.
-
#state_message ⇒ String
Encrypted Amazon EBS snapshots are copied asynchronously.
-
#storage_tier ⇒ String
The storage tier in which the snapshot is stored.
-
#tags ⇒ Array<Types::Tag>
Any tags assigned to the snapshot.
-
#transfer_type ⇒ String
Only for snapshot copies. -
#volume_id ⇒ String
The ID of the volume that was used to create the snapshot.
-
#volume_size ⇒ Integer
The size of the volume, in GiB.
Instance Attribute Details
#availability_zone ⇒ String
The Availability Zone or Local Zone of the snapshot. For example,
us-west-1a (Availability Zone) or us-west-2-lax-1a (Local Zone).
79393 79394 79395 79396 79397 79398 79399 79400 79401 79402 79403 79404 79405 79406 79407 79408 79409 79410 79411 79412 79413 79414 79415 79416 79417 79418 79419 |
# File 'lib/aws-sdk-ec2/types.rb', line 79393 class Snapshot < Struct.new( :owner_alias, :outpost_arn, :tags, :storage_tier, :restore_expiry_time, :sse_type, :availability_zone, :transfer_type, :completion_duration_minutes, :completion_time, :full_snapshot_size_in_bytes, :snapshot_id, :volume_id, :state, :state_message, :start_time, :progress, :owner_id, :description, :volume_size, :encrypted, :kms_key_id, :data_encryption_key_id) SENSITIVE = [] include Aws::Structure end |
#completion_duration_minutes ⇒ Integer
The completion duration requested for the time-based snapshot copy operation.
79393 79394 79395 79396 79397 79398 79399 79400 79401 79402 79403 79404 79405 79406 79407 79408 79409 79410 79411 79412 79413 79414 79415 79416 79417 79418 79419 |
# File 'lib/aws-sdk-ec2/types.rb', line 79393 class Snapshot < Struct.new( :owner_alias, :outpost_arn, :tags, :storage_tier, :restore_expiry_time, :sse_type, :availability_zone, :transfer_type, :completion_duration_minutes, :completion_time, :full_snapshot_size_in_bytes, :snapshot_id, :volume_id, :state, :state_message, :start_time, :progress, :owner_id, :description, :volume_size, :encrypted, :kms_key_id, :data_encryption_key_id) SENSITIVE = [] include Aws::Structure end |
#completion_time ⇒ Time
The time stamp when the snapshot was completed.
79393 79394 79395 79396 79397 79398 79399 79400 79401 79402 79403 79404 79405 79406 79407 79408 79409 79410 79411 79412 79413 79414 79415 79416 79417 79418 79419 |
# File 'lib/aws-sdk-ec2/types.rb', line 79393 class Snapshot < Struct.new( :owner_alias, :outpost_arn, :tags, :storage_tier, :restore_expiry_time, :sse_type, :availability_zone, :transfer_type, :completion_duration_minutes, :completion_time, :full_snapshot_size_in_bytes, :snapshot_id, :volume_id, :state, :state_message, :start_time, :progress, :owner_id, :description, :volume_size, :encrypted, :kms_key_id, :data_encryption_key_id) SENSITIVE = [] include Aws::Structure end |
#data_encryption_key_id ⇒ String
The data encryption key identifier for the snapshot. This value is a unique identifier that corresponds to the data encryption key that was used to encrypt the original volume or snapshot copy. Because data encryption keys are inherited by volumes created from snapshots, and vice versa, if snapshots share the same data encryption key identifier, then they belong to the same volume/snapshot lineage. This parameter is only returned by DescribeSnapshots.
79393 79394 79395 79396 79397 79398 79399 79400 79401 79402 79403 79404 79405 79406 79407 79408 79409 79410 79411 79412 79413 79414 79415 79416 79417 79418 79419 |
# File 'lib/aws-sdk-ec2/types.rb', line 79393 class Snapshot < Struct.new( :owner_alias, :outpost_arn, :tags, :storage_tier, :restore_expiry_time, :sse_type, :availability_zone, :transfer_type, :completion_duration_minutes, :completion_time, :full_snapshot_size_in_bytes, :snapshot_id, :volume_id, :state, :state_message, :start_time, :progress, :owner_id, :description, :volume_size, :encrypted, :kms_key_id, :data_encryption_key_id) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description for the snapshot.
79393 79394 79395 79396 79397 79398 79399 79400 79401 79402 79403 79404 79405 79406 79407 79408 79409 79410 79411 79412 79413 79414 79415 79416 79417 79418 79419 |
# File 'lib/aws-sdk-ec2/types.rb', line 79393 class Snapshot < Struct.new( :owner_alias, :outpost_arn, :tags, :storage_tier, :restore_expiry_time, :sse_type, :availability_zone, :transfer_type, :completion_duration_minutes, :completion_time, :full_snapshot_size_in_bytes, :snapshot_id, :volume_id, :state, :state_message, :start_time, :progress, :owner_id, :description, :volume_size, :encrypted, :kms_key_id, :data_encryption_key_id) SENSITIVE = [] include Aws::Structure end |
#encrypted ⇒ Boolean
Indicates whether the snapshot is encrypted.
79393 79394 79395 79396 79397 79398 79399 79400 79401 79402 79403 79404 79405 79406 79407 79408 79409 79410 79411 79412 79413 79414 79415 79416 79417 79418 79419 |
# File 'lib/aws-sdk-ec2/types.rb', line 79393 class Snapshot < Struct.new( :owner_alias, :outpost_arn, :tags, :storage_tier, :restore_expiry_time, :sse_type, :availability_zone, :transfer_type, :completion_duration_minutes, :completion_time, :full_snapshot_size_in_bytes, :snapshot_id, :volume_id, :state, :state_message, :start_time, :progress, :owner_id, :description, :volume_size, :encrypted, :kms_key_id, :data_encryption_key_id) SENSITIVE = [] include Aws::Structure end |
#full_snapshot_size_in_bytes ⇒ Integer
The full size of the snapshot, in bytes.
This is not the incremental size of the snapshot. This is the full snapshot size and represents the size of all the blocks that were written to the source volume at the time the snapshot was created.
79393 79394 79395 79396 79397 79398 79399 79400 79401 79402 79403 79404 79405 79406 79407 79408 79409 79410 79411 79412 79413 79414 79415 79416 79417 79418 79419 |
# File 'lib/aws-sdk-ec2/types.rb', line 79393 class Snapshot < Struct.new( :owner_alias, :outpost_arn, :tags, :storage_tier, :restore_expiry_time, :sse_type, :availability_zone, :transfer_type, :completion_duration_minutes, :completion_time, :full_snapshot_size_in_bytes, :snapshot_id, :volume_id, :state, :state_message, :start_time, :progress, :owner_id, :description, :volume_size, :encrypted, :kms_key_id, :data_encryption_key_id) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The Amazon Resource Name (ARN) of the KMS key that was used to protect the volume encryption key for the parent volume.
79393 79394 79395 79396 79397 79398 79399 79400 79401 79402 79403 79404 79405 79406 79407 79408 79409 79410 79411 79412 79413 79414 79415 79416 79417 79418 79419 |
# File 'lib/aws-sdk-ec2/types.rb', line 79393 class Snapshot < Struct.new( :owner_alias, :outpost_arn, :tags, :storage_tier, :restore_expiry_time, :sse_type, :availability_zone, :transfer_type, :completion_duration_minutes, :completion_time, :full_snapshot_size_in_bytes, :snapshot_id, :volume_id, :state, :state_message, :start_time, :progress, :owner_id, :description, :volume_size, :encrypted, :kms_key_id, :data_encryption_key_id) SENSITIVE = [] include Aws::Structure end |
#outpost_arn ⇒ String
The ARN of the Outpost on which the snapshot is stored. For more information, see Amazon EBS local snapshots on Outposts in the Amazon EBS User Guide.
79393 79394 79395 79396 79397 79398 79399 79400 79401 79402 79403 79404 79405 79406 79407 79408 79409 79410 79411 79412 79413 79414 79415 79416 79417 79418 79419 |
# File 'lib/aws-sdk-ec2/types.rb', line 79393 class Snapshot < Struct.new( :owner_alias, :outpost_arn, :tags, :storage_tier, :restore_expiry_time, :sse_type, :availability_zone, :transfer_type, :completion_duration_minutes, :completion_time, :full_snapshot_size_in_bytes, :snapshot_id, :volume_id, :state, :state_message, :start_time, :progress, :owner_id, :description, :volume_size, :encrypted, :kms_key_id, :data_encryption_key_id) SENSITIVE = [] include Aws::Structure end |
#owner_alias ⇒ String
The Amazon Web Services owner alias, from an Amazon-maintained list
(amazon). This is not the user-configured Amazon Web Services
account alias set using the IAM console.
79393 79394 79395 79396 79397 79398 79399 79400 79401 79402 79403 79404 79405 79406 79407 79408 79409 79410 79411 79412 79413 79414 79415 79416 79417 79418 79419 |
# File 'lib/aws-sdk-ec2/types.rb', line 79393 class Snapshot < Struct.new( :owner_alias, :outpost_arn, :tags, :storage_tier, :restore_expiry_time, :sse_type, :availability_zone, :transfer_type, :completion_duration_minutes, :completion_time, :full_snapshot_size_in_bytes, :snapshot_id, :volume_id, :state, :state_message, :start_time, :progress, :owner_id, :description, :volume_size, :encrypted, :kms_key_id, :data_encryption_key_id) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the EBS snapshot.
79393 79394 79395 79396 79397 79398 79399 79400 79401 79402 79403 79404 79405 79406 79407 79408 79409 79410 79411 79412 79413 79414 79415 79416 79417 79418 79419 |
# File 'lib/aws-sdk-ec2/types.rb', line 79393 class Snapshot < Struct.new( :owner_alias, :outpost_arn, :tags, :storage_tier, :restore_expiry_time, :sse_type, :availability_zone, :transfer_type, :completion_duration_minutes, :completion_time, :full_snapshot_size_in_bytes, :snapshot_id, :volume_id, :state, :state_message, :start_time, :progress, :owner_id, :description, :volume_size, :encrypted, :kms_key_id, :data_encryption_key_id) SENSITIVE = [] include Aws::Structure end |
#progress ⇒ String
The progress of the snapshot, as a percentage.
79393 79394 79395 79396 79397 79398 79399 79400 79401 79402 79403 79404 79405 79406 79407 79408 79409 79410 79411 79412 79413 79414 79415 79416 79417 79418 79419 |
# File 'lib/aws-sdk-ec2/types.rb', line 79393 class Snapshot < Struct.new( :owner_alias, :outpost_arn, :tags, :storage_tier, :restore_expiry_time, :sse_type, :availability_zone, :transfer_type, :completion_duration_minutes, :completion_time, :full_snapshot_size_in_bytes, :snapshot_id, :volume_id, :state, :state_message, :start_time, :progress, :owner_id, :description, :volume_size, :encrypted, :kms_key_id, :data_encryption_key_id) SENSITIVE = [] include Aws::Structure end |
#restore_expiry_time ⇒ Time
Only for archived snapshots that are temporarily restored. Indicates the date and time when a temporarily restored snapshot will be automatically re-archived.
79393 79394 79395 79396 79397 79398 79399 79400 79401 79402 79403 79404 79405 79406 79407 79408 79409 79410 79411 79412 79413 79414 79415 79416 79417 79418 79419 |
# File 'lib/aws-sdk-ec2/types.rb', line 79393 class Snapshot < Struct.new( :owner_alias, :outpost_arn, :tags, :storage_tier, :restore_expiry_time, :sse_type, :availability_zone, :transfer_type, :completion_duration_minutes, :completion_time, :full_snapshot_size_in_bytes, :snapshot_id, :volume_id, :state, :state_message, :start_time, :progress, :owner_id, :description, :volume_size, :encrypted, :kms_key_id, :data_encryption_key_id) SENSITIVE = [] include Aws::Structure end |
#snapshot_id ⇒ String
The ID of the snapshot. Each snapshot receives a unique identifier when it is created.
79393 79394 79395 79396 79397 79398 79399 79400 79401 79402 79403 79404 79405 79406 79407 79408 79409 79410 79411 79412 79413 79414 79415 79416 79417 79418 79419 |
# File 'lib/aws-sdk-ec2/types.rb', line 79393 class Snapshot < Struct.new( :owner_alias, :outpost_arn, :tags, :storage_tier, :restore_expiry_time, :sse_type, :availability_zone, :transfer_type, :completion_duration_minutes, :completion_time, :full_snapshot_size_in_bytes, :snapshot_id, :volume_id, :state, :state_message, :start_time, :progress, :owner_id, :description, :volume_size, :encrypted, :kms_key_id, :data_encryption_key_id) SENSITIVE = [] include Aws::Structure end |
#sse_type ⇒ String
Reserved for future use.
79393 79394 79395 79396 79397 79398 79399 79400 79401 79402 79403 79404 79405 79406 79407 79408 79409 79410 79411 79412 79413 79414 79415 79416 79417 79418 79419 |
# File 'lib/aws-sdk-ec2/types.rb', line 79393 class Snapshot < Struct.new( :owner_alias, :outpost_arn, :tags, :storage_tier, :restore_expiry_time, :sse_type, :availability_zone, :transfer_type, :completion_duration_minutes, :completion_time, :full_snapshot_size_in_bytes, :snapshot_id, :volume_id, :state, :state_message, :start_time, :progress, :owner_id, :description, :volume_size, :encrypted, :kms_key_id, :data_encryption_key_id) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The time stamp when the snapshot was initiated.
79393 79394 79395 79396 79397 79398 79399 79400 79401 79402 79403 79404 79405 79406 79407 79408 79409 79410 79411 79412 79413 79414 79415 79416 79417 79418 79419 |
# File 'lib/aws-sdk-ec2/types.rb', line 79393 class Snapshot < Struct.new( :owner_alias, :outpost_arn, :tags, :storage_tier, :restore_expiry_time, :sse_type, :availability_zone, :transfer_type, :completion_duration_minutes, :completion_time, :full_snapshot_size_in_bytes, :snapshot_id, :volume_id, :state, :state_message, :start_time, :progress, :owner_id, :description, :volume_size, :encrypted, :kms_key_id, :data_encryption_key_id) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The snapshot state.
79393 79394 79395 79396 79397 79398 79399 79400 79401 79402 79403 79404 79405 79406 79407 79408 79409 79410 79411 79412 79413 79414 79415 79416 79417 79418 79419 |
# File 'lib/aws-sdk-ec2/types.rb', line 79393 class Snapshot < Struct.new( :owner_alias, :outpost_arn, :tags, :storage_tier, :restore_expiry_time, :sse_type, :availability_zone, :transfer_type, :completion_duration_minutes, :completion_time, :full_snapshot_size_in_bytes, :snapshot_id, :volume_id, :state, :state_message, :start_time, :progress, :owner_id, :description, :volume_size, :encrypted, :kms_key_id, :data_encryption_key_id) SENSITIVE = [] include Aws::Structure end |
#state_message ⇒ String
Encrypted Amazon EBS snapshots are copied asynchronously. If a snapshot copy operation fails (for example, if the proper KMS permissions are not obtained) this field displays error state details to help you diagnose why the error occurred. This parameter is only returned by DescribeSnapshots.
79393 79394 79395 79396 79397 79398 79399 79400 79401 79402 79403 79404 79405 79406 79407 79408 79409 79410 79411 79412 79413 79414 79415 79416 79417 79418 79419 |
# File 'lib/aws-sdk-ec2/types.rb', line 79393 class Snapshot < Struct.new( :owner_alias, :outpost_arn, :tags, :storage_tier, :restore_expiry_time, :sse_type, :availability_zone, :transfer_type, :completion_duration_minutes, :completion_time, :full_snapshot_size_in_bytes, :snapshot_id, :volume_id, :state, :state_message, :start_time, :progress, :owner_id, :description, :volume_size, :encrypted, :kms_key_id, :data_encryption_key_id) SENSITIVE = [] include Aws::Structure end |
#storage_tier ⇒ String
The storage tier in which the snapshot is stored. standard
indicates that the snapshot is stored in the standard snapshot
storage tier and that it is ready for use. archive indicates that
the snapshot is currently archived and that it must be restored
before it can be used.
79393 79394 79395 79396 79397 79398 79399 79400 79401 79402 79403 79404 79405 79406 79407 79408 79409 79410 79411 79412 79413 79414 79415 79416 79417 79418 79419 |
# File 'lib/aws-sdk-ec2/types.rb', line 79393 class Snapshot < Struct.new( :owner_alias, :outpost_arn, :tags, :storage_tier, :restore_expiry_time, :sse_type, :availability_zone, :transfer_type, :completion_duration_minutes, :completion_time, :full_snapshot_size_in_bytes, :snapshot_id, :volume_id, :state, :state_message, :start_time, :progress, :owner_id, :description, :volume_size, :encrypted, :kms_key_id, :data_encryption_key_id) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Any tags assigned to the snapshot.
79393 79394 79395 79396 79397 79398 79399 79400 79401 79402 79403 79404 79405 79406 79407 79408 79409 79410 79411 79412 79413 79414 79415 79416 79417 79418 79419 |
# File 'lib/aws-sdk-ec2/types.rb', line 79393 class Snapshot < Struct.new( :owner_alias, :outpost_arn, :tags, :storage_tier, :restore_expiry_time, :sse_type, :availability_zone, :transfer_type, :completion_duration_minutes, :completion_time, :full_snapshot_size_in_bytes, :snapshot_id, :volume_id, :state, :state_message, :start_time, :progress, :owner_id, :description, :volume_size, :encrypted, :kms_key_id, :data_encryption_key_id) SENSITIVE = [] include Aws::Structure end |
#transfer_type ⇒ String
Indicates whether the snapshot copy was created with a standard or time-based snapshot copy operation. Time-based snapshot copy operations complete within the completion duration specified in the request. Standard snapshot copy operations are completed on a best-effort basis.
-
standard- The snapshot copy was created with a standard snapshot copy operation. -
time-based- The snapshot copy was created with a time-based snapshot copy operation.
79393 79394 79395 79396 79397 79398 79399 79400 79401 79402 79403 79404 79405 79406 79407 79408 79409 79410 79411 79412 79413 79414 79415 79416 79417 79418 79419 |
# File 'lib/aws-sdk-ec2/types.rb', line 79393 class Snapshot < Struct.new( :owner_alias, :outpost_arn, :tags, :storage_tier, :restore_expiry_time, :sse_type, :availability_zone, :transfer_type, :completion_duration_minutes, :completion_time, :full_snapshot_size_in_bytes, :snapshot_id, :volume_id, :state, :state_message, :start_time, :progress, :owner_id, :description, :volume_size, :encrypted, :kms_key_id, :data_encryption_key_id) SENSITIVE = [] include Aws::Structure end |
#volume_id ⇒ String
The ID of the volume that was used to create the snapshot. Snapshots created by a copy snapshot operation have an arbitrary volume ID that you should not use for any purpose.
79393 79394 79395 79396 79397 79398 79399 79400 79401 79402 79403 79404 79405 79406 79407 79408 79409 79410 79411 79412 79413 79414 79415 79416 79417 79418 79419 |
# File 'lib/aws-sdk-ec2/types.rb', line 79393 class Snapshot < Struct.new( :owner_alias, :outpost_arn, :tags, :storage_tier, :restore_expiry_time, :sse_type, :availability_zone, :transfer_type, :completion_duration_minutes, :completion_time, :full_snapshot_size_in_bytes, :snapshot_id, :volume_id, :state, :state_message, :start_time, :progress, :owner_id, :description, :volume_size, :encrypted, :kms_key_id, :data_encryption_key_id) SENSITIVE = [] include Aws::Structure end |
#volume_size ⇒ Integer
The size of the volume, in GiB.
79393 79394 79395 79396 79397 79398 79399 79400 79401 79402 79403 79404 79405 79406 79407 79408 79409 79410 79411 79412 79413 79414 79415 79416 79417 79418 79419 |
# File 'lib/aws-sdk-ec2/types.rb', line 79393 class Snapshot < Struct.new( :owner_alias, :outpost_arn, :tags, :storage_tier, :restore_expiry_time, :sse_type, :availability_zone, :transfer_type, :completion_duration_minutes, :completion_time, :full_snapshot_size_in_bytes, :snapshot_id, :volume_id, :state, :state_message, :start_time, :progress, :owner_id, :description, :volume_size, :encrypted, :kms_key_id, :data_encryption_key_id) SENSITIVE = [] include Aws::Structure end |