Class: Aws::EC2::Types::SnapshotDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::SnapshotDetail
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the snapshot created from the imported disk.
Constant Summary collapse
- SENSITIVE =
[:url]
Instance Attribute Summary collapse
-
#description ⇒ String
A description for the snapshot.
-
#device_name ⇒ String
The block device mapping for the snapshot.
-
#disk_image_size ⇒ Float
The size of the disk in the snapshot, in GiB.
-
#format ⇒ String
The format of the disk image from which the snapshot is created.
-
#progress ⇒ String
The percentage of progress for the task.
-
#snapshot_id ⇒ String
The snapshot ID of the disk being imported.
-
#status ⇒ String
A brief status of the snapshot creation.
-
#status_message ⇒ String
A detailed status message for the snapshot creation.
-
#url ⇒ String
The URL used to access the disk image.
-
#user_bucket ⇒ Types::UserBucketDetails
The Amazon S3 bucket for the disk image.
Instance Attribute Details
#description ⇒ String
A description for the snapshot.
78927 78928 78929 78930 78931 78932 78933 78934 78935 78936 78937 78938 78939 78940 |
# File 'lib/aws-sdk-ec2/types.rb', line 78927 class SnapshotDetail < Struct.new( :description, :device_name, :disk_image_size, :format, :progress, :snapshot_id, :status, :status_message, :url, :user_bucket) SENSITIVE = [:url] include Aws::Structure end |
#device_name ⇒ String
The block device mapping for the snapshot.
78927 78928 78929 78930 78931 78932 78933 78934 78935 78936 78937 78938 78939 78940 |
# File 'lib/aws-sdk-ec2/types.rb', line 78927 class SnapshotDetail < Struct.new( :description, :device_name, :disk_image_size, :format, :progress, :snapshot_id, :status, :status_message, :url, :user_bucket) SENSITIVE = [:url] include Aws::Structure end |
#disk_image_size ⇒ Float
The size of the disk in the snapshot, in GiB.
78927 78928 78929 78930 78931 78932 78933 78934 78935 78936 78937 78938 78939 78940 |
# File 'lib/aws-sdk-ec2/types.rb', line 78927 class SnapshotDetail < Struct.new( :description, :device_name, :disk_image_size, :format, :progress, :snapshot_id, :status, :status_message, :url, :user_bucket) SENSITIVE = [:url] include Aws::Structure end |
#format ⇒ String
The format of the disk image from which the snapshot is created.
78927 78928 78929 78930 78931 78932 78933 78934 78935 78936 78937 78938 78939 78940 |
# File 'lib/aws-sdk-ec2/types.rb', line 78927 class SnapshotDetail < Struct.new( :description, :device_name, :disk_image_size, :format, :progress, :snapshot_id, :status, :status_message, :url, :user_bucket) SENSITIVE = [:url] include Aws::Structure end |
#progress ⇒ String
The percentage of progress for the task.
78927 78928 78929 78930 78931 78932 78933 78934 78935 78936 78937 78938 78939 78940 |
# File 'lib/aws-sdk-ec2/types.rb', line 78927 class SnapshotDetail < Struct.new( :description, :device_name, :disk_image_size, :format, :progress, :snapshot_id, :status, :status_message, :url, :user_bucket) SENSITIVE = [:url] include Aws::Structure end |
#snapshot_id ⇒ String
The snapshot ID of the disk being imported.
78927 78928 78929 78930 78931 78932 78933 78934 78935 78936 78937 78938 78939 78940 |
# File 'lib/aws-sdk-ec2/types.rb', line 78927 class SnapshotDetail < Struct.new( :description, :device_name, :disk_image_size, :format, :progress, :snapshot_id, :status, :status_message, :url, :user_bucket) SENSITIVE = [:url] include Aws::Structure end |
#status ⇒ String
A brief status of the snapshot creation.
78927 78928 78929 78930 78931 78932 78933 78934 78935 78936 78937 78938 78939 78940 |
# File 'lib/aws-sdk-ec2/types.rb', line 78927 class SnapshotDetail < Struct.new( :description, :device_name, :disk_image_size, :format, :progress, :snapshot_id, :status, :status_message, :url, :user_bucket) SENSITIVE = [:url] include Aws::Structure end |
#status_message ⇒ String
A detailed status message for the snapshot creation.
78927 78928 78929 78930 78931 78932 78933 78934 78935 78936 78937 78938 78939 78940 |
# File 'lib/aws-sdk-ec2/types.rb', line 78927 class SnapshotDetail < Struct.new( :description, :device_name, :disk_image_size, :format, :progress, :snapshot_id, :status, :status_message, :url, :user_bucket) SENSITIVE = [:url] include Aws::Structure end |
#url ⇒ String
The URL used to access the disk image.
78927 78928 78929 78930 78931 78932 78933 78934 78935 78936 78937 78938 78939 78940 |
# File 'lib/aws-sdk-ec2/types.rb', line 78927 class SnapshotDetail < Struct.new( :description, :device_name, :disk_image_size, :format, :progress, :snapshot_id, :status, :status_message, :url, :user_bucket) SENSITIVE = [:url] include Aws::Structure end |
#user_bucket ⇒ Types::UserBucketDetails
The Amazon S3 bucket for the disk image.
78927 78928 78929 78930 78931 78932 78933 78934 78935 78936 78937 78938 78939 78940 |
# File 'lib/aws-sdk-ec2/types.rb', line 78927 class SnapshotDetail < Struct.new( :description, :device_name, :disk_image_size, :format, :progress, :snapshot_id, :status, :status_message, :url, :user_bucket) SENSITIVE = [:url] include Aws::Structure end |