Class: Aws::EC2::Types::SnapshotTierStatus

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Provides information about a snapshot's storage tier.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#archival_complete_timeTime

The date and time when the last archive process was completed.

Returns:

  • (Time)


82879
82880
82881
82882
82883
82884
82885
82886
82887
82888
82889
82890
82891
82892
82893
82894
# File 'lib/aws-sdk-ec2/types.rb', line 82879

class SnapshotTierStatus < Struct.new(
  :snapshot_id,
  :volume_id,
  :status,
  :owner_id,
  :tags,
  :storage_tier,
  :last_tiering_start_time,
  :last_tiering_progress,
  :last_tiering_operation_status,
  :last_tiering_operation_status_detail,
  :archival_complete_time,
  :restore_expiry_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_tiering_operation_statusString

The status of the last archive or restore process.

Returns:

  • (String)


82879
82880
82881
82882
82883
82884
82885
82886
82887
82888
82889
82890
82891
82892
82893
82894
# File 'lib/aws-sdk-ec2/types.rb', line 82879

class SnapshotTierStatus < Struct.new(
  :snapshot_id,
  :volume_id,
  :status,
  :owner_id,
  :tags,
  :storage_tier,
  :last_tiering_start_time,
  :last_tiering_progress,
  :last_tiering_operation_status,
  :last_tiering_operation_status_detail,
  :archival_complete_time,
  :restore_expiry_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_tiering_operation_status_detailString

A message describing the status of the last archive or restore process.

Returns:

  • (String)


82879
82880
82881
82882
82883
82884
82885
82886
82887
82888
82889
82890
82891
82892
82893
82894
# File 'lib/aws-sdk-ec2/types.rb', line 82879

class SnapshotTierStatus < Struct.new(
  :snapshot_id,
  :volume_id,
  :status,
  :owner_id,
  :tags,
  :storage_tier,
  :last_tiering_start_time,
  :last_tiering_progress,
  :last_tiering_operation_status,
  :last_tiering_operation_status_detail,
  :archival_complete_time,
  :restore_expiry_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_tiering_progressInteger

The progress of the last archive or restore process, as a percentage.

Returns:

  • (Integer)


82879
82880
82881
82882
82883
82884
82885
82886
82887
82888
82889
82890
82891
82892
82893
82894
# File 'lib/aws-sdk-ec2/types.rb', line 82879

class SnapshotTierStatus < Struct.new(
  :snapshot_id,
  :volume_id,
  :status,
  :owner_id,
  :tags,
  :storage_tier,
  :last_tiering_start_time,
  :last_tiering_progress,
  :last_tiering_operation_status,
  :last_tiering_operation_status_detail,
  :archival_complete_time,
  :restore_expiry_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_tiering_start_timeTime

The date and time when the last archive or restore process was started.

Returns:

  • (Time)


82879
82880
82881
82882
82883
82884
82885
82886
82887
82888
82889
82890
82891
82892
82893
82894
# File 'lib/aws-sdk-ec2/types.rb', line 82879

class SnapshotTierStatus < Struct.new(
  :snapshot_id,
  :volume_id,
  :status,
  :owner_id,
  :tags,
  :storage_tier,
  :last_tiering_start_time,
  :last_tiering_progress,
  :last_tiering_operation_status,
  :last_tiering_operation_status_detail,
  :archival_complete_time,
  :restore_expiry_time)
  SENSITIVE = []
  include Aws::Structure
end

#owner_idString

The ID of the Amazon Web Services account that owns the snapshot.

Returns:

  • (String)


82879
82880
82881
82882
82883
82884
82885
82886
82887
82888
82889
82890
82891
82892
82893
82894
# File 'lib/aws-sdk-ec2/types.rb', line 82879

class SnapshotTierStatus < Struct.new(
  :snapshot_id,
  :volume_id,
  :status,
  :owner_id,
  :tags,
  :storage_tier,
  :last_tiering_start_time,
  :last_tiering_progress,
  :last_tiering_operation_status,
  :last_tiering_operation_status_detail,
  :archival_complete_time,
  :restore_expiry_time)
  SENSITIVE = []
  include Aws::Structure
end

#restore_expiry_timeTime

Only for archived snapshots that are temporarily restored. Indicates the date and time when a temporarily restored snapshot will be automatically re-archived.

Returns:

  • (Time)


82879
82880
82881
82882
82883
82884
82885
82886
82887
82888
82889
82890
82891
82892
82893
82894
# File 'lib/aws-sdk-ec2/types.rb', line 82879

class SnapshotTierStatus < Struct.new(
  :snapshot_id,
  :volume_id,
  :status,
  :owner_id,
  :tags,
  :storage_tier,
  :last_tiering_start_time,
  :last_tiering_progress,
  :last_tiering_operation_status,
  :last_tiering_operation_status_detail,
  :archival_complete_time,
  :restore_expiry_time)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_idString

The ID of the snapshot.

Returns:

  • (String)


82879
82880
82881
82882
82883
82884
82885
82886
82887
82888
82889
82890
82891
82892
82893
82894
# File 'lib/aws-sdk-ec2/types.rb', line 82879

class SnapshotTierStatus < Struct.new(
  :snapshot_id,
  :volume_id,
  :status,
  :owner_id,
  :tags,
  :storage_tier,
  :last_tiering_start_time,
  :last_tiering_progress,
  :last_tiering_operation_status,
  :last_tiering_operation_status_detail,
  :archival_complete_time,
  :restore_expiry_time)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The state of the snapshot.

Returns:

  • (String)


82879
82880
82881
82882
82883
82884
82885
82886
82887
82888
82889
82890
82891
82892
82893
82894
# File 'lib/aws-sdk-ec2/types.rb', line 82879

class SnapshotTierStatus < Struct.new(
  :snapshot_id,
  :volume_id,
  :status,
  :owner_id,
  :tags,
  :storage_tier,
  :last_tiering_start_time,
  :last_tiering_progress,
  :last_tiering_operation_status,
  :last_tiering_operation_status_detail,
  :archival_complete_time,
  :restore_expiry_time)
  SENSITIVE = []
  include Aws::Structure
end

#storage_tierString

The storage tier in which the snapshot is stored. standard indicates that the snapshot is stored in the standard snapshot storage tier and that it is ready for use. archive indicates that the snapshot is currently archived and that it must be restored before it can be used.

Returns:

  • (String)


82879
82880
82881
82882
82883
82884
82885
82886
82887
82888
82889
82890
82891
82892
82893
82894
# File 'lib/aws-sdk-ec2/types.rb', line 82879

class SnapshotTierStatus < Struct.new(
  :snapshot_id,
  :volume_id,
  :status,
  :owner_id,
  :tags,
  :storage_tier,
  :last_tiering_start_time,
  :last_tiering_progress,
  :last_tiering_operation_status,
  :last_tiering_operation_status_detail,
  :archival_complete_time,
  :restore_expiry_time)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The tags that are assigned to the snapshot.

Returns:



82879
82880
82881
82882
82883
82884
82885
82886
82887
82888
82889
82890
82891
82892
82893
82894
# File 'lib/aws-sdk-ec2/types.rb', line 82879

class SnapshotTierStatus < Struct.new(
  :snapshot_id,
  :volume_id,
  :status,
  :owner_id,
  :tags,
  :storage_tier,
  :last_tiering_start_time,
  :last_tiering_progress,
  :last_tiering_operation_status,
  :last_tiering_operation_status_detail,
  :archival_complete_time,
  :restore_expiry_time)
  SENSITIVE = []
  include Aws::Structure
end

#volume_idString

The ID of the volume from which the snapshot was created.

Returns:

  • (String)


82879
82880
82881
82882
82883
82884
82885
82886
82887
82888
82889
82890
82891
82892
82893
82894
# File 'lib/aws-sdk-ec2/types.rb', line 82879

class SnapshotTierStatus < Struct.new(
  :snapshot_id,
  :volume_id,
  :status,
  :owner_id,
  :tags,
  :storage_tier,
  :last_tiering_start_time,
  :last_tiering_progress,
  :last_tiering_operation_status,
  :last_tiering_operation_status_detail,
  :archival_complete_time,
  :restore_expiry_time)
  SENSITIVE = []
  include Aws::Structure
end