Class: Aws::EC2::Types::SpotInstanceStateFault
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::SpotInstanceStateFault
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a Spot Instance state change.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
The reason code for the Spot Instance state change.
-
#message ⇒ String
The message for the Spot Instance state change.
Instance Attribute Details
#code ⇒ String
The reason code for the Spot Instance state change.
80801 80802 80803 80804 80805 80806 |
# File 'lib/aws-sdk-ec2/types.rb', line 80801 class SpotInstanceStateFault < Struct.new( :code, :message) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
The message for the Spot Instance state change.
80801 80802 80803 80804 80805 80806 |
# File 'lib/aws-sdk-ec2/types.rb', line 80801 class SpotInstanceStateFault < Struct.new( :code, :message) SENSITIVE = [] include Aws::Structure end |