Class: Aws::EC2::Types::StartVpcEndpointServicePrivateDnsVerificationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::StartVpcEndpointServicePrivateDnsVerificationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#service_id ⇒ String
The ID of the endpoint service.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
84641 84642 84643 84644 84645 84646 |
# File 'lib/aws-sdk-ec2/types.rb', line 84641 class StartVpcEndpointServicePrivateDnsVerificationRequest < Struct.new( :dry_run, :service_id) SENSITIVE = [] include Aws::Structure end |
#service_id ⇒ String
The ID of the endpoint service.
84641 84642 84643 84644 84645 84646 |
# File 'lib/aws-sdk-ec2/types.rb', line 84641 class StartVpcEndpointServicePrivateDnsVerificationRequest < Struct.new( :dry_run, :service_id) SENSITIVE = [] include Aws::Structure end |