Class: Aws::EC2::Types::StateReason
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::StateReason
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a state change.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
The reason code for the state change.
-
#message ⇒ String
The message for the state change.
Instance Attribute Details
#code ⇒ String
The reason code for the state change.
81064 81065 81066 81067 81068 81069 |
# File 'lib/aws-sdk-ec2/types.rb', line 81064 class StateReason < Struct.new( :code, :message) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
The message for the state change.
-
Server.InsufficientInstanceCapacity: There was insufficient capacity available to satisfy the launch request. -
Server.InternalError: An internal error caused the instance to terminate during launch. -
Server.ScheduledStop: The instance was stopped due to a scheduled retirement. -
Server.SpotInstanceShutdown: The instance was stopped because the number of Spot requests with a maximum price equal to or higher than the Spot price exceeded available capacity or because of an increase in the Spot price. -
Server.SpotInstanceTermination: The instance was terminated because the number of Spot requests with a maximum price equal to or higher than the Spot price exceeded available capacity or because of an increase in the Spot price. -
Client.InstanceInitiatedShutdown: The instance was shut down from the operating system of the instance. -
Client.InstanceTerminated: The instance was terminated or rebooted during AMI creation. -
Client.InternalError: A client error caused the instance to terminate during launch. -
Client.InvalidSnapshot.NotFound: The specified snapshot was not found. -
Client.UserInitiatedHibernate: Hibernation was initiated on the instance. -
Client.UserInitiatedShutdown: The instance was shut down using the Amazon EC2 API. -
Client.VolumeLimitExceeded: The limit on the number of EBS volumes or total storage was exceeded. Decrease usage or request an increase in your account limits.
81064 81065 81066 81067 81068 81069 |
# File 'lib/aws-sdk-ec2/types.rb', line 81064 class StateReason < Struct.new( :code, :message) SENSITIVE = [] include Aws::Structure end |