Class: Aws::EC2::Types::StoreImageTaskResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

The information about the AMI store task, including the progress of the task.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ami_idString

The ID of the AMI that is being stored.

Returns:

  • (String)


81218
81219
81220
81221
81222
81223
81224
81225
81226
81227
81228
# File 'lib/aws-sdk-ec2/types.rb', line 81218

class StoreImageTaskResult < Struct.new(
  :ami_id,
  :task_start_time,
  :bucket,
  :s3object_key,
  :progress_percentage,
  :store_task_state,
  :store_task_failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#bucketString

The name of the Amazon S3 bucket that contains the stored AMI object.

Returns:

  • (String)


81218
81219
81220
81221
81222
81223
81224
81225
81226
81227
81228
# File 'lib/aws-sdk-ec2/types.rb', line 81218

class StoreImageTaskResult < Struct.new(
  :ami_id,
  :task_start_time,
  :bucket,
  :s3object_key,
  :progress_percentage,
  :store_task_state,
  :store_task_failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#progress_percentageInteger

The progress of the task as a percentage.

Returns:

  • (Integer)


81218
81219
81220
81221
81222
81223
81224
81225
81226
81227
81228
# File 'lib/aws-sdk-ec2/types.rb', line 81218

class StoreImageTaskResult < Struct.new(
  :ami_id,
  :task_start_time,
  :bucket,
  :s3object_key,
  :progress_percentage,
  :store_task_state,
  :store_task_failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#s3object_keyString

The name of the stored AMI object in the bucket.

Returns:

  • (String)


81218
81219
81220
81221
81222
81223
81224
81225
81226
81227
81228
# File 'lib/aws-sdk-ec2/types.rb', line 81218

class StoreImageTaskResult < Struct.new(
  :ami_id,
  :task_start_time,
  :bucket,
  :s3object_key,
  :progress_percentage,
  :store_task_state,
  :store_task_failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#store_task_failure_reasonString

If the tasks fails, the reason for the failure is returned. If the task succeeds, null is returned.

Returns:

  • (String)


81218
81219
81220
81221
81222
81223
81224
81225
81226
81227
81228
# File 'lib/aws-sdk-ec2/types.rb', line 81218

class StoreImageTaskResult < Struct.new(
  :ami_id,
  :task_start_time,
  :bucket,
  :s3object_key,
  :progress_percentage,
  :store_task_state,
  :store_task_failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#store_task_stateString

The state of the store task (InProgress, Completed, or Failed).

Returns:

  • (String)


81218
81219
81220
81221
81222
81223
81224
81225
81226
81227
81228
# File 'lib/aws-sdk-ec2/types.rb', line 81218

class StoreImageTaskResult < Struct.new(
  :ami_id,
  :task_start_time,
  :bucket,
  :s3object_key,
  :progress_percentage,
  :store_task_state,
  :store_task_failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#task_start_timeTime

The time the task started.

Returns:

  • (Time)


81218
81219
81220
81221
81222
81223
81224
81225
81226
81227
81228
# File 'lib/aws-sdk-ec2/types.rb', line 81218

class StoreImageTaskResult < Struct.new(
  :ami_id,
  :task_start_time,
  :bucket,
  :s3object_key,
  :progress_percentage,
  :store_task_state,
  :store_task_failure_reason)
  SENSITIVE = []
  include Aws::Structure
end