Class: Aws::EC2::Types::Subnet

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes a subnet.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#assign_ipv_6_address_on_creationBoolean

Indicates whether a network interface created in this subnet (including a network interface created by RunInstances) receives an IPv6 address.

Returns:

  • (Boolean)


82066
82067
82068
82069
82070
82071
82072
82073
82074
82075
82076
82077
82078
82079
82080
82081
82082
82083
82084
82085
82086
82087
82088
82089
82090
82091
82092
# File 'lib/aws-sdk-ec2/types.rb', line 82066

class Subnet < Struct.new(
  :availability_zone_id,
  :enable_lni_at_device_index,
  :map_customer_owned_ip_on_launch,
  :customer_owned_ipv_4_pool,
  :owner_id,
  :assign_ipv_6_address_on_creation,
  :ipv_6_cidr_block_association_set,
  :tags,
  :subnet_arn,
  :outpost_arn,
  :enable_dns_64,
  :ipv_6_native,
  :private_dns_name_options_on_launch,
  :block_public_access_states,
  :type,
  :subnet_id,
  :state,
  :vpc_id,
  :cidr_block,
  :available_ip_address_count,
  :availability_zone,
  :default_for_az,
  :map_public_ip_on_launch)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zoneString

The Availability Zone of the subnet.

Returns:

  • (String)


82066
82067
82068
82069
82070
82071
82072
82073
82074
82075
82076
82077
82078
82079
82080
82081
82082
82083
82084
82085
82086
82087
82088
82089
82090
82091
82092
# File 'lib/aws-sdk-ec2/types.rb', line 82066

class Subnet < Struct.new(
  :availability_zone_id,
  :enable_lni_at_device_index,
  :map_customer_owned_ip_on_launch,
  :customer_owned_ipv_4_pool,
  :owner_id,
  :assign_ipv_6_address_on_creation,
  :ipv_6_cidr_block_association_set,
  :tags,
  :subnet_arn,
  :outpost_arn,
  :enable_dns_64,
  :ipv_6_native,
  :private_dns_name_options_on_launch,
  :block_public_access_states,
  :type,
  :subnet_id,
  :state,
  :vpc_id,
  :cidr_block,
  :available_ip_address_count,
  :availability_zone,
  :default_for_az,
  :map_public_ip_on_launch)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zone_idString

The AZ ID of the subnet.

Returns:

  • (String)


82066
82067
82068
82069
82070
82071
82072
82073
82074
82075
82076
82077
82078
82079
82080
82081
82082
82083
82084
82085
82086
82087
82088
82089
82090
82091
82092
# File 'lib/aws-sdk-ec2/types.rb', line 82066

class Subnet < Struct.new(
  :availability_zone_id,
  :enable_lni_at_device_index,
  :map_customer_owned_ip_on_launch,
  :customer_owned_ipv_4_pool,
  :owner_id,
  :assign_ipv_6_address_on_creation,
  :ipv_6_cidr_block_association_set,
  :tags,
  :subnet_arn,
  :outpost_arn,
  :enable_dns_64,
  :ipv_6_native,
  :private_dns_name_options_on_launch,
  :block_public_access_states,
  :type,
  :subnet_id,
  :state,
  :vpc_id,
  :cidr_block,
  :available_ip_address_count,
  :availability_zone,
  :default_for_az,
  :map_public_ip_on_launch)
  SENSITIVE = []
  include Aws::Structure
end

#available_ip_address_countInteger

The number of unused private IPv4 addresses in the subnet. The IPv4 addresses for any stopped instances are considered unavailable.

Returns:

  • (Integer)


82066
82067
82068
82069
82070
82071
82072
82073
82074
82075
82076
82077
82078
82079
82080
82081
82082
82083
82084
82085
82086
82087
82088
82089
82090
82091
82092
# File 'lib/aws-sdk-ec2/types.rb', line 82066

class Subnet < Struct.new(
  :availability_zone_id,
  :enable_lni_at_device_index,
  :map_customer_owned_ip_on_launch,
  :customer_owned_ipv_4_pool,
  :owner_id,
  :assign_ipv_6_address_on_creation,
  :ipv_6_cidr_block_association_set,
  :tags,
  :subnet_arn,
  :outpost_arn,
  :enable_dns_64,
  :ipv_6_native,
  :private_dns_name_options_on_launch,
  :block_public_access_states,
  :type,
  :subnet_id,
  :state,
  :vpc_id,
  :cidr_block,
  :available_ip_address_count,
  :availability_zone,
  :default_for_az,
  :map_public_ip_on_launch)
  SENSITIVE = []
  include Aws::Structure
end

#block_public_access_statesTypes::BlockPublicAccessStates

The state of VPC Block Public Access (BPA).



82066
82067
82068
82069
82070
82071
82072
82073
82074
82075
82076
82077
82078
82079
82080
82081
82082
82083
82084
82085
82086
82087
82088
82089
82090
82091
82092
# File 'lib/aws-sdk-ec2/types.rb', line 82066

class Subnet < Struct.new(
  :availability_zone_id,
  :enable_lni_at_device_index,
  :map_customer_owned_ip_on_launch,
  :customer_owned_ipv_4_pool,
  :owner_id,
  :assign_ipv_6_address_on_creation,
  :ipv_6_cidr_block_association_set,
  :tags,
  :subnet_arn,
  :outpost_arn,
  :enable_dns_64,
  :ipv_6_native,
  :private_dns_name_options_on_launch,
  :block_public_access_states,
  :type,
  :subnet_id,
  :state,
  :vpc_id,
  :cidr_block,
  :available_ip_address_count,
  :availability_zone,
  :default_for_az,
  :map_public_ip_on_launch)
  SENSITIVE = []
  include Aws::Structure
end

#cidr_blockString

The IPv4 CIDR block assigned to the subnet.

Returns:

  • (String)


82066
82067
82068
82069
82070
82071
82072
82073
82074
82075
82076
82077
82078
82079
82080
82081
82082
82083
82084
82085
82086
82087
82088
82089
82090
82091
82092
# File 'lib/aws-sdk-ec2/types.rb', line 82066

class Subnet < Struct.new(
  :availability_zone_id,
  :enable_lni_at_device_index,
  :map_customer_owned_ip_on_launch,
  :customer_owned_ipv_4_pool,
  :owner_id,
  :assign_ipv_6_address_on_creation,
  :ipv_6_cidr_block_association_set,
  :tags,
  :subnet_arn,
  :outpost_arn,
  :enable_dns_64,
  :ipv_6_native,
  :private_dns_name_options_on_launch,
  :block_public_access_states,
  :type,
  :subnet_id,
  :state,
  :vpc_id,
  :cidr_block,
  :available_ip_address_count,
  :availability_zone,
  :default_for_az,
  :map_public_ip_on_launch)
  SENSITIVE = []
  include Aws::Structure
end

#customer_owned_ipv_4_poolString

The customer-owned IPv4 address pool associated with the subnet.

Returns:

  • (String)


82066
82067
82068
82069
82070
82071
82072
82073
82074
82075
82076
82077
82078
82079
82080
82081
82082
82083
82084
82085
82086
82087
82088
82089
82090
82091
82092
# File 'lib/aws-sdk-ec2/types.rb', line 82066

class Subnet < Struct.new(
  :availability_zone_id,
  :enable_lni_at_device_index,
  :map_customer_owned_ip_on_launch,
  :customer_owned_ipv_4_pool,
  :owner_id,
  :assign_ipv_6_address_on_creation,
  :ipv_6_cidr_block_association_set,
  :tags,
  :subnet_arn,
  :outpost_arn,
  :enable_dns_64,
  :ipv_6_native,
  :private_dns_name_options_on_launch,
  :block_public_access_states,
  :type,
  :subnet_id,
  :state,
  :vpc_id,
  :cidr_block,
  :available_ip_address_count,
  :availability_zone,
  :default_for_az,
  :map_public_ip_on_launch)
  SENSITIVE = []
  include Aws::Structure
end

#default_for_azBoolean

Indicates whether this is the default subnet for the Availability Zone.

Returns:

  • (Boolean)


82066
82067
82068
82069
82070
82071
82072
82073
82074
82075
82076
82077
82078
82079
82080
82081
82082
82083
82084
82085
82086
82087
82088
82089
82090
82091
82092
# File 'lib/aws-sdk-ec2/types.rb', line 82066

class Subnet < Struct.new(
  :availability_zone_id,
  :enable_lni_at_device_index,
  :map_customer_owned_ip_on_launch,
  :customer_owned_ipv_4_pool,
  :owner_id,
  :assign_ipv_6_address_on_creation,
  :ipv_6_cidr_block_association_set,
  :tags,
  :subnet_arn,
  :outpost_arn,
  :enable_dns_64,
  :ipv_6_native,
  :private_dns_name_options_on_launch,
  :block_public_access_states,
  :type,
  :subnet_id,
  :state,
  :vpc_id,
  :cidr_block,
  :available_ip_address_count,
  :availability_zone,
  :default_for_az,
  :map_public_ip_on_launch)
  SENSITIVE = []
  include Aws::Structure
end

#enable_dns_64Boolean

Indicates whether DNS queries made to the Amazon-provided DNS Resolver in this subnet should return synthetic IPv6 addresses for IPv4-only destinations.

Returns:

  • (Boolean)


82066
82067
82068
82069
82070
82071
82072
82073
82074
82075
82076
82077
82078
82079
82080
82081
82082
82083
82084
82085
82086
82087
82088
82089
82090
82091
82092
# File 'lib/aws-sdk-ec2/types.rb', line 82066

class Subnet < Struct.new(
  :availability_zone_id,
  :enable_lni_at_device_index,
  :map_customer_owned_ip_on_launch,
  :customer_owned_ipv_4_pool,
  :owner_id,
  :assign_ipv_6_address_on_creation,
  :ipv_6_cidr_block_association_set,
  :tags,
  :subnet_arn,
  :outpost_arn,
  :enable_dns_64,
  :ipv_6_native,
  :private_dns_name_options_on_launch,
  :block_public_access_states,
  :type,
  :subnet_id,
  :state,
  :vpc_id,
  :cidr_block,
  :available_ip_address_count,
  :availability_zone,
  :default_for_az,
  :map_public_ip_on_launch)
  SENSITIVE = []
  include Aws::Structure
end

#enable_lni_at_device_indexInteger

Indicates the device position for local network interfaces in this subnet. For example, 1 indicates local network interfaces in this subnet are the secondary network interface (eth1).

Returns:

  • (Integer)


82066
82067
82068
82069
82070
82071
82072
82073
82074
82075
82076
82077
82078
82079
82080
82081
82082
82083
82084
82085
82086
82087
82088
82089
82090
82091
82092
# File 'lib/aws-sdk-ec2/types.rb', line 82066

class Subnet < Struct.new(
  :availability_zone_id,
  :enable_lni_at_device_index,
  :map_customer_owned_ip_on_launch,
  :customer_owned_ipv_4_pool,
  :owner_id,
  :assign_ipv_6_address_on_creation,
  :ipv_6_cidr_block_association_set,
  :tags,
  :subnet_arn,
  :outpost_arn,
  :enable_dns_64,
  :ipv_6_native,
  :private_dns_name_options_on_launch,
  :block_public_access_states,
  :type,
  :subnet_id,
  :state,
  :vpc_id,
  :cidr_block,
  :available_ip_address_count,
  :availability_zone,
  :default_for_az,
  :map_public_ip_on_launch)
  SENSITIVE = []
  include Aws::Structure
end

#ipv_6_cidr_block_association_setArray<Types::SubnetIpv6CidrBlockAssociation>

Information about the IPv6 CIDR blocks associated with the subnet.



82066
82067
82068
82069
82070
82071
82072
82073
82074
82075
82076
82077
82078
82079
82080
82081
82082
82083
82084
82085
82086
82087
82088
82089
82090
82091
82092
# File 'lib/aws-sdk-ec2/types.rb', line 82066

class Subnet < Struct.new(
  :availability_zone_id,
  :enable_lni_at_device_index,
  :map_customer_owned_ip_on_launch,
  :customer_owned_ipv_4_pool,
  :owner_id,
  :assign_ipv_6_address_on_creation,
  :ipv_6_cidr_block_association_set,
  :tags,
  :subnet_arn,
  :outpost_arn,
  :enable_dns_64,
  :ipv_6_native,
  :private_dns_name_options_on_launch,
  :block_public_access_states,
  :type,
  :subnet_id,
  :state,
  :vpc_id,
  :cidr_block,
  :available_ip_address_count,
  :availability_zone,
  :default_for_az,
  :map_public_ip_on_launch)
  SENSITIVE = []
  include Aws::Structure
end

#ipv_6_nativeBoolean

Indicates whether this is an IPv6 only subnet.

Returns:

  • (Boolean)


82066
82067
82068
82069
82070
82071
82072
82073
82074
82075
82076
82077
82078
82079
82080
82081
82082
82083
82084
82085
82086
82087
82088
82089
82090
82091
82092
# File 'lib/aws-sdk-ec2/types.rb', line 82066

class Subnet < Struct.new(
  :availability_zone_id,
  :enable_lni_at_device_index,
  :map_customer_owned_ip_on_launch,
  :customer_owned_ipv_4_pool,
  :owner_id,
  :assign_ipv_6_address_on_creation,
  :ipv_6_cidr_block_association_set,
  :tags,
  :subnet_arn,
  :outpost_arn,
  :enable_dns_64,
  :ipv_6_native,
  :private_dns_name_options_on_launch,
  :block_public_access_states,
  :type,
  :subnet_id,
  :state,
  :vpc_id,
  :cidr_block,
  :available_ip_address_count,
  :availability_zone,
  :default_for_az,
  :map_public_ip_on_launch)
  SENSITIVE = []
  include Aws::Structure
end

#map_customer_owned_ip_on_launchBoolean

Indicates whether a network interface created in this subnet (including a network interface created by RunInstances) receives a customer-owned IPv4 address.

Returns:

  • (Boolean)


82066
82067
82068
82069
82070
82071
82072
82073
82074
82075
82076
82077
82078
82079
82080
82081
82082
82083
82084
82085
82086
82087
82088
82089
82090
82091
82092
# File 'lib/aws-sdk-ec2/types.rb', line 82066

class Subnet < Struct.new(
  :availability_zone_id,
  :enable_lni_at_device_index,
  :map_customer_owned_ip_on_launch,
  :customer_owned_ipv_4_pool,
  :owner_id,
  :assign_ipv_6_address_on_creation,
  :ipv_6_cidr_block_association_set,
  :tags,
  :subnet_arn,
  :outpost_arn,
  :enable_dns_64,
  :ipv_6_native,
  :private_dns_name_options_on_launch,
  :block_public_access_states,
  :type,
  :subnet_id,
  :state,
  :vpc_id,
  :cidr_block,
  :available_ip_address_count,
  :availability_zone,
  :default_for_az,
  :map_public_ip_on_launch)
  SENSITIVE = []
  include Aws::Structure
end

#map_public_ip_on_launchBoolean

Indicates whether instances launched in this subnet receive a public IPv4 address.

Amazon Web Services charges for all public IPv4 addresses, including public IPv4 addresses associated with running instances and Elastic IP addresses. For more information, see the Public IPv4 Address tab on the Amazon VPC pricing page.

Returns:

  • (Boolean)


82066
82067
82068
82069
82070
82071
82072
82073
82074
82075
82076
82077
82078
82079
82080
82081
82082
82083
82084
82085
82086
82087
82088
82089
82090
82091
82092
# File 'lib/aws-sdk-ec2/types.rb', line 82066

class Subnet < Struct.new(
  :availability_zone_id,
  :enable_lni_at_device_index,
  :map_customer_owned_ip_on_launch,
  :customer_owned_ipv_4_pool,
  :owner_id,
  :assign_ipv_6_address_on_creation,
  :ipv_6_cidr_block_association_set,
  :tags,
  :subnet_arn,
  :outpost_arn,
  :enable_dns_64,
  :ipv_6_native,
  :private_dns_name_options_on_launch,
  :block_public_access_states,
  :type,
  :subnet_id,
  :state,
  :vpc_id,
  :cidr_block,
  :available_ip_address_count,
  :availability_zone,
  :default_for_az,
  :map_public_ip_on_launch)
  SENSITIVE = []
  include Aws::Structure
end

#outpost_arnString

The Amazon Resource Name (ARN) of the Outpost.

Returns:

  • (String)


82066
82067
82068
82069
82070
82071
82072
82073
82074
82075
82076
82077
82078
82079
82080
82081
82082
82083
82084
82085
82086
82087
82088
82089
82090
82091
82092
# File 'lib/aws-sdk-ec2/types.rb', line 82066

class Subnet < Struct.new(
  :availability_zone_id,
  :enable_lni_at_device_index,
  :map_customer_owned_ip_on_launch,
  :customer_owned_ipv_4_pool,
  :owner_id,
  :assign_ipv_6_address_on_creation,
  :ipv_6_cidr_block_association_set,
  :tags,
  :subnet_arn,
  :outpost_arn,
  :enable_dns_64,
  :ipv_6_native,
  :private_dns_name_options_on_launch,
  :block_public_access_states,
  :type,
  :subnet_id,
  :state,
  :vpc_id,
  :cidr_block,
  :available_ip_address_count,
  :availability_zone,
  :default_for_az,
  :map_public_ip_on_launch)
  SENSITIVE = []
  include Aws::Structure
end

#owner_idString

The ID of the Amazon Web Services account that owns the subnet.

Returns:

  • (String)


82066
82067
82068
82069
82070
82071
82072
82073
82074
82075
82076
82077
82078
82079
82080
82081
82082
82083
82084
82085
82086
82087
82088
82089
82090
82091
82092
# File 'lib/aws-sdk-ec2/types.rb', line 82066

class Subnet < Struct.new(
  :availability_zone_id,
  :enable_lni_at_device_index,
  :map_customer_owned_ip_on_launch,
  :customer_owned_ipv_4_pool,
  :owner_id,
  :assign_ipv_6_address_on_creation,
  :ipv_6_cidr_block_association_set,
  :tags,
  :subnet_arn,
  :outpost_arn,
  :enable_dns_64,
  :ipv_6_native,
  :private_dns_name_options_on_launch,
  :block_public_access_states,
  :type,
  :subnet_id,
  :state,
  :vpc_id,
  :cidr_block,
  :available_ip_address_count,
  :availability_zone,
  :default_for_az,
  :map_public_ip_on_launch)
  SENSITIVE = []
  include Aws::Structure
end

#private_dns_name_options_on_launchTypes::PrivateDnsNameOptionsOnLaunch

The type of hostnames to assign to instances in the subnet at launch. An instance hostname is based on the IPv4 address or ID of the instance.



82066
82067
82068
82069
82070
82071
82072
82073
82074
82075
82076
82077
82078
82079
82080
82081
82082
82083
82084
82085
82086
82087
82088
82089
82090
82091
82092
# File 'lib/aws-sdk-ec2/types.rb', line 82066

class Subnet < Struct.new(
  :availability_zone_id,
  :enable_lni_at_device_index,
  :map_customer_owned_ip_on_launch,
  :customer_owned_ipv_4_pool,
  :owner_id,
  :assign_ipv_6_address_on_creation,
  :ipv_6_cidr_block_association_set,
  :tags,
  :subnet_arn,
  :outpost_arn,
  :enable_dns_64,
  :ipv_6_native,
  :private_dns_name_options_on_launch,
  :block_public_access_states,
  :type,
  :subnet_id,
  :state,
  :vpc_id,
  :cidr_block,
  :available_ip_address_count,
  :availability_zone,
  :default_for_az,
  :map_public_ip_on_launch)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The current state of the subnet.

  • failed: The underlying infrastructure to support the subnet failed to provision as expected.

  • failed-insufficient-capacity: The underlying infrastructure to support the subnet failed to provision due to a shortage of EC2 instance capacity.

Returns:

  • (String)


82066
82067
82068
82069
82070
82071
82072
82073
82074
82075
82076
82077
82078
82079
82080
82081
82082
82083
82084
82085
82086
82087
82088
82089
82090
82091
82092
# File 'lib/aws-sdk-ec2/types.rb', line 82066

class Subnet < Struct.new(
  :availability_zone_id,
  :enable_lni_at_device_index,
  :map_customer_owned_ip_on_launch,
  :customer_owned_ipv_4_pool,
  :owner_id,
  :assign_ipv_6_address_on_creation,
  :ipv_6_cidr_block_association_set,
  :tags,
  :subnet_arn,
  :outpost_arn,
  :enable_dns_64,
  :ipv_6_native,
  :private_dns_name_options_on_launch,
  :block_public_access_states,
  :type,
  :subnet_id,
  :state,
  :vpc_id,
  :cidr_block,
  :available_ip_address_count,
  :availability_zone,
  :default_for_az,
  :map_public_ip_on_launch)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_arnString

The Amazon Resource Name (ARN) of the subnet.

Returns:

  • (String)


82066
82067
82068
82069
82070
82071
82072
82073
82074
82075
82076
82077
82078
82079
82080
82081
82082
82083
82084
82085
82086
82087
82088
82089
82090
82091
82092
# File 'lib/aws-sdk-ec2/types.rb', line 82066

class Subnet < Struct.new(
  :availability_zone_id,
  :enable_lni_at_device_index,
  :map_customer_owned_ip_on_launch,
  :customer_owned_ipv_4_pool,
  :owner_id,
  :assign_ipv_6_address_on_creation,
  :ipv_6_cidr_block_association_set,
  :tags,
  :subnet_arn,
  :outpost_arn,
  :enable_dns_64,
  :ipv_6_native,
  :private_dns_name_options_on_launch,
  :block_public_access_states,
  :type,
  :subnet_id,
  :state,
  :vpc_id,
  :cidr_block,
  :available_ip_address_count,
  :availability_zone,
  :default_for_az,
  :map_public_ip_on_launch)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idString

The ID of the subnet.

Returns:

  • (String)


82066
82067
82068
82069
82070
82071
82072
82073
82074
82075
82076
82077
82078
82079
82080
82081
82082
82083
82084
82085
82086
82087
82088
82089
82090
82091
82092
# File 'lib/aws-sdk-ec2/types.rb', line 82066

class Subnet < Struct.new(
  :availability_zone_id,
  :enable_lni_at_device_index,
  :map_customer_owned_ip_on_launch,
  :customer_owned_ipv_4_pool,
  :owner_id,
  :assign_ipv_6_address_on_creation,
  :ipv_6_cidr_block_association_set,
  :tags,
  :subnet_arn,
  :outpost_arn,
  :enable_dns_64,
  :ipv_6_native,
  :private_dns_name_options_on_launch,
  :block_public_access_states,
  :type,
  :subnet_id,
  :state,
  :vpc_id,
  :cidr_block,
  :available_ip_address_count,
  :availability_zone,
  :default_for_az,
  :map_public_ip_on_launch)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Any tags assigned to the subnet.

Returns:



82066
82067
82068
82069
82070
82071
82072
82073
82074
82075
82076
82077
82078
82079
82080
82081
82082
82083
82084
82085
82086
82087
82088
82089
82090
82091
82092
# File 'lib/aws-sdk-ec2/types.rb', line 82066

class Subnet < Struct.new(
  :availability_zone_id,
  :enable_lni_at_device_index,
  :map_customer_owned_ip_on_launch,
  :customer_owned_ipv_4_pool,
  :owner_id,
  :assign_ipv_6_address_on_creation,
  :ipv_6_cidr_block_association_set,
  :tags,
  :subnet_arn,
  :outpost_arn,
  :enable_dns_64,
  :ipv_6_native,
  :private_dns_name_options_on_launch,
  :block_public_access_states,
  :type,
  :subnet_id,
  :state,
  :vpc_id,
  :cidr_block,
  :available_ip_address_count,
  :availability_zone,
  :default_for_az,
  :map_public_ip_on_launch)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

Indicates if this is a subnet used with Amazon Elastic VMware Service (EVS). Possible values are Elastic VMware Service or no value. For more information about Amazon EVS, see Amazon Elastic VMware Service API Reference .

Returns:

  • (String)


82066
82067
82068
82069
82070
82071
82072
82073
82074
82075
82076
82077
82078
82079
82080
82081
82082
82083
82084
82085
82086
82087
82088
82089
82090
82091
82092
# File 'lib/aws-sdk-ec2/types.rb', line 82066

class Subnet < Struct.new(
  :availability_zone_id,
  :enable_lni_at_device_index,
  :map_customer_owned_ip_on_launch,
  :customer_owned_ipv_4_pool,
  :owner_id,
  :assign_ipv_6_address_on_creation,
  :ipv_6_cidr_block_association_set,
  :tags,
  :subnet_arn,
  :outpost_arn,
  :enable_dns_64,
  :ipv_6_native,
  :private_dns_name_options_on_launch,
  :block_public_access_states,
  :type,
  :subnet_id,
  :state,
  :vpc_id,
  :cidr_block,
  :available_ip_address_count,
  :availability_zone,
  :default_for_az,
  :map_public_ip_on_launch)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC the subnet is in.

Returns:

  • (String)


82066
82067
82068
82069
82070
82071
82072
82073
82074
82075
82076
82077
82078
82079
82080
82081
82082
82083
82084
82085
82086
82087
82088
82089
82090
82091
82092
# File 'lib/aws-sdk-ec2/types.rb', line 82066

class Subnet < Struct.new(
  :availability_zone_id,
  :enable_lni_at_device_index,
  :map_customer_owned_ip_on_launch,
  :customer_owned_ipv_4_pool,
  :owner_id,
  :assign_ipv_6_address_on_creation,
  :ipv_6_cidr_block_association_set,
  :tags,
  :subnet_arn,
  :outpost_arn,
  :enable_dns_64,
  :ipv_6_native,
  :private_dns_name_options_on_launch,
  :block_public_access_states,
  :type,
  :subnet_id,
  :state,
  :vpc_id,
  :cidr_block,
  :available_ip_address_count,
  :availability_zone,
  :default_for_az,
  :map_public_ip_on_launch)
  SENSITIVE = []
  include Aws::Structure
end