Class: Aws::EC2::Types::SubnetConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes the configuration of a subnet for a VPC endpoint.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ipv_4String

The IPv4 address to assign to the endpoint network interface in the subnet. You must provide an IPv4 address if the VPC endpoint supports IPv4.

If you specify an IPv4 address when modifying a VPC endpoint, we replace the existing endpoint network interface with a new endpoint network interface with this IP address. This process temporarily disconnects the subnet and the VPC endpoint.

Returns:

  • (String)


81503
81504
81505
81506
81507
81508
81509
# File 'lib/aws-sdk-ec2/types.rb', line 81503

class SubnetConfiguration < Struct.new(
  :subnet_id,
  :ipv_4,
  :ipv_6)
  SENSITIVE = []
  include Aws::Structure
end

#ipv_6String

The IPv6 address to assign to the endpoint network interface in the subnet. You must provide an IPv6 address if the VPC endpoint supports IPv6.

If you specify an IPv6 address when modifying a VPC endpoint, we replace the existing endpoint network interface with a new endpoint network interface with this IP address. This process temporarily disconnects the subnet and the VPC endpoint.

Returns:

  • (String)


81503
81504
81505
81506
81507
81508
81509
# File 'lib/aws-sdk-ec2/types.rb', line 81503

class SubnetConfiguration < Struct.new(
  :subnet_id,
  :ipv_4,
  :ipv_6)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idString

The ID of the subnet.

Returns:

  • (String)


81503
81504
81505
81506
81507
81508
81509
# File 'lib/aws-sdk-ec2/types.rb', line 81503

class SubnetConfiguration < Struct.new(
  :subnet_id,
  :ipv_4,
  :ipv_6)
  SENSITIVE = []
  include Aws::Structure
end