Class: Aws::EC2::Types::SuccessfulSuppressionResponseObject
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::SuccessfulSuppressionResponseObject
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a successful application status check suppression.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The ID of the instance.
-
#resume_at ⇒ Time
The date and time when suppression ends and health checks resume.
-
#suppress_at ⇒ Time
The date and time when suppression started.
Instance Attribute Details
#instance_id ⇒ String
The ID of the instance.
85182 85183 85184 85185 85186 85187 85188 |
# File 'lib/aws-sdk-ec2/types.rb', line 85182 class SuccessfulSuppressionResponseObject < Struct.new( :instance_id, :suppress_at, :resume_at) SENSITIVE = [] include Aws::Structure end |
#resume_at ⇒ Time
The date and time when suppression ends and health checks resume.
85182 85183 85184 85185 85186 85187 85188 |
# File 'lib/aws-sdk-ec2/types.rb', line 85182 class SuccessfulSuppressionResponseObject < Struct.new( :instance_id, :suppress_at, :resume_at) SENSITIVE = [] include Aws::Structure end |
#suppress_at ⇒ Time
The date and time when suppression started.
85182 85183 85184 85185 85186 85187 85188 |
# File 'lib/aws-sdk-ec2/types.rb', line 85182 class SuccessfulSuppressionResponseObject < Struct.new( :instance_id, :suppress_at, :resume_at) SENSITIVE = [] include Aws::Structure end |