Class: Aws::EC2::Types::TargetGroupsConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes the target groups to attach to a Spot Fleet. Spot Fleet registers the running Spot Instances with these target groups.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#target_groupsArray<Types::TargetGroup>

One or more target groups.

Returns:



82666
82667
82668
82669
82670
# File 'lib/aws-sdk-ec2/types.rb', line 82666

class TargetGroupsConfig < Struct.new(
  :target_groups)
  SENSITIVE = []
  include Aws::Structure
end