Class: Aws::EC2::Types::TargetNetwork

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes a target network associated with a Client VPN endpoint.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#association_idString

The ID of the association.

Returns:

  • (String)


81100
81101
81102
81103
81104
81105
81106
81107
81108
81109
81110
81111
# File 'lib/aws-sdk-ec2/types.rb', line 81100

class TargetNetwork < Struct.new(
  :association_id,
  :vpc_id,
  :target_network_id,
  :client_vpn_endpoint_id,
  :status,
  :security_groups,
  :availability_zones,
  :availability_zone_ids)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zone_idsArray<String>

The Availability Zone IDs for the target network association, if the Client VPN endpoint uses a Transit Gateway.

Returns:

  • (Array<String>)


81100
81101
81102
81103
81104
81105
81106
81107
81108
81109
81110
81111
# File 'lib/aws-sdk-ec2/types.rb', line 81100

class TargetNetwork < Struct.new(
  :association_id,
  :vpc_id,
  :target_network_id,
  :client_vpn_endpoint_id,
  :status,
  :security_groups,
  :availability_zones,
  :availability_zone_ids)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zonesArray<String>

The Availability Zone names for the target network association, if the Client VPN endpoint uses a Transit Gateway.

Returns:

  • (Array<String>)


81100
81101
81102
81103
81104
81105
81106
81107
81108
81109
81110
81111
# File 'lib/aws-sdk-ec2/types.rb', line 81100

class TargetNetwork < Struct.new(
  :association_id,
  :vpc_id,
  :target_network_id,
  :client_vpn_endpoint_id,
  :status,
  :security_groups,
  :availability_zones,
  :availability_zone_ids)
  SENSITIVE = []
  include Aws::Structure
end

#client_vpn_endpoint_idString

The ID of the Client VPN endpoint with which the target network is associated.

Returns:

  • (String)


81100
81101
81102
81103
81104
81105
81106
81107
81108
81109
81110
81111
# File 'lib/aws-sdk-ec2/types.rb', line 81100

class TargetNetwork < Struct.new(
  :association_id,
  :vpc_id,
  :target_network_id,
  :client_vpn_endpoint_id,
  :status,
  :security_groups,
  :availability_zones,
  :availability_zone_ids)
  SENSITIVE = []
  include Aws::Structure
end

#security_groupsArray<String>

The IDs of the security groups applied to the target network association.

Returns:

  • (Array<String>)


81100
81101
81102
81103
81104
81105
81106
81107
81108
81109
81110
81111
# File 'lib/aws-sdk-ec2/types.rb', line 81100

class TargetNetwork < Struct.new(
  :association_id,
  :vpc_id,
  :target_network_id,
  :client_vpn_endpoint_id,
  :status,
  :security_groups,
  :availability_zones,
  :availability_zone_ids)
  SENSITIVE = []
  include Aws::Structure
end

#statusTypes::AssociationStatus

The current state of the target network association.



81100
81101
81102
81103
81104
81105
81106
81107
81108
81109
81110
81111
# File 'lib/aws-sdk-ec2/types.rb', line 81100

class TargetNetwork < Struct.new(
  :association_id,
  :vpc_id,
  :target_network_id,
  :client_vpn_endpoint_id,
  :status,
  :security_groups,
  :availability_zones,
  :availability_zone_ids)
  SENSITIVE = []
  include Aws::Structure
end

#target_network_idString

The ID of the subnet specified as the target network.

Returns:

  • (String)


81100
81101
81102
81103
81104
81105
81106
81107
81108
81109
81110
81111
# File 'lib/aws-sdk-ec2/types.rb', line 81100

class TargetNetwork < Struct.new(
  :association_id,
  :vpc_id,
  :target_network_id,
  :client_vpn_endpoint_id,
  :status,
  :security_groups,
  :availability_zones,
  :availability_zone_ids)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC in which the target network (subnet) is located.

Returns:

  • (String)


81100
81101
81102
81103
81104
81105
81106
81107
81108
81109
81110
81111
# File 'lib/aws-sdk-ec2/types.rb', line 81100

class TargetNetwork < Struct.new(
  :association_id,
  :vpc_id,
  :target_network_id,
  :client_vpn_endpoint_id,
  :status,
  :security_groups,
  :availability_zones,
  :availability_zone_ids)
  SENSITIVE = []
  include Aws::Structure
end