Class: Aws::EC2::Types::TerminateClientVpnConnectionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::TerminateClientVpnConnectionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_vpn_endpoint_id ⇒ String
The ID of the Client VPN endpoint to which the client is connected.
-
#connection_id ⇒ String
The ID of the client connection to be terminated.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#username ⇒ String
The name of the user who initiated the connection.
Instance Attribute Details
#client_vpn_endpoint_id ⇒ String
The ID of the Client VPN endpoint to which the client is connected.
85766 85767 85768 85769 85770 85771 85772 85773 |
# File 'lib/aws-sdk-ec2/types.rb', line 85766 class TerminateClientVpnConnectionsRequest < Struct.new( :client_vpn_endpoint_id, :connection_id, :username, :dry_run) SENSITIVE = [] include Aws::Structure end |
#connection_id ⇒ String
The ID of the client connection to be terminated.
85766 85767 85768 85769 85770 85771 85772 85773 |
# File 'lib/aws-sdk-ec2/types.rb', line 85766 class TerminateClientVpnConnectionsRequest < Struct.new( :client_vpn_endpoint_id, :connection_id, :username, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
85766 85767 85768 85769 85770 85771 85772 85773 |
# File 'lib/aws-sdk-ec2/types.rb', line 85766 class TerminateClientVpnConnectionsRequest < Struct.new( :client_vpn_endpoint_id, :connection_id, :username, :dry_run) SENSITIVE = [] include Aws::Structure end |
#username ⇒ String
The name of the user who initiated the connection. Use this option to terminate all active connections for the specified user. This option can only be used if the user has established up to five connections.
85766 85767 85768 85769 85770 85771 85772 85773 |
# File 'lib/aws-sdk-ec2/types.rb', line 85766 class TerminateClientVpnConnectionsRequest < Struct.new( :client_vpn_endpoint_id, :connection_id, :username, :dry_run) SENSITIVE = [] include Aws::Structure end |