Class: Aws::EC2::Types::TransitGatewayAttachmentAssociation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes an association.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#stateString

The state of the association.

Returns:

  • (String)


84800
84801
84802
84803
84804
84805
84806
# File 'lib/aws-sdk-ec2/types.rb', line 84800

class TransitGatewayAttachmentAssociation < Struct.new(
  :transit_gateway_route_table_id,
  :transit_gateway_policy_table_id,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_policy_table_idString

The ID of the transit gateway policy table associated with the attachment.

Returns:

  • (String)


84800
84801
84802
84803
84804
84805
84806
# File 'lib/aws-sdk-ec2/types.rb', line 84800

class TransitGatewayAttachmentAssociation < Struct.new(
  :transit_gateway_route_table_id,
  :transit_gateway_policy_table_id,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_route_table_idString

The ID of the route table for the transit gateway.

Returns:

  • (String)


84800
84801
84802
84803
84804
84805
84806
# File 'lib/aws-sdk-ec2/types.rb', line 84800

class TransitGatewayAttachmentAssociation < Struct.new(
  :transit_gateway_route_table_id,
  :transit_gateway_policy_table_id,
  :state)
  SENSITIVE = []
  include Aws::Structure
end