Class: Aws::EC2::Types::TransitGatewayMeteringPolicyRule
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::TransitGatewayMeteringPolicyRule
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the traffic matching criteria for a transit gateway metering policy rule.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination_cidr_block ⇒ String
The destination CIDR block for the rule.
-
#destination_port_range ⇒ String
The destination port range for the rule.
-
#destination_transit_gateway_attachment_id ⇒ String
The ID of the destination transit gateway attachment.
-
#destination_transit_gateway_attachment_type ⇒ String
The type of the destination transit gateway attachment.
-
#protocol ⇒ String
The protocol for the rule (1, 6, 17, etc.).
-
#source_cidr_block ⇒ String
The source CIDR block for the rule.
-
#source_port_range ⇒ String
The source port range for the rule.
-
#source_transit_gateway_attachment_id ⇒ String
The ID of the source transit gateway attachment.
-
#source_transit_gateway_attachment_type ⇒ String
The type of the source transit gateway attachment.
Instance Attribute Details
#destination_cidr_block ⇒ String
The destination CIDR block for the rule.
83818 83819 83820 83821 83822 83823 83824 83825 83826 83827 83828 83829 83830 |
# File 'lib/aws-sdk-ec2/types.rb', line 83818 class TransitGatewayMeteringPolicyRule < Struct.new( :source_transit_gateway_attachment_id, :source_transit_gateway_attachment_type, :source_cidr_block, :source_port_range, :destination_transit_gateway_attachment_id, :destination_transit_gateway_attachment_type, :destination_cidr_block, :destination_port_range, :protocol) SENSITIVE = [] include Aws::Structure end |
#destination_port_range ⇒ String
The destination port range for the rule.
83818 83819 83820 83821 83822 83823 83824 83825 83826 83827 83828 83829 83830 |
# File 'lib/aws-sdk-ec2/types.rb', line 83818 class TransitGatewayMeteringPolicyRule < Struct.new( :source_transit_gateway_attachment_id, :source_transit_gateway_attachment_type, :source_cidr_block, :source_port_range, :destination_transit_gateway_attachment_id, :destination_transit_gateway_attachment_type, :destination_cidr_block, :destination_port_range, :protocol) SENSITIVE = [] include Aws::Structure end |
#destination_transit_gateway_attachment_id ⇒ String
The ID of the destination transit gateway attachment.
83818 83819 83820 83821 83822 83823 83824 83825 83826 83827 83828 83829 83830 |
# File 'lib/aws-sdk-ec2/types.rb', line 83818 class TransitGatewayMeteringPolicyRule < Struct.new( :source_transit_gateway_attachment_id, :source_transit_gateway_attachment_type, :source_cidr_block, :source_port_range, :destination_transit_gateway_attachment_id, :destination_transit_gateway_attachment_type, :destination_cidr_block, :destination_port_range, :protocol) SENSITIVE = [] include Aws::Structure end |
#destination_transit_gateway_attachment_type ⇒ String
The type of the destination transit gateway attachment. Note that
the tgw-peering resource type has been deprecated. To configure
metering policies for Connect, use the transport attachment type.
83818 83819 83820 83821 83822 83823 83824 83825 83826 83827 83828 83829 83830 |
# File 'lib/aws-sdk-ec2/types.rb', line 83818 class TransitGatewayMeteringPolicyRule < Struct.new( :source_transit_gateway_attachment_id, :source_transit_gateway_attachment_type, :source_cidr_block, :source_port_range, :destination_transit_gateway_attachment_id, :destination_transit_gateway_attachment_type, :destination_cidr_block, :destination_port_range, :protocol) SENSITIVE = [] include Aws::Structure end |
#protocol ⇒ String
The protocol for the rule (1, 6, 17, etc.).
83818 83819 83820 83821 83822 83823 83824 83825 83826 83827 83828 83829 83830 |
# File 'lib/aws-sdk-ec2/types.rb', line 83818 class TransitGatewayMeteringPolicyRule < Struct.new( :source_transit_gateway_attachment_id, :source_transit_gateway_attachment_type, :source_cidr_block, :source_port_range, :destination_transit_gateway_attachment_id, :destination_transit_gateway_attachment_type, :destination_cidr_block, :destination_port_range, :protocol) SENSITIVE = [] include Aws::Structure end |
#source_cidr_block ⇒ String
The source CIDR block for the rule.
83818 83819 83820 83821 83822 83823 83824 83825 83826 83827 83828 83829 83830 |
# File 'lib/aws-sdk-ec2/types.rb', line 83818 class TransitGatewayMeteringPolicyRule < Struct.new( :source_transit_gateway_attachment_id, :source_transit_gateway_attachment_type, :source_cidr_block, :source_port_range, :destination_transit_gateway_attachment_id, :destination_transit_gateway_attachment_type, :destination_cidr_block, :destination_port_range, :protocol) SENSITIVE = [] include Aws::Structure end |
#source_port_range ⇒ String
The source port range for the rule.
83818 83819 83820 83821 83822 83823 83824 83825 83826 83827 83828 83829 83830 |
# File 'lib/aws-sdk-ec2/types.rb', line 83818 class TransitGatewayMeteringPolicyRule < Struct.new( :source_transit_gateway_attachment_id, :source_transit_gateway_attachment_type, :source_cidr_block, :source_port_range, :destination_transit_gateway_attachment_id, :destination_transit_gateway_attachment_type, :destination_cidr_block, :destination_port_range, :protocol) SENSITIVE = [] include Aws::Structure end |
#source_transit_gateway_attachment_id ⇒ String
The ID of the source transit gateway attachment.
83818 83819 83820 83821 83822 83823 83824 83825 83826 83827 83828 83829 83830 |
# File 'lib/aws-sdk-ec2/types.rb', line 83818 class TransitGatewayMeteringPolicyRule < Struct.new( :source_transit_gateway_attachment_id, :source_transit_gateway_attachment_type, :source_cidr_block, :source_port_range, :destination_transit_gateway_attachment_id, :destination_transit_gateway_attachment_type, :destination_cidr_block, :destination_port_range, :protocol) SENSITIVE = [] include Aws::Structure end |
#source_transit_gateway_attachment_type ⇒ String
The type of the source transit gateway attachment. Note that the
tgw-peering resource type has been deprecated. To configure
metering policies for Connect, use the transport attachment type.
83818 83819 83820 83821 83822 83823 83824 83825 83826 83827 83828 83829 83830 |
# File 'lib/aws-sdk-ec2/types.rb', line 83818 class TransitGatewayMeteringPolicyRule < Struct.new( :source_transit_gateway_attachment_id, :source_transit_gateway_attachment_type, :source_cidr_block, :source_port_range, :destination_transit_gateway_attachment_id, :destination_transit_gateway_attachment_type, :destination_cidr_block, :destination_port_range, :protocol) SENSITIVE = [] include Aws::Structure end |