Class: Aws::EC2::Types::TransitGatewayPolicyRule

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes a rule associated with a transit gateway policy.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#destination_cidr_blockString

The destination CIDR block for the transit gateway policy rule.

Returns:

  • (String)


84012
84013
84014
84015
84016
84017
84018
84019
84020
84021
# File 'lib/aws-sdk-ec2/types.rb', line 84012

class TransitGatewayPolicyRule < Struct.new(
  :source_cidr_block,
  :source_port_range,
  :destination_cidr_block,
  :destination_port_range,
  :protocol,
  :meta_data)
  SENSITIVE = []
  include Aws::Structure
end

#destination_port_rangeString

The port range for the transit gateway policy rule. Currently this is set to * (all).

Returns:

  • (String)


84012
84013
84014
84015
84016
84017
84018
84019
84020
84021
# File 'lib/aws-sdk-ec2/types.rb', line 84012

class TransitGatewayPolicyRule < Struct.new(
  :source_cidr_block,
  :source_port_range,
  :destination_cidr_block,
  :destination_port_range,
  :protocol,
  :meta_data)
  SENSITIVE = []
  include Aws::Structure
end

#meta_dataTypes::TransitGatewayPolicyRuleMetaData

The meta data tags used for the transit gateway policy rule.



84012
84013
84014
84015
84016
84017
84018
84019
84020
84021
# File 'lib/aws-sdk-ec2/types.rb', line 84012

class TransitGatewayPolicyRule < Struct.new(
  :source_cidr_block,
  :source_port_range,
  :destination_cidr_block,
  :destination_port_range,
  :protocol,
  :meta_data)
  SENSITIVE = []
  include Aws::Structure
end

#protocolString

The protocol used by the transit gateway policy rule.

Returns:

  • (String)


84012
84013
84014
84015
84016
84017
84018
84019
84020
84021
# File 'lib/aws-sdk-ec2/types.rb', line 84012

class TransitGatewayPolicyRule < Struct.new(
  :source_cidr_block,
  :source_port_range,
  :destination_cidr_block,
  :destination_port_range,
  :protocol,
  :meta_data)
  SENSITIVE = []
  include Aws::Structure
end

#source_cidr_blockString

The source CIDR block for the transit gateway policy rule.

Returns:

  • (String)


84012
84013
84014
84015
84016
84017
84018
84019
84020
84021
# File 'lib/aws-sdk-ec2/types.rb', line 84012

class TransitGatewayPolicyRule < Struct.new(
  :source_cidr_block,
  :source_port_range,
  :destination_cidr_block,
  :destination_port_range,
  :protocol,
  :meta_data)
  SENSITIVE = []
  include Aws::Structure
end

#source_port_rangeString

The port range for the transit gateway policy rule. Currently this is set to * (all).

Returns:

  • (String)


84012
84013
84014
84015
84016
84017
84018
84019
84020
84021
# File 'lib/aws-sdk-ec2/types.rb', line 84012

class TransitGatewayPolicyRule < Struct.new(
  :source_cidr_block,
  :source_port_range,
  :destination_cidr_block,
  :destination_port_range,
  :protocol,
  :meta_data)
  SENSITIVE = []
  include Aws::Structure
end