Class: Aws::EC2::Types::TransitGatewayPolicyTable

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes a transit gateway policy table.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timeTime

The timestamp when the transit gateway policy table was created.

Returns:

  • (Time)


82920
82921
82922
82923
82924
82925
82926
82927
82928
# File 'lib/aws-sdk-ec2/types.rb', line 82920

class TransitGatewayPolicyTable < Struct.new(
  :transit_gateway_policy_table_id,
  :transit_gateway_id,
  :state,
  :creation_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of the transit gateway policy table

Returns:

  • (String)


82920
82921
82922
82923
82924
82925
82926
82927
82928
# File 'lib/aws-sdk-ec2/types.rb', line 82920

class TransitGatewayPolicyTable < Struct.new(
  :transit_gateway_policy_table_id,
  :transit_gateway_id,
  :state,
  :creation_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

he key-value pairs associated with the transit gateway policy table.

Returns:



82920
82921
82922
82923
82924
82925
82926
82927
82928
# File 'lib/aws-sdk-ec2/types.rb', line 82920

class TransitGatewayPolicyTable < Struct.new(
  :transit_gateway_policy_table_id,
  :transit_gateway_id,
  :state,
  :creation_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_idString

The ID of the transit gateway.

Returns:

  • (String)


82920
82921
82922
82923
82924
82925
82926
82927
82928
# File 'lib/aws-sdk-ec2/types.rb', line 82920

class TransitGatewayPolicyTable < Struct.new(
  :transit_gateway_policy_table_id,
  :transit_gateway_id,
  :state,
  :creation_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_policy_table_idString

The ID of the transit gateway policy table.

Returns:

  • (String)


82920
82921
82922
82923
82924
82925
82926
82927
82928
# File 'lib/aws-sdk-ec2/types.rb', line 82920

class TransitGatewayPolicyTable < Struct.new(
  :transit_gateway_policy_table_id,
  :transit_gateway_id,
  :state,
  :creation_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end