Class: Aws::EC2::Types::TransitGatewayRequestPolicyRuleMetaData

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

A metadata key-value pair for a transit gateway policy rule.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#meta_data_keyString

The key of the metadata pair for the policy rule.

Returns:

  • (String)


86109
86110
86111
86112
86113
86114
# File 'lib/aws-sdk-ec2/types.rb', line 86109

class TransitGatewayRequestPolicyRuleMetaData < Struct.new(
  :meta_data_key,
  :meta_data_value)
  SENSITIVE = []
  include Aws::Structure
end

#meta_data_valueString

The value of the metadata pair for the policy rule.

Returns:

  • (String)


86109
86110
86111
86112
86113
86114
# File 'lib/aws-sdk-ec2/types.rb', line 86109

class TransitGatewayRequestPolicyRuleMetaData < Struct.new(
  :meta_data_key,
  :meta_data_value)
  SENSITIVE = []
  include Aws::Structure
end