Class: Aws::EC2::Types::TransitGatewayRoute

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes a route for a transit gateway route table.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#destination_cidr_blockString

The CIDR block used for destination matches.

Returns:

  • (String)


83834
83835
83836
83837
83838
83839
83840
83841
83842
83843
# File 'lib/aws-sdk-ec2/types.rb', line 83834

class TransitGatewayRoute < Struct.new(
  :destination_cidr_block,
  :prefix_list_id,
  :transit_gateway_route_table_announcement_id,
  :transit_gateway_attachments,
  :type,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#prefix_list_idString

The ID of the prefix list used for destination matches.

Returns:

  • (String)


83834
83835
83836
83837
83838
83839
83840
83841
83842
83843
# File 'lib/aws-sdk-ec2/types.rb', line 83834

class TransitGatewayRoute < Struct.new(
  :destination_cidr_block,
  :prefix_list_id,
  :transit_gateway_route_table_announcement_id,
  :transit_gateway_attachments,
  :type,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of the route.

Returns:

  • (String)


83834
83835
83836
83837
83838
83839
83840
83841
83842
83843
# File 'lib/aws-sdk-ec2/types.rb', line 83834

class TransitGatewayRoute < Struct.new(
  :destination_cidr_block,
  :prefix_list_id,
  :transit_gateway_route_table_announcement_id,
  :transit_gateway_attachments,
  :type,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_attachmentsArray<Types::TransitGatewayRouteAttachment>

The attachments.



83834
83835
83836
83837
83838
83839
83840
83841
83842
83843
# File 'lib/aws-sdk-ec2/types.rb', line 83834

class TransitGatewayRoute < Struct.new(
  :destination_cidr_block,
  :prefix_list_id,
  :transit_gateway_route_table_announcement_id,
  :transit_gateway_attachments,
  :type,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_route_table_announcement_idString

The ID of the transit gateway route table announcement.

Returns:

  • (String)


83834
83835
83836
83837
83838
83839
83840
83841
83842
83843
# File 'lib/aws-sdk-ec2/types.rb', line 83834

class TransitGatewayRoute < Struct.new(
  :destination_cidr_block,
  :prefix_list_id,
  :transit_gateway_route_table_announcement_id,
  :transit_gateway_attachments,
  :type,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The route type.

Returns:

  • (String)


83834
83835
83836
83837
83838
83839
83840
83841
83842
83843
# File 'lib/aws-sdk-ec2/types.rb', line 83834

class TransitGatewayRoute < Struct.new(
  :destination_cidr_block,
  :prefix_list_id,
  :transit_gateway_route_table_announcement_id,
  :transit_gateway_attachments,
  :type,
  :state)
  SENSITIVE = []
  include Aws::Structure
end