Class: Aws::EC2::Types::TransitGatewayRouteTable

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes a transit gateway route table.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timeTime

The creation time.

Returns:

  • (Time)


83272
83273
83274
83275
83276
83277
83278
83279
83280
83281
83282
# File 'lib/aws-sdk-ec2/types.rb', line 83272

class TransitGatewayRouteTable < Struct.new(
  :transit_gateway_route_table_id,
  :transit_gateway_id,
  :state,
  :default_association_route_table,
  :default_propagation_route_table,
  :creation_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#default_association_route_tableBoolean

Indicates whether this is the default association route table for the transit gateway.

Returns:

  • (Boolean)


83272
83273
83274
83275
83276
83277
83278
83279
83280
83281
83282
# File 'lib/aws-sdk-ec2/types.rb', line 83272

class TransitGatewayRouteTable < Struct.new(
  :transit_gateway_route_table_id,
  :transit_gateway_id,
  :state,
  :default_association_route_table,
  :default_propagation_route_table,
  :creation_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#default_propagation_route_tableBoolean

Indicates whether this is the default propagation route table for the transit gateway.

Returns:

  • (Boolean)


83272
83273
83274
83275
83276
83277
83278
83279
83280
83281
83282
# File 'lib/aws-sdk-ec2/types.rb', line 83272

class TransitGatewayRouteTable < Struct.new(
  :transit_gateway_route_table_id,
  :transit_gateway_id,
  :state,
  :default_association_route_table,
  :default_propagation_route_table,
  :creation_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of the transit gateway route table.

Returns:

  • (String)


83272
83273
83274
83275
83276
83277
83278
83279
83280
83281
83282
# File 'lib/aws-sdk-ec2/types.rb', line 83272

class TransitGatewayRouteTable < Struct.new(
  :transit_gateway_route_table_id,
  :transit_gateway_id,
  :state,
  :default_association_route_table,
  :default_propagation_route_table,
  :creation_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Any tags assigned to the route table.

Returns:



83272
83273
83274
83275
83276
83277
83278
83279
83280
83281
83282
# File 'lib/aws-sdk-ec2/types.rb', line 83272

class TransitGatewayRouteTable < Struct.new(
  :transit_gateway_route_table_id,
  :transit_gateway_id,
  :state,
  :default_association_route_table,
  :default_propagation_route_table,
  :creation_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_idString

The ID of the transit gateway.

Returns:

  • (String)


83272
83273
83274
83275
83276
83277
83278
83279
83280
83281
83282
# File 'lib/aws-sdk-ec2/types.rb', line 83272

class TransitGatewayRouteTable < Struct.new(
  :transit_gateway_route_table_id,
  :transit_gateway_id,
  :state,
  :default_association_route_table,
  :default_propagation_route_table,
  :creation_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_route_table_idString

The ID of the transit gateway route table.

Returns:

  • (String)


83272
83273
83274
83275
83276
83277
83278
83279
83280
83281
83282
# File 'lib/aws-sdk-ec2/types.rb', line 83272

class TransitGatewayRouteTable < Struct.new(
  :transit_gateway_route_table_id,
  :transit_gateway_id,
  :state,
  :default_association_route_table,
  :default_propagation_route_table,
  :creation_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end