Class: Aws::EC2::Types::UnsuccessfulInstanceCreditSpecificationItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes the burstable performance instance whose credit option for CPU usage was not modified.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#errorTypes::UnsuccessfulInstanceCreditSpecificationItemError

The applicable error for the burstable performance instance whose credit option for CPU usage was not modified.



88336
88337
88338
88339
88340
88341
# File 'lib/aws-sdk-ec2/types.rb', line 88336

class UnsuccessfulInstanceCreditSpecificationItem < Struct.new(
  :instance_id,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The ID of the instance.

Returns:

  • (String)


88336
88337
88338
88339
88340
88341
# File 'lib/aws-sdk-ec2/types.rb', line 88336

class UnsuccessfulInstanceCreditSpecificationItem < Struct.new(
  :instance_id,
  :error)
  SENSITIVE = []
  include Aws::Structure
end