Class: Aws::EC2::Types::UnsuccessfulSuppressionResponseObject
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::UnsuccessfulSuppressionResponseObject
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes an unsuccessful application status check suppression.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The ID of the instance.
-
#reason ⇒ String
The reason the suppression failed.
-
#resume_at ⇒ Time
The date and time when health checks would have resumed.
-
#suppress_at ⇒ Time
The date and time when suppression was attempted.
Instance Attribute Details
#instance_id ⇒ String
The ID of the instance.
88427 88428 88429 88430 88431 88432 88433 88434 |
# File 'lib/aws-sdk-ec2/types.rb', line 88427 class UnsuccessfulSuppressionResponseObject < Struct.new( :instance_id, :suppress_at, :resume_at, :reason) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ String
The reason the suppression failed.
88427 88428 88429 88430 88431 88432 88433 88434 |
# File 'lib/aws-sdk-ec2/types.rb', line 88427 class UnsuccessfulSuppressionResponseObject < Struct.new( :instance_id, :suppress_at, :resume_at, :reason) SENSITIVE = [] include Aws::Structure end |
#resume_at ⇒ Time
The date and time when health checks would have resumed.
88427 88428 88429 88430 88431 88432 88433 88434 |
# File 'lib/aws-sdk-ec2/types.rb', line 88427 class UnsuccessfulSuppressionResponseObject < Struct.new( :instance_id, :suppress_at, :resume_at, :reason) SENSITIVE = [] include Aws::Structure end |
#suppress_at ⇒ Time
The date and time when suppression was attempted.
88427 88428 88429 88430 88431 88432 88433 88434 |
# File 'lib/aws-sdk-ec2/types.rb', line 88427 class UnsuccessfulSuppressionResponseObject < Struct.new( :instance_id, :suppress_at, :resume_at, :reason) SENSITIVE = [] include Aws::Structure end |