Class: Aws::EC2::Types::UpdateSecurityGroupRuleDescriptionsIngressRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::UpdateSecurityGroupRuleDescriptionsIngressRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#group_id ⇒ String
The ID of the security group.
-
#group_name ⇒ String
[Default VPC] The name of the security group.
-
#ip_permissions ⇒ Array<Types::IpPermission>
The IP permissions for the security group rule.
-
#security_group_rule_descriptions ⇒ Array<Types::SecurityGroupRuleDescription>
The description for the ingress security group rules.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
88829 88830 88831 88832 88833 88834 88835 88836 88837 |
# File 'lib/aws-sdk-ec2/types.rb', line 88829 class UpdateSecurityGroupRuleDescriptionsIngressRequest < Struct.new( :dry_run, :group_id, :group_name, :ip_permissions, :security_group_rule_descriptions) SENSITIVE = [] include Aws::Structure end |
#group_id ⇒ String
The ID of the security group. You must specify either the security group ID or the security group name in the request. For security groups in a nondefault VPC, you must specify the security group ID.
88829 88830 88831 88832 88833 88834 88835 88836 88837 |
# File 'lib/aws-sdk-ec2/types.rb', line 88829 class UpdateSecurityGroupRuleDescriptionsIngressRequest < Struct.new( :dry_run, :group_id, :group_name, :ip_permissions, :security_group_rule_descriptions) SENSITIVE = [] include Aws::Structure end |
#group_name ⇒ String
[Default VPC] The name of the security group. You must specify either the security group ID or the security group name. For security groups in a nondefault VPC, you must specify the security group ID.
88829 88830 88831 88832 88833 88834 88835 88836 88837 |
# File 'lib/aws-sdk-ec2/types.rb', line 88829 class UpdateSecurityGroupRuleDescriptionsIngressRequest < Struct.new( :dry_run, :group_id, :group_name, :ip_permissions, :security_group_rule_descriptions) SENSITIVE = [] include Aws::Structure end |
#ip_permissions ⇒ Array<Types::IpPermission>
The IP permissions for the security group rule. You must specify either IP permissions or a description.
88829 88830 88831 88832 88833 88834 88835 88836 88837 |
# File 'lib/aws-sdk-ec2/types.rb', line 88829 class UpdateSecurityGroupRuleDescriptionsIngressRequest < Struct.new( :dry_run, :group_id, :group_name, :ip_permissions, :security_group_rule_descriptions) SENSITIVE = [] include Aws::Structure end |
#security_group_rule_descriptions ⇒ Array<Types::SecurityGroupRuleDescription>
The description for the ingress security group rules. You must specify either a description or IP permissions.
88829 88830 88831 88832 88833 88834 88835 88836 88837 |
# File 'lib/aws-sdk-ec2/types.rb', line 88829 class UpdateSecurityGroupRuleDescriptionsIngressRequest < Struct.new( :dry_run, :group_id, :group_name, :ip_permissions, :security_group_rule_descriptions) SENSITIVE = [] include Aws::Structure end |