Class: Aws::EC2::Types::UserIdGroupPair

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes a security group and Amazon Web Services account ID pair.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description for the security group rule that references this user ID group pair.

Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*

Returns:

  • (String)


88950
88951
88952
88953
88954
88955
88956
88957
88958
88959
88960
# File 'lib/aws-sdk-ec2/types.rb', line 88950

class UserIdGroupPair < Struct.new(
  :description,
  :user_id,
  :group_name,
  :group_id,
  :vpc_id,
  :vpc_peering_connection_id,
  :peering_status)
  SENSITIVE = []
  include Aws::Structure
end

#group_idString

The ID of the security group.

Returns:

  • (String)


88950
88951
88952
88953
88954
88955
88956
88957
88958
88959
88960
# File 'lib/aws-sdk-ec2/types.rb', line 88950

class UserIdGroupPair < Struct.new(
  :description,
  :user_id,
  :group_name,
  :group_id,
  :vpc_id,
  :vpc_peering_connection_id,
  :peering_status)
  SENSITIVE = []
  include Aws::Structure
end

#group_nameString

[Default VPC] The name of the security group. For a security group in a nondefault VPC, use the security group ID.

For a referenced security group in another VPC, this value is not returned if the referenced security group is deleted.

Returns:

  • (String)


88950
88951
88952
88953
88954
88955
88956
88957
88958
88959
88960
# File 'lib/aws-sdk-ec2/types.rb', line 88950

class UserIdGroupPair < Struct.new(
  :description,
  :user_id,
  :group_name,
  :group_id,
  :vpc_id,
  :vpc_peering_connection_id,
  :peering_status)
  SENSITIVE = []
  include Aws::Structure
end

#peering_statusString

The status of a VPC peering connection, if applicable.

Returns:

  • (String)


88950
88951
88952
88953
88954
88955
88956
88957
88958
88959
88960
# File 'lib/aws-sdk-ec2/types.rb', line 88950

class UserIdGroupPair < Struct.new(
  :description,
  :user_id,
  :group_name,
  :group_id,
  :vpc_id,
  :vpc_peering_connection_id,
  :peering_status)
  SENSITIVE = []
  include Aws::Structure
end

#user_idString

The ID of an Amazon Web Services account.

For a referenced security group in another VPC, the account ID of the referenced security group is returned in the response. If the referenced security group is deleted, this value is not returned.

Returns:

  • (String)


88950
88951
88952
88953
88954
88955
88956
88957
88958
88959
88960
# File 'lib/aws-sdk-ec2/types.rb', line 88950

class UserIdGroupPair < Struct.new(
  :description,
  :user_id,
  :group_name,
  :group_id,
  :vpc_id,
  :vpc_peering_connection_id,
  :peering_status)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC for the referenced security group, if applicable.

Returns:

  • (String)


88950
88951
88952
88953
88954
88955
88956
88957
88958
88959
88960
# File 'lib/aws-sdk-ec2/types.rb', line 88950

class UserIdGroupPair < Struct.new(
  :description,
  :user_id,
  :group_name,
  :group_id,
  :vpc_id,
  :vpc_peering_connection_id,
  :peering_status)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_peering_connection_idString

The ID of the VPC peering connection, if applicable.

Returns:

  • (String)


88950
88951
88952
88953
88954
88955
88956
88957
88958
88959
88960
# File 'lib/aws-sdk-ec2/types.rb', line 88950

class UserIdGroupPair < Struct.new(
  :description,
  :user_id,
  :group_name,
  :group_id,
  :vpc_id,
  :vpc_peering_connection_id,
  :peering_status)
  SENSITIVE = []
  include Aws::Structure
end