Class: Aws::EC2::Types::ValidationError
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ValidationError
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
The error code and error message that is returned for a parameter or parameter combination that is not valid when a new launch template or new version of a launch template is created.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
The error code that indicates why the parameter or parameter combination is not valid.
-
#message ⇒ String
The error message that describes why the parameter or parameter combination is not valid.
Instance Attribute Details
#code ⇒ String
The error code that indicates why the parameter or parameter combination is not valid. For more information about error codes, see Error codes.
85235 85236 85237 85238 85239 85240 |
# File 'lib/aws-sdk-ec2/types.rb', line 85235 class ValidationError < Struct.new( :code, :message) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
The error message that describes why the parameter or parameter combination is not valid. For more information about error messages, see Error codes.
85235 85236 85237 85238 85239 85240 |
# File 'lib/aws-sdk-ec2/types.rb', line 85235 class ValidationError < Struct.new( :code, :message) SENSITIVE = [] include Aws::Structure end |