Class: Aws::EC2::Types::VerifiedAccessInstanceUserTrustProviderClientConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::VerifiedAccessInstanceUserTrustProviderClientConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the trust provider.
Constant Summary collapse
- SENSITIVE =
[:client_secret]
Instance Attribute Summary collapse
-
#authorization_endpoint ⇒ String
The authorization endpoint of the IdP.
-
#client_id ⇒ String
The OAuth 2.0 client identifier.
-
#client_secret ⇒ String
The OAuth 2.0 client secret.
-
#issuer ⇒ String
The OIDC issuer identifier of the IdP.
-
#pkce_enabled ⇒ Boolean
Indicates whether Proof of Key Code Exchange (PKCE) is enabled.
-
#public_signing_key_endpoint ⇒ String
The public signing key endpoint.
-
#scopes ⇒ String
The set of user claims to be requested from the IdP.
-
#token_endpoint ⇒ String
The token endpoint of the IdP.
-
#type ⇒ String
The trust provider type.
-
#user_info_endpoint ⇒ String
The user info endpoint of the IdP.
Instance Attribute Details
#authorization_endpoint ⇒ String
The authorization endpoint of the IdP.
84338 84339 84340 84341 84342 84343 84344 84345 84346 84347 84348 84349 84350 84351 |
# File 'lib/aws-sdk-ec2/types.rb', line 84338 class VerifiedAccessInstanceUserTrustProviderClientConfiguration < Struct.new( :type, :scopes, :issuer, :authorization_endpoint, :public_signing_key_endpoint, :token_endpoint, :user_info_endpoint, :client_id, :client_secret, :pkce_enabled) SENSITIVE = [:client_secret] include Aws::Structure end |
#client_id ⇒ String
The OAuth 2.0 client identifier.
84338 84339 84340 84341 84342 84343 84344 84345 84346 84347 84348 84349 84350 84351 |
# File 'lib/aws-sdk-ec2/types.rb', line 84338 class VerifiedAccessInstanceUserTrustProviderClientConfiguration < Struct.new( :type, :scopes, :issuer, :authorization_endpoint, :public_signing_key_endpoint, :token_endpoint, :user_info_endpoint, :client_id, :client_secret, :pkce_enabled) SENSITIVE = [:client_secret] include Aws::Structure end |
#client_secret ⇒ String
The OAuth 2.0 client secret.
84338 84339 84340 84341 84342 84343 84344 84345 84346 84347 84348 84349 84350 84351 |
# File 'lib/aws-sdk-ec2/types.rb', line 84338 class VerifiedAccessInstanceUserTrustProviderClientConfiguration < Struct.new( :type, :scopes, :issuer, :authorization_endpoint, :public_signing_key_endpoint, :token_endpoint, :user_info_endpoint, :client_id, :client_secret, :pkce_enabled) SENSITIVE = [:client_secret] include Aws::Structure end |
#issuer ⇒ String
The OIDC issuer identifier of the IdP.
84338 84339 84340 84341 84342 84343 84344 84345 84346 84347 84348 84349 84350 84351 |
# File 'lib/aws-sdk-ec2/types.rb', line 84338 class VerifiedAccessInstanceUserTrustProviderClientConfiguration < Struct.new( :type, :scopes, :issuer, :authorization_endpoint, :public_signing_key_endpoint, :token_endpoint, :user_info_endpoint, :client_id, :client_secret, :pkce_enabled) SENSITIVE = [:client_secret] include Aws::Structure end |
#pkce_enabled ⇒ Boolean
Indicates whether Proof of Key Code Exchange (PKCE) is enabled.
84338 84339 84340 84341 84342 84343 84344 84345 84346 84347 84348 84349 84350 84351 |
# File 'lib/aws-sdk-ec2/types.rb', line 84338 class VerifiedAccessInstanceUserTrustProviderClientConfiguration < Struct.new( :type, :scopes, :issuer, :authorization_endpoint, :public_signing_key_endpoint, :token_endpoint, :user_info_endpoint, :client_id, :client_secret, :pkce_enabled) SENSITIVE = [:client_secret] include Aws::Structure end |
#public_signing_key_endpoint ⇒ String
The public signing key endpoint.
84338 84339 84340 84341 84342 84343 84344 84345 84346 84347 84348 84349 84350 84351 |
# File 'lib/aws-sdk-ec2/types.rb', line 84338 class VerifiedAccessInstanceUserTrustProviderClientConfiguration < Struct.new( :type, :scopes, :issuer, :authorization_endpoint, :public_signing_key_endpoint, :token_endpoint, :user_info_endpoint, :client_id, :client_secret, :pkce_enabled) SENSITIVE = [:client_secret] include Aws::Structure end |
#scopes ⇒ String
The set of user claims to be requested from the IdP.
84338 84339 84340 84341 84342 84343 84344 84345 84346 84347 84348 84349 84350 84351 |
# File 'lib/aws-sdk-ec2/types.rb', line 84338 class VerifiedAccessInstanceUserTrustProviderClientConfiguration < Struct.new( :type, :scopes, :issuer, :authorization_endpoint, :public_signing_key_endpoint, :token_endpoint, :user_info_endpoint, :client_id, :client_secret, :pkce_enabled) SENSITIVE = [:client_secret] include Aws::Structure end |
#token_endpoint ⇒ String
The token endpoint of the IdP.
84338 84339 84340 84341 84342 84343 84344 84345 84346 84347 84348 84349 84350 84351 |
# File 'lib/aws-sdk-ec2/types.rb', line 84338 class VerifiedAccessInstanceUserTrustProviderClientConfiguration < Struct.new( :type, :scopes, :issuer, :authorization_endpoint, :public_signing_key_endpoint, :token_endpoint, :user_info_endpoint, :client_id, :client_secret, :pkce_enabled) SENSITIVE = [:client_secret] include Aws::Structure end |
#type ⇒ String
The trust provider type.
84338 84339 84340 84341 84342 84343 84344 84345 84346 84347 84348 84349 84350 84351 |
# File 'lib/aws-sdk-ec2/types.rb', line 84338 class VerifiedAccessInstanceUserTrustProviderClientConfiguration < Struct.new( :type, :scopes, :issuer, :authorization_endpoint, :public_signing_key_endpoint, :token_endpoint, :user_info_endpoint, :client_id, :client_secret, :pkce_enabled) SENSITIVE = [:client_secret] include Aws::Structure end |
#user_info_endpoint ⇒ String
The user info endpoint of the IdP.
84338 84339 84340 84341 84342 84343 84344 84345 84346 84347 84348 84349 84350 84351 |
# File 'lib/aws-sdk-ec2/types.rb', line 84338 class VerifiedAccessInstanceUserTrustProviderClientConfiguration < Struct.new( :type, :scopes, :issuer, :authorization_endpoint, :public_signing_key_endpoint, :token_endpoint, :user_info_endpoint, :client_id, :client_secret, :pkce_enabled) SENSITIVE = [:client_secret] include Aws::Structure end |