Class: Aws::EC2::Types::VolumeAttachment

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes volume attachment details.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#associated_resourceString

The ARN of the Amazon Web Services-managed resource to which the volume is attached.

Returns:

  • (String)


90159
90160
90161
90162
90163
90164
90165
90166
90167
90168
90169
90170
90171
# File 'lib/aws-sdk-ec2/types.rb', line 90159

class VolumeAttachment < Struct.new(
  :delete_on_termination,
  :associated_resource,
  :instance_owning_service,
  :ebs_card_index,
  :volume_id,
  :instance_id,
  :device,
  :state,
  :attach_time)
  SENSITIVE = []
  include Aws::Structure
end

#attach_timeTime

The time stamp when the attachment initiated.

Returns:

  • (Time)


90159
90160
90161
90162
90163
90164
90165
90166
90167
90168
90169
90170
90171
# File 'lib/aws-sdk-ec2/types.rb', line 90159

class VolumeAttachment < Struct.new(
  :delete_on_termination,
  :associated_resource,
  :instance_owning_service,
  :ebs_card_index,
  :volume_id,
  :instance_id,
  :device,
  :state,
  :attach_time)
  SENSITIVE = []
  include Aws::Structure
end

#delete_on_terminationBoolean

Indicates whether the EBS volume is deleted on instance termination.

Returns:

  • (Boolean)


90159
90160
90161
90162
90163
90164
90165
90166
90167
90168
90169
90170
90171
# File 'lib/aws-sdk-ec2/types.rb', line 90159

class VolumeAttachment < Struct.new(
  :delete_on_termination,
  :associated_resource,
  :instance_owning_service,
  :ebs_card_index,
  :volume_id,
  :instance_id,
  :device,
  :state,
  :attach_time)
  SENSITIVE = []
  include Aws::Structure
end

#deviceString

The device name.

If the volume is attached to an Amazon Web Services-managed resource, this parameter returns null.

Returns:

  • (String)


90159
90160
90161
90162
90163
90164
90165
90166
90167
90168
90169
90170
90171
# File 'lib/aws-sdk-ec2/types.rb', line 90159

class VolumeAttachment < Struct.new(
  :delete_on_termination,
  :associated_resource,
  :instance_owning_service,
  :ebs_card_index,
  :volume_id,
  :instance_id,
  :device,
  :state,
  :attach_time)
  SENSITIVE = []
  include Aws::Structure
end

#ebs_card_indexInteger

The index of the EBS card. Some instance types support multiple EBS cards. The default EBS card index is 0.

Returns:

  • (Integer)


90159
90160
90161
90162
90163
90164
90165
90166
90167
90168
90169
90170
90171
# File 'lib/aws-sdk-ec2/types.rb', line 90159

class VolumeAttachment < Struct.new(
  :delete_on_termination,
  :associated_resource,
  :instance_owning_service,
  :ebs_card_index,
  :volume_id,
  :instance_id,
  :device,
  :state,
  :attach_time)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The ID of the instance.

If the volume is attached to an Amazon Web Services-managed resource, this parameter returns null.

Returns:

  • (String)


90159
90160
90161
90162
90163
90164
90165
90166
90167
90168
90169
90170
90171
# File 'lib/aws-sdk-ec2/types.rb', line 90159

class VolumeAttachment < Struct.new(
  :delete_on_termination,
  :associated_resource,
  :instance_owning_service,
  :ebs_card_index,
  :volume_id,
  :instance_id,
  :device,
  :state,
  :attach_time)
  SENSITIVE = []
  include Aws::Structure
end

#instance_owning_serviceString

The service principal of the Amazon Web Services service that owns the underlying resource to which the volume is attached.

This parameter is returned only for volumes that are attached to Amazon Web Services-managed resources.

Returns:

  • (String)


90159
90160
90161
90162
90163
90164
90165
90166
90167
90168
90169
90170
90171
# File 'lib/aws-sdk-ec2/types.rb', line 90159

class VolumeAttachment < Struct.new(
  :delete_on_termination,
  :associated_resource,
  :instance_owning_service,
  :ebs_card_index,
  :volume_id,
  :instance_id,
  :device,
  :state,
  :attach_time)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The attachment state of the volume.

Returns:

  • (String)


90159
90160
90161
90162
90163
90164
90165
90166
90167
90168
90169
90170
90171
# File 'lib/aws-sdk-ec2/types.rb', line 90159

class VolumeAttachment < Struct.new(
  :delete_on_termination,
  :associated_resource,
  :instance_owning_service,
  :ebs_card_index,
  :volume_id,
  :instance_id,
  :device,
  :state,
  :attach_time)
  SENSITIVE = []
  include Aws::Structure
end

#volume_idString

The ID of the volume.

Returns:

  • (String)


90159
90160
90161
90162
90163
90164
90165
90166
90167
90168
90169
90170
90171
# File 'lib/aws-sdk-ec2/types.rb', line 90159

class VolumeAttachment < Struct.new(
  :delete_on_termination,
  :associated_resource,
  :instance_owning_service,
  :ebs_card_index,
  :volume_id,
  :instance_id,
  :device,
  :state,
  :attach_time)
  SENSITIVE = []
  include Aws::Structure
end