Class: Aws::EC2::Types::VolumeModification

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes the modification status of an EBS volume.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#end_timeTime

The modification completion or failure time.

Returns:

  • (Time)


86245
86246
86247
86248
86249
86250
86251
86252
86253
86254
86255
86256
86257
86258
86259
86260
86261
86262
86263
86264
86265
# File 'lib/aws-sdk-ec2/types.rb', line 86245

class VolumeModification < Struct.new(
  :volume_id,
  :modification_state,
  :status_message,
  :target_size,
  :target_iops,
  :target_volume_type,
  :target_throughput,
  :target_multi_attach_enabled,
  :original_size,
  :original_iops,
  :original_volume_type,
  :original_throughput,
  :original_multi_attach_enabled,
  :progress,
  :start_time,
  :end_time,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end

#modification_stateString

The current modification state.

Returns:

  • (String)


86245
86246
86247
86248
86249
86250
86251
86252
86253
86254
86255
86256
86257
86258
86259
86260
86261
86262
86263
86264
86265
# File 'lib/aws-sdk-ec2/types.rb', line 86245

class VolumeModification < Struct.new(
  :volume_id,
  :modification_state,
  :status_message,
  :target_size,
  :target_iops,
  :target_volume_type,
  :target_throughput,
  :target_multi_attach_enabled,
  :original_size,
  :original_iops,
  :original_volume_type,
  :original_throughput,
  :original_multi_attach_enabled,
  :progress,
  :start_time,
  :end_time,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end

#operatorTypes::OperatorResponse

Describes whether the resource is managed by a service provider and, if so, describes the service provider that manages it.



86245
86246
86247
86248
86249
86250
86251
86252
86253
86254
86255
86256
86257
86258
86259
86260
86261
86262
86263
86264
86265
# File 'lib/aws-sdk-ec2/types.rb', line 86245

class VolumeModification < Struct.new(
  :volume_id,
  :modification_state,
  :status_message,
  :target_size,
  :target_iops,
  :target_volume_type,
  :target_throughput,
  :target_multi_attach_enabled,
  :original_size,
  :original_iops,
  :original_volume_type,
  :original_throughput,
  :original_multi_attach_enabled,
  :progress,
  :start_time,
  :end_time,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end

#original_iopsInteger

The original IOPS rate of the volume.

Returns:

  • (Integer)


86245
86246
86247
86248
86249
86250
86251
86252
86253
86254
86255
86256
86257
86258
86259
86260
86261
86262
86263
86264
86265
# File 'lib/aws-sdk-ec2/types.rb', line 86245

class VolumeModification < Struct.new(
  :volume_id,
  :modification_state,
  :status_message,
  :target_size,
  :target_iops,
  :target_volume_type,
  :target_throughput,
  :target_multi_attach_enabled,
  :original_size,
  :original_iops,
  :original_volume_type,
  :original_throughput,
  :original_multi_attach_enabled,
  :progress,
  :start_time,
  :end_time,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end

#original_multi_attach_enabledBoolean

The original setting for Amazon EBS Multi-Attach.

Returns:

  • (Boolean)


86245
86246
86247
86248
86249
86250
86251
86252
86253
86254
86255
86256
86257
86258
86259
86260
86261
86262
86263
86264
86265
# File 'lib/aws-sdk-ec2/types.rb', line 86245

class VolumeModification < Struct.new(
  :volume_id,
  :modification_state,
  :status_message,
  :target_size,
  :target_iops,
  :target_volume_type,
  :target_throughput,
  :target_multi_attach_enabled,
  :original_size,
  :original_iops,
  :original_volume_type,
  :original_throughput,
  :original_multi_attach_enabled,
  :progress,
  :start_time,
  :end_time,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end

#original_sizeInteger

The original size of the volume, in GiB.

Returns:

  • (Integer)


86245
86246
86247
86248
86249
86250
86251
86252
86253
86254
86255
86256
86257
86258
86259
86260
86261
86262
86263
86264
86265
# File 'lib/aws-sdk-ec2/types.rb', line 86245

class VolumeModification < Struct.new(
  :volume_id,
  :modification_state,
  :status_message,
  :target_size,
  :target_iops,
  :target_volume_type,
  :target_throughput,
  :target_multi_attach_enabled,
  :original_size,
  :original_iops,
  :original_volume_type,
  :original_throughput,
  :original_multi_attach_enabled,
  :progress,
  :start_time,
  :end_time,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end

#original_throughputInteger

The original throughput of the volume, in MiB/s.

Returns:

  • (Integer)


86245
86246
86247
86248
86249
86250
86251
86252
86253
86254
86255
86256
86257
86258
86259
86260
86261
86262
86263
86264
86265
# File 'lib/aws-sdk-ec2/types.rb', line 86245

class VolumeModification < Struct.new(
  :volume_id,
  :modification_state,
  :status_message,
  :target_size,
  :target_iops,
  :target_volume_type,
  :target_throughput,
  :target_multi_attach_enabled,
  :original_size,
  :original_iops,
  :original_volume_type,
  :original_throughput,
  :original_multi_attach_enabled,
  :progress,
  :start_time,
  :end_time,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end

#original_volume_typeString

The original EBS volume type of the volume.

Returns:

  • (String)


86245
86246
86247
86248
86249
86250
86251
86252
86253
86254
86255
86256
86257
86258
86259
86260
86261
86262
86263
86264
86265
# File 'lib/aws-sdk-ec2/types.rb', line 86245

class VolumeModification < Struct.new(
  :volume_id,
  :modification_state,
  :status_message,
  :target_size,
  :target_iops,
  :target_volume_type,
  :target_throughput,
  :target_multi_attach_enabled,
  :original_size,
  :original_iops,
  :original_volume_type,
  :original_throughput,
  :original_multi_attach_enabled,
  :progress,
  :start_time,
  :end_time,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end

#progressInteger

The modification progress, from 0 to 100 percent complete.

Returns:

  • (Integer)


86245
86246
86247
86248
86249
86250
86251
86252
86253
86254
86255
86256
86257
86258
86259
86260
86261
86262
86263
86264
86265
# File 'lib/aws-sdk-ec2/types.rb', line 86245

class VolumeModification < Struct.new(
  :volume_id,
  :modification_state,
  :status_message,
  :target_size,
  :target_iops,
  :target_volume_type,
  :target_throughput,
  :target_multi_attach_enabled,
  :original_size,
  :original_iops,
  :original_volume_type,
  :original_throughput,
  :original_multi_attach_enabled,
  :progress,
  :start_time,
  :end_time,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The modification start time.

Returns:

  • (Time)


86245
86246
86247
86248
86249
86250
86251
86252
86253
86254
86255
86256
86257
86258
86259
86260
86261
86262
86263
86264
86265
# File 'lib/aws-sdk-ec2/types.rb', line 86245

class VolumeModification < Struct.new(
  :volume_id,
  :modification_state,
  :status_message,
  :target_size,
  :target_iops,
  :target_volume_type,
  :target_throughput,
  :target_multi_attach_enabled,
  :original_size,
  :original_iops,
  :original_volume_type,
  :original_throughput,
  :original_multi_attach_enabled,
  :progress,
  :start_time,
  :end_time,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end

#status_messageString

A status message about the modification progress or failure.

Returns:

  • (String)


86245
86246
86247
86248
86249
86250
86251
86252
86253
86254
86255
86256
86257
86258
86259
86260
86261
86262
86263
86264
86265
# File 'lib/aws-sdk-ec2/types.rb', line 86245

class VolumeModification < Struct.new(
  :volume_id,
  :modification_state,
  :status_message,
  :target_size,
  :target_iops,
  :target_volume_type,
  :target_throughput,
  :target_multi_attach_enabled,
  :original_size,
  :original_iops,
  :original_volume_type,
  :original_throughput,
  :original_multi_attach_enabled,
  :progress,
  :start_time,
  :end_time,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end

#target_iopsInteger

The target IOPS rate of the volume.

Returns:

  • (Integer)


86245
86246
86247
86248
86249
86250
86251
86252
86253
86254
86255
86256
86257
86258
86259
86260
86261
86262
86263
86264
86265
# File 'lib/aws-sdk-ec2/types.rb', line 86245

class VolumeModification < Struct.new(
  :volume_id,
  :modification_state,
  :status_message,
  :target_size,
  :target_iops,
  :target_volume_type,
  :target_throughput,
  :target_multi_attach_enabled,
  :original_size,
  :original_iops,
  :original_volume_type,
  :original_throughput,
  :original_multi_attach_enabled,
  :progress,
  :start_time,
  :end_time,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end

#target_multi_attach_enabledBoolean

The target setting for Amazon EBS Multi-Attach.

Returns:

  • (Boolean)


86245
86246
86247
86248
86249
86250
86251
86252
86253
86254
86255
86256
86257
86258
86259
86260
86261
86262
86263
86264
86265
# File 'lib/aws-sdk-ec2/types.rb', line 86245

class VolumeModification < Struct.new(
  :volume_id,
  :modification_state,
  :status_message,
  :target_size,
  :target_iops,
  :target_volume_type,
  :target_throughput,
  :target_multi_attach_enabled,
  :original_size,
  :original_iops,
  :original_volume_type,
  :original_throughput,
  :original_multi_attach_enabled,
  :progress,
  :start_time,
  :end_time,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end

#target_sizeInteger

The target size of the volume, in GiB.

Returns:

  • (Integer)


86245
86246
86247
86248
86249
86250
86251
86252
86253
86254
86255
86256
86257
86258
86259
86260
86261
86262
86263
86264
86265
# File 'lib/aws-sdk-ec2/types.rb', line 86245

class VolumeModification < Struct.new(
  :volume_id,
  :modification_state,
  :status_message,
  :target_size,
  :target_iops,
  :target_volume_type,
  :target_throughput,
  :target_multi_attach_enabled,
  :original_size,
  :original_iops,
  :original_volume_type,
  :original_throughput,
  :original_multi_attach_enabled,
  :progress,
  :start_time,
  :end_time,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end

#target_throughputInteger

The target throughput of the volume, in MiB/s.

Returns:

  • (Integer)


86245
86246
86247
86248
86249
86250
86251
86252
86253
86254
86255
86256
86257
86258
86259
86260
86261
86262
86263
86264
86265
# File 'lib/aws-sdk-ec2/types.rb', line 86245

class VolumeModification < Struct.new(
  :volume_id,
  :modification_state,
  :status_message,
  :target_size,
  :target_iops,
  :target_volume_type,
  :target_throughput,
  :target_multi_attach_enabled,
  :original_size,
  :original_iops,
  :original_volume_type,
  :original_throughput,
  :original_multi_attach_enabled,
  :progress,
  :start_time,
  :end_time,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end

#target_volume_typeString

The target EBS volume type of the volume.

Returns:

  • (String)


86245
86246
86247
86248
86249
86250
86251
86252
86253
86254
86255
86256
86257
86258
86259
86260
86261
86262
86263
86264
86265
# File 'lib/aws-sdk-ec2/types.rb', line 86245

class VolumeModification < Struct.new(
  :volume_id,
  :modification_state,
  :status_message,
  :target_size,
  :target_iops,
  :target_volume_type,
  :target_throughput,
  :target_multi_attach_enabled,
  :original_size,
  :original_iops,
  :original_volume_type,
  :original_throughput,
  :original_multi_attach_enabled,
  :progress,
  :start_time,
  :end_time,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end

#volume_idString

The ID of the volume.

Returns:

  • (String)


86245
86246
86247
86248
86249
86250
86251
86252
86253
86254
86255
86256
86257
86258
86259
86260
86261
86262
86263
86264
86265
# File 'lib/aws-sdk-ec2/types.rb', line 86245

class VolumeModification < Struct.new(
  :volume_id,
  :modification_state,
  :status_message,
  :target_size,
  :target_iops,
  :target_volume_type,
  :target_throughput,
  :target_multi_attach_enabled,
  :original_size,
  :original_iops,
  :original_volume_type,
  :original_throughput,
  :original_multi_attach_enabled,
  :progress,
  :start_time,
  :end_time,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end