Class: Aws::EC2::Types::VpcBlockPublicAccessExclusion
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::VpcBlockPublicAccessExclusion
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
A VPC BPA exclusion is a mode that can be applied to a single VPC or subnet that exempts it from the account’s BPA mode and will allow bidirectional or egress-only access. You can create BPA exclusions for VPCs and subnets even when BPA is not enabled on the account to ensure that there is no traffic disruption to the exclusions when VPC BPA is turned on. To learn more about VPC BPA, see Block public access to VPCs and subnets in the Amazon VPC User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ Time
When the exclusion was created.
-
#deletion_timestamp ⇒ Time
When the exclusion was deleted.
-
#exclusion_id ⇒ String
The ID of the exclusion.
-
#internet_gateway_exclusion_mode ⇒ String
The exclusion mode for internet gateway traffic.
-
#last_update_timestamp ⇒ Time
When the exclusion was last updated.
-
#reason ⇒ String
The reason for the current exclusion state.
-
#resource_arn ⇒ String
The ARN of the exclusion.
-
#state ⇒ String
The state of the exclusion.
-
#tags ⇒ Array<Types::Tag>
tag- The key/value combination of a tag assigned to the resource.
Instance Attribute Details
#creation_timestamp ⇒ Time
When the exclusion was created.
89280 89281 89282 89283 89284 89285 89286 89287 89288 89289 89290 89291 89292 |
# File 'lib/aws-sdk-ec2/types.rb', line 89280 class VpcBlockPublicAccessExclusion < Struct.new( :exclusion_id, :internet_gateway_exclusion_mode, :resource_arn, :state, :reason, :creation_timestamp, :last_update_timestamp, :deletion_timestamp, :tags) SENSITIVE = [] include Aws::Structure end |
#deletion_timestamp ⇒ Time
When the exclusion was deleted.
89280 89281 89282 89283 89284 89285 89286 89287 89288 89289 89290 89291 89292 |
# File 'lib/aws-sdk-ec2/types.rb', line 89280 class VpcBlockPublicAccessExclusion < Struct.new( :exclusion_id, :internet_gateway_exclusion_mode, :resource_arn, :state, :reason, :creation_timestamp, :last_update_timestamp, :deletion_timestamp, :tags) SENSITIVE = [] include Aws::Structure end |
#exclusion_id ⇒ String
The ID of the exclusion.
89280 89281 89282 89283 89284 89285 89286 89287 89288 89289 89290 89291 89292 |
# File 'lib/aws-sdk-ec2/types.rb', line 89280 class VpcBlockPublicAccessExclusion < Struct.new( :exclusion_id, :internet_gateway_exclusion_mode, :resource_arn, :state, :reason, :creation_timestamp, :last_update_timestamp, :deletion_timestamp, :tags) SENSITIVE = [] include Aws::Structure end |
#internet_gateway_exclusion_mode ⇒ String
The exclusion mode for internet gateway traffic.
-
allow-bidirectional: Allow all internet traffic to and from the excluded VPCs and subnets. -
allow-egress: Allow outbound internet traffic from the excluded VPCs and subnets. Block inbound internet traffic to the excluded VPCs and subnets. Only applies when VPC Block Public Access is set to Bidirectional.
89280 89281 89282 89283 89284 89285 89286 89287 89288 89289 89290 89291 89292 |
# File 'lib/aws-sdk-ec2/types.rb', line 89280 class VpcBlockPublicAccessExclusion < Struct.new( :exclusion_id, :internet_gateway_exclusion_mode, :resource_arn, :state, :reason, :creation_timestamp, :last_update_timestamp, :deletion_timestamp, :tags) SENSITIVE = [] include Aws::Structure end |
#last_update_timestamp ⇒ Time
When the exclusion was last updated.
89280 89281 89282 89283 89284 89285 89286 89287 89288 89289 89290 89291 89292 |
# File 'lib/aws-sdk-ec2/types.rb', line 89280 class VpcBlockPublicAccessExclusion < Struct.new( :exclusion_id, :internet_gateway_exclusion_mode, :resource_arn, :state, :reason, :creation_timestamp, :last_update_timestamp, :deletion_timestamp, :tags) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ String
The reason for the current exclusion state.
89280 89281 89282 89283 89284 89285 89286 89287 89288 89289 89290 89291 89292 |
# File 'lib/aws-sdk-ec2/types.rb', line 89280 class VpcBlockPublicAccessExclusion < Struct.new( :exclusion_id, :internet_gateway_exclusion_mode, :resource_arn, :state, :reason, :creation_timestamp, :last_update_timestamp, :deletion_timestamp, :tags) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The ARN of the exclusion.
89280 89281 89282 89283 89284 89285 89286 89287 89288 89289 89290 89291 89292 |
# File 'lib/aws-sdk-ec2/types.rb', line 89280 class VpcBlockPublicAccessExclusion < Struct.new( :exclusion_id, :internet_gateway_exclusion_mode, :resource_arn, :state, :reason, :creation_timestamp, :last_update_timestamp, :deletion_timestamp, :tags) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the exclusion.
89280 89281 89282 89283 89284 89285 89286 89287 89288 89289 89290 89291 89292 |
# File 'lib/aws-sdk-ec2/types.rb', line 89280 class VpcBlockPublicAccessExclusion < Struct.new( :exclusion_id, :internet_gateway_exclusion_mode, :resource_arn, :state, :reason, :creation_timestamp, :last_update_timestamp, :deletion_timestamp, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
tag - The key/value combination of a tag assigned to the resource.
Use the tag key in the filter name and the tag value as the filter
value. For example, to find all resources that have a tag with the
key Owner and the value TeamA, specify tag:Owner for the
filter name and TeamA for the filter value.
89280 89281 89282 89283 89284 89285 89286 89287 89288 89289 89290 89291 89292 |
# File 'lib/aws-sdk-ec2/types.rb', line 89280 class VpcBlockPublicAccessExclusion < Struct.new( :exclusion_id, :internet_gateway_exclusion_mode, :resource_arn, :state, :reason, :creation_timestamp, :last_update_timestamp, :deletion_timestamp, :tags) SENSITIVE = [] include Aws::Structure end |