Class: Aws::EC2::Types::VpcEncryptionControlExclusion
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::VpcEncryptionControlExclusion
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes an exclusion configuration for VPC Encryption Control.
For more information, see Enforce VPC encryption in transit in the Amazon VPC User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#state ⇒ String
The current state of the exclusion configuration.
-
#state_message ⇒ String
A message providing additional information about the exclusion state.
Instance Attribute Details
#state ⇒ String
The current state of the exclusion configuration.
87334 87335 87336 87337 87338 87339 |
# File 'lib/aws-sdk-ec2/types.rb', line 87334 class VpcEncryptionControlExclusion < Struct.new( :state, :state_message) SENSITIVE = [] include Aws::Structure end |
#state_message ⇒ String
A message providing additional information about the exclusion state.
87334 87335 87336 87337 87338 87339 |
# File 'lib/aws-sdk-ec2/types.rb', line 87334 class VpcEncryptionControlExclusion < Struct.new( :state, :state_message) SENSITIVE = [] include Aws::Structure end |