Class: Aws::EC2::Types::VpcEncryptionNonCompliantResource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes a resource that is not compliant with VPC encryption requirements.

For more information, see Enforce VPC encryption in transit in the Amazon VPC User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description of the non-compliant resource.

Returns:

  • (String)


91120
91121
91122
91123
91124
91125
91126
91127
# File 'lib/aws-sdk-ec2/types.rb', line 91120

class VpcEncryptionNonCompliantResource < Struct.new(
  :id,
  :type,
  :description,
  :is_excludable)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the non-compliant resource.

Returns:

  • (String)


91120
91121
91122
91123
91124
91125
91126
91127
# File 'lib/aws-sdk-ec2/types.rb', line 91120

class VpcEncryptionNonCompliantResource < Struct.new(
  :id,
  :type,
  :description,
  :is_excludable)
  SENSITIVE = []
  include Aws::Structure
end

#is_excludableBoolean

Indicates whether the resource can be excluded from encryption enforcement.

Returns:

  • (Boolean)


91120
91121
91122
91123
91124
91125
91126
91127
# File 'lib/aws-sdk-ec2/types.rb', line 91120

class VpcEncryptionNonCompliantResource < Struct.new(
  :id,
  :type,
  :description,
  :is_excludable)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the non-compliant resource.

Returns:

  • (String)


91120
91121
91122
91123
91124
91125
91126
91127
# File 'lib/aws-sdk-ec2/types.rb', line 91120

class VpcEncryptionNonCompliantResource < Struct.new(
  :id,
  :type,
  :description,
  :is_excludable)
  SENSITIVE = []
  include Aws::Structure
end