Class: Aws::EC2::Types::VpcEndpointAssociation
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::VpcEndpointAssociation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the VPC resources, VPC endpoint services, Lattice services, or service networks associated with the VPC endpoint.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#associated_resource_accessibility ⇒ String
The connectivity status of the resources associated to a VPC endpoint.
-
#associated_resource_arn ⇒ String
The Amazon Resource Name (ARN) of the associated resource.
-
#dns_entry ⇒ Types::DnsEntry
The DNS entry of the VPC endpoint association.
-
#failure_code ⇒ String
An error code related to why an VPC endpoint association failed.
-
#failure_reason ⇒ String
A message related to why an VPC endpoint association failed.
-
#id ⇒ String
The ID of the VPC endpoint association.
-
#private_dns_entry ⇒ Types::DnsEntry
The private DNS entry of the VPC endpoint association.
-
#resource_configuration_group_arn ⇒ String
The Amazon Resource Name (ARN) of the resource configuration group.
-
#service_network_arn ⇒ String
The Amazon Resource Name (ARN) of the service network.
-
#service_network_name ⇒ String
The name of the service network.
-
#tags ⇒ Array<Types::Tag>
The tags to apply to the VPC endpoint association.
-
#vpc_endpoint_id ⇒ String
The ID of the VPC endpoint.
Instance Attribute Details
#associated_resource_accessibility ⇒ String
The connectivity status of the resources associated to a VPC
endpoint. The resource is accessible if the associated resource
configuration is AVAILABLE, otherwise the resource is
inaccessible.
91471 91472 91473 91474 91475 91476 91477 91478 91479 91480 91481 91482 91483 91484 91485 91486 |
# File 'lib/aws-sdk-ec2/types.rb', line 91471 class VpcEndpointAssociation < Struct.new( :id, :vpc_endpoint_id, :service_network_arn, :service_network_name, :associated_resource_accessibility, :failure_reason, :failure_code, :dns_entry, :private_dns_entry, :associated_resource_arn, :resource_configuration_group_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#associated_resource_arn ⇒ String
The Amazon Resource Name (ARN) of the associated resource.
91471 91472 91473 91474 91475 91476 91477 91478 91479 91480 91481 91482 91483 91484 91485 91486 |
# File 'lib/aws-sdk-ec2/types.rb', line 91471 class VpcEndpointAssociation < Struct.new( :id, :vpc_endpoint_id, :service_network_arn, :service_network_name, :associated_resource_accessibility, :failure_reason, :failure_code, :dns_entry, :private_dns_entry, :associated_resource_arn, :resource_configuration_group_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#dns_entry ⇒ Types::DnsEntry
The DNS entry of the VPC endpoint association.
91471 91472 91473 91474 91475 91476 91477 91478 91479 91480 91481 91482 91483 91484 91485 91486 |
# File 'lib/aws-sdk-ec2/types.rb', line 91471 class VpcEndpointAssociation < Struct.new( :id, :vpc_endpoint_id, :service_network_arn, :service_network_name, :associated_resource_accessibility, :failure_reason, :failure_code, :dns_entry, :private_dns_entry, :associated_resource_arn, :resource_configuration_group_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#failure_code ⇒ String
An error code related to why an VPC endpoint association failed.
91471 91472 91473 91474 91475 91476 91477 91478 91479 91480 91481 91482 91483 91484 91485 91486 |
# File 'lib/aws-sdk-ec2/types.rb', line 91471 class VpcEndpointAssociation < Struct.new( :id, :vpc_endpoint_id, :service_network_arn, :service_network_name, :associated_resource_accessibility, :failure_reason, :failure_code, :dns_entry, :private_dns_entry, :associated_resource_arn, :resource_configuration_group_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
A message related to why an VPC endpoint association failed.
91471 91472 91473 91474 91475 91476 91477 91478 91479 91480 91481 91482 91483 91484 91485 91486 |
# File 'lib/aws-sdk-ec2/types.rb', line 91471 class VpcEndpointAssociation < Struct.new( :id, :vpc_endpoint_id, :service_network_arn, :service_network_name, :associated_resource_accessibility, :failure_reason, :failure_code, :dns_entry, :private_dns_entry, :associated_resource_arn, :resource_configuration_group_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the VPC endpoint association.
91471 91472 91473 91474 91475 91476 91477 91478 91479 91480 91481 91482 91483 91484 91485 91486 |
# File 'lib/aws-sdk-ec2/types.rb', line 91471 class VpcEndpointAssociation < Struct.new( :id, :vpc_endpoint_id, :service_network_arn, :service_network_name, :associated_resource_accessibility, :failure_reason, :failure_code, :dns_entry, :private_dns_entry, :associated_resource_arn, :resource_configuration_group_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#private_dns_entry ⇒ Types::DnsEntry
The private DNS entry of the VPC endpoint association.
91471 91472 91473 91474 91475 91476 91477 91478 91479 91480 91481 91482 91483 91484 91485 91486 |
# File 'lib/aws-sdk-ec2/types.rb', line 91471 class VpcEndpointAssociation < Struct.new( :id, :vpc_endpoint_id, :service_network_arn, :service_network_name, :associated_resource_accessibility, :failure_reason, :failure_code, :dns_entry, :private_dns_entry, :associated_resource_arn, :resource_configuration_group_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#resource_configuration_group_arn ⇒ String
The Amazon Resource Name (ARN) of the resource configuration group.
91471 91472 91473 91474 91475 91476 91477 91478 91479 91480 91481 91482 91483 91484 91485 91486 |
# File 'lib/aws-sdk-ec2/types.rb', line 91471 class VpcEndpointAssociation < Struct.new( :id, :vpc_endpoint_id, :service_network_arn, :service_network_name, :associated_resource_accessibility, :failure_reason, :failure_code, :dns_entry, :private_dns_entry, :associated_resource_arn, :resource_configuration_group_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#service_network_arn ⇒ String
The Amazon Resource Name (ARN) of the service network.
91471 91472 91473 91474 91475 91476 91477 91478 91479 91480 91481 91482 91483 91484 91485 91486 |
# File 'lib/aws-sdk-ec2/types.rb', line 91471 class VpcEndpointAssociation < Struct.new( :id, :vpc_endpoint_id, :service_network_arn, :service_network_name, :associated_resource_accessibility, :failure_reason, :failure_code, :dns_entry, :private_dns_entry, :associated_resource_arn, :resource_configuration_group_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#service_network_name ⇒ String
The name of the service network.
91471 91472 91473 91474 91475 91476 91477 91478 91479 91480 91481 91482 91483 91484 91485 91486 |
# File 'lib/aws-sdk-ec2/types.rb', line 91471 class VpcEndpointAssociation < Struct.new( :id, :vpc_endpoint_id, :service_network_arn, :service_network_name, :associated_resource_accessibility, :failure_reason, :failure_code, :dns_entry, :private_dns_entry, :associated_resource_arn, :resource_configuration_group_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags to apply to the VPC endpoint association.
91471 91472 91473 91474 91475 91476 91477 91478 91479 91480 91481 91482 91483 91484 91485 91486 |
# File 'lib/aws-sdk-ec2/types.rb', line 91471 class VpcEndpointAssociation < Struct.new( :id, :vpc_endpoint_id, :service_network_arn, :service_network_name, :associated_resource_accessibility, :failure_reason, :failure_code, :dns_entry, :private_dns_entry, :associated_resource_arn, :resource_configuration_group_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#vpc_endpoint_id ⇒ String
The ID of the VPC endpoint.
91471 91472 91473 91474 91475 91476 91477 91478 91479 91480 91481 91482 91483 91484 91485 91486 |
# File 'lib/aws-sdk-ec2/types.rb', line 91471 class VpcEndpointAssociation < Struct.new( :id, :vpc_endpoint_id, :service_network_arn, :service_network_name, :associated_resource_accessibility, :failure_reason, :failure_code, :dns_entry, :private_dns_entry, :associated_resource_arn, :resource_configuration_group_arn, :tags) SENSITIVE = [] include Aws::Structure end |