Class: Aws::EC2::Types::VpcPeeringConnection

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes a VPC peering connection.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#accepter_vpc_infoTypes::VpcPeeringConnectionVpcInfo

Information about the accepter VPC. CIDR block information is only returned when describing an active VPC peering connection.



84964
84965
84966
84967
84968
84969
84970
84971
84972
84973
# File 'lib/aws-sdk-ec2/types.rb', line 84964

class VpcPeeringConnection < Struct.new(
  :accepter_vpc_info,
  :expiration_time,
  :requester_vpc_info,
  :status,
  :tags,
  :vpc_peering_connection_id)
  SENSITIVE = []
  include Aws::Structure
end

#expiration_timeTime

The time that an unaccepted VPC peering connection will expire.

Returns:

  • (Time)


84964
84965
84966
84967
84968
84969
84970
84971
84972
84973
# File 'lib/aws-sdk-ec2/types.rb', line 84964

class VpcPeeringConnection < Struct.new(
  :accepter_vpc_info,
  :expiration_time,
  :requester_vpc_info,
  :status,
  :tags,
  :vpc_peering_connection_id)
  SENSITIVE = []
  include Aws::Structure
end

#requester_vpc_infoTypes::VpcPeeringConnectionVpcInfo

Information about the requester VPC. CIDR block information is only returned when describing an active VPC peering connection.



84964
84965
84966
84967
84968
84969
84970
84971
84972
84973
# File 'lib/aws-sdk-ec2/types.rb', line 84964

class VpcPeeringConnection < Struct.new(
  :accepter_vpc_info,
  :expiration_time,
  :requester_vpc_info,
  :status,
  :tags,
  :vpc_peering_connection_id)
  SENSITIVE = []
  include Aws::Structure
end

#statusTypes::VpcPeeringConnectionStateReason

The status of the VPC peering connection.



84964
84965
84966
84967
84968
84969
84970
84971
84972
84973
# File 'lib/aws-sdk-ec2/types.rb', line 84964

class VpcPeeringConnection < Struct.new(
  :accepter_vpc_info,
  :expiration_time,
  :requester_vpc_info,
  :status,
  :tags,
  :vpc_peering_connection_id)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Any tags assigned to the resource.

Returns:



84964
84965
84966
84967
84968
84969
84970
84971
84972
84973
# File 'lib/aws-sdk-ec2/types.rb', line 84964

class VpcPeeringConnection < Struct.new(
  :accepter_vpc_info,
  :expiration_time,
  :requester_vpc_info,
  :status,
  :tags,
  :vpc_peering_connection_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_peering_connection_idString

The ID of the VPC peering connection.

Returns:

  • (String)


84964
84965
84966
84967
84968
84969
84970
84971
84972
84973
# File 'lib/aws-sdk-ec2/types.rb', line 84964

class VpcPeeringConnection < Struct.new(
  :accepter_vpc_info,
  :expiration_time,
  :requester_vpc_info,
  :status,
  :tags,
  :vpc_peering_connection_id)
  SENSITIVE = []
  include Aws::Structure
end