Class: Aws::EC2::Types::VpnConcentrator

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes a VPN concentrator.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#stateString

The current state of the VPN concentrator.

Returns:

  • (String)


85093
85094
85095
85096
85097
85098
85099
85100
85101
85102
# File 'lib/aws-sdk-ec2/types.rb', line 85093

class VpnConcentrator < Struct.new(
  :vpn_concentrator_id,
  :state,
  :transit_gateway_id,
  :transit_gateway_attachment_id,
  :type,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Any tags assigned to the VPN concentrator.

Returns:



85093
85094
85095
85096
85097
85098
85099
85100
85101
85102
# File 'lib/aws-sdk-ec2/types.rb', line 85093

class VpnConcentrator < Struct.new(
  :vpn_concentrator_id,
  :state,
  :transit_gateway_id,
  :transit_gateway_attachment_id,
  :type,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_attachment_idString

The ID of the transit gateway attachment for the VPN concentrator.

Returns:

  • (String)


85093
85094
85095
85096
85097
85098
85099
85100
85101
85102
# File 'lib/aws-sdk-ec2/types.rb', line 85093

class VpnConcentrator < Struct.new(
  :vpn_concentrator_id,
  :state,
  :transit_gateway_id,
  :transit_gateway_attachment_id,
  :type,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_idString

The ID of the transit gateway associated with the VPN concentrator.

Returns:

  • (String)


85093
85094
85095
85096
85097
85098
85099
85100
85101
85102
# File 'lib/aws-sdk-ec2/types.rb', line 85093

class VpnConcentrator < Struct.new(
  :vpn_concentrator_id,
  :state,
  :transit_gateway_id,
  :transit_gateway_attachment_id,
  :type,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of VPN concentrator.

Returns:

  • (String)


85093
85094
85095
85096
85097
85098
85099
85100
85101
85102
# File 'lib/aws-sdk-ec2/types.rb', line 85093

class VpnConcentrator < Struct.new(
  :vpn_concentrator_id,
  :state,
  :transit_gateway_id,
  :transit_gateway_attachment_id,
  :type,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#vpn_concentrator_idString

The ID of the VPN concentrator.

Returns:

  • (String)


85093
85094
85095
85096
85097
85098
85099
85100
85101
85102
# File 'lib/aws-sdk-ec2/types.rb', line 85093

class VpnConcentrator < Struct.new(
  :vpn_concentrator_id,
  :state,
  :transit_gateway_id,
  :transit_gateway_attachment_id,
  :type,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end