Class: Aws::EC2::VpcPeeringConnection

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/vpc_peering_connection.rbs,
lib/aws-sdk-ec2/vpc_peering_connection.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Associations collapse

Instance Method Summary collapse

Constructor Details

#initialize(id, options) ⇒ void #initialize(id:, client:) ⇒ void #initialize(args) ⇒ void

Overloads:

  • #initialize(id, options) ⇒ void

    Parameters:

    • id (String)
    • options (Hash[Symbol, untyped])
  • #initialize(id:, client:) ⇒ void

    Parameters:

    • id: (String)
    • client: (Client)
  • #initialize(args) ⇒ void

    Parameters:

    • args (Hash[Symbol, untyped])


22
23
24
25
26
27
28
# File 'lib/aws-sdk-ec2/vpc_peering_connection.rb', line 22

def initialize(*args)
  options = Hash === args.last ? args.pop.dup : {}
  @id = extract_id(args, options)
  @data = options.delete(:data)
  @client = options.delete(:client) || Client.new(options)
  @waiter_block_warned = false
end

Instance Method Details

#accept(options = {}) ⇒ Object



254
255
256
257
258
259
260
# File 'lib/aws-sdk-ec2/vpc_peering_connection.rb', line 254

def accept(options = {})
  options = options.merge(vpc_peering_connection_id: @id)
  resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    @client.accept_vpc_peering_connection(options)
  end
  resp.data
end

#accepter_vpcVpc?

Returns:



305
306
307
308
309
310
311
312
313
314
# File 'lib/aws-sdk-ec2/vpc_peering_connection.rb', line 305

def accepter_vpc
  if data[:accepter_vpc_info][:vpc_id]
    Vpc.new(
      id: data[:accepter_vpc_info][:vpc_id],
      client: @client
    )
  else
    nil
  end
end

#accepter_vpc_infoTypes::VpcPeeringConnectionVpcInfo



41
42
43
# File 'lib/aws-sdk-ec2/vpc_peering_connection.rb', line 41

def accepter_vpc_info
  data[:accepter_vpc_info]
end

#clientClient

Returns:



73
74
75
# File 'lib/aws-sdk-ec2/vpc_peering_connection.rb', line 73

def client
  @client
end

#dataTypes::VpcPeeringConnection



95
96
97
98
# File 'lib/aws-sdk-ec2/vpc_peering_connection.rb', line 95

def data
  load unless @data
  @data
end

#data_loaded?Boolean

Returns:

  • (Boolean)


103
104
105
# File 'lib/aws-sdk-ec2/vpc_peering_connection.rb', line 103

def data_loaded?
  !!@data
end

#delete(options = {}) ⇒ Object



274
275
276
277
278
279
280
# File 'lib/aws-sdk-ec2/vpc_peering_connection.rb', line 274

def delete(options = {})
  options = options.merge(vpc_peering_connection_id: @id)
  resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    @client.delete_vpc_peering_connection(options)
  end
  resp.data
end

#exists?(max_attempts:, delay:, before_attempt:, before_wait:) ⇒ Boolean #exists?(arg0) ⇒ Boolean

Overloads:

  • #exists?(max_attempts:, delay:, before_attempt:, before_wait:) ⇒ Boolean

    Parameters:

    • max_attempts: (Integer)
    • delay: (Numeric)
    • before_attempt: (^(Integer attempts) -)

      void]

    • before_wait: (^(Integer attempts, untyped response) -)

      void]

    Returns:

    • (Boolean)
  • #exists?(arg0) ⇒ Boolean

    Parameters:

    • arg0 (Hash[Symbol, untyped])

    Returns:

    • (Boolean)


110
111
112
113
114
115
116
117
118
119
# File 'lib/aws-sdk-ec2/vpc_peering_connection.rb', line 110

def exists?(options = {})
  begin
    wait_until_exists(options.merge(max_attempts: 1))
    true
  rescue Aws::Waiters::Errors::UnexpectedError => e
    raise e.error
  rescue Aws::Waiters::Errors::WaiterFailed
    false
  end
end

#expiration_time::Time

Returns:

  • (::Time)


47
48
49
# File 'lib/aws-sdk-ec2/vpc_peering_connection.rb', line 47

def expiration_time
  data[:expiration_time]
end

#idString Also known as: vpc_peering_connection_id

Returns:

  • (String)


33
34
35
# File 'lib/aws-sdk-ec2/vpc_peering_connection.rb', line 33

def id
  @id
end

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


330
331
332
# File 'lib/aws-sdk-ec2/vpc_peering_connection.rb', line 330

def identifiers
  { id: @id }
end

#loadself Also known as: reload

Returns:

  • (self)


83
84
85
86
87
88
89
# File 'lib/aws-sdk-ec2/vpc_peering_connection.rb', line 83

def load
  resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    @client.describe_vpc_peering_connections(vpc_peering_connection_ids: [@id])
  end
  @data = resp.vpc_peering_connections[0]
  self
end

#reject(options = {}) ⇒ Object



294
295
296
297
298
299
300
# File 'lib/aws-sdk-ec2/vpc_peering_connection.rb', line 294

def reject(options = {})
  options = options.merge(vpc_peering_connection_id: @id)
  resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    @client.reject_vpc_peering_connection(options)
  end
  resp.data
end

#requester_vpcVpc?

Returns:



317
318
319
320
321
322
323
324
325
326
# File 'lib/aws-sdk-ec2/vpc_peering_connection.rb', line 317

def requester_vpc
  if data[:requester_vpc_info][:vpc_id]
    Vpc.new(
      id: data[:requester_vpc_info][:vpc_id],
      client: @client
    )
  else
    nil
  end
end

#requester_vpc_infoTypes::VpcPeeringConnectionVpcInfo



54
55
56
# File 'lib/aws-sdk-ec2/vpc_peering_connection.rb', line 54

def requester_vpc_info
  data[:requester_vpc_info]
end

#statusTypes::VpcPeeringConnectionStateReason



60
61
62
# File 'lib/aws-sdk-ec2/vpc_peering_connection.rb', line 60

def status
  data[:status]
end

#tags::Array[Types::Tag]

Returns:



66
67
68
# File 'lib/aws-sdk-ec2/vpc_peering_connection.rb', line 66

def tags
  data[:tags]
end

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::EC2::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/aws-sdk-ec2/vpc_peering_connection.rb', line 221

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end

#wait_until_exists(max_attempts:, delay:, before_attempt:, before_wait:) ⇒ void #wait_until_exists(arg0) ⇒ void

Overloads:

  • #wait_until_exists(max_attempts:, delay:, before_attempt:, before_wait:) ⇒ void

    This method returns an undefined value.

    Parameters:

    • max_attempts: (Integer)
    • delay: (Numeric)
    • before_attempt: (^(Integer attempts) -)

      void]

    • before_wait: (^(Integer attempts, untyped response) -)

      void]

  • #wait_until_exists(arg0) ⇒ void

    This method returns an undefined value.

    Parameters:

    • arg0 (Hash[Symbol, untyped])


127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/aws-sdk-ec2/vpc_peering_connection.rb', line 127

def wait_until_exists(options = {}, &block)
  options, params = separate_params_and_options(options)
  waiter = Waiters::VpcPeeringConnectionExists.new(options)
  yield_waiter_and_warn(waiter, &block) if block_given?
  resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    waiter.wait(params.merge(vpc_peering_connection_ids: [@id]))
  end
  VpcPeeringConnection.new({
    id: @id,
    data: resp.data.vpc_peering_connections[0],
    client: @client
  })
end