Class: Aws::EC2::Waiters::ConversionTaskCompleted

Inherits:
Object
  • Object
show all
Defined in:
sig/waiters.rbs,
lib/aws-sdk-ec2/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ ConversionTaskCompleted

Returns a new instance of ConversionTaskCompleted.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 40
  • :delay (Integer) — default: 15
  • :before_attempt (Proc)
  • :before_wait (Proc)


206
207
# File 'lib/aws-sdk-ec2/waiters.rb', line 206

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



244
245
246
# File 'lib/aws-sdk-ec2/waiters.rb', line 244

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeConversionTasksResult

Returns a response object which responds to the following methods:

Options Hash (params):

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

  • :conversion_task_ids (Array<String>)

    The conversion task IDs.

Returns:



239
# File 'lib/aws-sdk-ec2/waiters.rb', line 239

def wait: (