Class: Aws::EC2::Waiters::ExportTaskCancelled
- Inherits:
-
Object
- Object
- Aws::EC2::Waiters::ExportTaskCancelled
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-ec2/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ExportTaskCancelled
constructor
A new instance of ExportTaskCancelled.
-
#wait(params = {}) ⇒ Types::DescribeExportTasksResult
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ExportTaskCancelled
Returns a new instance of ExportTaskCancelled.
342 343 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 342
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
366 367 368 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 366 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeExportTasksResult
Returns a response object which responds to the following methods:
- #export_tasks => Array<Types::ExportTask>
361 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 361
def wait: (
|