Class: Aws::EC2::Waiters::ImageUsageReportAvailable

Inherits:
Object
  • Object
show all
Defined in:
sig/waiters.rbs,
lib/aws-sdk-ec2/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ ImageUsageReportAvailable

Returns a new instance of ImageUsageReportAvailable.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 40
  • :delay (Integer) — default: 15
  • :before_attempt (Proc)
  • :before_wait (Proc)


501
502
# File 'lib/aws-sdk-ec2/waiters.rb', line 501

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



533
534
535
# File 'lib/aws-sdk-ec2/waiters.rb', line 533

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeImageUsageReportsResult

Returns a response object which responds to the following methods:

Options Hash (params):

  • :image_ids (Array<String>)

    The IDs of the images for filtering the reports. If specified, only reports containing these images are returned.

  • :report_ids (Array<String>)

    The IDs of the image usage reports.

  • :next_token (String)

    The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

  • :filters (Array<Types::Filter>)

    The filters.

    • creation-time - The time when the report was created, in the ISO 8601 format in the UTC time zone (YYYY-MM-DDThh:mm:ss.sssZ), for example, 2025-11-29T11:04:43.305Z. You can use a wildcard (*), for example, 2025-11-29T*, which matches an entire day.

    • state - The state of the report (available | pending | error).

    • tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.

    • tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

  • :max_results (Integer)

    The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.

Returns:



528
# File 'lib/aws-sdk-ec2/waiters.rb', line 528

def wait: (