Class: Aws::EC2::Waiters::NatGatewayAvailable
- Inherits:
-
Object
- Object
- Aws::EC2::Waiters::NatGatewayAvailable
- Defined in:
- lib/aws-sdk-ec2/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ NatGatewayAvailable
constructor
A new instance of NatGatewayAvailable.
-
#wait(params = {}) ⇒ Types::DescribeNatGatewaysResult
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ NatGatewayAvailable
Returns a new instance of NatGatewayAvailable.
878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 878 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 40, delay: 15, poller: Aws::Waiters::Poller.new( operation_name: :describe_nat_gateways, acceptors: [ { "state" => "success", "matcher" => "pathAll", "argument" => "nat_gateways[].state", "expected" => "available" }, { "state" => "failure", "matcher" => "pathAny", "argument" => "nat_gateways[].state", "expected" => "failed" }, { "state" => "failure", "matcher" => "pathAny", "argument" => "nat_gateways[].state", "expected" => "deleting" }, { "state" => "failure", "matcher" => "pathAny", "argument" => "nat_gateways[].state", "expected" => "deleted" }, { "state" => "retry", "matcher" => "error", "expected" => "NatGatewayNotFound" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
927 928 929 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 927 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeNatGatewaysResult
Returns a response object which responds to the following methods:
-
#nat_gateways => Array<Types::NatGateway>
-
#next_token => String
922 923 924 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 922 def wait(params = {}) @waiter.wait(client: @client, params: params) end |