Class: Aws::EC2::Waiters::NatGatewayDeleted

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-ec2/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ NatGatewayDeleted

Returns a new instance of NatGatewayDeleted.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 40
  • :delay (Integer) — default: 15
  • :before_attempt (Proc)
  • :before_wait (Proc)


935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
# File 'lib/aws-sdk-ec2/waiters.rb', line 935

def initialize(options)
  @client = options.fetch(:client)
  @waiter = Aws::Waiters::Waiter.new({
    max_attempts: 40,
    delay: 15,
    poller: Aws::Waiters::Poller.new(
      operation_name: :describe_nat_gateways,
      acceptors: [
        {
          "state" => "success",
          "matcher" => "pathAll",
          "argument" => "nat_gateways[].state",
          "expected" => "deleted"
        },
        {
          "state" => "success",
          "matcher" => "error",
          "expected" => "NatGatewayNotFound"
        }
      ]
    )
  }.merge(options))
end

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



966
967
968
# File 'lib/aws-sdk-ec2/waiters.rb', line 966

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeNatGatewaysResult

Returns a response object which responds to the following methods:

Options Hash (params):

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

  • :filter (Array<Types::Filter>)

    The filters.

    • ‘nat-gateway-id` - The ID of the NAT gateway.

    • ‘state` - The state of the NAT gateway (`pending` | `failed` | `available` | `deleting` | `deleted`).

    • ‘subnet-id` - The ID of the subnet in which the NAT gateway resides.

    • ‘tag` - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key `Owner` and the value `TeamA`, specify `tag:Owner` for the filter name and `TeamA` for the filter value.

    • ‘tag-key` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.

    • ‘vpc-id` - The ID of the VPC in which the NAT gateway resides.

  • :max_results (Integer)

    The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].

    [1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination

  • :nat_gateway_ids (Array<String>)

    The IDs of the NAT gateways.

  • :next_token (String)

    The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Returns:



961
962
963
# File 'lib/aws-sdk-ec2/waiters.rb', line 961

def wait(params = {})
  @waiter.wait(client: @client, params: params)
end