Class: Aws::EC2::Waiters::PasswordDataAvailable

Inherits:
Object
  • Object
show all
Defined in:
sig/waiters.rbs,
lib/aws-sdk-ec2/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ PasswordDataAvailable

Returns a new instance of PasswordDataAvailable.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 40
  • :delay (Integer) — default: 15
  • :before_attempt (Proc)
  • :before_wait (Proc)


1025
1026
# File 'lib/aws-sdk-ec2/waiters.rb', line 1025

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



1049
1050
1051
# File 'lib/aws-sdk-ec2/waiters.rb', line 1049

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::GetPasswordDataResult

Returns a response object which responds to the following methods:

Options Hash (params):

  • :instance_id (required, String)

    The ID of the Windows instance.

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:



1044
# File 'lib/aws-sdk-ec2/waiters.rb', line 1044

def wait: (