Class: Aws::EC2::Waiters::SecondaryNetworkCreateComplete

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-ec2/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ SecondaryNetworkCreateComplete

Returns a new instance of SecondaryNetworkCreateComplete.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 30
  • :delay (Integer) — default: 10
  • :before_attempt (Proc)
  • :before_wait (Proc)


1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
# File 'lib/aws-sdk-ec2/waiters.rb', line 1061

def initialize(options)
  @client = options.fetch(:client)
  @waiter = Aws::Waiters::Waiter.new({
    max_attempts: 30,
    delay: 10,
    poller: Aws::Waiters::Poller.new(
      operation_name: :describe_secondary_networks,
      acceptors: [
        {
          "expected" => "create-complete",
          "matcher" => "pathAll",
          "state" => "success",
          "argument" => "secondary_networks[].state"
        },
        {
          "expected" => "create-failed",
          "matcher" => "pathAny",
          "state" => "failure",
          "argument" => "secondary_networks[].state"
        },
        {
          "matcher" => "error",
          "expected" => "InvalidSecondaryNetworkId.NotFound",
          "state" => "retry"
        }
      ]
    )
  }.merge(options))
end

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



1098
1099
1100
# File 'lib/aws-sdk-ec2/waiters.rb', line 1098

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeSecondaryNetworksResult

Returns a response object which responds to the following methods:

Options Hash (params):

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

  • :filters (Array<Types::Filter>)

    The filters. The following are the possible values:

    • ‘ipv4-cidr-block-association.association-id` - The association ID for an IPv4 CIDR block associated with the secondary network.

    • ‘ipv4-cidr-block-association.cidr-block` - An IPv4 CIDR block associated with the secondary network.

    • ‘ipv4-cidr-block-association.state` - The state of an IPv4 CIDR block associated with the secondary network.

    • ‘owner-id` - The ID of the Amazon Web Services account that owns the secondary network.

    • ‘secondary-network-id` - The ID of the secondary network.

    • ‘secondary-network-arn` - The ARN of the secondary network.

    • ‘state` - The state of the secondary network (`create-in-progress` | `create-complete` | `create-failed` | `delete-in-progress` | `delete-complete` | `delete-failed`).

    • ‘tag`:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key `Owner` and the value `TeamA`, specify `tag:Owner` for the filter name and `TeamA` for the filter value.

    • ‘tag-key` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.

    • ‘type` - The type of the secondary network (`rdma`).

  • :max_results (Integer)

    The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.

  • :next_token (String)

    The token for the next page of results.

  • :secondary_network_ids (Array<String>)

    The IDs of the secondary networks.

Returns:



1093
1094
1095
# File 'lib/aws-sdk-ec2/waiters.rb', line 1093

def wait(params = {})
  @waiter.wait(client: @client, params: params)
end