Class: Aws::EC2::Waiters::SecurityGroupExists
- Inherits:
-
Object
- Object
- Aws::EC2::Waiters::SecurityGroupExists
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-ec2/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ SecurityGroupExists
constructor
A new instance of SecurityGroupExists.
-
#wait(params = {}) ⇒ Types::DescribeSecurityGroupsResult
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ SecurityGroupExists
Returns a new instance of SecurityGroupExists.
1247 1248 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1247
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1278 1279 1280 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1278 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeSecurityGroupsResult
Returns a response object which responds to the following methods:
- #next_token => String
- #security_groups => Array<Types::SecurityGroup>
1273 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1273
def wait: (
|