Class: Aws::EC2::Waiters::SecurityGroupVpcAssociationAssociated

Inherits:
Object
  • Object
show all
Defined in:
sig/waiters.rbs,
lib/aws-sdk-ec2/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ SecurityGroupVpcAssociationAssociated

Returns a new instance of SecurityGroupVpcAssociationAssociated.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 7
  • :delay (Integer) — default: 10
  • :before_attempt (Proc)
  • :before_wait (Proc)


1290
1291
# File 'lib/aws-sdk-ec2/waiters.rb', line 1290

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



1328
1329
1330
# File 'lib/aws-sdk-ec2/waiters.rb', line 1328

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeSecurityGroupVpcAssociationsResult

Returns a response object which responds to the following methods:

Options Hash (params):

  • :filters (Array<Types::Filter>)

    Security group VPC association filters.

    • group-id: The security group ID.

    • group-owner-id: The group owner ID.

    • state: The state of the association.

    • vpc-id: The ID of the associated VPC.

    • vpc-owner-id: The account ID of the VPC owner.

  • :next_token (String)

    The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

  • :max_results (Integer)

    The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:



1323
# File 'lib/aws-sdk-ec2/waiters.rb', line 1323

def wait: (