Class: Aws::EC2::Waiters::SecurityGroupVpcAssociationDisassociated

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-ec2/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ SecurityGroupVpcAssociationDisassociated

Returns a new instance of SecurityGroupVpcAssociationDisassociated.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 7
  • :delay (Integer) — default: 10
  • :before_attempt (Proc)
  • :before_wait (Proc)


1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
# File 'lib/aws-sdk-ec2/waiters.rb', line 1150

def initialize(options)
  @client = options.fetch(:client)
  @waiter = Aws::Waiters::Waiter.new({
    max_attempts: 7,
    delay: 10,
    poller: Aws::Waiters::Poller.new(
      operation_name: :describe_security_group_vpc_associations,
      acceptors: [
        {
          "expected" => "disassociated",
          "matcher" => "pathAll",
          "state" => "success",
          "argument" => "security_group_vpc_associations[].state"
        },
        {
          "expected" => "disassociating",
          "matcher" => "pathAny",
          "state" => "retry",
          "argument" => "security_group_vpc_associations[].state"
        },
        {
          "expected" => "disassociation-failed",
          "matcher" => "pathAny",
          "state" => "failure",
          "argument" => "security_group_vpc_associations[].state"
        },
        {
          "expected" => true,
          "matcher" => "path",
          "state" => "success",
          "argument" => "length(security_group_vpc_associations[]) == `0`"
        }
      ]
    )
  }.merge(options))
end

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



1194
1195
1196
# File 'lib/aws-sdk-ec2/waiters.rb', line 1194

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeSecurityGroupVpcAssociationsResult

Returns a response object which responds to the following methods:

Options Hash (params):

  • :filters (Array<Types::Filter>)

    Security group VPC association filters.

    • ‘group-id`: The security group ID.

    • ‘group-owner-id`: The group owner ID.

    • ‘state`: The state of the association.

    • ‘vpc-id`: The ID of the associated VPC.

    • ‘vpc-owner-id`: The account ID of the VPC owner.

  • :next_token (String)

    The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

  • :max_results (Integer)

    The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].

    [1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:



1189
1190
1191
# File 'lib/aws-sdk-ec2/waiters.rb', line 1189

def wait(params = {})
  @waiter.wait(client: @client, params: params)
end