Class: Aws::EC2::Waiters::SnapshotCompleted

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-ec2/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ SnapshotCompleted

Returns a new instance of SnapshotCompleted.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 40
  • :delay (Integer) — default: 15
  • :before_attempt (Proc)
  • :before_wait (Proc)


1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
# File 'lib/aws-sdk-ec2/waiters.rb', line 1206

def initialize(options)
  @client = options.fetch(:client)
  @waiter = Aws::Waiters::Waiter.new({
    max_attempts: 40,
    delay: 15,
    poller: Aws::Waiters::Poller.new(
      operation_name: :describe_snapshots,
      acceptors: [
        {
          "expected" => "completed",
          "matcher" => "pathAll",
          "state" => "success",
          "argument" => "snapshots[].state"
        },
        {
          "expected" => "error",
          "matcher" => "pathAny",
          "state" => "failure",
          "argument" => "snapshots[].state"
        }
      ]
    )
  }.merge(options))
end

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



1238
1239
1240
# File 'lib/aws-sdk-ec2/waiters.rb', line 1238

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeSnapshotsResult

Returns a response object which responds to the following methods:

Options Hash (params):

  • :max_results (Integer)

    The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].

    [1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination

  • :next_token (String)

    The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

  • :owner_ids (Array<String>)

    Scopes the results to snapshots with the specified owners. You can specify a combination of Amazon Web Services account IDs, ‘self`, and `amazon`.

  • :restorable_by_user_ids (Array<String>)

    The IDs of the Amazon Web Services accounts that can create volumes from the snapshot.

  • :snapshot_ids (Array<String>)

    The snapshot IDs.

    Default: Describes the snapshots for which you have create volume permissions.

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

  • :filters (Array<Types::Filter>)

    The filters.

    • ‘description` - A description of the snapshot.

    • ‘encrypted` - Indicates whether the snapshot is encrypted (`true` | `false`)

    • ‘owner-alias` - The owner alias, from an Amazon-maintained list (`amazon`). This is not the user-configured Amazon Web Services account alias set using the IAM console. We recommend that you use the related parameter instead of this filter.

    • ‘owner-id` - The Amazon Web Services account ID of the owner. We recommend that you use the related parameter instead of this filter.

    • ‘progress` - The progress of the snapshot, as a percentage (for example, 80%).

    • ‘snapshot-id` - The snapshot ID.

    • ‘start-time` - The time stamp when the snapshot was initiated.

    • ‘status` - The status of the snapshot (`pending` | `completed` | `error`).

    • ‘storage-tier` - The storage tier of the snapshot (`archive` | `standard`).

    • ‘transfer-type` - The type of operation used to create the snapshot (`time-based` | `standard`).

    • ‘tag`:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key `Owner` and the value `TeamA`, specify `tag:Owner` for the filter name and `TeamA` for the filter value.

    • ‘tag-key` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.

    • ‘volume-id` - The ID of the volume the snapshot is for.

    • ‘volume-size` - The size of the volume, in GiB.

Returns:



1233
1234
1235
# File 'lib/aws-sdk-ec2/waiters.rb', line 1233

def wait(params = {})
  @waiter.wait(client: @client, params: params)
end