Class: Aws::EC2::Waiters::StoreImageTaskComplete

Inherits:
Object
  • Object
show all
Defined in:
sig/waiters.rbs,
lib/aws-sdk-ec2/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ StoreImageTaskComplete

Returns a new instance of StoreImageTaskComplete.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 40
  • :delay (Integer) — default: 5
  • :before_attempt (Proc)
  • :before_wait (Proc)


1557
1558
# File 'lib/aws-sdk-ec2/waiters.rb', line 1557

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



1595
1596
1597
# File 'lib/aws-sdk-ec2/waiters.rb', line 1595

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeStoreImageTasksResult

Returns a response object which responds to the following methods:

Options Hash (params):

  • :image_ids (Array<String>)

    The AMI IDs for which to show progress. Up to 20 AMI IDs can be included in a request.

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

  • :filters (Array<Types::Filter>)

    The filters.

    • task-state - Returns tasks in a certain state (InProgress | Completed | Failed)

    • bucket - Returns task information for tasks that targeted a specific bucket. For the filter value, specify the bucket name.

    When you specify the ImageIds parameter, any filters that you specify are ignored. To use the filters, you must remove the ImageIds parameter.

  • :next_token (String)

    The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

  • :max_results (Integer)

    The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.

    You cannot specify this parameter and the ImageIds parameter in the same call.

Returns:



1590
# File 'lib/aws-sdk-ec2/waiters.rb', line 1590

def wait: (