Class: Aws::EC2::Waiters::SubnetAvailable
- Inherits:
-
Object
- Object
- Aws::EC2::Waiters::SubnetAvailable
- Defined in:
- lib/aws-sdk-ec2/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ SubnetAvailable
constructor
A new instance of SubnetAvailable.
-
#wait(params = {}) ⇒ Types::DescribeSubnetsResult
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ SubnetAvailable
Returns a new instance of SubnetAvailable.
1607 1608 1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1607 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 40, delay: 15, poller: Aws::Waiters::Poller.new( operation_name: :describe_subnets, acceptors: [{ "expected" => "available", "matcher" => "pathAll", "state" => "success", "argument" => "subnets[].state" }] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1631 1632 1633 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1631 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeSubnetsResult
Returns a response object which responds to the following methods:
-
#next_token => String
-
#subnets => Array<Types::Subnet>
1626 1627 1628 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1626 def wait(params = {}) @waiter.wait(client: @client, params: params) end |