Class: Aws::EC2::Waiters::SystemStatusOk
- Inherits:
-
Object
- Object
- Aws::EC2::Waiters::SystemStatusOk
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-ec2/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ SystemStatusOk
constructor
A new instance of SystemStatusOk.
-
#wait(params = {}) ⇒ Types::DescribeInstanceStatusResult
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ SystemStatusOk
Returns a new instance of SystemStatusOk.
1643 1644 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1643
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1667 1668 1669 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1667 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeInstanceStatusResult
Returns a response object which responds to the following methods:
- #instance_statuses => Array<Types::InstanceStatus>
- #next_token => String
1662 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1662
def wait: (
|