Class: Aws::EC2::Waiters::VolumeDeleted

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-ec2/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ VolumeDeleted

Returns a new instance of VolumeDeleted.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 40
  • :delay (Integer) — default: 15
  • :before_attempt (Proc)
  • :before_wait (Proc)


1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
1745
# File 'lib/aws-sdk-ec2/waiters.rb', line 1723

def initialize(options)
  @client = options.fetch(:client)
  @waiter = Aws::Waiters::Waiter.new({
    max_attempts: 40,
    delay: 15,
    poller: Aws::Waiters::Poller.new(
      operation_name: :describe_volumes,
      acceptors: [
        {
          "expected" => "deleted",
          "matcher" => "pathAll",
          "state" => "success",
          "argument" => "volumes[].state"
        },
        {
          "matcher" => "error",
          "expected" => "InvalidVolume.NotFound",
          "state" => "success"
        }
      ]
    )
  }.merge(options))
end

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



1754
1755
1756
# File 'lib/aws-sdk-ec2/waiters.rb', line 1754

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeVolumesResult

Returns a response object which responds to the following methods:

Options Hash (params):

  • :volume_ids (Array<String>)

    The volume IDs. If not specified, then all volumes are included in the response.

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

  • :filters (Array<Types::Filter>)

    The filters.

    • ‘attachment.attach-time` - The time stamp when the attachment initiated.

    • ‘attachment.delete-on-termination` - Whether the volume is deleted on instance termination.

    • ‘attachment.device` - The device name specified in the block device mapping (for example, `/dev/sda1`).

    • ‘attachment.instance-id` - The ID of the instance the volume is attached to.

    • ‘attachment.status` - The attachment state (`attaching` | `attached` | `detaching`).

    • ‘availability-zone` - The Availability Zone in which the volume was created.

    • ‘availability-zone-id` - The ID of the Availability Zone in which the volume was created.

    • ‘create-time` - The time stamp when the volume was created.

    • ‘encrypted` - Indicates whether the volume is encrypted (`true` | `false`)

    • ‘fast-restored` - Indicates whether the volume was created from a snapshot that is enabled for fast snapshot restore (`true` | `false`).

    • ‘multi-attach-enabled` - Indicates whether the volume is enabled for Multi-Attach (`true` | `false`)

    • ‘operator.managed` - A Boolean that indicates whether this is a managed volume.

    • ‘operator.principal` - The principal that manages the volume. Only valid for managed volumes, where `managed` is `true`.

    • ‘size` - The size of the volume, in GiB.

    • ‘snapshot-id` - The snapshot from which the volume was created.

    • ‘status` - The state of the volume (`creating` | `available` | `in-use` | `deleting` | `deleted` | `error`).

    • ‘tag`:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key `Owner` and the value `TeamA`, specify `tag:Owner` for the filter name and `TeamA` for the filter value.

    • ‘tag-key` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.

    • ‘volume-id` - The volume ID.

    • ‘volume-type` - The Amazon EBS volume type (`gp2` | `gp3` | `io1` | `io2` | `st1` | `sc1`| `standard`)

  • :next_token (String)

    The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

  • :max_results (Integer)

    The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].

    [1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination

Returns:



1749
1750
1751
# File 'lib/aws-sdk-ec2/waiters.rb', line 1749

def wait(params = {})
  @waiter.wait(client: @client, params: params)
end