Class: Aws::EC2::Waiters::VpcAvailable
- Inherits:
-
Object
- Object
- Aws::EC2::Waiters::VpcAvailable
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-ec2/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ VpcAvailable
constructor
A new instance of VpcAvailable.
-
#wait(params = {}) ⇒ Types::DescribeVpcsResult
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ VpcAvailable
Returns a new instance of VpcAvailable.
1810 1811 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1810
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1834 1835 1836 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1834 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeVpcsResult
Returns a response object which responds to the following methods:
- #next_token => String
- #vpcs => Array<Types::Vpc>
1829 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1829
def wait: (
|