Class: Aws::EC2::Waiters::VpcExists
- Inherits:
-
Object
- Object
- Aws::EC2::Waiters::VpcExists
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-ec2/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ VpcExists
constructor
A new instance of VpcExists.
-
#wait(params = {}) ⇒ Types::DescribeVpcsResult
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ VpcExists
Returns a new instance of VpcExists.
1846 1847 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1846
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1876 1877 1878 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1876 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeVpcsResult
Returns a response object which responds to the following methods:
- #next_token => String
- #vpcs => Array<Types::Vpc>
1871 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1871
def wait: (
|