Class: Aws::EC2::Waiters::VpcPeeringConnectionDeleted
- Inherits:
-
Object
- Object
- Aws::EC2::Waiters::VpcPeeringConnectionDeleted
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-ec2/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ VpcPeeringConnectionDeleted
constructor
A new instance of VpcPeeringConnectionDeleted.
-
#wait(params = {}) ⇒ Types::DescribeVpcPeeringConnectionsResult
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ VpcPeeringConnectionDeleted
Returns a new instance of VpcPeeringConnectionDeleted.
1888 1889 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1888
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1919 1920 1921 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1919 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeVpcPeeringConnectionsResult
Returns a response object which responds to the following methods:
- #vpc_peering_connections => Array<Types::VpcPeeringConnection>
- #next_token => String
1914 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1914
def wait: (
|