Class: Aws::EC2::Waiters::VpcPeeringConnectionExists
- Inherits:
-
Object
- Object
- Aws::EC2::Waiters::VpcPeeringConnectionExists
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-ec2/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ VpcPeeringConnectionExists
constructor
A new instance of VpcPeeringConnectionExists.
-
#wait(params = {}) ⇒ Types::DescribeVpcPeeringConnectionsResult
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ VpcPeeringConnectionExists
Returns a new instance of VpcPeeringConnectionExists.
1931 1932 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1931
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1961 1962 1963 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1961 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeVpcPeeringConnectionsResult
Returns a response object which responds to the following methods:
- #vpc_peering_connections => Array<Types::VpcPeeringConnection>
- #next_token => String
1956 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1956
def wait: (
|