Class: Aws::EC2::Waiters::VpnConnectionAvailable

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-ec2/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ VpnConnectionAvailable

Returns a new instance of VpnConnectionAvailable.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 40
  • :delay (Integer) — default: 15
  • :before_attempt (Proc)
  • :before_wait (Proc)


1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
1991
1992
1993
1994
1995
1996
1997
1998
1999
2000
2001
2002
# File 'lib/aws-sdk-ec2/waiters.rb', line 1973

def initialize(options)
  @client = options.fetch(:client)
  @waiter = Aws::Waiters::Waiter.new({
    max_attempts: 40,
    delay: 15,
    poller: Aws::Waiters::Poller.new(
      operation_name: :describe_vpn_connections,
      acceptors: [
        {
          "expected" => "available",
          "matcher" => "pathAll",
          "state" => "success",
          "argument" => "vpn_connections[].state"
        },
        {
          "expected" => "deleting",
          "matcher" => "pathAny",
          "state" => "failure",
          "argument" => "vpn_connections[].state"
        },
        {
          "expected" => "deleted",
          "matcher" => "pathAny",
          "state" => "failure",
          "argument" => "vpn_connections[].state"
        }
      ]
    )
  }.merge(options))
end

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



2011
2012
2013
# File 'lib/aws-sdk-ec2/waiters.rb', line 2011

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeVpnConnectionsResult

Returns a response object which responds to the following methods:

Options Hash (params):

  • :filters (Array<Types::Filter>)

    One or more filters.

    • ‘customer-gateway-configuration` - The configuration information for the customer gateway.

    • ‘customer-gateway-id` - The ID of a customer gateway associated with the VPN connection.

    • ‘state` - The state of the VPN connection (`pending` | `available` | `deleting` | `deleted`).

    • ‘option.static-routes-only` - Indicates whether the connection has static routes only. Used for devices that do not support Border Gateway Protocol (BGP).

    • ‘route.destination-cidr-block` - The destination CIDR block. This corresponds to the subnet used in a customer data center.

    • ‘bgp-asn` - The BGP Autonomous System Number (ASN) associated with a BGP device.

    • ‘tag`:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key `Owner` and the value `TeamA`, specify `tag:Owner` for the filter name and `TeamA` for the filter value.

    • ‘tag-key` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.

    • ‘type` - The type of VPN connection. Currently the only supported type is `ipsec.1`.

    • ‘vpn-connection-id` - The ID of the VPN connection.

    • ‘vpn-gateway-id` - The ID of a virtual private gateway associated with the VPN connection.

    • ‘transit-gateway-id` - The ID of a transit gateway associated with the VPN connection.

  • :vpn_connection_ids (Array<String>)

    One or more VPN connection IDs.

    Default: Describes your VPN connections.

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:



2006
2007
2008
# File 'lib/aws-sdk-ec2/waiters.rb', line 2006

def wait(params = {})
  @waiter.wait(client: @client, params: params)
end