Class: Aws::EC2::Waiters::VpnConnectionDeleted

Inherits:
Object
  • Object
show all
Defined in:
sig/waiters.rbs,
lib/aws-sdk-ec2/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ VpnConnectionDeleted

Returns a new instance of VpnConnectionDeleted.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 40
  • :delay (Integer) — default: 15
  • :before_attempt (Proc)
  • :before_wait (Proc)


2023
2024
# File 'lib/aws-sdk-ec2/waiters.rb', line 2023

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



2055
2056
2057
# File 'lib/aws-sdk-ec2/waiters.rb', line 2055

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeVpnConnectionsResult

Returns a response object which responds to the following methods:

Options Hash (params):

  • :filters (Array<Types::Filter>)

    One or more filters.

    • customer-gateway-configuration - The configuration information for the customer gateway.

    • customer-gateway-id - The ID of a customer gateway associated with the VPN connection.

    • state - The state of the VPN connection (pending | available | deleting | deleted).

    • option.static-routes-only - Indicates whether the connection has static routes only. Used for devices that do not support Border Gateway Protocol (BGP).

    • route.destination-cidr-block - The destination CIDR block. This corresponds to the subnet used in a customer data center.

    • bgp-asn - The BGP Autonomous System Number (ASN) associated with a BGP device.

    • tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.

    • tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.

    • type - The type of VPN connection. Currently the only supported type is ipsec.1.

    • vpn-connection-id - The ID of the VPN connection.

    • vpn-gateway-id - The ID of a virtual private gateway associated with the VPN connection.

    • transit-gateway-id - The ID of a transit gateway associated with the VPN connection.

  • :vpn_connection_ids (Array<String>)

    One or more VPN connection IDs.

    Default: Describes your VPN connections.

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:



2050
# File 'lib/aws-sdk-ec2/waiters.rb', line 2050

def wait: (