Class: Aws::EC2::Instance::Collection

Inherits:
Resources::Collection
  • Object
show all
Extended by:
Deprecations
Defined in:
lib/aws-sdk-ec2/customizations/instance.rb,
lib/aws-sdk-ec2/instance.rb

Batch Actions collapse

Instance Method Details

#batch_create_tags(options = {}) ⇒ void

This method returns an undefined value.

Examples:

Request syntax with placeholder values


instance.batch_create_tags({
  dry_run: false,
  tags: [ # required
    {
      key: "String",
      value: "String",
    },
  ],
})

Parameters:

  • options ({}) (defaults to: {})

Options Hash (options):

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

  • :tags (required, Array<Types::Tag>)

    The tags. The ‘value` parameter is required, but if you don’t want the tag to have a value, specify the parameter with no value, and we set the value to an empty string.



1982
1983
1984
1985
1986
1987
1988
1989
1990
1991
1992
1993
1994
# File 'lib/aws-sdk-ec2/instance.rb', line 1982

def batch_create_tags(options = {})
  batch_enum.each do |batch|
    params = Aws::Util.copy_hash(options)
    params[:resources] ||= []
    batch.each do |item|
      params[:resources] << item.id
    end
    Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
      batch[0].client.create_tags(params)
    end
  end
  nil
end

#batch_delete_tags!(options = {}) ⇒ void

This method returns an undefined value.

Examples:

Request syntax with placeholder values


instance.batch_delete_tags!({
  dry_run: false,
  tags: [
    {
      key: "String",
      value: "String",
    },
  ],
})

Parameters:

  • options ({}) (defaults to: {})

Options Hash (options):

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

  • :tags (Array<Types::Tag>)

    The tags to delete. Specify a tag key and an optional tag value to delete specific tags. If you specify a tag key without a tag value, we delete any tag with this key regardless of its value. If you specify a tag key with an empty string as the tag value, we delete the tag only if its value is an empty string.

    If you omit this parameter, we delete all user-defined tags for the specified resources. We do not delete Amazon Web Services-generated tags (tags that have the ‘aws:` prefix).

    Constraints: Up to 1000 tags.



2026
2027
2028
2029
2030
2031
2032
2033
2034
2035
2036
2037
2038
# File 'lib/aws-sdk-ec2/instance.rb', line 2026

def batch_delete_tags!(options = {})
  batch_enum.each do |batch|
    params = Aws::Util.copy_hash(options)
    params[:resources] ||= []
    batch.each do |item|
      params[:resources] << item.id
    end
    Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
      batch[0].client.delete_tags(params)
    end
  end
  nil
end

#batch_monitor(options = {}) ⇒ void

This method returns an undefined value.

Examples:

Request syntax with placeholder values


instance.batch_monitor({
  dry_run: false,
})

Parameters:

  • options ({}) (defaults to: {})

Options Hash (options):

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.



2052
2053
2054
2055
2056
2057
2058
2059
2060
2061
2062
2063
2064
# File 'lib/aws-sdk-ec2/instance.rb', line 2052

def batch_monitor(options = {})
  batch_enum.each do |batch|
    params = Aws::Util.copy_hash(options)
    params[:instance_ids] ||= []
    batch.each do |item|
      params[:instance_ids] << item.id
    end
    Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
      batch[0].client.monitor_instances(params)
    end
  end
  nil
end

#batch_reboot(options = {}) ⇒ void

This method returns an undefined value.

Examples:

Request syntax with placeholder values


instance.batch_reboot({
  dry_run: false,
})

Parameters:

  • options ({}) (defaults to: {})

Options Hash (options):

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.



2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
# File 'lib/aws-sdk-ec2/instance.rb', line 2078

def batch_reboot(options = {})
  batch_enum.each do |batch|
    params = Aws::Util.copy_hash(options)
    params[:instance_ids] ||= []
    batch.each do |item|
      params[:instance_ids] << item.id
    end
    Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
      batch[0].client.reboot_instances(params)
    end
  end
  nil
end

#batch_start(options = {}) ⇒ void

This method returns an undefined value.

Examples:

Request syntax with placeholder values


instance.batch_start({
  additional_info: "String",
  dry_run: false,
})

Parameters:

  • options ({}) (defaults to: {})

Options Hash (options):

  • :additional_info (String)

    Reserved.

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.



2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
# File 'lib/aws-sdk-ec2/instance.rb', line 2107

def batch_start(options = {})
  batch_enum.each do |batch|
    params = Aws::Util.copy_hash(options)
    params[:instance_ids] ||= []
    batch.each do |item|
      params[:instance_ids] << item.id
    end
    Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
      batch[0].client.start_instances(params)
    end
  end
  nil
end

#batch_stop(options = {}) ⇒ void

This method returns an undefined value.

Examples:

Request syntax with placeholder values


instance.batch_stop({
  hibernate: false,
  skip_os_shutdown: false,
  dry_run: false,
  force: false,
})

Parameters:

  • options ({}) (defaults to: {})

Options Hash (options):

  • :hibernate (Boolean)

    Hibernates the instance if the instance was enabled for hibernation at launch. If the instance cannot hibernate successfully, a normal shutdown occurs. For more information, see [Hibernate your Amazon EC2 instance] in the *Amazon EC2 User Guide*.

    Default: ‘false`

    [1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/Hibernate.html

  • :skip_os_shutdown (Boolean)

    Specifies whether to bypass the graceful OS shutdown process when the instance is stopped.

    Bypassing the graceful OS shutdown might result in data loss or corruption (for example, memory contents not flushed to disk or loss of in-flight IOs) or skipped shutdown scripts.

    Default: ‘false`

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

  • :force (Boolean)

    Forces the instance to stop. The instance will first attempt a graceful shutdown, which includes flushing file system caches and metadata. If the graceful shutdown fails to complete within the timeout period, the instance shuts down forcibly without flushing the file system caches and metadata.

    After using this option, you must perform file system check and repair procedures. This option is not recommended for Windows instances. For more information, see [Troubleshoot Amazon EC2 instance stop issues] in the *Amazon EC2 User Guide*.

    Default: ‘false`

    [1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/TroubleshootingInstancesStopping.html



2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
# File 'lib/aws-sdk-ec2/instance.rb', line 2173

def batch_stop(options = {})
  batch_enum.each do |batch|
    params = Aws::Util.copy_hash(options)
    params[:instance_ids] ||= []
    batch.each do |item|
      params[:instance_ids] << item.id
    end
    Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
      batch[0].client.stop_instances(params)
    end
  end
  nil
end

#batch_terminate!(options = {}) ⇒ void

This method returns an undefined value.

Examples:

Request syntax with placeholder values


instance.batch_terminate!({
  force: false,
  skip_os_shutdown: false,
  dry_run: false,
})

Parameters:

  • options ({}) (defaults to: {})

Options Hash (options):

  • :force (Boolean)

    Forces the instances to terminate. The instance will first attempt a graceful shutdown, which includes flushing file system caches and metadata. If the graceful shutdown fails to complete within the timeout period, the instance shuts down forcibly without flushing the file system caches and metadata.

  • :skip_os_shutdown (Boolean)

    Specifies whether to bypass the graceful OS shutdown process when the instance is terminated.

    Default: ‘false`

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.



2212
2213
2214
2215
2216
2217
2218
2219
2220
2221
2222
2223
2224
# File 'lib/aws-sdk-ec2/instance.rb', line 2212

def batch_terminate!(options = {})
  batch_enum.each do |batch|
    params = Aws::Util.copy_hash(options)
    params[:instance_ids] ||= []
    batch.each do |item|
      params[:instance_ids] << item.id
    end
    Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
      batch[0].client.terminate_instances(params)
    end
  end
  nil
end

#batch_unmonitor(options = {}) ⇒ void

This method returns an undefined value.

Examples:

Request syntax with placeholder values


instance.batch_unmonitor({
  dry_run: false,
})

Parameters:

  • options ({}) (defaults to: {})

Options Hash (options):

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.



2238
2239
2240
2241
2242
2243
2244
2245
2246
2247
2248
2249
2250
# File 'lib/aws-sdk-ec2/instance.rb', line 2238

def batch_unmonitor(options = {})
  batch_enum.each do |batch|
    params = Aws::Util.copy_hash(options)
    params[:instance_ids] ||= []
    batch.each do |item|
      params[:instance_ids] << item.id
    end
    Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
      batch[0].client.unmonitor_instances(params)
    end
  end
  nil
end