Class: Aws::EC2::RouteTable
- Inherits:
-
Object
- Object
- Aws::EC2::RouteTable
- Extended by:
- Deprecations
- Defined in:
- sig/route_table.rbs,
lib/aws-sdk-ec2/route_table.rb
Overview
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
- #id ⇒ String (also: #route_table_id)
-
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the route table.
-
#propagating_vgws ⇒ Array<Types::PropagatingVgw>
Any virtual private gateway (VGW) propagating routes.
-
#tags ⇒ Array<Types::Tag>
Any tags assigned to the route table.
-
#vpc_id ⇒ String
The ID of the VPC.
Actions collapse
- #associate_with_subnet(options = {}) ⇒ RouteTableAssociation
- #create_route(options = {}) ⇒ Route
- #create_tags(options = {}) ⇒ Tag::Collection
- #delete(options = {}) ⇒ EmptyStructure
- #delete_tags(options = {}) ⇒ Tag::Collection
Associations collapse
- #associations ⇒ RouteTableAssociation::Collection
- #identifiers ⇒ Object deprecated private Deprecated.
- #routes ⇒ Route::Collection
- #vpc ⇒ Vpc?
Instance Method Summary collapse
- #client ⇒ Client
-
#data ⇒ Types::RouteTable
Returns the data for this RouteTable.
-
#data_loaded? ⇒ Boolean
Returns
trueif this resource is loaded. -
#initialize(*args) ⇒ RouteTable
constructor
A new instance of RouteTable.
-
#load ⇒ self
(also: #reload)
Loads, or reloads #data for the current RouteTable.
-
#wait_until(options = {}) {|resource| ... } ⇒ Resource
deprecated
Deprecated.
Use [Aws::EC2::Client] #wait_until instead
Constructor Details
#initialize(id, options = {}) ⇒ RouteTable #initialize(options = {}) ⇒ RouteTable
Returns a new instance of RouteTable.
13 14 15 |
# File 'sig/route_table.rbs', line 13
def initialize: (String id, Hash[Symbol, untyped] options) -> void
| (id: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void
|
Instance Method Details
#associate_with_subnet(options = {}) ⇒ RouteTableAssociation
47 |
# File 'sig/route_table.rbs', line 47
def associate_with_subnet: (
|
#associations ⇒ RouteTableAssociation::Collection
107 |
# File 'sig/route_table.rbs', line 107
def associations: () -> RouteTableAssociation::Collection
|
#create_tags(options = {}) ⇒ Tag::Collection
77 |
# File 'sig/route_table.rbs', line 77
def create_tags: (
|
#data ⇒ Types::RouteTable
Returns the data for this Aws::EC2::RouteTable. Calls
Client#describe_route_tables if #data_loaded? is false.
40 |
# File 'sig/route_table.rbs', line 40
def data: () -> Types::RouteTable
|
#data_loaded? ⇒ Boolean
43 |
# File 'sig/route_table.rbs', line 43
def data_loaded?: () -> bool
|
#delete(options = {}) ⇒ EmptyStructure
101 |
# File 'sig/route_table.rbs', line 101
def delete: (
|
#delete_tags(options = {}) ⇒ Tag::Collection
89 |
# File 'sig/route_table.rbs', line 89
def delete_tags: (
|
#id ⇒ String Also known as: route_table_id
18 |
# File 'sig/route_table.rbs', line 18
def id: () -> String
|
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
462 463 464 |
# File 'lib/aws-sdk-ec2/route_table.rb', line 462 def identifiers { id: @id } end |
#load ⇒ self Also known as: reload
Loads, or reloads #data for the current Aws::EC2::RouteTable.
Returns self making it possible to chain methods.
route_table.reload.data
36 |
# File 'sig/route_table.rbs', line 36
def load: () -> self
|
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the route table.
31 |
# File 'sig/route_table.rbs', line 31
def owner_id: () -> ::String
|
#propagating_vgws ⇒ Array<Types::PropagatingVgw>
Any virtual private gateway (VGW) propagating routes.
22 |
# File 'sig/route_table.rbs', line 22
def propagating_vgws: () -> ::Array[Types::PropagatingVgw]
|
#routes ⇒ Route::Collection
110 |
# File 'sig/route_table.rbs', line 110
def routes: () -> Route::Collection
|
#tags ⇒ Array<Types::Tag>
Any tags assigned to the route table.
25 |
# File 'sig/route_table.rbs', line 25
def tags: () -> ::Array[Types::Tag]
|
#vpc_id ⇒ String
The ID of the VPC.
28 |
# File 'sig/route_table.rbs', line 28
def vpc_id: () -> ::String
|
#wait_until(options = {}) {|resource| ... } ⇒ Resource
Use [Aws::EC2::Client] #wait_until instead
The waiting operation is performed on a copy. The original resource remains unchanged.
Waiter polls an API operation until a resource enters a desired state.
Basic Usage
Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.
# polls in a loop until condition is true
resource.wait_until() {|resource| condition}
Example
instance.wait_until(max_attempts:10, delay:5) do |instance|
instance.state.name == 'running'
end
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:
# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
throw :failure if Time.now - started_at > 3600
end
# disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}
Handling Errors
When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.
begin
resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
attempts attempt in seconds invoked before each attempt invoked before each wait
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/aws-sdk-ec2/route_table.rb', line 179 def wait_until( = {}, &block) self_copy = self.dup attempts = 0 [:max_attempts] = 10 unless .key?(:max_attempts) [:delay] ||= 10 [:poller] = Proc.new do attempts += 1 if block.call(self_copy) [:success, self_copy] else self_copy.reload unless attempts == [:max_attempts] :retry end end Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do Aws::Waiters::Waiter.new().wait({}) end end |