Class: Aws::EC2::RouteTableAssociation
- Inherits:
-
Object
- Object
- Aws::EC2::RouteTableAssociation
- Extended by:
- Deprecations
- Defined in:
- sig/route_table_association.rbs,
lib/aws-sdk-ec2/route_table_association.rb
Overview
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
- #association_state ⇒ Types::RouteTableAssociationState
- #gateway_id ⇒ ::String
- #id ⇒ String (also: #route_table_association_id)
- #main ⇒ Boolean
- #public_ipv_4_pool ⇒ ::String
- #route_table_id ⇒ ::String
- #subnet_id ⇒ ::String
Actions collapse
Associations collapse
- #identifiers ⇒ Object deprecated private Deprecated.
- #route_table ⇒ RouteTable?
- #subnet ⇒ Subnet?
Instance Method Summary collapse
- #client ⇒ Client
- #data ⇒ Types::RouteTableAssociation
- #data_loaded? ⇒ Boolean
- #initialize(*args) ⇒ RouteTableAssociation constructor
- #load ⇒ Object (also: #reload) private
-
#wait_until(options = {}) {|resource| ... } ⇒ Resource
deprecated
Deprecated.
Use [Aws::EC2::Client] #wait_until instead
Constructor Details
#initialize(id, options) ⇒ void #initialize(id:, client:) ⇒ void #initialize(args) ⇒ void
22 23 24 25 26 27 28 |
# File 'lib/aws-sdk-ec2/route_table_association.rb', line 22 def initialize(*args) = Hash === args.last ? args.pop.dup : {} @id = extract_id(args, ) @data = .delete(:data) @client = .delete(:client) || Client.new() @waiter_block_warned = false end |
Instance Method Details
#association_state ⇒ Types::RouteTableAssociationState
72 73 74 |
# File 'lib/aws-sdk-ec2/route_table_association.rb', line 72 def association_state data[:association_state] end |
#client ⇒ Client
79 80 81 |
# File 'lib/aws-sdk-ec2/route_table_association.rb', line 79 def client @client end |
#data ⇒ Types::RouteTableAssociation
94 95 96 97 |
# File 'lib/aws-sdk-ec2/route_table_association.rb', line 94 def data load unless @data @data end |
#data_loaded? ⇒ Boolean
102 103 104 |
# File 'lib/aws-sdk-ec2/route_table_association.rb', line 102 def data_loaded? !!@data end |
#delete(options = {}) ⇒ Object
219 220 221 222 223 224 225 |
# File 'lib/aws-sdk-ec2/route_table_association.rb', line 219 def delete( = {}) = .merge(association_id: @id) resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.disassociate_route_table() end resp.data end |
#gateway_id ⇒ ::String
59 60 61 |
# File 'lib/aws-sdk-ec2/route_table_association.rb', line 59 def gateway_id data[:gateway_id] end |
#id ⇒ String Also known as: route_table_association_id
33 34 35 |
# File 'lib/aws-sdk-ec2/route_table_association.rb', line 33 def id @id end |
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
281 282 283 |
# File 'lib/aws-sdk-ec2/route_table_association.rb', line 281 def identifiers { id: @id } end |
#load ⇒ Object Also known as: reload
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
85 86 87 88 |
# File 'lib/aws-sdk-ec2/route_table_association.rb', line 85 def load msg = "#load is not implemented, data only available via enumeration" raise NotImplementedError, msg end |
#main ⇒ Boolean
40 41 42 |
# File 'lib/aws-sdk-ec2/route_table_association.rb', line 40 def main data[:main] end |
#public_ipv_4_pool ⇒ ::String
66 67 68 |
# File 'lib/aws-sdk-ec2/route_table_association.rb', line 66 def public_ipv_4_pool data[:public_ipv_4_pool] end |
#replace_subnet(options = {}) ⇒ Object
242 243 244 245 246 247 248 249 250 251 |
# File 'lib/aws-sdk-ec2/route_table_association.rb', line 242 def replace_subnet( = {}) = .merge(association_id: @id) resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.replace_route_table_association() end RouteTableAssociation.new( id: resp.data.new_association_id, client: @client ) end |
#route_table ⇒ RouteTable?
256 257 258 259 260 261 262 263 264 265 |
# File 'lib/aws-sdk-ec2/route_table_association.rb', line 256 def route_table if data[:route_table_id] RouteTable.new( id: data[:route_table_id], client: @client ) else nil end end |
#route_table_id ⇒ ::String
46 47 48 |
# File 'lib/aws-sdk-ec2/route_table_association.rb', line 46 def route_table_id data[:route_table_id] end |
#subnet ⇒ Subnet?
268 269 270 271 272 273 274 275 276 277 |
# File 'lib/aws-sdk-ec2/route_table_association.rb', line 268 def subnet if data[:subnet_id] Subnet.new( id: data[:subnet_id], client: @client ) else nil end end |
#subnet_id ⇒ ::String
53 54 55 |
# File 'lib/aws-sdk-ec2/route_table_association.rb', line 53 def subnet_id data[:subnet_id] end |
#wait_until(options = {}) {|resource| ... } ⇒ Resource
Use [Aws::EC2::Client] #wait_until instead
The waiting operation is performed on a copy. The original resource remains unchanged.
Waiter polls an API operation until a resource enters a desired state.
Basic Usage
Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.
# polls in a loop until condition is true
resource.wait_until() {|resource| condition}
Example
instance.wait_until(max_attempts:10, delay:5) do |instance|
instance.state.name == 'running'
end
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:
# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
throw :failure if Time.now - started_at > 3600
end
# disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}
Handling Errors
When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.
begin
resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
attempts attempt in seconds invoked before each attempt invoked before each wait
186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/aws-sdk-ec2/route_table_association.rb', line 186 def wait_until( = {}, &block) self_copy = self.dup attempts = 0 [:max_attempts] = 10 unless .key?(:max_attempts) [:delay] ||= 10 [:poller] = Proc.new do attempts += 1 if block.call(self_copy) [:success, self_copy] else self_copy.reload unless attempts == [:max_attempts] :retry end end Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do Aws::Waiters::Waiter.new().wait({}) end end |