Class: Aws::EC2::Types::AllocateIpamPoolCidrRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allowed_cidrsArray<String>

Include a particular CIDR range that can be returned by the pool. Allowed CIDRs are only allowed if using netmask length for allocation.

Returns:

  • (Array<String>)


1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
# File 'lib/aws-sdk-ec2/types.rb', line 1401

class AllocateIpamPoolCidrRequest < Struct.new(
  :dry_run,
  :ipam_pool_id,
  :cidr,
  :netmask_length,
  :client_token,
  :description,
  :preview_next_cidr,
  :allowed_cidrs,
  :disallowed_cidrs,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#cidrString

The CIDR you would like to allocate from the IPAM pool. Note the following:

  • If there is no DefaultNetmaskLength allocation rule set on the pool, you must specify either the NetmaskLength or the CIDR.

  • If the DefaultNetmaskLength allocation rule is set on the pool, you can specify either the NetmaskLength or the CIDR and the DefaultNetmaskLength allocation rule will be ignored.

Possible values: Any available IPv4 or IPv6 CIDR.

Returns:

  • (String)


1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
# File 'lib/aws-sdk-ec2/types.rb', line 1401

class AllocateIpamPoolCidrRequest < Struct.new(
  :dry_run,
  :ipam_pool_id,
  :cidr,
  :netmask_length,
  :client_token,
  :description,
  :preview_next_cidr,
  :allowed_cidrs,
  :disallowed_cidrs,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [Ensuring idempotency].

**A suitable default value is auto-generated.** You should normally not need to pass this option.

[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html

Returns:

  • (String)


1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
# File 'lib/aws-sdk-ec2/types.rb', line 1401

class AllocateIpamPoolCidrRequest < Struct.new(
  :dry_run,
  :ipam_pool_id,
  :cidr,
  :netmask_length,
  :client_token,
  :description,
  :preview_next_cidr,
  :allowed_cidrs,
  :disallowed_cidrs,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description for the allocation.

Returns:

  • (String)


1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
# File 'lib/aws-sdk-ec2/types.rb', line 1401

class AllocateIpamPoolCidrRequest < Struct.new(
  :dry_run,
  :ipam_pool_id,
  :cidr,
  :netmask_length,
  :client_token,
  :description,
  :preview_next_cidr,
  :allowed_cidrs,
  :disallowed_cidrs,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#disallowed_cidrsArray<String>

Exclude a particular CIDR range from being returned by the pool. Disallowed CIDRs are only allowed if using netmask length for allocation.

Returns:

  • (Array<String>)


1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
# File 'lib/aws-sdk-ec2/types.rb', line 1401

class AllocateIpamPoolCidrRequest < Struct.new(
  :dry_run,
  :ipam_pool_id,
  :cidr,
  :netmask_length,
  :client_token,
  :description,
  :preview_next_cidr,
  :allowed_cidrs,
  :disallowed_cidrs,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
# File 'lib/aws-sdk-ec2/types.rb', line 1401

class AllocateIpamPoolCidrRequest < Struct.new(
  :dry_run,
  :ipam_pool_id,
  :cidr,
  :netmask_length,
  :client_token,
  :description,
  :preview_next_cidr,
  :allowed_cidrs,
  :disallowed_cidrs,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_pool_idString

The ID of the IPAM pool from which you would like to allocate a CIDR.

Returns:

  • (String)


1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
# File 'lib/aws-sdk-ec2/types.rb', line 1401

class AllocateIpamPoolCidrRequest < Struct.new(
  :dry_run,
  :ipam_pool_id,
  :cidr,
  :netmask_length,
  :client_token,
  :description,
  :preview_next_cidr,
  :allowed_cidrs,
  :disallowed_cidrs,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#netmask_lengthInteger

The netmask length of the CIDR you would like to allocate from the IPAM pool. Note the following:

  • If there is no DefaultNetmaskLength allocation rule set on the pool, you must specify either the NetmaskLength or the CIDR.

  • If the DefaultNetmaskLength allocation rule is set on the pool, you can specify either the NetmaskLength or the CIDR and the DefaultNetmaskLength allocation rule will be ignored.

Possible netmask lengths for IPv4 addresses are 0 - 32. Possible netmask lengths for IPv6 addresses are 0 - 128.

Returns:

  • (Integer)


1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
# File 'lib/aws-sdk-ec2/types.rb', line 1401

class AllocateIpamPoolCidrRequest < Struct.new(
  :dry_run,
  :ipam_pool_id,
  :cidr,
  :netmask_length,
  :client_token,
  :description,
  :preview_next_cidr,
  :allowed_cidrs,
  :disallowed_cidrs,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#preview_next_cidrBoolean

A preview of the next available CIDR in a pool.

Returns:

  • (Boolean)


1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
# File 'lib/aws-sdk-ec2/types.rb', line 1401

class AllocateIpamPoolCidrRequest < Struct.new(
  :dry_run,
  :ipam_pool_id,
  :cidr,
  :netmask_length,
  :client_token,
  :description,
  :preview_next_cidr,
  :allowed_cidrs,
  :disallowed_cidrs,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key ‘Owner` and the value `TeamA`, specify `tag:Owner` for the filter name and `TeamA` for the filter value.

If you specify tags, the request is authorized against the allocation resource in addition to the pool resource.

Returns:



1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
# File 'lib/aws-sdk-ec2/types.rb', line 1401

class AllocateIpamPoolCidrRequest < Struct.new(
  :dry_run,
  :ipam_pool_id,
  :cidr,
  :netmask_length,
  :client_token,
  :description,
  :preview_next_cidr,
  :allowed_cidrs,
  :disallowed_cidrs,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end