Class: Aws::EC2::Types::ApplicationStatus
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ApplicationStatus
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the application-level health status for an instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#details ⇒ Array<Types::ApplicationStatusDetail>
Details about the application status checks for the instance.
-
#resume_at ⇒ Time
The date and time when application status reporting resumes after suppression.
-
#status ⇒ String
The current instance-level application status.
-
#status_since ⇒ Time
The date and time when the current status started.
-
#status_time_stamp ⇒ Time
The date and time of the last status update.
Instance Attribute Details
#details ⇒ Array<Types::ApplicationStatusDetail>
Details about the application status checks for the instance.
1925 1926 1927 1928 1929 1930 1931 1932 1933 |
# File 'lib/aws-sdk-ec2/types.rb', line 1925 class ApplicationStatus < Struct.new( :status, :status_time_stamp, :status_since, :resume_at, :details) SENSITIVE = [] include Aws::Structure end |
#resume_at ⇒ Time
The date and time when application status reporting resumes after suppression.
1925 1926 1927 1928 1929 1930 1931 1932 1933 |
# File 'lib/aws-sdk-ec2/types.rb', line 1925 class ApplicationStatus < Struct.new( :status, :status_time_stamp, :status_since, :resume_at, :details) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current instance-level application status. This status is
derived from application status checks with Aggregation set to
included. Possible values:
-
ok– All included checks passed. -
impaired– At least one included check failed. -
initializing– At least one included check is initializing, and no included check is impaired. -
insufficient-data– At least one included check has insufficient data, and no included check is impaired or initializing. -
not-applicable– No checks withAggregationset toincludedapply to the instance. -
suppressed– Application status reporting is suppressed for the instance.
Checks with Aggregation set to excluded do not affect this
value.
1925 1926 1927 1928 1929 1930 1931 1932 1933 |
# File 'lib/aws-sdk-ec2/types.rb', line 1925 class ApplicationStatus < Struct.new( :status, :status_time_stamp, :status_since, :resume_at, :details) SENSITIVE = [] include Aws::Structure end |
#status_since ⇒ Time
The date and time when the current status started.
1925 1926 1927 1928 1929 1930 1931 1932 1933 |
# File 'lib/aws-sdk-ec2/types.rb', line 1925 class ApplicationStatus < Struct.new( :status, :status_time_stamp, :status_since, :resume_at, :details) SENSITIVE = [] include Aws::Structure end |
#status_time_stamp ⇒ Time
The date and time of the last status update.
1925 1926 1927 1928 1929 1930 1931 1932 1933 |
# File 'lib/aws-sdk-ec2/types.rb', line 1925 class ApplicationStatus < Struct.new( :status, :status_time_stamp, :status_since, :resume_at, :details) SENSITIVE = [] include Aws::Structure end |