Class: Aws::EC2::Types::ApplicationStatusCheckAssociationObject
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ApplicationStatusCheckAssociationObject
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Information about an application status check association. Each item
in the associationSet of a
DescribeApplicationStatusCheckAssociations response is of this type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_status_check_id ⇒ String
The ID of the application status check.
-
#association_type ⇒ String
The type of target that the application status check is associated with.
-
#key ⇒ String
The key for the association.
-
#value ⇒ String
The value for the association target.
Instance Attribute Details
#application_status_check_id ⇒ String
The ID of the application status check.
1967 1968 1969 1970 1971 1972 1973 1974 |
# File 'lib/aws-sdk-ec2/types.rb', line 1967 class ApplicationStatusCheckAssociationObject < Struct.new( :application_status_check_id, :association_type, :key, :value) SENSITIVE = [] include Aws::Structure end |
#association_type ⇒ String
The type of target that the application status check is associated with. Possible values:
-
tag– The check applies to current and future instances with a matching tag key-value pair. -
instance-id– The check applies to a specific instance.
1967 1968 1969 1970 1971 1972 1973 1974 |
# File 'lib/aws-sdk-ec2/types.rb', line 1967 class ApplicationStatusCheckAssociationObject < Struct.new( :application_status_check_id, :association_type, :key, :value) SENSITIVE = [] include Aws::Structure end |
#key ⇒ String
The key for the association. This value is present only for tag-based associations, where it contains the tag key. For instance-based associations, this value is absent.
1967 1968 1969 1970 1971 1972 1973 1974 |
# File 'lib/aws-sdk-ec2/types.rb', line 1967 class ApplicationStatusCheckAssociationObject < Struct.new( :application_status_check_id, :association_type, :key, :value) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
The value for the association target. For tag-based associations,
this is the tag value. For instance-based associations, this is the
instance ID (for example, i-0123456789abcdef0).
1967 1968 1969 1970 1971 1972 1973 1974 |
# File 'lib/aws-sdk-ec2/types.rb', line 1967 class ApplicationStatusCheckAssociationObject < Struct.new( :application_status_check_id, :association_type, :key, :value) SENSITIVE = [] include Aws::Structure end |