Class: Aws::EC2::Types::ApplicationStatusDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ApplicationStatusDetail
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the details of an application status check for an instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aggregation ⇒ String
The aggregation setting for the application status check.
-
#application_status_check_id ⇒ String
The ID of the application status check.
-
#check_update_time ⇒ Time
The date and time when the check was last updated.
-
#reason ⇒ Types::ApplicationStatusReason
The reason for the current status.
-
#status ⇒ String
The status of the individual application status check.
-
#status_since ⇒ Time
The date and time when the current status started for this check.
-
#status_time_stamp ⇒ Time
The date and time of the last status update for this check.
Instance Attribute Details
#aggregation ⇒ String
The aggregation setting for the application status check. When set
to included, the result of this check contributes to the
instance-level application status. When set to excluded, the check
runs independently and does not affect the instance-level status.
2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 |
# File 'lib/aws-sdk-ec2/types.rb', line 2159 class ApplicationStatusDetail < Struct.new( :application_status_check_id, :check_update_time, :aggregation, :status, :status_time_stamp, :status_since, :reason) SENSITIVE = [] include Aws::Structure end |
#application_status_check_id ⇒ String
The ID of the application status check.
2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 |
# File 'lib/aws-sdk-ec2/types.rb', line 2159 class ApplicationStatusDetail < Struct.new( :application_status_check_id, :check_update_time, :aggregation, :status, :status_time_stamp, :status_since, :reason) SENSITIVE = [] include Aws::Structure end |
#check_update_time ⇒ Time
The date and time when the check was last updated.
2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 |
# File 'lib/aws-sdk-ec2/types.rb', line 2159 class ApplicationStatusDetail < Struct.new( :application_status_check_id, :check_update_time, :aggregation, :status, :status_time_stamp, :status_since, :reason) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ Types::ApplicationStatusReason
The reason for the current status.
2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 |
# File 'lib/aws-sdk-ec2/types.rb', line 2159 class ApplicationStatusDetail < Struct.new( :application_status_check_id, :check_update_time, :aggregation, :status, :status_time_stamp, :status_since, :reason) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the individual application status check. Possible values:
-
passed– The check reached its success threshold. -
failed– The check reached its failure threshold. -
initializing– The check is initializing or has not reached a success or failure threshold. -
insufficient-data– The check does not have enough data to determine a result. -
not-applicable– The check does not apply to the instance.
This value reflects the check result and is not affected by aggregation or suppression.
2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 |
# File 'lib/aws-sdk-ec2/types.rb', line 2159 class ApplicationStatusDetail < Struct.new( :application_status_check_id, :check_update_time, :aggregation, :status, :status_time_stamp, :status_since, :reason) SENSITIVE = [] include Aws::Structure end |
#status_since ⇒ Time
The date and time when the current status started for this check.
2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 |
# File 'lib/aws-sdk-ec2/types.rb', line 2159 class ApplicationStatusDetail < Struct.new( :application_status_check_id, :check_update_time, :aggregation, :status, :status_time_stamp, :status_since, :reason) SENSITIVE = [] include Aws::Structure end |
#status_time_stamp ⇒ Time
The date and time of the last status update for this check.
2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 |
# File 'lib/aws-sdk-ec2/types.rb', line 2159 class ApplicationStatusDetail < Struct.new( :application_status_check_id, :check_update_time, :aggregation, :status, :status_time_stamp, :status_since, :reason) SENSITIVE = [] include Aws::Structure end |