Class: Aws::EC2::Types::ApplySecurityGroupsToClientVpnTargetNetworkRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ApplySecurityGroupsToClientVpnTargetNetworkRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_vpn_endpoint_id ⇒ String
The ID of the Client VPN endpoint.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#security_group_ids ⇒ Array<String>
The IDs of the security groups to apply to the associated target network.
-
#vpc_id ⇒ String
The ID of the VPC in which the associated target network is located.
Instance Attribute Details
#client_vpn_endpoint_id ⇒ String
The ID of the Client VPN endpoint.
1748 1749 1750 1751 1752 1753 1754 1755 |
# File 'lib/aws-sdk-ec2/types.rb', line 1748 class ApplySecurityGroupsToClientVpnTargetNetworkRequest < Struct.new( :client_vpn_endpoint_id, :vpc_id, :security_group_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
1748 1749 1750 1751 1752 1753 1754 1755 |
# File 'lib/aws-sdk-ec2/types.rb', line 1748 class ApplySecurityGroupsToClientVpnTargetNetworkRequest < Struct.new( :client_vpn_endpoint_id, :vpc_id, :security_group_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
The IDs of the security groups to apply to the associated target network. Up to 5 security groups can be applied to an associated target network.
1748 1749 1750 1751 1752 1753 1754 1755 |
# File 'lib/aws-sdk-ec2/types.rb', line 1748 class ApplySecurityGroupsToClientVpnTargetNetworkRequest < Struct.new( :client_vpn_endpoint_id, :vpc_id, :security_group_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC in which the associated target network is located.
1748 1749 1750 1751 1752 1753 1754 1755 |
# File 'lib/aws-sdk-ec2/types.rb', line 1748 class ApplySecurityGroupsToClientVpnTargetNetworkRequest < Struct.new( :client_vpn_endpoint_id, :vpc_id, :security_group_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |