Class: Aws::EC2::Types::AsnAuthorizationContext
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::AsnAuthorizationContext
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Provides authorization for Amazon to bring an Autonomous System Number (ASN) to a specific Amazon Web Services account using bring your own ASN (BYOASN). For details on the format of the message and signature, see Tutorial: Bring your ASN to IPAM in the Amazon VPC IPAM guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
The authorization context's message.
-
#signature ⇒ String
The authorization context's signature.
Instance Attribute Details
#message ⇒ String
The authorization context's message.
2350 2351 2352 2353 2354 2355 |
# File 'lib/aws-sdk-ec2/types.rb', line 2350 class AsnAuthorizationContext < Struct.new( :message, :signature) SENSITIVE = [] include Aws::Structure end |
#signature ⇒ String
The authorization context's signature.
2350 2351 2352 2353 2354 2355 |
# File 'lib/aws-sdk-ec2/types.rb', line 2350 class AsnAuthorizationContext < Struct.new( :message, :signature) SENSITIVE = [] include Aws::Structure end |