Class: Aws::EC2::Types::AssignPrivateNatGatewayAddressRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


2020
2021
2022
2023
2024
2025
2026
2027
# File 'lib/aws-sdk-ec2/types.rb', line 2020

class AssignPrivateNatGatewayAddressRequest < Struct.new(
  :nat_gateway_id,
  :private_ip_addresses,
  :private_ip_address_count,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#nat_gateway_idString

The ID of the NAT gateway.

Returns:

  • (String)


2020
2021
2022
2023
2024
2025
2026
2027
# File 'lib/aws-sdk-ec2/types.rb', line 2020

class AssignPrivateNatGatewayAddressRequest < Struct.new(
  :nat_gateway_id,
  :private_ip_addresses,
  :private_ip_address_count,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#private_ip_address_countInteger

The number of private IP addresses to assign to the NAT gateway. You can’t specify this parameter when also specifying private IP addresses.

Returns:

  • (Integer)


2020
2021
2022
2023
2024
2025
2026
2027
# File 'lib/aws-sdk-ec2/types.rb', line 2020

class AssignPrivateNatGatewayAddressRequest < Struct.new(
  :nat_gateway_id,
  :private_ip_addresses,
  :private_ip_address_count,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#private_ip_addressesArray<String>

The private IPv4 addresses you want to assign to the private NAT gateway.

Returns:

  • (Array<String>)


2020
2021
2022
2023
2024
2025
2026
2027
# File 'lib/aws-sdk-ec2/types.rb', line 2020

class AssignPrivateNatGatewayAddressRequest < Struct.new(
  :nat_gateway_id,
  :private_ip_addresses,
  :private_ip_address_count,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end