Class: Aws::EC2::Types::AssociateApplicationStatusCheckRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::AssociateApplicationStatusCheckRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_status_check_id ⇒ String
The ID of the application status check to associate.
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#instance_ids ⇒ Array<String>
The IDs of the instances to associate with the application status check.
-
#target_tag_associations ⇒ Array<Types::CustomTagKeyValueRequestPair>
The [tags][1] to associate the application status check with.
Instance Attribute Details
#application_status_check_id ⇒ String
The ID of the application status check to associate.
2671 2672 2673 2674 2675 2676 2677 2678 2679 |
# File 'lib/aws-sdk-ec2/types.rb', line 2671 class AssociateApplicationStatusCheckRequest < Struct.new( :application_status_check_id, :target_tag_associations, :instance_ids, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring idempotency.
A suitable default value is auto-generated. You should normally not need to pass this option.
2671 2672 2673 2674 2675 2676 2677 2678 2679 |
# File 'lib/aws-sdk-ec2/types.rb', line 2671 class AssociateApplicationStatusCheckRequest < Struct.new( :application_status_check_id, :target_tag_associations, :instance_ids, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
2671 2672 2673 2674 2675 2676 2677 2678 2679 |
# File 'lib/aws-sdk-ec2/types.rb', line 2671 class AssociateApplicationStatusCheckRequest < Struct.new( :application_status_check_id, :target_tag_associations, :instance_ids, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#instance_ids ⇒ Array<String>
The IDs of the instances to associate with the application status check.
2671 2672 2673 2674 2675 2676 2677 2678 2679 |
# File 'lib/aws-sdk-ec2/types.rb', line 2671 class AssociateApplicationStatusCheckRequest < Struct.new( :application_status_check_id, :target_tag_associations, :instance_ids, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#target_tag_associations ⇒ Array<Types::CustomTagKeyValueRequestPair>
The tags to associate the application status check with. Each tag is a key-value pair. When you associate tags, the application status check automatically monitors all instances that have the specified tags.
2671 2672 2673 2674 2675 2676 2677 2678 2679 |
# File 'lib/aws-sdk-ec2/types.rb', line 2671 class AssociateApplicationStatusCheckRequest < Struct.new( :application_status_check_id, :target_tag_associations, :instance_ids, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |