Class: Aws::EC2::Types::AssociateClientVpnTargetNetworkRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::AssociateClientVpnTargetNetworkRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone ⇒ String
The Availability Zone name for the Transit Gateway association.
-
#availability_zone_id ⇒ String
The Availability Zone ID for the Transit Gateway association.
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#client_vpn_endpoint_id ⇒ String
The ID of the Client VPN endpoint.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#subnet_id ⇒ String
The ID of the subnet to associate with the Client VPN endpoint.
Instance Attribute Details
#availability_zone ⇒ String
The Availability Zone name for the Transit Gateway association. Required if when associating an Availability Zone with a Client VPN endpoint that uses a Transit Gateway. You cannot specify both ‘SubnetId` and `AvailabilityZone`.
2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 |
# File 'lib/aws-sdk-ec2/types.rb', line 2213 class AssociateClientVpnTargetNetworkRequest < Struct.new( :client_vpn_endpoint_id, :subnet_id, :client_token, :dry_run, :availability_zone, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
The Availability Zone ID for the Transit Gateway association. Required if when associating an Availability Zone with a Client VPN endpoint that uses a Transit Gateway. You cannot specify both ‘AvailabilityZone` and `AvailabilityZoneId`.
2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 |
# File 'lib/aws-sdk-ec2/types.rb', line 2213 class AssociateClientVpnTargetNetworkRequest < Struct.new( :client_vpn_endpoint_id, :subnet_id, :client_token, :dry_run, :availability_zone, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [Ensuring idempotency].
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html
2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 |
# File 'lib/aws-sdk-ec2/types.rb', line 2213 class AssociateClientVpnTargetNetworkRequest < Struct.new( :client_vpn_endpoint_id, :subnet_id, :client_token, :dry_run, :availability_zone, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#client_vpn_endpoint_id ⇒ String
The ID of the Client VPN endpoint.
2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 |
# File 'lib/aws-sdk-ec2/types.rb', line 2213 class AssociateClientVpnTargetNetworkRequest < Struct.new( :client_vpn_endpoint_id, :subnet_id, :client_token, :dry_run, :availability_zone, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 |
# File 'lib/aws-sdk-ec2/types.rb', line 2213 class AssociateClientVpnTargetNetworkRequest < Struct.new( :client_vpn_endpoint_id, :subnet_id, :client_token, :dry_run, :availability_zone, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#subnet_id ⇒ String
The ID of the subnet to associate with the Client VPN endpoint. Required for VPC-based endpoints. For Transit Gateway-based endpoints, use ‘AvailabilityZone` or `AvailabilityZoneId` instead.
2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 |
# File 'lib/aws-sdk-ec2/types.rb', line 2213 class AssociateClientVpnTargetNetworkRequest < Struct.new( :client_vpn_endpoint_id, :subnet_id, :client_token, :dry_run, :availability_zone, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |