Class: Aws::EC2::Types::AssociateClientVpnTargetNetworkRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [Ensuring idempotency].

**A suitable default value is auto-generated.** You should normally not need to pass this option.

[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html

Returns:

  • (String)


2165
2166
2167
2168
2169
2170
2171
2172
# File 'lib/aws-sdk-ec2/types.rb', line 2165

class AssociateClientVpnTargetNetworkRequest < Struct.new(
  :client_vpn_endpoint_id,
  :subnet_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#client_vpn_endpoint_idString

The ID of the Client VPN endpoint.

Returns:

  • (String)


2165
2166
2167
2168
2169
2170
2171
2172
# File 'lib/aws-sdk-ec2/types.rb', line 2165

class AssociateClientVpnTargetNetworkRequest < Struct.new(
  :client_vpn_endpoint_id,
  :subnet_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


2165
2166
2167
2168
2169
2170
2171
2172
# File 'lib/aws-sdk-ec2/types.rb', line 2165

class AssociateClientVpnTargetNetworkRequest < Struct.new(
  :client_vpn_endpoint_id,
  :subnet_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idString

The ID of the subnet to associate with the Client VPN endpoint.

Returns:

  • (String)


2165
2166
2167
2168
2169
2170
2171
2172
# File 'lib/aws-sdk-ec2/types.rb', line 2165

class AssociateClientVpnTargetNetworkRequest < Struct.new(
  :client_vpn_endpoint_id,
  :subnet_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end