Class: Aws::EC2::Types::AssociateDhcpOptionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dhcp_options_idString

The ID of the DHCP options set, or ‘default` to associate no DHCP options with the VPC.

Returns:

  • (String)


2259
2260
2261
2262
2263
2264
2265
# File 'lib/aws-sdk-ec2/types.rb', line 2259

class AssociateDhcpOptionsRequest < Struct.new(
  :dhcp_options_id,
  :vpc_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


2259
2260
2261
2262
2263
2264
2265
# File 'lib/aws-sdk-ec2/types.rb', line 2259

class AssociateDhcpOptionsRequest < Struct.new(
  :dhcp_options_id,
  :vpc_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC.

Returns:

  • (String)


2259
2260
2261
2262
2263
2264
2265
# File 'lib/aws-sdk-ec2/types.rb', line 2259

class AssociateDhcpOptionsRequest < Struct.new(
  :dhcp_options_id,
  :vpc_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end