Class: Aws::EC2::Types::AssociateIpamByoasnRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::AssociateIpamByoasnRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asn ⇒ String
A public 2-byte or 4-byte ASN.
-
#cidr ⇒ String
The BYOIP CIDR you want to associate with an ASN.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#asn ⇒ String
A public 2-byte or 4-byte ASN.
2414 2415 2416 2417 2418 2419 2420 |
# File 'lib/aws-sdk-ec2/types.rb', line 2414 class AssociateIpamByoasnRequest < Struct.new( :dry_run, :asn, :cidr) SENSITIVE = [] include Aws::Structure end |
#cidr ⇒ String
The BYOIP CIDR you want to associate with an ASN.
2414 2415 2416 2417 2418 2419 2420 |
# File 'lib/aws-sdk-ec2/types.rb', line 2414 class AssociateIpamByoasnRequest < Struct.new( :dry_run, :asn, :cidr) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
2414 2415 2416 2417 2418 2419 2420 |
# File 'lib/aws-sdk-ec2/types.rb', line 2414 class AssociateIpamByoasnRequest < Struct.new( :dry_run, :asn, :cidr) SENSITIVE = [] include Aws::Structure end |