Class: Aws::EC2::Types::AssociateIpamByoasnRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#asnString

A public 2-byte or 4-byte ASN.

Returns:

  • (String)


2402
2403
2404
2405
2406
2407
2408
# File 'lib/aws-sdk-ec2/types.rb', line 2402

class AssociateIpamByoasnRequest < Struct.new(
  :dry_run,
  :asn,
  :cidr)
  SENSITIVE = []
  include Aws::Structure
end

#cidrString

The BYOIP CIDR you want to associate with an ASN.

Returns:

  • (String)


2402
2403
2404
2405
2406
2407
2408
# File 'lib/aws-sdk-ec2/types.rb', line 2402

class AssociateIpamByoasnRequest < Struct.new(
  :dry_run,
  :asn,
  :cidr)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


2402
2403
2404
2405
2406
2407
2408
# File 'lib/aws-sdk-ec2/types.rb', line 2402

class AssociateIpamByoasnRequest < Struct.new(
  :dry_run,
  :asn,
  :cidr)
  SENSITIVE = []
  include Aws::Structure
end