Class: Aws::EC2::Types::AssociateIpamResourceDiscoveryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::AssociateIpamResourceDiscoveryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A client token.
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#ipam_id ⇒ String
An IPAM ID.
-
#ipam_resource_discovery_id ⇒ String
A resource discovery ID.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
Tag specifications.
Instance Attribute Details
#client_token ⇒ String
A client token.
A suitable default value is auto-generated. You should normally not need to pass this option.
2572 2573 2574 2575 2576 2577 2578 2579 2580 |
# File 'lib/aws-sdk-ec2/types.rb', line 2572 class AssociateIpamResourceDiscoveryRequest < Struct.new( :dry_run, :ipam_id, :ipam_resource_discovery_id, :tag_specifications, :client_token) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action
without actually making the request and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
2572 2573 2574 2575 2576 2577 2578 2579 2580 |
# File 'lib/aws-sdk-ec2/types.rb', line 2572 class AssociateIpamResourceDiscoveryRequest < Struct.new( :dry_run, :ipam_id, :ipam_resource_discovery_id, :tag_specifications, :client_token) SENSITIVE = [] include Aws::Structure end |
#ipam_id ⇒ String
An IPAM ID.
2572 2573 2574 2575 2576 2577 2578 2579 2580 |
# File 'lib/aws-sdk-ec2/types.rb', line 2572 class AssociateIpamResourceDiscoveryRequest < Struct.new( :dry_run, :ipam_id, :ipam_resource_discovery_id, :tag_specifications, :client_token) SENSITIVE = [] include Aws::Structure end |
#ipam_resource_discovery_id ⇒ String
A resource discovery ID.
2572 2573 2574 2575 2576 2577 2578 2579 2580 |
# File 'lib/aws-sdk-ec2/types.rb', line 2572 class AssociateIpamResourceDiscoveryRequest < Struct.new( :dry_run, :ipam_id, :ipam_resource_discovery_id, :tag_specifications, :client_token) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
Tag specifications.
2572 2573 2574 2575 2576 2577 2578 2579 2580 |
# File 'lib/aws-sdk-ec2/types.rb', line 2572 class AssociateIpamResourceDiscoveryRequest < Struct.new( :dry_run, :ipam_id, :ipam_resource_discovery_id, :tag_specifications, :client_token) SENSITIVE = [] include Aws::Structure end |