Class: Aws::EC2::Types::AssociateIpamResourceDiscoveryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A client token.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


2450
2451
2452
2453
2454
2455
2456
2457
2458
# File 'lib/aws-sdk-ec2/types.rb', line 2450

class AssociateIpamResourceDiscoveryRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :ipam_resource_discovery_id,
  :tag_specifications,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


2450
2451
2452
2453
2454
2455
2456
2457
2458
# File 'lib/aws-sdk-ec2/types.rb', line 2450

class AssociateIpamResourceDiscoveryRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :ipam_resource_discovery_id,
  :tag_specifications,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_idString

An IPAM ID.

Returns:

  • (String)


2450
2451
2452
2453
2454
2455
2456
2457
2458
# File 'lib/aws-sdk-ec2/types.rb', line 2450

class AssociateIpamResourceDiscoveryRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :ipam_resource_discovery_id,
  :tag_specifications,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_resource_discovery_idString

A resource discovery ID.

Returns:

  • (String)


2450
2451
2452
2453
2454
2455
2456
2457
2458
# File 'lib/aws-sdk-ec2/types.rb', line 2450

class AssociateIpamResourceDiscoveryRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :ipam_resource_discovery_id,
  :tag_specifications,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

Tag specifications.

Returns:



2450
2451
2452
2453
2454
2455
2456
2457
2458
# File 'lib/aws-sdk-ec2/types.rb', line 2450

class AssociateIpamResourceDiscoveryRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :ipam_resource_discovery_id,
  :tag_specifications,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end