Class: Aws::EC2::Types::AssociateRouteServerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::AssociateRouteServerRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#route_server_id ⇒ String
The unique identifier for the route server to be associated.
-
#vpc_id ⇒ String
The ID of the VPC to associate with the route server.
Instance Attribute Details
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
2565 2566 2567 2568 2569 2570 2571 |
# File 'lib/aws-sdk-ec2/types.rb', line 2565 class AssociateRouteServerRequest < Struct.new( :route_server_id, :vpc_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#route_server_id ⇒ String
The unique identifier for the route server to be associated.
2565 2566 2567 2568 2569 2570 2571 |
# File 'lib/aws-sdk-ec2/types.rb', line 2565 class AssociateRouteServerRequest < Struct.new( :route_server_id, :vpc_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC to associate with the route server.
2565 2566 2567 2568 2569 2570 2571 |
# File 'lib/aws-sdk-ec2/types.rb', line 2565 class AssociateRouteServerRequest < Struct.new( :route_server_id, :vpc_id, :dry_run) SENSITIVE = [] include Aws::Structure end |