Class: Aws::EC2::Types::AssociateRouteTableRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::AssociateRouteTableRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#gateway_id ⇒ String
The ID of the internet gateway or virtual private gateway.
-
#public_ipv_4_pool ⇒ String
The ID of a public IPv4 pool.
-
#route_table_id ⇒ String
The ID of the route table.
-
#subnet_id ⇒ String
The ID of the subnet.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
3181 3182 3183 3184 3185 3186 3187 3188 3189 |
# File 'lib/aws-sdk-ec2/types.rb', line 3181 class AssociateRouteTableRequest < Struct.new( :gateway_id, :public_ipv_4_pool, :dry_run, :subnet_id, :route_table_id) SENSITIVE = [] include Aws::Structure end |
#gateway_id ⇒ String
The ID of the internet gateway or virtual private gateway.
3181 3182 3183 3184 3185 3186 3187 3188 3189 |
# File 'lib/aws-sdk-ec2/types.rb', line 3181 class AssociateRouteTableRequest < Struct.new( :gateway_id, :public_ipv_4_pool, :dry_run, :subnet_id, :route_table_id) SENSITIVE = [] include Aws::Structure end |
#public_ipv_4_pool ⇒ String
The ID of a public IPv4 pool. A public IPv4 pool is a pool of IPv4 addresses that you've brought to Amazon Web Services with BYOIP.
3181 3182 3183 3184 3185 3186 3187 3188 3189 |
# File 'lib/aws-sdk-ec2/types.rb', line 3181 class AssociateRouteTableRequest < Struct.new( :gateway_id, :public_ipv_4_pool, :dry_run, :subnet_id, :route_table_id) SENSITIVE = [] include Aws::Structure end |
#route_table_id ⇒ String
The ID of the route table.
3181 3182 3183 3184 3185 3186 3187 3188 3189 |
# File 'lib/aws-sdk-ec2/types.rb', line 3181 class AssociateRouteTableRequest < Struct.new( :gateway_id, :public_ipv_4_pool, :dry_run, :subnet_id, :route_table_id) SENSITIVE = [] include Aws::Structure end |
#subnet_id ⇒ String
The ID of the subnet.
3181 3182 3183 3184 3185 3186 3187 3188 3189 |
# File 'lib/aws-sdk-ec2/types.rb', line 3181 class AssociateRouteTableRequest < Struct.new( :gateway_id, :public_ipv_4_pool, :dry_run, :subnet_id, :route_table_id) SENSITIVE = [] include Aws::Structure end |