Class: Aws::EC2::Types::AssociateRouteTableRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


2612
2613
2614
2615
2616
2617
2618
2619
2620
# File 'lib/aws-sdk-ec2/types.rb', line 2612

class AssociateRouteTableRequest < Struct.new(
  :gateway_id,
  :public_ipv_4_pool,
  :dry_run,
  :subnet_id,
  :route_table_id)
  SENSITIVE = []
  include Aws::Structure
end

#gateway_idString

The ID of the internet gateway or virtual private gateway.

Returns:

  • (String)


2612
2613
2614
2615
2616
2617
2618
2619
2620
# File 'lib/aws-sdk-ec2/types.rb', line 2612

class AssociateRouteTableRequest < Struct.new(
  :gateway_id,
  :public_ipv_4_pool,
  :dry_run,
  :subnet_id,
  :route_table_id)
  SENSITIVE = []
  include Aws::Structure
end

#public_ipv_4_poolString

The ID of a public IPv4 pool. A public IPv4 pool is a pool of IPv4 addresses that you’ve brought to Amazon Web Services with BYOIP.

Returns:

  • (String)


2612
2613
2614
2615
2616
2617
2618
2619
2620
# File 'lib/aws-sdk-ec2/types.rb', line 2612

class AssociateRouteTableRequest < Struct.new(
  :gateway_id,
  :public_ipv_4_pool,
  :dry_run,
  :subnet_id,
  :route_table_id)
  SENSITIVE = []
  include Aws::Structure
end

#route_table_idString

The ID of the route table.

Returns:

  • (String)


2612
2613
2614
2615
2616
2617
2618
2619
2620
# File 'lib/aws-sdk-ec2/types.rb', line 2612

class AssociateRouteTableRequest < Struct.new(
  :gateway_id,
  :public_ipv_4_pool,
  :dry_run,
  :subnet_id,
  :route_table_id)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idString

The ID of the subnet.

Returns:

  • (String)


2612
2613
2614
2615
2616
2617
2618
2619
2620
# File 'lib/aws-sdk-ec2/types.rb', line 2612

class AssociateRouteTableRequest < Struct.new(
  :gateway_id,
  :public_ipv_4_pool,
  :dry_run,
  :subnet_id,
  :route_table_id)
  SENSITIVE = []
  include Aws::Structure
end