Class: Aws::EC2::Types::AssociateTrunkInterfaceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::AssociateTrunkInterfaceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#branch_interface_id ⇒ String
The ID of the branch network interface.
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#gre_key ⇒ Integer
The application key.
-
#trunk_interface_id ⇒ String
The ID of the trunk network interface.
-
#vlan_id ⇒ Integer
The ID of the VLAN.
Instance Attribute Details
#branch_interface_id ⇒ String
The ID of the branch network interface.
3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 |
# File 'lib/aws-sdk-ec2/types.rb', line 3449 class AssociateTrunkInterfaceRequest < Struct.new( :branch_interface_id, :trunk_interface_id, :vlan_id, :gre_key, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring idempotency.
A suitable default value is auto-generated. You should normally not need to pass this option.
3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 |
# File 'lib/aws-sdk-ec2/types.rb', line 3449 class AssociateTrunkInterfaceRequest < Struct.new( :branch_interface_id, :trunk_interface_id, :vlan_id, :gre_key, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 |
# File 'lib/aws-sdk-ec2/types.rb', line 3449 class AssociateTrunkInterfaceRequest < Struct.new( :branch_interface_id, :trunk_interface_id, :vlan_id, :gre_key, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#gre_key ⇒ Integer
The application key. This applies to the GRE protocol.
3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 |
# File 'lib/aws-sdk-ec2/types.rb', line 3449 class AssociateTrunkInterfaceRequest < Struct.new( :branch_interface_id, :trunk_interface_id, :vlan_id, :gre_key, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#trunk_interface_id ⇒ String
The ID of the trunk network interface.
3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 |
# File 'lib/aws-sdk-ec2/types.rb', line 3449 class AssociateTrunkInterfaceRequest < Struct.new( :branch_interface_id, :trunk_interface_id, :vlan_id, :gre_key, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#vlan_id ⇒ Integer
The ID of the VLAN. This applies to the VLAN protocol.
3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 |
# File 'lib/aws-sdk-ec2/types.rb', line 3449 class AssociateTrunkInterfaceRequest < Struct.new( :branch_interface_id, :trunk_interface_id, :vlan_id, :gre_key, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |