Class: Aws::EC2::Types::AttachClassicLinkVpcRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::AttachClassicLinkVpcRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#groups ⇒ Array<String>
The IDs of the security groups.
-
#instance_id ⇒ String
The ID of the EC2-Classic instance.
-
#vpc_id ⇒ String
The ID of the ClassicLink-enabled VPC.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
3729 3730 3731 3732 3733 3734 3735 3736 |
# File 'lib/aws-sdk-ec2/types.rb', line 3729 class AttachClassicLinkVpcRequest < Struct.new( :dry_run, :instance_id, :vpc_id, :groups) SENSITIVE = [] include Aws::Structure end |
#groups ⇒ Array<String>
The IDs of the security groups. You cannot specify security groups from a different VPC.
3729 3730 3731 3732 3733 3734 3735 3736 |
# File 'lib/aws-sdk-ec2/types.rb', line 3729 class AttachClassicLinkVpcRequest < Struct.new( :dry_run, :instance_id, :vpc_id, :groups) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the EC2-Classic instance.
3729 3730 3731 3732 3733 3734 3735 3736 |
# File 'lib/aws-sdk-ec2/types.rb', line 3729 class AttachClassicLinkVpcRequest < Struct.new( :dry_run, :instance_id, :vpc_id, :groups) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the ClassicLink-enabled VPC.
3729 3730 3731 3732 3733 3734 3735 3736 |
# File 'lib/aws-sdk-ec2/types.rb', line 3729 class AttachClassicLinkVpcRequest < Struct.new( :dry_run, :instance_id, :vpc_id, :groups) SENSITIVE = [] include Aws::Structure end |