Class: Aws::EC2::Types::AttachClassicLinkVpcRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


3727
3728
3729
3730
3731
3732
3733
3734
# File 'lib/aws-sdk-ec2/types.rb', line 3727

class AttachClassicLinkVpcRequest < Struct.new(
  :dry_run,
  :instance_id,
  :vpc_id,
  :groups)
  SENSITIVE = []
  include Aws::Structure
end

#groupsArray<String>

The IDs of the security groups. You cannot specify security groups from a different VPC.

Returns:

  • (Array<String>)


3727
3728
3729
3730
3731
3732
3733
3734
# File 'lib/aws-sdk-ec2/types.rb', line 3727

class AttachClassicLinkVpcRequest < Struct.new(
  :dry_run,
  :instance_id,
  :vpc_id,
  :groups)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The ID of the EC2-Classic instance.

Returns:

  • (String)


3727
3728
3729
3730
3731
3732
3733
3734
# File 'lib/aws-sdk-ec2/types.rb', line 3727

class AttachClassicLinkVpcRequest < Struct.new(
  :dry_run,
  :instance_id,
  :vpc_id,
  :groups)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the ClassicLink-enabled VPC.

Returns:

  • (String)


3727
3728
3729
3730
3731
3732
3733
3734
# File 'lib/aws-sdk-ec2/types.rb', line 3727

class AttachClassicLinkVpcRequest < Struct.new(
  :dry_run,
  :instance_id,
  :vpc_id,
  :groups)
  SENSITIVE = []
  include Aws::Structure
end