Class: Aws::EC2::Types::AttachImageWatermarkRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::AttachImageWatermarkRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#image_id ⇒ String
The ID of the AMI.
-
#watermark_name ⇒ String
The name for the watermark.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
3771 3772 3773 3774 3775 3776 3777 |
# File 'lib/aws-sdk-ec2/types.rb', line 3771 class AttachImageWatermarkRequest < Struct.new( :image_id, :watermark_name, :dry_run) SENSITIVE = [] include Aws::Structure end |
#image_id ⇒ String
The ID of the AMI.
3771 3772 3773 3774 3775 3776 3777 |
# File 'lib/aws-sdk-ec2/types.rb', line 3771 class AttachImageWatermarkRequest < Struct.new( :image_id, :watermark_name, :dry_run) SENSITIVE = [] include Aws::Structure end |
#watermark_name ⇒ String
The name for the watermark. Combined with the caller's account ID
to form the WatermarkKey (accountId:watermarkName).
Constraints: 3-128 alphanumeric characters, parentheses (()), square brackets ([]), spaces ( ), periods (.), slashes (/), dashes (-), single quotes ('), at-signs (@), or underscores(_)
3771 3772 3773 3774 3775 3776 3777 |
# File 'lib/aws-sdk-ec2/types.rb', line 3771 class AttachImageWatermarkRequest < Struct.new( :image_id, :watermark_name, :dry_run) SENSITIVE = [] include Aws::Structure end |