Class: Aws::EC2::Types::AttachInternetGatewayRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::AttachInternetGatewayRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#internet_gateway_id ⇒ String
The ID of the internet gateway.
-
#vpc_id ⇒ String
The ID of the VPC.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
3209 3210 3211 3212 3213 3214 3215 |
# File 'lib/aws-sdk-ec2/types.rb', line 3209 class AttachInternetGatewayRequest < Struct.new( :dry_run, :internet_gateway_id, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#internet_gateway_id ⇒ String
The ID of the internet gateway.
3209 3210 3211 3212 3213 3214 3215 |
# File 'lib/aws-sdk-ec2/types.rb', line 3209 class AttachInternetGatewayRequest < Struct.new( :dry_run, :internet_gateway_id, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC.
3209 3210 3211 3212 3213 3214 3215 |
# File 'lib/aws-sdk-ec2/types.rb', line 3209 class AttachInternetGatewayRequest < Struct.new( :dry_run, :internet_gateway_id, :vpc_id) SENSITIVE = [] include Aws::Structure end |