Class: Aws::EC2::Types::AttachInternetGatewayRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


3197
3198
3199
3200
3201
3202
3203
# File 'lib/aws-sdk-ec2/types.rb', line 3197

class AttachInternetGatewayRequest < Struct.new(
  :dry_run,
  :internet_gateway_id,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#internet_gateway_idString

The ID of the internet gateway.

Returns:

  • (String)


3197
3198
3199
3200
3201
3202
3203
# File 'lib/aws-sdk-ec2/types.rb', line 3197

class AttachInternetGatewayRequest < Struct.new(
  :dry_run,
  :internet_gateway_id,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC.

Returns:

  • (String)


3197
3198
3199
3200
3201
3202
3203
# File 'lib/aws-sdk-ec2/types.rb', line 3197

class AttachInternetGatewayRequest < Struct.new(
  :dry_run,
  :internet_gateway_id,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end