Class: Aws::EC2::Types::AttachNetworkInterfaceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::AttachNetworkInterfaceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for AttachNetworkInterface.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#device_index ⇒ Integer
The index of the device for the network interface attachment.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#ena_queue_count ⇒ Integer
The number of ENA queues to be created with the instance.
-
#ena_srd_specification ⇒ Types::EnaSrdSpecification
Configures ENA Express for the network interface that this action attaches to the instance.
-
#instance_id ⇒ String
The ID of the instance.
-
#network_card_index ⇒ Integer
The index of the network card.
-
#network_interface_id ⇒ String
The ID of the network interface.
Instance Attribute Details
#device_index ⇒ Integer
The index of the device for the network interface attachment.
3193 3194 3195 3196 3197 3198 3199 3200 3201 3202 3203 |
# File 'lib/aws-sdk-ec2/types.rb', line 3193 class AttachNetworkInterfaceRequest < Struct.new( :network_card_index, :ena_srd_specification, :ena_queue_count, :dry_run, :network_interface_id, :instance_id, :device_index) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
3193 3194 3195 3196 3197 3198 3199 3200 3201 3202 3203 |
# File 'lib/aws-sdk-ec2/types.rb', line 3193 class AttachNetworkInterfaceRequest < Struct.new( :network_card_index, :ena_srd_specification, :ena_queue_count, :dry_run, :network_interface_id, :instance_id, :device_index) SENSITIVE = [] include Aws::Structure end |
#ena_queue_count ⇒ Integer
The number of ENA queues to be created with the instance.
3193 3194 3195 3196 3197 3198 3199 3200 3201 3202 3203 |
# File 'lib/aws-sdk-ec2/types.rb', line 3193 class AttachNetworkInterfaceRequest < Struct.new( :network_card_index, :ena_srd_specification, :ena_queue_count, :dry_run, :network_interface_id, :instance_id, :device_index) SENSITIVE = [] include Aws::Structure end |
#ena_srd_specification ⇒ Types::EnaSrdSpecification
Configures ENA Express for the network interface that this action attaches to the instance.
3193 3194 3195 3196 3197 3198 3199 3200 3201 3202 3203 |
# File 'lib/aws-sdk-ec2/types.rb', line 3193 class AttachNetworkInterfaceRequest < Struct.new( :network_card_index, :ena_srd_specification, :ena_queue_count, :dry_run, :network_interface_id, :instance_id, :device_index) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the instance.
3193 3194 3195 3196 3197 3198 3199 3200 3201 3202 3203 |
# File 'lib/aws-sdk-ec2/types.rb', line 3193 class AttachNetworkInterfaceRequest < Struct.new( :network_card_index, :ena_srd_specification, :ena_queue_count, :dry_run, :network_interface_id, :instance_id, :device_index) SENSITIVE = [] include Aws::Structure end |
#network_card_index ⇒ Integer
The index of the network card. Some instance types support multiple network cards. The primary network interface must be assigned to network card index 0. The default is network card index 0.
3193 3194 3195 3196 3197 3198 3199 3200 3201 3202 3203 |
# File 'lib/aws-sdk-ec2/types.rb', line 3193 class AttachNetworkInterfaceRequest < Struct.new( :network_card_index, :ena_srd_specification, :ena_queue_count, :dry_run, :network_interface_id, :instance_id, :device_index) SENSITIVE = [] include Aws::Structure end |
#network_interface_id ⇒ String
The ID of the network interface.
3193 3194 3195 3196 3197 3198 3199 3200 3201 3202 3203 |
# File 'lib/aws-sdk-ec2/types.rb', line 3193 class AttachNetworkInterfaceRequest < Struct.new( :network_card_index, :ena_srd_specification, :ena_queue_count, :dry_run, :network_interface_id, :instance_id, :device_index) SENSITIVE = [] include Aws::Structure end |