Class: Aws::EC2::Types::AttachVolumeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#deviceString

The device name (for example, ‘/dev/sdh` or `xvdh`).

Returns:

  • (String)


3412
3413
3414
3415
3416
3417
3418
3419
3420
# File 'lib/aws-sdk-ec2/types.rb', line 3412

class AttachVolumeRequest < Struct.new(
  :device,
  :instance_id,
  :volume_id,
  :ebs_card_index,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


3412
3413
3414
3415
3416
3417
3418
3419
3420
# File 'lib/aws-sdk-ec2/types.rb', line 3412

class AttachVolumeRequest < Struct.new(
  :device,
  :instance_id,
  :volume_id,
  :ebs_card_index,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#ebs_card_indexInteger

The index of the EBS card. Some instance types support multiple EBS cards. The default EBS card index is 0.

Returns:

  • (Integer)


3412
3413
3414
3415
3416
3417
3418
3419
3420
# File 'lib/aws-sdk-ec2/types.rb', line 3412

class AttachVolumeRequest < Struct.new(
  :device,
  :instance_id,
  :volume_id,
  :ebs_card_index,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The ID of the instance.

Returns:

  • (String)


3412
3413
3414
3415
3416
3417
3418
3419
3420
# File 'lib/aws-sdk-ec2/types.rb', line 3412

class AttachVolumeRequest < Struct.new(
  :device,
  :instance_id,
  :volume_id,
  :ebs_card_index,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#volume_idString

The ID of the EBS volume. The volume and instance must be within the same Availability Zone.

Returns:

  • (String)


3412
3413
3414
3415
3416
3417
3418
3419
3420
# File 'lib/aws-sdk-ec2/types.rb', line 3412

class AttachVolumeRequest < Struct.new(
  :device,
  :instance_id,
  :volume_id,
  :ebs_card_index,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end