Class: Aws::EC2::Types::AttachVpnGatewayRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::AttachVpnGatewayRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for AttachVpnGateway.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#vpc_id ⇒ String
The ID of the VPC.
-
#vpn_gateway_id ⇒ String
The ID of the virtual private gateway.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
3998 3999 4000 4001 4002 4003 4004 |
# File 'lib/aws-sdk-ec2/types.rb', line 3998 class AttachVpnGatewayRequest < Struct.new( :vpc_id, :vpn_gateway_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC.
3998 3999 4000 4001 4002 4003 4004 |
# File 'lib/aws-sdk-ec2/types.rb', line 3998 class AttachVpnGatewayRequest < Struct.new( :vpc_id, :vpn_gateway_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#vpn_gateway_id ⇒ String
The ID of the virtual private gateway.
3998 3999 4000 4001 4002 4003 4004 |
# File 'lib/aws-sdk-ec2/types.rb', line 3998 class AttachVpnGatewayRequest < Struct.new( :vpc_id, :vpn_gateway_id, :dry_run) SENSITIVE = [] include Aws::Structure end |