Class: Aws::EC2::Types::AttachVpnGatewayRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::AttachVpnGatewayRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for AttachVpnGateway.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#vpc_id ⇒ String
The ID of the VPC.
-
#vpn_gateway_id ⇒ String
The ID of the virtual private gateway.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
3551 3552 3553 3554 3555 3556 3557 |
# File 'lib/aws-sdk-ec2/types.rb', line 3551 class AttachVpnGatewayRequest < Struct.new( :vpc_id, :vpn_gateway_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC.
3551 3552 3553 3554 3555 3556 3557 |
# File 'lib/aws-sdk-ec2/types.rb', line 3551 class AttachVpnGatewayRequest < Struct.new( :vpc_id, :vpn_gateway_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#vpn_gateway_id ⇒ String
The ID of the virtual private gateway.
3551 3552 3553 3554 3555 3556 3557 |
# File 'lib/aws-sdk-ec2/types.rb', line 3551 class AttachVpnGatewayRequest < Struct.new( :vpc_id, :vpn_gateway_id, :dry_run) SENSITIVE = [] include Aws::Structure end |