Class: Aws::EC2::Types::AvailableCapacity

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

The capacity information for instances that can be launched onto the Dedicated Host.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#available_instance_capacityArray<Types::InstanceCapacity>

The number of instances that can be launched onto the Dedicated Host depending on the host’s available capacity. For Dedicated Hosts that support multiple instance types, this parameter represents the number of instances for each instance size that is supported on the host.

Returns:



4088
4089
4090
4091
4092
4093
# File 'lib/aws-sdk-ec2/types.rb', line 4088

class AvailableCapacity < Struct.new(
  :available_instance_capacity,
  :available_v_cpus)
  SENSITIVE = []
  include Aws::Structure
end

#available_v_cpusInteger

The number of vCPUs available for launching instances onto the Dedicated Host.

Returns:

  • (Integer)


4088
4089
4090
4091
4092
4093
# File 'lib/aws-sdk-ec2/types.rb', line 4088

class AvailableCapacity < Struct.new(
  :available_instance_capacity,
  :available_v_cpus)
  SENSITIVE = []
  include Aws::Structure
end