Class: Aws::EC2::Types::BatchModifyIpamRoutingPolicyRegistrationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::BatchModifyIpamRoutingPolicyRegistrationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier to ensure that the operation completes no more than one time.
-
#delta_json ⇒ String
The batch modifications to apply, in JSON format.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#force ⇒ Boolean
Forces the batch modification even if individual changes conflict with announced routes.
-
#ipam_internet_registry_association_id ⇒ String
The ID of the IPAM internet registry association.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, the operation ignores the request, but does not return an error.
A suitable default value is auto-generated. You should normally not need to pass this option.
4829 4830 4831 4832 4833 4834 4835 4836 4837 |
# File 'lib/aws-sdk-ec2/types.rb', line 4829 class BatchModifyIpamRoutingPolicyRegistrationsRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id, :delta_json, :force, :client_token) SENSITIVE = [] include Aws::Structure end |
#delta_json ⇒ String
The batch modifications to apply, in JSON format.
4829 4830 4831 4832 4833 4834 4835 4836 4837 |
# File 'lib/aws-sdk-ec2/types.rb', line 4829 class BatchModifyIpamRoutingPolicyRegistrationsRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id, :delta_json, :force, :client_token) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
4829 4830 4831 4832 4833 4834 4835 4836 4837 |
# File 'lib/aws-sdk-ec2/types.rb', line 4829 class BatchModifyIpamRoutingPolicyRegistrationsRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id, :delta_json, :force, :client_token) SENSITIVE = [] include Aws::Structure end |
#force ⇒ Boolean
Forces the batch modification even if individual changes conflict
with announced routes. Default: false.
4829 4830 4831 4832 4833 4834 4835 4836 4837 |
# File 'lib/aws-sdk-ec2/types.rb', line 4829 class BatchModifyIpamRoutingPolicyRegistrationsRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id, :delta_json, :force, :client_token) SENSITIVE = [] include Aws::Structure end |
#ipam_internet_registry_association_id ⇒ String
The ID of the IPAM internet registry association.
4829 4830 4831 4832 4833 4834 4835 4836 4837 |
# File 'lib/aws-sdk-ec2/types.rb', line 4829 class BatchModifyIpamRoutingPolicyRegistrationsRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id, :delta_json, :force, :client_token) SENSITIVE = [] include Aws::Structure end |