Class: Aws::EC2::Types::BundleInstanceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::BundleInstanceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for BundleInstance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#instance_id ⇒ String
The ID of the instance to bundle.
-
#storage ⇒ Types::Storage
The bucket in which to store the AMI.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
4944 4945 4946 4947 4948 4949 4950 |
# File 'lib/aws-sdk-ec2/types.rb', line 4944 class BundleInstanceRequest < Struct.new( :instance_id, :storage, :dry_run) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the instance to bundle.
Default: None
4944 4945 4946 4947 4948 4949 4950 |
# File 'lib/aws-sdk-ec2/types.rb', line 4944 class BundleInstanceRequest < Struct.new( :instance_id, :storage, :dry_run) SENSITIVE = [] include Aws::Structure end |
#storage ⇒ Types::Storage
The bucket in which to store the AMI. You can specify a bucket that you already own or a new bucket that Amazon EC2 creates on your behalf. If you specify a bucket that belongs to someone else, Amazon EC2 returns an error.
4944 4945 4946 4947 4948 4949 4950 |
# File 'lib/aws-sdk-ec2/types.rb', line 4944 class BundleInstanceRequest < Struct.new( :instance_id, :storage, :dry_run) SENSITIVE = [] include Aws::Structure end |