Class: Aws::EC2::Types::CancelBundleTaskRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CancelBundleTaskRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for CancelBundleTask.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bundle_id ⇒ String
The ID of the bundle task.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#bundle_id ⇒ String
The ID of the bundle task.
5250 5251 5252 5253 5254 5255 |
# File 'lib/aws-sdk-ec2/types.rb', line 5250 class CancelBundleTaskRequest < Struct.new( :bundle_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
5250 5251 5252 5253 5254 5255 |
# File 'lib/aws-sdk-ec2/types.rb', line 5250 class CancelBundleTaskRequest < Struct.new( :bundle_id, :dry_run) SENSITIVE = [] include Aws::Structure end |