Class: Aws::EC2::Types::CancelBundleTaskRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for CancelBundleTask.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bundle_idString

The ID of the bundle task.

Returns:

  • (String)


4573
4574
4575
4576
4577
4578
# File 'lib/aws-sdk-ec2/types.rb', line 4573

class CancelBundleTaskRequest < Struct.new(
  :bundle_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


4573
4574
4575
4576
4577
4578
# File 'lib/aws-sdk-ec2/types.rb', line 4573

class CancelBundleTaskRequest < Struct.new(
  :bundle_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end