Class: Aws::EC2::Types::CancelCapacityReservationFleetsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_reservation_fleet_idsArray<String>

The IDs of the Capacity Reservation Fleets to cancel.

Returns:

  • (Array<String>)


4534
4535
4536
4537
4538
4539
# File 'lib/aws-sdk-ec2/types.rb', line 4534

class CancelCapacityReservationFleetsRequest < Struct.new(
  :dry_run,
  :capacity_reservation_fleet_ids)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


4534
4535
4536
4537
4538
4539
# File 'lib/aws-sdk-ec2/types.rb', line 4534

class CancelCapacityReservationFleetsRequest < Struct.new(
  :dry_run,
  :capacity_reservation_fleet_ids)
  SENSITIVE = []
  include Aws::Structure
end