Class: Aws::EC2::Types::CancelCapacityReservationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#apply_cancellation_chargesString

Specifies the cancellation charge type to apply when cancelling a future-dated Capacity Reservation during its commitment duration. Possible values include ‘commitment-wind-down`, which continues billing for the remaining commitment duration without delivering capacity.

Returns:

  • (String)


4692
4693
4694
4695
4696
4697
4698
4699
# File 'lib/aws-sdk-ec2/types.rb', line 4692

class CancelCapacityReservationRequest < Struct.new(
  :capacity_reservation_id,
  :dry_run,
  :apply_cancellation_charges,
  :quote_id)
  SENSITIVE = []
  include Aws::Structure
end

#capacity_reservation_idString

The ID of the Capacity Reservation to be cancelled.

Returns:

  • (String)


4692
4693
4694
4695
4696
4697
4698
4699
# File 'lib/aws-sdk-ec2/types.rb', line 4692

class CancelCapacityReservationRequest < Struct.new(
  :capacity_reservation_id,
  :dry_run,
  :apply_cancellation_charges,
  :quote_id)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


4692
4693
4694
4695
4696
4697
4698
4699
# File 'lib/aws-sdk-ec2/types.rb', line 4692

class CancelCapacityReservationRequest < Struct.new(
  :capacity_reservation_id,
  :dry_run,
  :apply_cancellation_charges,
  :quote_id)
  SENSITIVE = []
  include Aws::Structure
end

#quote_idString

The ID of the cancellation quote to use for the cancellation. You can generate a cancellation quote by using the ‘CreateCapacityReservationCancellationQuote` action. The cancellation quote must be in an `active` state.

Returns:

  • (String)


4692
4693
4694
4695
4696
4697
4698
4699
# File 'lib/aws-sdk-ec2/types.rb', line 4692

class CancelCapacityReservationRequest < Struct.new(
  :capacity_reservation_id,
  :dry_run,
  :apply_cancellation_charges,
  :quote_id)
  SENSITIVE = []
  include Aws::Structure
end