Class: Aws::EC2::Types::CancelCapacityReservationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CancelCapacityReservationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_reservation_id ⇒ String
The ID of the Capacity Reservation to be cancelled.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#capacity_reservation_id ⇒ String
The ID of the Capacity Reservation to be cancelled.
4677 4678 4679 4680 4681 4682 |
# File 'lib/aws-sdk-ec2/types.rb', line 4677 class CancelCapacityReservationRequest < Struct.new( :capacity_reservation_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
4677 4678 4679 4680 4681 4682 |
# File 'lib/aws-sdk-ec2/types.rb', line 4677 class CancelCapacityReservationRequest < Struct.new( :capacity_reservation_id, :dry_run) SENSITIVE = [] include Aws::Structure end |