Class: Aws::EC2::Types::CancelConversionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#conversion_task_idString

The ID of the conversion task.

Returns:

  • (String)


5331
5332
5333
5334
5335
5336
5337
# File 'lib/aws-sdk-ec2/types.rb', line 5331

class CancelConversionRequest < Struct.new(
  :dry_run,
  :conversion_task_id,
  :reason_message)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


5331
5332
5333
5334
5335
5336
5337
# File 'lib/aws-sdk-ec2/types.rb', line 5331

class CancelConversionRequest < Struct.new(
  :dry_run,
  :conversion_task_id,
  :reason_message)
  SENSITIVE = []
  include Aws::Structure
end

#reason_messageString

The reason for canceling the conversion task.

Returns:

  • (String)


5331
5332
5333
5334
5335
5336
5337
# File 'lib/aws-sdk-ec2/types.rb', line 5331

class CancelConversionRequest < Struct.new(
  :dry_run,
  :conversion_task_id,
  :reason_message)
  SENSITIVE = []
  include Aws::Structure
end