Class: Aws::EC2::Types::CancelDeclarativePoliciesReportRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


4723
4724
4725
4726
4727
4728
# File 'lib/aws-sdk-ec2/types.rb', line 4723

class CancelDeclarativePoliciesReportRequest < Struct.new(
  :dry_run,
  :report_id)
  SENSITIVE = []
  include Aws::Structure
end

#report_idString

The ID of the report.

Returns:

  • (String)


4723
4724
4725
4726
4727
4728
# File 'lib/aws-sdk-ec2/types.rb', line 4723

class CancelDeclarativePoliciesReportRequest < Struct.new(
  :dry_run,
  :report_id)
  SENSITIVE = []
  include Aws::Structure
end