Class: Aws::EC2::Types::CancelDeclarativePoliciesReportRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


4673
4674
4675
4676
4677
4678
# File 'lib/aws-sdk-ec2/types.rb', line 4673

class CancelDeclarativePoliciesReportRequest < Struct.new(
  :dry_run,
  :report_id)
  SENSITIVE = []
  include Aws::Structure
end

#report_idString

The ID of the report.

Returns:

  • (String)


4673
4674
4675
4676
4677
4678
# File 'lib/aws-sdk-ec2/types.rb', line 4673

class CancelDeclarativePoliciesReportRequest < Struct.new(
  :dry_run,
  :report_id)
  SENSITIVE = []
  include Aws::Structure
end