Class: Aws::EC2::Types::CancelDeclarativePoliciesReportRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CancelDeclarativePoliciesReportRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#report_id ⇒ String
The ID of the report.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
4631 4632 4633 4634 4635 4636 |
# File 'lib/aws-sdk-ec2/types.rb', line 4631 class CancelDeclarativePoliciesReportRequest < Struct.new( :dry_run, :report_id) SENSITIVE = [] include Aws::Structure end |
#report_id ⇒ String
The ID of the report.
4631 4632 4633 4634 4635 4636 |
# File 'lib/aws-sdk-ec2/types.rb', line 4631 class CancelDeclarativePoliciesReportRequest < Struct.new( :dry_run, :report_id) SENSITIVE = [] include Aws::Structure end |