Class: Aws::EC2::Types::CancelImageLaunchPermissionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


4951
4952
4953
4954
4955
4956
# File 'lib/aws-sdk-ec2/types.rb', line 4951

class CancelImageLaunchPermissionRequest < Struct.new(
  :image_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#image_idString

The ID of the AMI that was shared with your Amazon Web Services account.

Returns:

  • (String)


4951
4952
4953
4954
4955
4956
# File 'lib/aws-sdk-ec2/types.rb', line 4951

class CancelImageLaunchPermissionRequest < Struct.new(
  :image_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end