Class: Aws::EC2::Types::CancelImageLaunchPermissionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CancelImageLaunchPermissionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#image_id ⇒ String
The ID of the AMI that was shared with your Amazon Web Services account.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
4798 4799 4800 4801 4802 4803 |
# File 'lib/aws-sdk-ec2/types.rb', line 4798 class CancelImageLaunchPermissionRequest < Struct.new( :image_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#image_id ⇒ String
The ID of the AMI that was shared with your Amazon Web Services account.
4798 4799 4800 4801 4802 4803 |
# File 'lib/aws-sdk-ec2/types.rb', line 4798 class CancelImageLaunchPermissionRequest < Struct.new( :image_id, :dry_run) SENSITIVE = [] include Aws::Structure end |