Class: Aws::EC2::Types::CancelImportTaskRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CancelImportTaskRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cancel_reason ⇒ String
The reason for canceling the task.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#import_task_id ⇒ String
The ID of the import image or import snapshot task to be canceled.
Instance Attribute Details
#cancel_reason ⇒ String
The reason for canceling the task.
4988 4989 4990 4991 4992 4993 4994 |
# File 'lib/aws-sdk-ec2/types.rb', line 4988 class CancelImportTaskRequest < Struct.new( :cancel_reason, :dry_run, :import_task_id) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
4988 4989 4990 4991 4992 4993 4994 |
# File 'lib/aws-sdk-ec2/types.rb', line 4988 class CancelImportTaskRequest < Struct.new( :cancel_reason, :dry_run, :import_task_id) SENSITIVE = [] include Aws::Structure end |
#import_task_id ⇒ String
The ID of the import image or import snapshot task to be canceled.
4988 4989 4990 4991 4992 4993 4994 |
# File 'lib/aws-sdk-ec2/types.rb', line 4988 class CancelImportTaskRequest < Struct.new( :cancel_reason, :dry_run, :import_task_id) SENSITIVE = [] include Aws::Structure end |