Class: Aws::EC2::Types::CancelImportTaskRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cancel_reasonString

The reason for canceling the task.

Returns:

  • (String)


4714
4715
4716
4717
4718
4719
4720
# File 'lib/aws-sdk-ec2/types.rb', line 4714

class CancelImportTaskRequest < Struct.new(
  :cancel_reason,
  :dry_run,
  :import_task_id)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


4714
4715
4716
4717
4718
4719
4720
# File 'lib/aws-sdk-ec2/types.rb', line 4714

class CancelImportTaskRequest < Struct.new(
  :cancel_reason,
  :dry_run,
  :import_task_id)
  SENSITIVE = []
  include Aws::Structure
end

#import_task_idString

The ID of the import image or import snapshot task to be canceled.

Returns:

  • (String)


4714
4715
4716
4717
4718
4719
4720
# File 'lib/aws-sdk-ec2/types.rb', line 4714

class CancelImportTaskRequest < Struct.new(
  :cancel_reason,
  :dry_run,
  :import_task_id)
  SENSITIVE = []
  include Aws::Structure
end