Class: Aws::EC2::Types::CancelSpotFleetRequestsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CancelSpotFleetRequestsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for CancelSpotFleetRequests.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#spot_fleet_request_ids ⇒ Array<String>
The IDs of the Spot Fleet requests.
-
#terminate_instances ⇒ Boolean
Indicates whether to terminate the associated instances when the Spot Fleet request is canceled.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
5622 5623 5624 5625 5626 5627 5628 |
# File 'lib/aws-sdk-ec2/types.rb', line 5622 class CancelSpotFleetRequestsRequest < Struct.new( :dry_run, :spot_fleet_request_ids, :terminate_instances) SENSITIVE = [] include Aws::Structure end |
#spot_fleet_request_ids ⇒ Array<String>
The IDs of the Spot Fleet requests.
Constraint: You can specify up to 100 IDs in a single request.
5622 5623 5624 5625 5626 5627 5628 |
# File 'lib/aws-sdk-ec2/types.rb', line 5622 class CancelSpotFleetRequestsRequest < Struct.new( :dry_run, :spot_fleet_request_ids, :terminate_instances) SENSITIVE = [] include Aws::Structure end |
#terminate_instances ⇒ Boolean
Indicates whether to terminate the associated instances when the Spot Fleet request is canceled. The default is to terminate the instances.
To let the instances continue to run after the Spot Fleet request is
canceled, specify no-terminate-instances.
5622 5623 5624 5625 5626 5627 5628 |
# File 'lib/aws-sdk-ec2/types.rb', line 5622 class CancelSpotFleetRequestsRequest < Struct.new( :dry_run, :spot_fleet_request_ids, :terminate_instances) SENSITIVE = [] include Aws::Structure end |