Class: Aws::EC2::Types::CancelSpotInstanceRequestsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for CancelSpotInstanceRequests.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


5008
5009
5010
5011
5012
5013
# File 'lib/aws-sdk-ec2/types.rb', line 5008

class CancelSpotInstanceRequestsRequest < Struct.new(
  :dry_run,
  :spot_instance_request_ids)
  SENSITIVE = []
  include Aws::Structure
end

#spot_instance_request_idsArray<String>

The IDs of the Spot Instance requests.

Returns:

  • (Array<String>)


5008
5009
5010
5011
5012
5013
# File 'lib/aws-sdk-ec2/types.rb', line 5008

class CancelSpotInstanceRequestsRequest < Struct.new(
  :dry_run,
  :spot_instance_request_ids)
  SENSITIVE = []
  include Aws::Structure
end