Class: Aws::EC2::Types::CancelSpotInstanceRequestsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for CancelSpotInstanceRequests.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


4904
4905
4906
4907
4908
4909
# File 'lib/aws-sdk-ec2/types.rb', line 4904

class CancelSpotInstanceRequestsRequest < Struct.new(
  :dry_run,
  :spot_instance_request_ids)
  SENSITIVE = []
  include Aws::Structure
end

#spot_instance_request_idsArray<String>

The IDs of the Spot Instance requests.

Returns:

  • (Array<String>)


4904
4905
4906
4907
4908
4909
# File 'lib/aws-sdk-ec2/types.rb', line 4904

class CancelSpotInstanceRequestsRequest < Struct.new(
  :dry_run,
  :spot_instance_request_ids)
  SENSITIVE = []
  include Aws::Structure
end