Class: Aws::EC2::Types::CancellationTerms
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CancellationTerms
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the cancellation terms for cancelling a future-dated Capacity Reservation during its commitment duration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cancellation_type ⇒ String
The type of cancellation charge.
-
#charge_commitment_duration_hours ⇒ Integer
The number of hours for which cancellation charges will apply.
-
#charge_end_date ⇒ Time
The date and time at which cancellation charges will stop.
-
#committed_instance_count ⇒ Integer
The number of instances under commitment after cancellation.
-
#reservation_state ⇒ String
The state that the Capacity Reservation will transition to after cancellation.
Instance Attribute Details
#cancellation_type ⇒ String
The type of cancellation charge. Possible values include ‘commitment-wind-down`.
5073 5074 5075 5076 5077 5078 5079 5080 5081 |
# File 'lib/aws-sdk-ec2/types.rb', line 5073 class CancellationTerms < Struct.new( :cancellation_type, :reservation_state, :committed_instance_count, :charge_commitment_duration_hours, :charge_end_date) SENSITIVE = [] include Aws::Structure end |
#charge_commitment_duration_hours ⇒ Integer
The number of hours for which cancellation charges will apply.
5073 5074 5075 5076 5077 5078 5079 5080 5081 |
# File 'lib/aws-sdk-ec2/types.rb', line 5073 class CancellationTerms < Struct.new( :cancellation_type, :reservation_state, :committed_instance_count, :charge_commitment_duration_hours, :charge_end_date) SENSITIVE = [] include Aws::Structure end |
#charge_end_date ⇒ Time
The date and time at which cancellation charges will stop.
5073 5074 5075 5076 5077 5078 5079 5080 5081 |
# File 'lib/aws-sdk-ec2/types.rb', line 5073 class CancellationTerms < Struct.new( :cancellation_type, :reservation_state, :committed_instance_count, :charge_commitment_duration_hours, :charge_end_date) SENSITIVE = [] include Aws::Structure end |
#committed_instance_count ⇒ Integer
The number of instances under commitment after cancellation.
5073 5074 5075 5076 5077 5078 5079 5080 5081 |
# File 'lib/aws-sdk-ec2/types.rb', line 5073 class CancellationTerms < Struct.new( :cancellation_type, :reservation_state, :committed_instance_count, :charge_commitment_duration_hours, :charge_end_date) SENSITIVE = [] include Aws::Structure end |
#reservation_state ⇒ String
The state that the Capacity Reservation will transition to after cancellation.
5073 5074 5075 5076 5077 5078 5079 5080 5081 |
# File 'lib/aws-sdk-ec2/types.rb', line 5073 class CancellationTerms < Struct.new( :cancellation_type, :reservation_state, :committed_instance_count, :charge_commitment_duration_hours, :charge_end_date) SENSITIVE = [] include Aws::Structure end |