Class: Aws::EC2::Types::CapacityReservationTopology
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CapacityReservationTopology
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Information about the Capacity Reservation topology.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone ⇒ String
The name of the Availability Zone or Local Zone that the Capacity Reservation is in.
-
#availability_zone_id ⇒ String
The ID of the Availability Zone or Local Zone that the Capacity Reservation is in.
-
#capacity_block_id ⇒ String
The ID of the Capacity Block.
-
#capacity_reservation_id ⇒ String
The ID of the Capacity Reservation.
-
#group_name ⇒ String
The name of the placement group that the Capacity Reservation is in.
-
#instance_type ⇒ String
The instance type.
-
#network_nodes ⇒ Array<String>
The network nodes.
-
#state ⇒ String
The current state of the Capacity Reservation.
Instance Attribute Details
#availability_zone ⇒ String
The name of the Availability Zone or Local Zone that the Capacity Reservation is in.
6602 6603 6604 6605 6606 6607 6608 6609 6610 6611 6612 6613 |
# File 'lib/aws-sdk-ec2/types.rb', line 6602 class CapacityReservationTopology < Struct.new( :capacity_reservation_id, :capacity_block_id, :state, :instance_type, :group_name, :network_nodes, :availability_zone_id, :availability_zone) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
The ID of the Availability Zone or Local Zone that the Capacity Reservation is in.
6602 6603 6604 6605 6606 6607 6608 6609 6610 6611 6612 6613 |
# File 'lib/aws-sdk-ec2/types.rb', line 6602 class CapacityReservationTopology < Struct.new( :capacity_reservation_id, :capacity_block_id, :state, :instance_type, :group_name, :network_nodes, :availability_zone_id, :availability_zone) SENSITIVE = [] include Aws::Structure end |
#capacity_block_id ⇒ String
The ID of the Capacity Block. This parameter is only supported for UltraServer instances and identifies instances within the UltraServer domain.
6602 6603 6604 6605 6606 6607 6608 6609 6610 6611 6612 6613 |
# File 'lib/aws-sdk-ec2/types.rb', line 6602 class CapacityReservationTopology < Struct.new( :capacity_reservation_id, :capacity_block_id, :state, :instance_type, :group_name, :network_nodes, :availability_zone_id, :availability_zone) SENSITIVE = [] include Aws::Structure end |
#capacity_reservation_id ⇒ String
The ID of the Capacity Reservation.
6602 6603 6604 6605 6606 6607 6608 6609 6610 6611 6612 6613 |
# File 'lib/aws-sdk-ec2/types.rb', line 6602 class CapacityReservationTopology < Struct.new( :capacity_reservation_id, :capacity_block_id, :state, :instance_type, :group_name, :network_nodes, :availability_zone_id, :availability_zone) SENSITIVE = [] include Aws::Structure end |
#group_name ⇒ String
The name of the placement group that the Capacity Reservation is in.
6602 6603 6604 6605 6606 6607 6608 6609 6610 6611 6612 6613 |
# File 'lib/aws-sdk-ec2/types.rb', line 6602 class CapacityReservationTopology < Struct.new( :capacity_reservation_id, :capacity_block_id, :state, :instance_type, :group_name, :network_nodes, :availability_zone_id, :availability_zone) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The instance type.
6602 6603 6604 6605 6606 6607 6608 6609 6610 6611 6612 6613 |
# File 'lib/aws-sdk-ec2/types.rb', line 6602 class CapacityReservationTopology < Struct.new( :capacity_reservation_id, :capacity_block_id, :state, :instance_type, :group_name, :network_nodes, :availability_zone_id, :availability_zone) SENSITIVE = [] include Aws::Structure end |
#network_nodes ⇒ Array<String>
The network nodes. The nodes are hashed based on your account. Capacity Reservations from different accounts running under the same server will return a different hashed list of strings.
The value is ‘null` or empty if:
-
The instance type is not supported.
-
The Capacity Reservation is in a state other than ‘active` or `pending`.
6602 6603 6604 6605 6606 6607 6608 6609 6610 6611 6612 6613 |
# File 'lib/aws-sdk-ec2/types.rb', line 6602 class CapacityReservationTopology < Struct.new( :capacity_reservation_id, :capacity_block_id, :state, :instance_type, :group_name, :network_nodes, :availability_zone_id, :availability_zone) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the Capacity Reservation. For the list of possible states, see [DescribeCapacityReservations].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeCapacityReservations.html
6602 6603 6604 6605 6606 6607 6608 6609 6610 6611 6612 6613 |
# File 'lib/aws-sdk-ec2/types.rb', line 6602 class CapacityReservationTopology < Struct.new( :capacity_reservation_id, :capacity_block_id, :state, :instance_type, :group_name, :network_nodes, :availability_zone_id, :availability_zone) SENSITIVE = [] include Aws::Structure end |