Class: Aws::EC2::Types::ClientVpnRoute

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Information about a Client VPN endpoint route.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_vpn_endpoint_idString

The ID of the Client VPN endpoint with which the route is associated.

Returns:

  • (String)


8307
8308
8309
8310
8311
8312
8313
8314
8315
8316
8317
8318
# File 'lib/aws-sdk-ec2/types.rb', line 8307

class ClientVpnRoute < Struct.new(
  :client_vpn_endpoint_id,
  :destination_cidr,
  :target_subnet,
  :type,
  :origin,
  :status,
  :description,
  :transit_gateway_attachment_id)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A brief description of the route.

Returns:

  • (String)


8307
8308
8309
8310
8311
8312
8313
8314
8315
8316
8317
8318
# File 'lib/aws-sdk-ec2/types.rb', line 8307

class ClientVpnRoute < Struct.new(
  :client_vpn_endpoint_id,
  :destination_cidr,
  :target_subnet,
  :type,
  :origin,
  :status,
  :description,
  :transit_gateway_attachment_id)
  SENSITIVE = []
  include Aws::Structure
end

#destination_cidrString

The IPv4 address range, in CIDR notation, of the route destination.

Returns:

  • (String)


8307
8308
8309
8310
8311
8312
8313
8314
8315
8316
8317
8318
# File 'lib/aws-sdk-ec2/types.rb', line 8307

class ClientVpnRoute < Struct.new(
  :client_vpn_endpoint_id,
  :destination_cidr,
  :target_subnet,
  :type,
  :origin,
  :status,
  :description,
  :transit_gateway_attachment_id)
  SENSITIVE = []
  include Aws::Structure
end

#originString

Indicates how the route was associated with the Client VPN endpoint. associate indicates that the route was automatically added when the target network was associated with the Client VPN endpoint. add-route indicates that the route was manually added using the CreateClientVpnRoute action.

Returns:

  • (String)


8307
8308
8309
8310
8311
8312
8313
8314
8315
8316
8317
8318
# File 'lib/aws-sdk-ec2/types.rb', line 8307

class ClientVpnRoute < Struct.new(
  :client_vpn_endpoint_id,
  :destination_cidr,
  :target_subnet,
  :type,
  :origin,
  :status,
  :description,
  :transit_gateway_attachment_id)
  SENSITIVE = []
  include Aws::Structure
end

#statusTypes::ClientVpnRouteStatus

The current state of the route.



8307
8308
8309
8310
8311
8312
8313
8314
8315
8316
8317
8318
# File 'lib/aws-sdk-ec2/types.rb', line 8307

class ClientVpnRoute < Struct.new(
  :client_vpn_endpoint_id,
  :destination_cidr,
  :target_subnet,
  :type,
  :origin,
  :status,
  :description,
  :transit_gateway_attachment_id)
  SENSITIVE = []
  include Aws::Structure
end

#target_subnetString

The ID of the subnet through which traffic is routed.

Returns:

  • (String)


8307
8308
8309
8310
8311
8312
8313
8314
8315
8316
8317
8318
# File 'lib/aws-sdk-ec2/types.rb', line 8307

class ClientVpnRoute < Struct.new(
  :client_vpn_endpoint_id,
  :destination_cidr,
  :target_subnet,
  :type,
  :origin,
  :status,
  :description,
  :transit_gateway_attachment_id)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_attachment_idString

The ID of the Transit Gateway attachment, if the route targets a Transit Gateway.

Returns:

  • (String)


8307
8308
8309
8310
8311
8312
8313
8314
8315
8316
8317
8318
# File 'lib/aws-sdk-ec2/types.rb', line 8307

class ClientVpnRoute < Struct.new(
  :client_vpn_endpoint_id,
  :destination_cidr,
  :target_subnet,
  :type,
  :origin,
  :status,
  :description,
  :transit_gateway_attachment_id)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The route type.

Returns:

  • (String)


8307
8308
8309
8310
8311
8312
8313
8314
8315
8316
8317
8318
# File 'lib/aws-sdk-ec2/types.rb', line 8307

class ClientVpnRoute < Struct.new(
  :client_vpn_endpoint_id,
  :destination_cidr,
  :target_subnet,
  :type,
  :origin,
  :status,
  :description,
  :transit_gateway_attachment_id)
  SENSITIVE = []
  include Aws::Structure
end