Class: Aws::EC2::Types::ClientVpnRoute
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ClientVpnRoute
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Information about a Client VPN endpoint route.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_vpn_endpoint_id ⇒ String
The ID of the Client VPN endpoint with which the route is associated.
-
#description ⇒ String
A brief description of the route.
-
#destination_cidr ⇒ String
The IPv4 address range, in CIDR notation, of the route destination.
-
#origin ⇒ String
Indicates how the route was associated with the Client VPN endpoint.
-
#status ⇒ Types::ClientVpnRouteStatus
The current state of the route.
-
#target_subnet ⇒ String
The ID of the subnet through which traffic is routed.
-
#transit_gateway_attachment_id ⇒ String
The ID of the Transit Gateway attachment, if the route targets a Transit Gateway.
-
#type ⇒ String
The route type.
Instance Attribute Details
#client_vpn_endpoint_id ⇒ String
The ID of the Client VPN endpoint with which the route is associated.
7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 |
# File 'lib/aws-sdk-ec2/types.rb', line 7685 class ClientVpnRoute < Struct.new( :client_vpn_endpoint_id, :destination_cidr, :target_subnet, :type, :origin, :status, :description, :transit_gateway_attachment_id) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A brief description of the route.
7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 |
# File 'lib/aws-sdk-ec2/types.rb', line 7685 class ClientVpnRoute < Struct.new( :client_vpn_endpoint_id, :destination_cidr, :target_subnet, :type, :origin, :status, :description, :transit_gateway_attachment_id) SENSITIVE = [] include Aws::Structure end |
#destination_cidr ⇒ String
The IPv4 address range, in CIDR notation, of the route destination.
7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 |
# File 'lib/aws-sdk-ec2/types.rb', line 7685 class ClientVpnRoute < Struct.new( :client_vpn_endpoint_id, :destination_cidr, :target_subnet, :type, :origin, :status, :description, :transit_gateway_attachment_id) SENSITIVE = [] include Aws::Structure end |
#origin ⇒ String
Indicates how the route was associated with the Client VPN endpoint.
associate indicates that the route was automatically added when
the target network was associated with the Client VPN endpoint.
add-route indicates that the route was manually added using the
CreateClientVpnRoute action.
7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 |
# File 'lib/aws-sdk-ec2/types.rb', line 7685 class ClientVpnRoute < Struct.new( :client_vpn_endpoint_id, :destination_cidr, :target_subnet, :type, :origin, :status, :description, :transit_gateway_attachment_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::ClientVpnRouteStatus
The current state of the route.
7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 |
# File 'lib/aws-sdk-ec2/types.rb', line 7685 class ClientVpnRoute < Struct.new( :client_vpn_endpoint_id, :destination_cidr, :target_subnet, :type, :origin, :status, :description, :transit_gateway_attachment_id) SENSITIVE = [] include Aws::Structure end |
#target_subnet ⇒ String
The ID of the subnet through which traffic is routed.
7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 |
# File 'lib/aws-sdk-ec2/types.rb', line 7685 class ClientVpnRoute < Struct.new( :client_vpn_endpoint_id, :destination_cidr, :target_subnet, :type, :origin, :status, :description, :transit_gateway_attachment_id) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_attachment_id ⇒ String
The ID of the Transit Gateway attachment, if the route targets a Transit Gateway.
7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 |
# File 'lib/aws-sdk-ec2/types.rb', line 7685 class ClientVpnRoute < Struct.new( :client_vpn_endpoint_id, :destination_cidr, :target_subnet, :type, :origin, :status, :description, :transit_gateway_attachment_id) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The route type.
7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 |
# File 'lib/aws-sdk-ec2/types.rb', line 7685 class ClientVpnRoute < Struct.new( :client_vpn_endpoint_id, :destination_cidr, :target_subnet, :type, :origin, :status, :description, :transit_gateway_attachment_id) SENSITIVE = [] include Aws::Structure end |