Class: Aws::EC2::Types::CopyFpgaImageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CopyFpgaImageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#description ⇒ String
The description for the new AFI.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#name ⇒ String
The name for the new AFI.
-
#source_fpga_image_id ⇒ String
The ID of the source AFI.
-
#source_region ⇒ String
The Region that contains the source AFI.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [Ensuring idempotency].
[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html
8101 8102 8103 8104 8105 8106 8107 8108 8109 8110 |
# File 'lib/aws-sdk-ec2/types.rb', line 8101 class CopyFpgaImageRequest < Struct.new( :dry_run, :source_fpga_image_id, :description, :name, :source_region, :client_token) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description for the new AFI.
8101 8102 8103 8104 8105 8106 8107 8108 8109 8110 |
# File 'lib/aws-sdk-ec2/types.rb', line 8101 class CopyFpgaImageRequest < Struct.new( :dry_run, :source_fpga_image_id, :description, :name, :source_region, :client_token) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
8101 8102 8103 8104 8105 8106 8107 8108 8109 8110 |
# File 'lib/aws-sdk-ec2/types.rb', line 8101 class CopyFpgaImageRequest < Struct.new( :dry_run, :source_fpga_image_id, :description, :name, :source_region, :client_token) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name for the new AFI. The default is the name of the source AFI.
8101 8102 8103 8104 8105 8106 8107 8108 8109 8110 |
# File 'lib/aws-sdk-ec2/types.rb', line 8101 class CopyFpgaImageRequest < Struct.new( :dry_run, :source_fpga_image_id, :description, :name, :source_region, :client_token) SENSITIVE = [] include Aws::Structure end |
#source_fpga_image_id ⇒ String
The ID of the source AFI.
8101 8102 8103 8104 8105 8106 8107 8108 8109 8110 |
# File 'lib/aws-sdk-ec2/types.rb', line 8101 class CopyFpgaImageRequest < Struct.new( :dry_run, :source_fpga_image_id, :description, :name, :source_region, :client_token) SENSITIVE = [] include Aws::Structure end |
#source_region ⇒ String
The Region that contains the source AFI.
8101 8102 8103 8104 8105 8106 8107 8108 8109 8110 |
# File 'lib/aws-sdk-ec2/types.rb', line 8101 class CopyFpgaImageRequest < Struct.new( :dry_run, :source_fpga_image_id, :description, :name, :source_region, :client_token) SENSITIVE = [] include Aws::Structure end |