Class: Aws::EC2::Types::CreateApplicationStatusCheckRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateApplicationStatusCheckRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aggregation ⇒ String
The aggregation setting for the application status check.
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#device_index ⇒ Integer
The index of the network device to use for the health check.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#failure_threshold ⇒ Integer
The number of consecutive failed health checks before the application status is considered impaired.
-
#health_check_paths ⇒ Array<Types::HealthCheckPathRequestObject>
The health check paths to use for the application status check.
-
#initialization_grace_period_seconds ⇒ Integer
The number of seconds to wait before starting health checks after an instance is launched.
-
#interval ⇒ Integer
The interval, in seconds, between health checks.
-
#ip_scope ⇒ String
The IP scope to use for the health check.
-
#ip_version ⇒ String
The IP version to use for the health check.
-
#path ⇒ String
The URL path to use for the health check HTTP request (for example,
/healthor/status). -
#port ⇒ Integer
The port to use for the health check.
-
#protocol ⇒ String
The protocol to use for the health check.
-
#status_code_matcher ⇒ String
The HTTP status codes that indicate a successful health check response.
-
#success_threshold ⇒ Integer
The number of consecutive successful health checks before the application status is considered healthy.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the application status check.
-
#timeout ⇒ Integer
The amount of time, in seconds, to wait for a health check response before considering it failed.
Instance Attribute Details
#aggregation ⇒ String
The aggregation setting for the application status check. When set
to included, the result of this check contributes to the
instance-level application status reported by
DescribeApplicationStatus. When set to excluded, the check runs
independently and does not affect the instance-level status. Valid
values: included | excluded.
9682 9683 9684 9685 9686 9687 9688 9689 9690 9691 9692 9693 9694 9695 9696 9697 9698 9699 9700 9701 9702 |
# File 'lib/aws-sdk-ec2/types.rb', line 9682 class CreateApplicationStatusCheckRequest < Struct.new( :health_check_paths, :aggregation, :protocol, :port, :path, :device_index, :ip_version, :ip_scope, :interval, :timeout, :failure_threshold, :success_threshold, :status_code_matcher, :initialization_grace_period_seconds, :tag_specifications, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring idempotency.
A suitable default value is auto-generated. You should normally not need to pass this option.
9682 9683 9684 9685 9686 9687 9688 9689 9690 9691 9692 9693 9694 9695 9696 9697 9698 9699 9700 9701 9702 |
# File 'lib/aws-sdk-ec2/types.rb', line 9682 class CreateApplicationStatusCheckRequest < Struct.new( :health_check_paths, :aggregation, :protocol, :port, :path, :device_index, :ip_version, :ip_scope, :interval, :timeout, :failure_threshold, :success_threshold, :status_code_matcher, :initialization_grace_period_seconds, :tag_specifications, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#device_index ⇒ Integer
The index of the network device to use for the health check. The value must be greater than or equal to 0.
9682 9683 9684 9685 9686 9687 9688 9689 9690 9691 9692 9693 9694 9695 9696 9697 9698 9699 9700 9701 9702 |
# File 'lib/aws-sdk-ec2/types.rb', line 9682 class CreateApplicationStatusCheckRequest < Struct.new( :health_check_paths, :aggregation, :protocol, :port, :path, :device_index, :ip_version, :ip_scope, :interval, :timeout, :failure_threshold, :success_threshold, :status_code_matcher, :initialization_grace_period_seconds, :tag_specifications, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
9682 9683 9684 9685 9686 9687 9688 9689 9690 9691 9692 9693 9694 9695 9696 9697 9698 9699 9700 9701 9702 |
# File 'lib/aws-sdk-ec2/types.rb', line 9682 class CreateApplicationStatusCheckRequest < Struct.new( :health_check_paths, :aggregation, :protocol, :port, :path, :device_index, :ip_version, :ip_scope, :interval, :timeout, :failure_threshold, :success_threshold, :status_code_matcher, :initialization_grace_period_seconds, :tag_specifications, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#failure_threshold ⇒ Integer
The number of consecutive failed health checks before the application status is considered impaired. The value must be greater than 0.
9682 9683 9684 9685 9686 9687 9688 9689 9690 9691 9692 9693 9694 9695 9696 9697 9698 9699 9700 9701 9702 |
# File 'lib/aws-sdk-ec2/types.rb', line 9682 class CreateApplicationStatusCheckRequest < Struct.new( :health_check_paths, :aggregation, :protocol, :port, :path, :device_index, :ip_version, :ip_scope, :interval, :timeout, :failure_threshold, :success_threshold, :status_code_matcher, :initialization_grace_period_seconds, :tag_specifications, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#health_check_paths ⇒ Array<Types::HealthCheckPathRequestObject>
The health check paths to use for the application status check. Health check paths define the network path from a source subnet to one or more destination subnets for cross-Availability Zone or Availability Zone to Local Zone health checking. If omitted, health checks are performed in the same subnet as the instance.
9682 9683 9684 9685 9686 9687 9688 9689 9690 9691 9692 9693 9694 9695 9696 9697 9698 9699 9700 9701 9702 |
# File 'lib/aws-sdk-ec2/types.rb', line 9682 class CreateApplicationStatusCheckRequest < Struct.new( :health_check_paths, :aggregation, :protocol, :port, :path, :device_index, :ip_version, :ip_scope, :interval, :timeout, :failure_threshold, :success_threshold, :status_code_matcher, :initialization_grace_period_seconds, :tag_specifications, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#initialization_grace_period_seconds ⇒ Integer
The number of seconds to wait before starting health checks after an instance is launched. Valid values: 1 to 600.
9682 9683 9684 9685 9686 9687 9688 9689 9690 9691 9692 9693 9694 9695 9696 9697 9698 9699 9700 9701 9702 |
# File 'lib/aws-sdk-ec2/types.rb', line 9682 class CreateApplicationStatusCheckRequest < Struct.new( :health_check_paths, :aggregation, :protocol, :port, :path, :device_index, :ip_version, :ip_scope, :interval, :timeout, :failure_threshold, :success_threshold, :status_code_matcher, :initialization_grace_period_seconds, :tag_specifications, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#interval ⇒ Integer
The interval, in seconds, between health checks. Valid value: 60.
9682 9683 9684 9685 9686 9687 9688 9689 9690 9691 9692 9693 9694 9695 9696 9697 9698 9699 9700 9701 9702 |
# File 'lib/aws-sdk-ec2/types.rb', line 9682 class CreateApplicationStatusCheckRequest < Struct.new( :health_check_paths, :aggregation, :protocol, :port, :path, :device_index, :ip_version, :ip_scope, :interval, :timeout, :failure_threshold, :success_threshold, :status_code_matcher, :initialization_grace_period_seconds, :tag_specifications, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#ip_scope ⇒ String
The IP scope to use for the health check. Valid value: private.
9682 9683 9684 9685 9686 9687 9688 9689 9690 9691 9692 9693 9694 9695 9696 9697 9698 9699 9700 9701 9702 |
# File 'lib/aws-sdk-ec2/types.rb', line 9682 class CreateApplicationStatusCheckRequest < Struct.new( :health_check_paths, :aggregation, :protocol, :port, :path, :device_index, :ip_version, :ip_scope, :interval, :timeout, :failure_threshold, :success_threshold, :status_code_matcher, :initialization_grace_period_seconds, :tag_specifications, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#ip_version ⇒ String
The IP version to use for the health check. Valid values: ipv4 and
ipv6.
9682 9683 9684 9685 9686 9687 9688 9689 9690 9691 9692 9693 9694 9695 9696 9697 9698 9699 9700 9701 9702 |
# File 'lib/aws-sdk-ec2/types.rb', line 9682 class CreateApplicationStatusCheckRequest < Struct.new( :health_check_paths, :aggregation, :protocol, :port, :path, :device_index, :ip_version, :ip_scope, :interval, :timeout, :failure_threshold, :success_threshold, :status_code_matcher, :initialization_grace_period_seconds, :tag_specifications, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#path ⇒ String
The URL path to use for the health check HTTP request (for example,
/health or /status).
9682 9683 9684 9685 9686 9687 9688 9689 9690 9691 9692 9693 9694 9695 9696 9697 9698 9699 9700 9701 9702 |
# File 'lib/aws-sdk-ec2/types.rb', line 9682 class CreateApplicationStatusCheckRequest < Struct.new( :health_check_paths, :aggregation, :protocol, :port, :path, :device_index, :ip_version, :ip_scope, :interval, :timeout, :failure_threshold, :success_threshold, :status_code_matcher, :initialization_grace_period_seconds, :tag_specifications, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
The port to use for the health check. Valid values: 1 to 65535.
9682 9683 9684 9685 9686 9687 9688 9689 9690 9691 9692 9693 9694 9695 9696 9697 9698 9699 9700 9701 9702 |
# File 'lib/aws-sdk-ec2/types.rb', line 9682 class CreateApplicationStatusCheckRequest < Struct.new( :health_check_paths, :aggregation, :protocol, :port, :path, :device_index, :ip_version, :ip_scope, :interval, :timeout, :failure_threshold, :success_threshold, :status_code_matcher, :initialization_grace_period_seconds, :tag_specifications, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#protocol ⇒ String
The protocol to use for the health check. Valid values: http |
https.
9682 9683 9684 9685 9686 9687 9688 9689 9690 9691 9692 9693 9694 9695 9696 9697 9698 9699 9700 9701 9702 |
# File 'lib/aws-sdk-ec2/types.rb', line 9682 class CreateApplicationStatusCheckRequest < Struct.new( :health_check_paths, :aggregation, :protocol, :port, :path, :device_index, :ip_version, :ip_scope, :interval, :timeout, :failure_threshold, :success_threshold, :status_code_matcher, :initialization_grace_period_seconds, :tag_specifications, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#status_code_matcher ⇒ String
The HTTP status codes that indicate a successful health check
response. Specify a comma-separated list of individual status codes
or ranges, for example, 200,202,300-399. For a range, the first
value must be less than the second value. Maximum length: 64
characters. Default: 200.
9682 9683 9684 9685 9686 9687 9688 9689 9690 9691 9692 9693 9694 9695 9696 9697 9698 9699 9700 9701 9702 |
# File 'lib/aws-sdk-ec2/types.rb', line 9682 class CreateApplicationStatusCheckRequest < Struct.new( :health_check_paths, :aggregation, :protocol, :port, :path, :device_index, :ip_version, :ip_scope, :interval, :timeout, :failure_threshold, :success_threshold, :status_code_matcher, :initialization_grace_period_seconds, :tag_specifications, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#success_threshold ⇒ Integer
The number of consecutive successful health checks before the application status is considered healthy. The value must be greater than 0.
9682 9683 9684 9685 9686 9687 9688 9689 9690 9691 9692 9693 9694 9695 9696 9697 9698 9699 9700 9701 9702 |
# File 'lib/aws-sdk-ec2/types.rb', line 9682 class CreateApplicationStatusCheckRequest < Struct.new( :health_check_paths, :aggregation, :protocol, :port, :path, :device_index, :ip_version, :ip_scope, :interval, :timeout, :failure_threshold, :success_threshold, :status_code_matcher, :initialization_grace_period_seconds, :tag_specifications, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the application status check.
9682 9683 9684 9685 9686 9687 9688 9689 9690 9691 9692 9693 9694 9695 9696 9697 9698 9699 9700 9701 9702 |
# File 'lib/aws-sdk-ec2/types.rb', line 9682 class CreateApplicationStatusCheckRequest < Struct.new( :health_check_paths, :aggregation, :protocol, :port, :path, :device_index, :ip_version, :ip_scope, :interval, :timeout, :failure_threshold, :success_threshold, :status_code_matcher, :initialization_grace_period_seconds, :tag_specifications, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#timeout ⇒ Integer
The amount of time, in seconds, to wait for a health check response
before considering it failed. Valid values: 1 to 30. The value must
be less than Interval.
9682 9683 9684 9685 9686 9687 9688 9689 9690 9691 9692 9693 9694 9695 9696 9697 9698 9699 9700 9701 9702 |
# File 'lib/aws-sdk-ec2/types.rb', line 9682 class CreateApplicationStatusCheckRequest < Struct.new( :health_check_paths, :aggregation, :protocol, :port, :path, :device_index, :ip_version, :ip_scope, :interval, :timeout, :failure_threshold, :success_threshold, :status_code_matcher, :initialization_grace_period_seconds, :tag_specifications, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |