Class: Aws::EC2::Types::CreateCapacityManagerDataExportRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateCapacityManagerDataExportRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#output_format ⇒ String
The file format for the exported data.
-
#s3_bucket_name ⇒ String
The name of the S3 bucket where the capacity data export files will be delivered.
-
#s3_bucket_prefix ⇒ String
The S3 key prefix for the exported data files.
-
#schedule ⇒ String
The frequency at which data exports are generated.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the data export configuration.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensure Idempotency.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
8636 8637 8638 8639 8640 8641 8642 8643 8644 8645 8646 |
# File 'lib/aws-sdk-ec2/types.rb', line 8636 class CreateCapacityManagerDataExportRequest < Struct.new( :s3_bucket_name, :s3_bucket_prefix, :schedule, :output_format, :client_token, :dry_run, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
8636 8637 8638 8639 8640 8641 8642 8643 8644 8645 8646 |
# File 'lib/aws-sdk-ec2/types.rb', line 8636 class CreateCapacityManagerDataExportRequest < Struct.new( :s3_bucket_name, :s3_bucket_prefix, :schedule, :output_format, :client_token, :dry_run, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#output_format ⇒ String
The file format for the exported data. Parquet format is recommended for large datasets and better compression.
8636 8637 8638 8639 8640 8641 8642 8643 8644 8645 8646 |
# File 'lib/aws-sdk-ec2/types.rb', line 8636 class CreateCapacityManagerDataExportRequest < Struct.new( :s3_bucket_name, :s3_bucket_prefix, :schedule, :output_format, :client_token, :dry_run, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#s3_bucket_name ⇒ String
The name of the S3 bucket where the capacity data export files will be delivered. The bucket must exist and you must have write permissions to it.
8636 8637 8638 8639 8640 8641 8642 8643 8644 8645 8646 |
# File 'lib/aws-sdk-ec2/types.rb', line 8636 class CreateCapacityManagerDataExportRequest < Struct.new( :s3_bucket_name, :s3_bucket_prefix, :schedule, :output_format, :client_token, :dry_run, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#s3_bucket_prefix ⇒ String
The S3 key prefix for the exported data files. This allows you to organize exports in a specific folder structure within your bucket. If not specified, files are placed at the bucket root.
8636 8637 8638 8639 8640 8641 8642 8643 8644 8645 8646 |
# File 'lib/aws-sdk-ec2/types.rb', line 8636 class CreateCapacityManagerDataExportRequest < Struct.new( :s3_bucket_name, :s3_bucket_prefix, :schedule, :output_format, :client_token, :dry_run, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#schedule ⇒ String
The frequency at which data exports are generated.
8636 8637 8638 8639 8640 8641 8642 8643 8644 8645 8646 |
# File 'lib/aws-sdk-ec2/types.rb', line 8636 class CreateCapacityManagerDataExportRequest < Struct.new( :s3_bucket_name, :s3_bucket_prefix, :schedule, :output_format, :client_token, :dry_run, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the data export configuration. You can tag the export for organization and cost tracking purposes.
8636 8637 8638 8639 8640 8641 8642 8643 8644 8645 8646 |
# File 'lib/aws-sdk-ec2/types.rb', line 8636 class CreateCapacityManagerDataExportRequest < Struct.new( :s3_bucket_name, :s3_bucket_prefix, :schedule, :output_format, :client_token, :dry_run, :tag_specifications) SENSITIVE = [] include Aws::Structure end |