Class: Aws::EC2::Types::CreateCapacityManagerDataExportRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensure Idempotency.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
8568
# File 'lib/aws-sdk-ec2/types.rb', line 8558

class CreateCapacityManagerDataExportRequest < Struct.new(
  :s3_bucket_name,
  :s3_bucket_prefix,
  :schedule,
  :output_format,
  :client_token,
  :dry_run,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
8568
# File 'lib/aws-sdk-ec2/types.rb', line 8558

class CreateCapacityManagerDataExportRequest < Struct.new(
  :s3_bucket_name,
  :s3_bucket_prefix,
  :schedule,
  :output_format,
  :client_token,
  :dry_run,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#output_formatString

The file format for the exported data. Parquet format is recommended for large datasets and better compression.

Returns:

  • (String)


8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
8568
# File 'lib/aws-sdk-ec2/types.rb', line 8558

class CreateCapacityManagerDataExportRequest < Struct.new(
  :s3_bucket_name,
  :s3_bucket_prefix,
  :schedule,
  :output_format,
  :client_token,
  :dry_run,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#s3_bucket_nameString

The name of the S3 bucket where the capacity data export files will be delivered. The bucket must exist and you must have write permissions to it.

Returns:

  • (String)


8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
8568
# File 'lib/aws-sdk-ec2/types.rb', line 8558

class CreateCapacityManagerDataExportRequest < Struct.new(
  :s3_bucket_name,
  :s3_bucket_prefix,
  :schedule,
  :output_format,
  :client_token,
  :dry_run,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#s3_bucket_prefixString

The S3 key prefix for the exported data files. This allows you to organize exports in a specific folder structure within your bucket. If not specified, files are placed at the bucket root.

Returns:

  • (String)


8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
8568
# File 'lib/aws-sdk-ec2/types.rb', line 8558

class CreateCapacityManagerDataExportRequest < Struct.new(
  :s3_bucket_name,
  :s3_bucket_prefix,
  :schedule,
  :output_format,
  :client_token,
  :dry_run,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#scheduleString

The frequency at which data exports are generated.

Returns:

  • (String)


8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
8568
# File 'lib/aws-sdk-ec2/types.rb', line 8558

class CreateCapacityManagerDataExportRequest < Struct.new(
  :s3_bucket_name,
  :s3_bucket_prefix,
  :schedule,
  :output_format,
  :client_token,
  :dry_run,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the data export configuration. You can tag the export for organization and cost tracking purposes.

Returns:



8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
8568
# File 'lib/aws-sdk-ec2/types.rb', line 8558

class CreateCapacityManagerDataExportRequest < Struct.new(
  :s3_bucket_name,
  :s3_bucket_prefix,
  :schedule,
  :output_format,
  :client_token,
  :dry_run,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end