Class: Aws::EC2::Types::CreateCapacityManagerDataExportResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateCapacityManagerDataExportResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_manager_data_export_id ⇒ String
The unique identifier for the created data export configuration.
Instance Attribute Details
#capacity_manager_data_export_id ⇒ String
The unique identifier for the created data export configuration. Use this ID to reference the export in other API calls.
8577 8578 8579 8580 8581 |
# File 'lib/aws-sdk-ec2/types.rb', line 8577 class CreateCapacityManagerDataExportResult < Struct.new( :capacity_manager_data_export_id) SENSITIVE = [] include Aws::Structure end |