Class: Aws::EC2::Types::CreateCapacityReservationBySplittingRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [Ensure Idempotency].

**A suitable default value is auto-generated.** You should normally not need to pass this option.

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html

Returns:

  • (String)


9016
9017
9018
9019
9020
9021
9022
9023
9024
# File 'lib/aws-sdk-ec2/types.rb', line 9016

class CreateCapacityReservationBySplittingRequest < Struct.new(
  :dry_run,
  :client_token,
  :source_capacity_reservation_id,
  :instance_count,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


9016
9017
9018
9019
9020
9021
9022
9023
9024
# File 'lib/aws-sdk-ec2/types.rb', line 9016

class CreateCapacityReservationBySplittingRequest < Struct.new(
  :dry_run,
  :client_token,
  :source_capacity_reservation_id,
  :instance_count,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#instance_countInteger

The number of instances to split from the source Capacity Reservation.

Returns:

  • (Integer)


9016
9017
9018
9019
9020
9021
9022
9023
9024
# File 'lib/aws-sdk-ec2/types.rb', line 9016

class CreateCapacityReservationBySplittingRequest < Struct.new(
  :dry_run,
  :client_token,
  :source_capacity_reservation_id,
  :instance_count,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#source_capacity_reservation_idString

The ID of the Capacity Reservation from which you want to split the capacity.

Returns:

  • (String)


9016
9017
9018
9019
9020
9021
9022
9023
9024
# File 'lib/aws-sdk-ec2/types.rb', line 9016

class CreateCapacityReservationBySplittingRequest < Struct.new(
  :dry_run,
  :client_token,
  :source_capacity_reservation_id,
  :instance_count,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the new Capacity Reservation.

Returns:



9016
9017
9018
9019
9020
9021
9022
9023
9024
# File 'lib/aws-sdk-ec2/types.rb', line 9016

class CreateCapacityReservationBySplittingRequest < Struct.new(
  :dry_run,
  :client_token,
  :source_capacity_reservation_id,
  :instance_count,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end