Class: Aws::EC2::Types::CreateCapacityReservationBySplittingRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateCapacityReservationBySplittingRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#instance_count ⇒ Integer
The number of instances to split from the source Capacity Reservation.
-
#source_capacity_reservation_id ⇒ String
The ID of the Capacity Reservation from which you want to split the capacity.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the new Capacity Reservation.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [Ensure Idempotency].
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html
8863 8864 8865 8866 8867 8868 8869 8870 8871 |
# File 'lib/aws-sdk-ec2/types.rb', line 8863 class CreateCapacityReservationBySplittingRequest < Struct.new( :dry_run, :client_token, :source_capacity_reservation_id, :instance_count, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
8863 8864 8865 8866 8867 8868 8869 8870 8871 |
# File 'lib/aws-sdk-ec2/types.rb', line 8863 class CreateCapacityReservationBySplittingRequest < Struct.new( :dry_run, :client_token, :source_capacity_reservation_id, :instance_count, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#instance_count ⇒ Integer
The number of instances to split from the source Capacity Reservation.
8863 8864 8865 8866 8867 8868 8869 8870 8871 |
# File 'lib/aws-sdk-ec2/types.rb', line 8863 class CreateCapacityReservationBySplittingRequest < Struct.new( :dry_run, :client_token, :source_capacity_reservation_id, :instance_count, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#source_capacity_reservation_id ⇒ String
The ID of the Capacity Reservation from which you want to split the capacity.
8863 8864 8865 8866 8867 8868 8869 8870 8871 |
# File 'lib/aws-sdk-ec2/types.rb', line 8863 class CreateCapacityReservationBySplittingRequest < Struct.new( :dry_run, :client_token, :source_capacity_reservation_id, :instance_count, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the new Capacity Reservation.
8863 8864 8865 8866 8867 8868 8869 8870 8871 |
# File 'lib/aws-sdk-ec2/types.rb', line 8863 class CreateCapacityReservationBySplittingRequest < Struct.new( :dry_run, :client_token, :source_capacity_reservation_id, :instance_count, :tag_specifications) SENSITIVE = [] include Aws::Structure end |