Class: Aws::EC2::Types::CreateCapacityReservationCancellationQuoteRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_reservation_idString

The ID of the Capacity Reservation.

Returns:

  • (String)


9080
9081
9082
9083
9084
9085
9086
9087
# File 'lib/aws-sdk-ec2/types.rb', line 9080

class CreateCapacityReservationCancellationQuoteRequest < Struct.new(
  :capacity_reservation_id,
  :client_token,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [Ensure Idempotency].

**A suitable default value is auto-generated.** You should normally not need to pass this option.

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html

Returns:

  • (String)


9080
9081
9082
9083
9084
9085
9086
9087
# File 'lib/aws-sdk-ec2/types.rb', line 9080

class CreateCapacityReservationCancellationQuoteRequest < Struct.new(
  :capacity_reservation_id,
  :client_token,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


9080
9081
9082
9083
9084
9085
9086
9087
# File 'lib/aws-sdk-ec2/types.rb', line 9080

class CreateCapacityReservationCancellationQuoteRequest < Struct.new(
  :capacity_reservation_id,
  :client_token,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the cancellation quote.

Returns:



9080
9081
9082
9083
9084
9085
9086
9087
# File 'lib/aws-sdk-ec2/types.rb', line 9080

class CreateCapacityReservationCancellationQuoteRequest < Struct.new(
  :capacity_reservation_id,
  :client_token,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end