Class: Aws::EC2::Types::CreateCapacityReservationCancellationQuoteRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateCapacityReservationCancellationQuoteRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_reservation_id ⇒ String
The ID of the Capacity Reservation.
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the cancellation quote.
Instance Attribute Details
#capacity_reservation_id ⇒ String
The ID of the Capacity Reservation.
9080 9081 9082 9083 9084 9085 9086 9087 |
# File 'lib/aws-sdk-ec2/types.rb', line 9080 class CreateCapacityReservationCancellationQuoteRequest < Struct.new( :capacity_reservation_id, :client_token, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [Ensure Idempotency].
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html
9080 9081 9082 9083 9084 9085 9086 9087 |
# File 'lib/aws-sdk-ec2/types.rb', line 9080 class CreateCapacityReservationCancellationQuoteRequest < Struct.new( :capacity_reservation_id, :client_token, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
9080 9081 9082 9083 9084 9085 9086 9087 |
# File 'lib/aws-sdk-ec2/types.rb', line 9080 class CreateCapacityReservationCancellationQuoteRequest < Struct.new( :capacity_reservation_id, :client_token, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the cancellation quote.
9080 9081 9082 9083 9084 9085 9086 9087 |
# File 'lib/aws-sdk-ec2/types.rb', line 9080 class CreateCapacityReservationCancellationQuoteRequest < Struct.new( :capacity_reservation_id, :client_token, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |