Class: Aws::EC2::Types::CreateCarrierGatewayRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateCarrierGatewayRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to associate with the carrier gateway.
-
#vpc_id ⇒ String
The ID of the VPC to associate with the carrier gateway.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [How to ensure idempotency].
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html
9370 9371 9372 9373 9374 9375 9376 9377 |
# File 'lib/aws-sdk-ec2/types.rb', line 9370 class CreateCarrierGatewayRequest < Struct.new( :vpc_id, :tag_specifications, :dry_run, :client_token) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
9370 9371 9372 9373 9374 9375 9376 9377 |
# File 'lib/aws-sdk-ec2/types.rb', line 9370 class CreateCarrierGatewayRequest < Struct.new( :vpc_id, :tag_specifications, :dry_run, :client_token) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to associate with the carrier gateway.
9370 9371 9372 9373 9374 9375 9376 9377 |
# File 'lib/aws-sdk-ec2/types.rb', line 9370 class CreateCarrierGatewayRequest < Struct.new( :vpc_id, :tag_specifications, :dry_run, :client_token) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC to associate with the carrier gateway.
9370 9371 9372 9373 9374 9375 9376 9377 |
# File 'lib/aws-sdk-ec2/types.rb', line 9370 class CreateCarrierGatewayRequest < Struct.new( :vpc_id, :tag_specifications, :dry_run, :client_token) SENSITIVE = [] include Aws::Structure end |