Class: Aws::EC2::Types::CreateCoipCidrRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cidrString

A customer-owned IP address range to create.

Returns:

  • (String)


9538
9539
9540
9541
9542
9543
9544
# File 'lib/aws-sdk-ec2/types.rb', line 9538

class CreateCoipCidrRequest < Struct.new(
  :cidr,
  :coip_pool_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#coip_pool_idString

The ID of the address pool.

Returns:

  • (String)


9538
9539
9540
9541
9542
9543
9544
# File 'lib/aws-sdk-ec2/types.rb', line 9538

class CreateCoipCidrRequest < Struct.new(
  :cidr,
  :coip_pool_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


9538
9539
9540
9541
9542
9543
9544
# File 'lib/aws-sdk-ec2/types.rb', line 9538

class CreateCoipCidrRequest < Struct.new(
  :cidr,
  :coip_pool_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end