Class: Aws::EC2::Types::CreateCoipCidrRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateCoipCidrRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cidr ⇒ String
A customer-owned IP address range to create.
-
#coip_pool_id ⇒ String
The ID of the address pool.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#cidr ⇒ String
A customer-owned IP address range to create.
9466 9467 9468 9469 9470 9471 9472 |
# File 'lib/aws-sdk-ec2/types.rb', line 9466 class CreateCoipCidrRequest < Struct.new( :cidr, :coip_pool_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#coip_pool_id ⇒ String
The ID of the address pool.
9466 9467 9468 9469 9470 9471 9472 |
# File 'lib/aws-sdk-ec2/types.rb', line 9466 class CreateCoipCidrRequest < Struct.new( :cidr, :coip_pool_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
9466 9467 9468 9469 9470 9471 9472 |
# File 'lib/aws-sdk-ec2/types.rb', line 9466 class CreateCoipCidrRequest < Struct.new( :cidr, :coip_pool_id, :dry_run) SENSITIVE = [] include Aws::Structure end |