Class: Aws::EC2::Types::CreateCoipPoolRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


10696
10697
10698
10699
10700
10701
10702
# File 'lib/aws-sdk-ec2/types.rb', line 10696

class CreateCoipPoolRequest < Struct.new(
  :local_gateway_route_table_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#local_gateway_route_table_idString

The ID of the local gateway route table.

Returns:

  • (String)


10696
10697
10698
10699
10700
10701
10702
# File 'lib/aws-sdk-ec2/types.rb', line 10696

class CreateCoipPoolRequest < Struct.new(
  :local_gateway_route_table_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to assign to the CoIP address pool.

Returns:



10696
10697
10698
10699
10700
10701
10702
# File 'lib/aws-sdk-ec2/types.rb', line 10696

class CreateCoipPoolRequest < Struct.new(
  :local_gateway_route_table_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end