Class: Aws::EC2::Types::CreateCustomerGatewayRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateCustomerGatewayRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for CreateCustomerGateway.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bgp_asn ⇒ Integer
For customer gateway devices that support BGP, specify the device’s ASN.
-
#bgp_asn_extended ⇒ Integer
For customer gateway devices that support BGP, specify the device’s ASN.
-
#certificate_arn ⇒ String
The Amazon Resource Name (ARN) for the customer gateway certificate.
-
#device_name ⇒ String
A name for the customer gateway device.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#ip_address ⇒ String
The IP address for the customer gateway device’s outside interface.
-
#public_ip ⇒ String
*This member has been deprecated.* The Internet-routable IP address for the customer gateway’s outside interface.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the customer gateway.
-
#type ⇒ String
The type of VPN connection that this customer gateway supports (‘ipsec.1`).
Instance Attribute Details
#bgp_asn ⇒ Integer
For customer gateway devices that support BGP, specify the device’s ASN. You must specify either ‘BgpAsn` or `BgpAsnExtended` when creating the customer gateway. If the ASN is larger than `2,147,483,647`, you must use `BgpAsnExtended`.
Default: 65000
Valid values: ‘1` to `2,147,483,647`
9836 9837 9838 9839 9840 9841 9842 9843 9844 9845 9846 9847 9848 |
# File 'lib/aws-sdk-ec2/types.rb', line 9836 class CreateCustomerGatewayRequest < Struct.new( :bgp_asn, :public_ip, :certificate_arn, :type, :tag_specifications, :device_name, :ip_address, :bgp_asn_extended, :dry_run) SENSITIVE = [] include Aws::Structure end |
#bgp_asn_extended ⇒ Integer
For customer gateway devices that support BGP, specify the device’s ASN. You must specify either ‘BgpAsn` or `BgpAsnExtended` when creating the customer gateway. If the ASN is larger than `2,147,483,647`, you must use `BgpAsnExtended`.
Valid values: ‘2,147,483,648` to `4,294,967,295`
9836 9837 9838 9839 9840 9841 9842 9843 9844 9845 9846 9847 9848 |
# File 'lib/aws-sdk-ec2/types.rb', line 9836 class CreateCustomerGatewayRequest < Struct.new( :bgp_asn, :public_ip, :certificate_arn, :type, :tag_specifications, :device_name, :ip_address, :bgp_asn_extended, :dry_run) SENSITIVE = [] include Aws::Structure end |
#certificate_arn ⇒ String
The Amazon Resource Name (ARN) for the customer gateway certificate.
9836 9837 9838 9839 9840 9841 9842 9843 9844 9845 9846 9847 9848 |
# File 'lib/aws-sdk-ec2/types.rb', line 9836 class CreateCustomerGatewayRequest < Struct.new( :bgp_asn, :public_ip, :certificate_arn, :type, :tag_specifications, :device_name, :ip_address, :bgp_asn_extended, :dry_run) SENSITIVE = [] include Aws::Structure end |
#device_name ⇒ String
A name for the customer gateway device.
Length Constraints: Up to 255 characters.
9836 9837 9838 9839 9840 9841 9842 9843 9844 9845 9846 9847 9848 |
# File 'lib/aws-sdk-ec2/types.rb', line 9836 class CreateCustomerGatewayRequest < Struct.new( :bgp_asn, :public_ip, :certificate_arn, :type, :tag_specifications, :device_name, :ip_address, :bgp_asn_extended, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
9836 9837 9838 9839 9840 9841 9842 9843 9844 9845 9846 9847 9848 |
# File 'lib/aws-sdk-ec2/types.rb', line 9836 class CreateCustomerGatewayRequest < Struct.new( :bgp_asn, :public_ip, :certificate_arn, :type, :tag_specifications, :device_name, :ip_address, :bgp_asn_extended, :dry_run) SENSITIVE = [] include Aws::Structure end |
#ip_address ⇒ String
The IP address for the customer gateway device’s outside interface. The address must be static. If ‘OutsideIpAddressType` in your VPN connection options is set to `PrivateIpv4`, you can use an RFC6598 or RFC1918 private IPv4 address. If `OutsideIpAddressType` is set to `Ipv6`, you can use an IPv6 address.
9836 9837 9838 9839 9840 9841 9842 9843 9844 9845 9846 9847 9848 |
# File 'lib/aws-sdk-ec2/types.rb', line 9836 class CreateCustomerGatewayRequest < Struct.new( :bgp_asn, :public_ip, :certificate_arn, :type, :tag_specifications, :device_name, :ip_address, :bgp_asn_extended, :dry_run) SENSITIVE = [] include Aws::Structure end |
#public_ip ⇒ String
*This member has been deprecated.* The Internet-routable IP address for the customer gateway’s outside interface. The address must be static.
9836 9837 9838 9839 9840 9841 9842 9843 9844 9845 9846 9847 9848 |
# File 'lib/aws-sdk-ec2/types.rb', line 9836 class CreateCustomerGatewayRequest < Struct.new( :bgp_asn, :public_ip, :certificate_arn, :type, :tag_specifications, :device_name, :ip_address, :bgp_asn_extended, :dry_run) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the customer gateway.
9836 9837 9838 9839 9840 9841 9842 9843 9844 9845 9846 9847 9848 |
# File 'lib/aws-sdk-ec2/types.rb', line 9836 class CreateCustomerGatewayRequest < Struct.new( :bgp_asn, :public_ip, :certificate_arn, :type, :tag_specifications, :device_name, :ip_address, :bgp_asn_extended, :dry_run) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of VPN connection that this customer gateway supports (‘ipsec.1`).
9836 9837 9838 9839 9840 9841 9842 9843 9844 9845 9846 9847 9848 |
# File 'lib/aws-sdk-ec2/types.rb', line 9836 class CreateCustomerGatewayRequest < Struct.new( :bgp_asn, :public_ip, :certificate_arn, :type, :tag_specifications, :device_name, :ip_address, :bgp_asn_extended, :dry_run) SENSITIVE = [] include Aws::Structure end |