Class: Aws::EC2::Types::CreateDefaultSubnetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateDefaultSubnetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone ⇒ String
The Availability Zone in which to create the default subnet.
-
#availability_zone_id ⇒ String
The ID of the Availability Zone.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#ipv_6_native ⇒ Boolean
Indicates whether to create an IPv6 only subnet.
Instance Attribute Details
#availability_zone ⇒ String
The Availability Zone in which to create the default subnet.
Either ‘AvailabilityZone` or `AvailabilityZoneId` must be specified, but not both.
10140 10141 10142 10143 10144 10145 10146 10147 |
# File 'lib/aws-sdk-ec2/types.rb', line 10140 class CreateDefaultSubnetRequest < Struct.new( :availability_zone, :dry_run, :ipv_6_native, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
The ID of the Availability Zone.
Either ‘AvailabilityZone` or `AvailabilityZoneId` must be specified, but not both.
10140 10141 10142 10143 10144 10145 10146 10147 |
# File 'lib/aws-sdk-ec2/types.rb', line 10140 class CreateDefaultSubnetRequest < Struct.new( :availability_zone, :dry_run, :ipv_6_native, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
10140 10141 10142 10143 10144 10145 10146 10147 |
# File 'lib/aws-sdk-ec2/types.rb', line 10140 class CreateDefaultSubnetRequest < Struct.new( :availability_zone, :dry_run, :ipv_6_native, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#ipv_6_native ⇒ Boolean
Indicates whether to create an IPv6 only subnet. If you already have a default subnet for this Availability Zone, you must delete it before you can create an IPv6 only subnet.
10140 10141 10142 10143 10144 10145 10146 10147 |
# File 'lib/aws-sdk-ec2/types.rb', line 10140 class CreateDefaultSubnetRequest < Struct.new( :availability_zone, :dry_run, :ipv_6_native, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |