Class: Aws::EC2::Types::CreateDefaultSubnetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_zoneString

The Availability Zone in which to create the default subnet.

Either ‘AvailabilityZone` or `AvailabilityZoneId` must be specified, but not both.

Returns:

  • (String)


10097
10098
10099
10100
10101
10102
10103
10104
# File 'lib/aws-sdk-ec2/types.rb', line 10097

class CreateDefaultSubnetRequest < Struct.new(
  :availability_zone,
  :dry_run,
  :ipv_6_native,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zone_idString

The ID of the Availability Zone.

Either ‘AvailabilityZone` or `AvailabilityZoneId` must be specified, but not both.

Returns:

  • (String)


10097
10098
10099
10100
10101
10102
10103
10104
# File 'lib/aws-sdk-ec2/types.rb', line 10097

class CreateDefaultSubnetRequest < Struct.new(
  :availability_zone,
  :dry_run,
  :ipv_6_native,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


10097
10098
10099
10100
10101
10102
10103
10104
# File 'lib/aws-sdk-ec2/types.rb', line 10097

class CreateDefaultSubnetRequest < Struct.new(
  :availability_zone,
  :dry_run,
  :ipv_6_native,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#ipv_6_nativeBoolean

Indicates whether to create an IPv6 only subnet. If you already have a default subnet for this Availability Zone, you must delete it before you can create an IPv6 only subnet.

Returns:

  • (Boolean)


10097
10098
10099
10100
10101
10102
10103
10104
# File 'lib/aws-sdk-ec2/types.rb', line 10097

class CreateDefaultSubnetRequest < Struct.new(
  :availability_zone,
  :dry_run,
  :ipv_6_native,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end