Class: Aws::EC2::Types::CreateDefaultVpcRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


9923
9924
9925
9926
9927
# File 'lib/aws-sdk-ec2/types.rb', line 9923

class CreateDefaultVpcRequest < Struct.new(
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end