Class: Aws::EC2::Types::CreateDhcpOptionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateDhcpOptionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dhcp_configurations ⇒ Array<Types::NewDhcpConfiguration>
A DHCP configuration option.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the DHCP option.
Instance Attribute Details
#dhcp_configurations ⇒ Array<Types::NewDhcpConfiguration>
A DHCP configuration option.
10981 10982 10983 10984 10985 10986 10987 |
# File 'lib/aws-sdk-ec2/types.rb', line 10981 class CreateDhcpOptionsRequest < Struct.new( :dhcp_configurations, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
10981 10982 10983 10984 10985 10986 10987 |
# File 'lib/aws-sdk-ec2/types.rb', line 10981 class CreateDhcpOptionsRequest < Struct.new( :dhcp_configurations, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the DHCP option.
10981 10982 10983 10984 10985 10986 10987 |
# File 'lib/aws-sdk-ec2/types.rb', line 10981 class CreateDhcpOptionsRequest < Struct.new( :dhcp_configurations, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |