Class: Aws::EC2::Types::CreateFleetInstance

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes the instances that were launched by the fleet.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_zoneString

The name of the Availability Zone in which the instance was launched. For example, us-east-2a.

Supported only for fleets of type instant.

Returns:

  • (String)


11149
11150
11151
11152
11153
11154
11155
11156
11157
11158
11159
11160
# File 'lib/aws-sdk-ec2/types.rb', line 11149

class CreateFleetInstance < Struct.new(
  :launch_template_and_overrides,
  :lifecycle,
  :instance_ids,
  :instance_type,
  :platform,
  :availability_zone_id,
  :availability_zone,
  :subnet_id)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zone_idString

The ID of the Availability Zone in which the instance was launched. For example, use2-az1.

Supported only for fleets of type instant.

Returns:

  • (String)


11149
11150
11151
11152
11153
11154
11155
11156
11157
11158
11159
11160
# File 'lib/aws-sdk-ec2/types.rb', line 11149

class CreateFleetInstance < Struct.new(
  :launch_template_and_overrides,
  :lifecycle,
  :instance_ids,
  :instance_type,
  :platform,
  :availability_zone_id,
  :availability_zone,
  :subnet_id)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idsArray<String>

The IDs of the instances.

Returns:

  • (Array<String>)


11149
11150
11151
11152
11153
11154
11155
11156
11157
11158
11159
11160
# File 'lib/aws-sdk-ec2/types.rb', line 11149

class CreateFleetInstance < Struct.new(
  :launch_template_and_overrides,
  :lifecycle,
  :instance_ids,
  :instance_type,
  :platform,
  :availability_zone_id,
  :availability_zone,
  :subnet_id)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

The instance type.

Returns:

  • (String)


11149
11150
11151
11152
11153
11154
11155
11156
11157
11158
11159
11160
# File 'lib/aws-sdk-ec2/types.rb', line 11149

class CreateFleetInstance < Struct.new(
  :launch_template_and_overrides,
  :lifecycle,
  :instance_ids,
  :instance_type,
  :platform,
  :availability_zone_id,
  :availability_zone,
  :subnet_id)
  SENSITIVE = []
  include Aws::Structure
end

#launch_template_and_overridesTypes::LaunchTemplateAndOverridesResponse

The launch templates and overrides that were used for launching the instances. The values that you specify in the Overrides replace the values in the launch template.



11149
11150
11151
11152
11153
11154
11155
11156
11157
11158
11159
11160
# File 'lib/aws-sdk-ec2/types.rb', line 11149

class CreateFleetInstance < Struct.new(
  :launch_template_and_overrides,
  :lifecycle,
  :instance_ids,
  :instance_type,
  :platform,
  :availability_zone_id,
  :availability_zone,
  :subnet_id)
  SENSITIVE = []
  include Aws::Structure
end

#lifecycleString

Indicates if the instance that was launched is a Spot, On-Demand, Capacity Block, or Interruptible Capacity Reservation instance.

Returns:

  • (String)


11149
11150
11151
11152
11153
11154
11155
11156
11157
11158
11159
11160
# File 'lib/aws-sdk-ec2/types.rb', line 11149

class CreateFleetInstance < Struct.new(
  :launch_template_and_overrides,
  :lifecycle,
  :instance_ids,
  :instance_type,
  :platform,
  :availability_zone_id,
  :availability_zone,
  :subnet_id)
  SENSITIVE = []
  include Aws::Structure
end

#platformString

The value is windows for Windows instances in an EC2 Fleet. Otherwise, the value is blank.

Returns:

  • (String)


11149
11150
11151
11152
11153
11154
11155
11156
11157
11158
11159
11160
# File 'lib/aws-sdk-ec2/types.rb', line 11149

class CreateFleetInstance < Struct.new(
  :launch_template_and_overrides,
  :lifecycle,
  :instance_ids,
  :instance_type,
  :platform,
  :availability_zone_id,
  :availability_zone,
  :subnet_id)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idString

The ID of the subnet in which the instance was launched.

Supported only for fleets of type instant.

Returns:

  • (String)


11149
11150
11151
11152
11153
11154
11155
11156
11157
11158
11159
11160
# File 'lib/aws-sdk-ec2/types.rb', line 11149

class CreateFleetInstance < Struct.new(
  :launch_template_and_overrides,
  :lifecycle,
  :instance_ids,
  :instance_type,
  :platform,
  :availability_zone_id,
  :availability_zone,
  :subnet_id)
  SENSITIVE = []
  include Aws::Structure
end