Class: Aws::EC2::Types::CreateFleetInstance
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateFleetInstance
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the instances that were launched by the fleet.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone ⇒ String
The name of the Availability Zone in which the instance was launched.
-
#availability_zone_id ⇒ String
The ID of the Availability Zone in which the instance was launched.
-
#instance_ids ⇒ Array<String>
The IDs of the instances.
-
#instance_type ⇒ String
The instance type.
-
#launch_template_and_overrides ⇒ Types::LaunchTemplateAndOverridesResponse
The launch templates and overrides that were used for launching the instances.
-
#lifecycle ⇒ String
Indicates if the instance that was launched is a Spot, On-Demand, Capacity Block, or Interruptible Capacity Reservation instance.
-
#platform ⇒ String
The value is
windowsfor Windows instances in an EC2 Fleet. -
#subnet_id ⇒ String
The ID of the subnet in which the instance was launched.
Instance Attribute Details
#availability_zone ⇒ String
The name of the Availability Zone in which the instance was
launched. For example, us-east-2a.
Supported only for fleets of type instant.
11149 11150 11151 11152 11153 11154 11155 11156 11157 11158 11159 11160 |
# File 'lib/aws-sdk-ec2/types.rb', line 11149 class CreateFleetInstance < Struct.new( :launch_template_and_overrides, :lifecycle, :instance_ids, :instance_type, :platform, :availability_zone_id, :availability_zone, :subnet_id) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
The ID of the Availability Zone in which the instance was launched.
For example, use2-az1.
Supported only for fleets of type instant.
11149 11150 11151 11152 11153 11154 11155 11156 11157 11158 11159 11160 |
# File 'lib/aws-sdk-ec2/types.rb', line 11149 class CreateFleetInstance < Struct.new( :launch_template_and_overrides, :lifecycle, :instance_ids, :instance_type, :platform, :availability_zone_id, :availability_zone, :subnet_id) SENSITIVE = [] include Aws::Structure end |
#instance_ids ⇒ Array<String>
The IDs of the instances.
11149 11150 11151 11152 11153 11154 11155 11156 11157 11158 11159 11160 |
# File 'lib/aws-sdk-ec2/types.rb', line 11149 class CreateFleetInstance < Struct.new( :launch_template_and_overrides, :lifecycle, :instance_ids, :instance_type, :platform, :availability_zone_id, :availability_zone, :subnet_id) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The instance type.
11149 11150 11151 11152 11153 11154 11155 11156 11157 11158 11159 11160 |
# File 'lib/aws-sdk-ec2/types.rb', line 11149 class CreateFleetInstance < Struct.new( :launch_template_and_overrides, :lifecycle, :instance_ids, :instance_type, :platform, :availability_zone_id, :availability_zone, :subnet_id) SENSITIVE = [] include Aws::Structure end |
#launch_template_and_overrides ⇒ Types::LaunchTemplateAndOverridesResponse
The launch templates and overrides that were used for launching the instances. The values that you specify in the Overrides replace the values in the launch template.
11149 11150 11151 11152 11153 11154 11155 11156 11157 11158 11159 11160 |
# File 'lib/aws-sdk-ec2/types.rb', line 11149 class CreateFleetInstance < Struct.new( :launch_template_and_overrides, :lifecycle, :instance_ids, :instance_type, :platform, :availability_zone_id, :availability_zone, :subnet_id) SENSITIVE = [] include Aws::Structure end |
#lifecycle ⇒ String
Indicates if the instance that was launched is a Spot, On-Demand, Capacity Block, or Interruptible Capacity Reservation instance.
11149 11150 11151 11152 11153 11154 11155 11156 11157 11158 11159 11160 |
# File 'lib/aws-sdk-ec2/types.rb', line 11149 class CreateFleetInstance < Struct.new( :launch_template_and_overrides, :lifecycle, :instance_ids, :instance_type, :platform, :availability_zone_id, :availability_zone, :subnet_id) SENSITIVE = [] include Aws::Structure end |
#platform ⇒ String
The value is windows for Windows instances in an EC2 Fleet.
Otherwise, the value is blank.
11149 11150 11151 11152 11153 11154 11155 11156 11157 11158 11159 11160 |
# File 'lib/aws-sdk-ec2/types.rb', line 11149 class CreateFleetInstance < Struct.new( :launch_template_and_overrides, :lifecycle, :instance_ids, :instance_type, :platform, :availability_zone_id, :availability_zone, :subnet_id) SENSITIVE = [] include Aws::Structure end |
#subnet_id ⇒ String
The ID of the subnet in which the instance was launched.
Supported only for fleets of type instant.
11149 11150 11151 11152 11153 11154 11155 11156 11157 11158 11159 11160 |
# File 'lib/aws-sdk-ec2/types.rb', line 11149 class CreateFleetInstance < Struct.new( :launch_template_and_overrides, :lifecycle, :instance_ids, :instance_type, :platform, :availability_zone_id, :availability_zone, :subnet_id) SENSITIVE = [] include Aws::Structure end |