Class: Aws::EC2::Types::CreateFleetInstance
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateFleetInstance
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the instances that were launched by the fleet.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_ids ⇒ Array<String>
The IDs of the instances.
-
#instance_type ⇒ String
The instance type.
-
#launch_template_and_overrides ⇒ Types::LaunchTemplateAndOverridesResponse
The launch templates and overrides that were used for launching the instances.
-
#lifecycle ⇒ String
Indicates if the instance that was launched is a Spot, On-Demand, Capacity Block, or Interruptible Capacity Reservation instance.
-
#platform ⇒ String
The value is ‘windows` for Windows instances in an EC2 Fleet.
Instance Attribute Details
#instance_ids ⇒ Array<String>
The IDs of the instances.
10432 10433 10434 10435 10436 10437 10438 10439 10440 |
# File 'lib/aws-sdk-ec2/types.rb', line 10432 class CreateFleetInstance < Struct.new( :launch_template_and_overrides, :lifecycle, :instance_ids, :instance_type, :platform) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The instance type.
10432 10433 10434 10435 10436 10437 10438 10439 10440 |
# File 'lib/aws-sdk-ec2/types.rb', line 10432 class CreateFleetInstance < Struct.new( :launch_template_and_overrides, :lifecycle, :instance_ids, :instance_type, :platform) SENSITIVE = [] include Aws::Structure end |
#launch_template_and_overrides ⇒ Types::LaunchTemplateAndOverridesResponse
The launch templates and overrides that were used for launching the instances. The values that you specify in the Overrides replace the values in the launch template.
10432 10433 10434 10435 10436 10437 10438 10439 10440 |
# File 'lib/aws-sdk-ec2/types.rb', line 10432 class CreateFleetInstance < Struct.new( :launch_template_and_overrides, :lifecycle, :instance_ids, :instance_type, :platform) SENSITIVE = [] include Aws::Structure end |
#lifecycle ⇒ String
Indicates if the instance that was launched is a Spot, On-Demand, Capacity Block, or Interruptible Capacity Reservation instance.
10432 10433 10434 10435 10436 10437 10438 10439 10440 |
# File 'lib/aws-sdk-ec2/types.rb', line 10432 class CreateFleetInstance < Struct.new( :launch_template_and_overrides, :lifecycle, :instance_ids, :instance_type, :platform) SENSITIVE = [] include Aws::Structure end |
#platform ⇒ String
The value is ‘windows` for Windows instances in an EC2 Fleet. Otherwise, the value is blank.
10432 10433 10434 10435 10436 10437 10438 10439 10440 |
# File 'lib/aws-sdk-ec2/types.rb', line 10432 class CreateFleetInstance < Struct.new( :launch_template_and_overrides, :lifecycle, :instance_ids, :instance_type, :platform) SENSITIVE = [] include Aws::Structure end |