Class: Aws::EC2::Types::CreateFpgaImageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateFpgaImageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#description ⇒ String
A description for the AFI.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#input_storage_location ⇒ Types::StorageLocation
The location of the encrypted design checkpoint in Amazon S3.
-
#logs_storage_location ⇒ Types::StorageLocation
The location in Amazon S3 for the output logs.
-
#name ⇒ String
A name for the AFI.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the FPGA image during creation.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring Idempotency.
11626 11627 11628 11629 11630 11631 11632 11633 11634 11635 11636 |
# File 'lib/aws-sdk-ec2/types.rb', line 11626 class CreateFpgaImageRequest < Struct.new( :dry_run, :input_storage_location, :logs_storage_location, :description, :name, :client_token, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description for the AFI.
11626 11627 11628 11629 11630 11631 11632 11633 11634 11635 11636 |
# File 'lib/aws-sdk-ec2/types.rb', line 11626 class CreateFpgaImageRequest < Struct.new( :dry_run, :input_storage_location, :logs_storage_location, :description, :name, :client_token, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
11626 11627 11628 11629 11630 11631 11632 11633 11634 11635 11636 |
# File 'lib/aws-sdk-ec2/types.rb', line 11626 class CreateFpgaImageRequest < Struct.new( :dry_run, :input_storage_location, :logs_storage_location, :description, :name, :client_token, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#input_storage_location ⇒ Types::StorageLocation
The location of the encrypted design checkpoint in Amazon S3. The input must be a tarball.
11626 11627 11628 11629 11630 11631 11632 11633 11634 11635 11636 |
# File 'lib/aws-sdk-ec2/types.rb', line 11626 class CreateFpgaImageRequest < Struct.new( :dry_run, :input_storage_location, :logs_storage_location, :description, :name, :client_token, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#logs_storage_location ⇒ Types::StorageLocation
The location in Amazon S3 for the output logs.
11626 11627 11628 11629 11630 11631 11632 11633 11634 11635 11636 |
# File 'lib/aws-sdk-ec2/types.rb', line 11626 class CreateFpgaImageRequest < Struct.new( :dry_run, :input_storage_location, :logs_storage_location, :description, :name, :client_token, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A name for the AFI.
11626 11627 11628 11629 11630 11631 11632 11633 11634 11635 11636 |
# File 'lib/aws-sdk-ec2/types.rb', line 11626 class CreateFpgaImageRequest < Struct.new( :dry_run, :input_storage_location, :logs_storage_location, :description, :name, :client_token, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the FPGA image during creation.
11626 11627 11628 11629 11630 11631 11632 11633 11634 11635 11636 |
# File 'lib/aws-sdk-ec2/types.rb', line 11626 class CreateFpgaImageRequest < Struct.new( :dry_run, :input_storage_location, :logs_storage_location, :description, :name, :client_token, :tag_specifications) SENSITIVE = [] include Aws::Structure end |