Class: Aws::EC2::Types::CreateFpgaImageRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring Idempotency.

Returns:

  • (String)


11561
11562
11563
11564
11565
11566
11567
11568
11569
11570
11571
# File 'lib/aws-sdk-ec2/types.rb', line 11561

class CreateFpgaImageRequest < Struct.new(
  :dry_run,
  :input_storage_location,
  :logs_storage_location,
  :description,
  :name,
  :client_token,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description for the AFI.

Returns:

  • (String)


11561
11562
11563
11564
11565
11566
11567
11568
11569
11570
11571
# File 'lib/aws-sdk-ec2/types.rb', line 11561

class CreateFpgaImageRequest < Struct.new(
  :dry_run,
  :input_storage_location,
  :logs_storage_location,
  :description,
  :name,
  :client_token,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


11561
11562
11563
11564
11565
11566
11567
11568
11569
11570
11571
# File 'lib/aws-sdk-ec2/types.rb', line 11561

class CreateFpgaImageRequest < Struct.new(
  :dry_run,
  :input_storage_location,
  :logs_storage_location,
  :description,
  :name,
  :client_token,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#input_storage_locationTypes::StorageLocation

The location of the encrypted design checkpoint in Amazon S3. The input must be a tarball.



11561
11562
11563
11564
11565
11566
11567
11568
11569
11570
11571
# File 'lib/aws-sdk-ec2/types.rb', line 11561

class CreateFpgaImageRequest < Struct.new(
  :dry_run,
  :input_storage_location,
  :logs_storage_location,
  :description,
  :name,
  :client_token,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#logs_storage_locationTypes::StorageLocation

The location in Amazon S3 for the output logs.



11561
11562
11563
11564
11565
11566
11567
11568
11569
11570
11571
# File 'lib/aws-sdk-ec2/types.rb', line 11561

class CreateFpgaImageRequest < Struct.new(
  :dry_run,
  :input_storage_location,
  :logs_storage_location,
  :description,
  :name,
  :client_token,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A name for the AFI.

Returns:

  • (String)


11561
11562
11563
11564
11565
11566
11567
11568
11569
11570
11571
# File 'lib/aws-sdk-ec2/types.rb', line 11561

class CreateFpgaImageRequest < Struct.new(
  :dry_run,
  :input_storage_location,
  :logs_storage_location,
  :description,
  :name,
  :client_token,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the FPGA image during creation.

Returns:



11561
11562
11563
11564
11565
11566
11567
11568
11569
11570
11571
# File 'lib/aws-sdk-ec2/types.rb', line 11561

class CreateFpgaImageRequest < Struct.new(
  :dry_run,
  :input_storage_location,
  :logs_storage_location,
  :description,
  :name,
  :client_token,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end