Class: Aws::EC2::Types::CreateFpgaImageRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [Ensuring Idempotency].

[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html

Returns:

  • (String)


10839
10840
10841
10842
10843
10844
10845
10846
10847
10848
10849
# File 'lib/aws-sdk-ec2/types.rb', line 10839

class CreateFpgaImageRequest < Struct.new(
  :dry_run,
  :input_storage_location,
  :logs_storage_location,
  :description,
  :name,
  :client_token,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description for the AFI.

Returns:

  • (String)


10839
10840
10841
10842
10843
10844
10845
10846
10847
10848
10849
# File 'lib/aws-sdk-ec2/types.rb', line 10839

class CreateFpgaImageRequest < Struct.new(
  :dry_run,
  :input_storage_location,
  :logs_storage_location,
  :description,
  :name,
  :client_token,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


10839
10840
10841
10842
10843
10844
10845
10846
10847
10848
10849
# File 'lib/aws-sdk-ec2/types.rb', line 10839

class CreateFpgaImageRequest < Struct.new(
  :dry_run,
  :input_storage_location,
  :logs_storage_location,
  :description,
  :name,
  :client_token,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#input_storage_locationTypes::StorageLocation

The location of the encrypted design checkpoint in Amazon S3. The input must be a tarball.



10839
10840
10841
10842
10843
10844
10845
10846
10847
10848
10849
# File 'lib/aws-sdk-ec2/types.rb', line 10839

class CreateFpgaImageRequest < Struct.new(
  :dry_run,
  :input_storage_location,
  :logs_storage_location,
  :description,
  :name,
  :client_token,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#logs_storage_locationTypes::StorageLocation

The location in Amazon S3 for the output logs.



10839
10840
10841
10842
10843
10844
10845
10846
10847
10848
10849
# File 'lib/aws-sdk-ec2/types.rb', line 10839

class CreateFpgaImageRequest < Struct.new(
  :dry_run,
  :input_storage_location,
  :logs_storage_location,
  :description,
  :name,
  :client_token,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A name for the AFI.

Returns:

  • (String)


10839
10840
10841
10842
10843
10844
10845
10846
10847
10848
10849
# File 'lib/aws-sdk-ec2/types.rb', line 10839

class CreateFpgaImageRequest < Struct.new(
  :dry_run,
  :input_storage_location,
  :logs_storage_location,
  :description,
  :name,
  :client_token,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the FPGA image during creation.

Returns:



10839
10840
10841
10842
10843
10844
10845
10846
10847
10848
10849
# File 'lib/aws-sdk-ec2/types.rb', line 10839

class CreateFpgaImageRequest < Struct.new(
  :dry_run,
  :input_storage_location,
  :logs_storage_location,
  :description,
  :name,
  :client_token,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end