Class: Aws::EC2::Types::CreateImageUsageReportRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idsArray<String>

The Amazon Web Services account IDs to include in the report. To include all accounts, omit this parameter.

Returns:

  • (Array<String>)


10518
10519
10520
10521
10522
10523
10524
10525
10526
10527
# File 'lib/aws-sdk-ec2/types.rb', line 10518

class CreateImageUsageReportRequest < Struct.new(
  :image_id,
  :dry_run,
  :resource_types,
  :account_ids,
  :client_token,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


10518
10519
10520
10521
10522
10523
10524
10525
10526
10527
# File 'lib/aws-sdk-ec2/types.rb', line 10518

class CreateImageUsageReportRequest < Struct.new(
  :image_id,
  :dry_run,
  :resource_types,
  :account_ids,
  :client_token,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


10518
10519
10520
10521
10522
10523
10524
10525
10526
10527
# File 'lib/aws-sdk-ec2/types.rb', line 10518

class CreateImageUsageReportRequest < Struct.new(
  :image_id,
  :dry_run,
  :resource_types,
  :account_ids,
  :client_token,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#image_idString

The ID of the image to report on.

Returns:

  • (String)


10518
10519
10520
10521
10522
10523
10524
10525
10526
10527
# File 'lib/aws-sdk-ec2/types.rb', line 10518

class CreateImageUsageReportRequest < Struct.new(
  :image_id,
  :dry_run,
  :resource_types,
  :account_ids,
  :client_token,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typesArray<Types::ImageUsageResourceTypeRequest>

The resource types to include in the report.



10518
10519
10520
10521
10522
10523
10524
10525
10526
10527
# File 'lib/aws-sdk-ec2/types.rb', line 10518

class CreateImageUsageReportRequest < Struct.new(
  :image_id,
  :dry_run,
  :resource_types,
  :account_ids,
  :client_token,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the report on creation. The ‘ResourceType` must be set to `image-usage-report`; any other value will cause the report creation to fail.

To tag a report after it has been created, see [CreateTags].

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateTags.html

Returns:



10518
10519
10520
10521
10522
10523
10524
10525
10526
10527
# File 'lib/aws-sdk-ec2/types.rb', line 10518

class CreateImageUsageReportRequest < Struct.new(
  :image_id,
  :dry_run,
  :resource_types,
  :account_ids,
  :client_token,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end