Class: Aws::EC2::Types::CreateInstanceConnectEndpointRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateInstanceConnectEndpointRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#ip_address_type ⇒ String
The IP address type of the endpoint.
-
#preserve_client_ip ⇒ Boolean
Indicates whether the client IP address is preserved as the source.
-
#security_group_ids ⇒ Array<String>
One or more security groups to associate with the endpoint.
-
#subnet_id ⇒ String
The ID of the subnet in which to create the EC2 Instance Connect Endpoint.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the EC2 Instance Connect Endpoint during creation.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
10610 10611 10612 10613 10614 10615 10616 10617 10618 10619 10620 |
# File 'lib/aws-sdk-ec2/types.rb', line 10610 class CreateInstanceConnectEndpointRequest < Struct.new( :dry_run, :subnet_id, :security_group_ids, :preserve_client_ip, :client_token, :tag_specifications, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
10610 10611 10612 10613 10614 10615 10616 10617 10618 10619 10620 |
# File 'lib/aws-sdk-ec2/types.rb', line 10610 class CreateInstanceConnectEndpointRequest < Struct.new( :dry_run, :subnet_id, :security_group_ids, :preserve_client_ip, :client_token, :tag_specifications, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#ip_address_type ⇒ String
The IP address type of the endpoint.
If no value is specified, the default value is determined by the IP address type of the subnet:
-
‘dualstack` - If the subnet has both IPv4 and IPv6 CIDRs
-
‘ipv4` - If the subnet has only IPv4 CIDRs
-
‘ipv6` - If the subnet has only IPv6 CIDRs
<note markdown=“1”> ‘PreserveClientIp` is only supported on IPv4 EC2 Instance Connect Endpoints. To use `PreserveClientIp`, the value for `IpAddressType` must be `ipv4`.
</note>
10610 10611 10612 10613 10614 10615 10616 10617 10618 10619 10620 |
# File 'lib/aws-sdk-ec2/types.rb', line 10610 class CreateInstanceConnectEndpointRequest < Struct.new( :dry_run, :subnet_id, :security_group_ids, :preserve_client_ip, :client_token, :tag_specifications, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#preserve_client_ip ⇒ Boolean
Indicates whether the client IP address is preserved as the source. The following are the possible values.
-
‘true` - Use the client IP address as the source.
-
‘false` - Use the network interface IP address as the source.
<note markdown=“1”> ‘PreserveClientIp` is only supported on IPv4 EC2 Instance Connect Endpoints. To use `PreserveClientIp`, the value for `IpAddressType` must be `ipv4`.
</note>
Default: ‘false`
10610 10611 10612 10613 10614 10615 10616 10617 10618 10619 10620 |
# File 'lib/aws-sdk-ec2/types.rb', line 10610 class CreateInstanceConnectEndpointRequest < Struct.new( :dry_run, :subnet_id, :security_group_ids, :preserve_client_ip, :client_token, :tag_specifications, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
One or more security groups to associate with the endpoint. If you don’t specify a security group, the default security group for your VPC will be associated with the endpoint.
10610 10611 10612 10613 10614 10615 10616 10617 10618 10619 10620 |
# File 'lib/aws-sdk-ec2/types.rb', line 10610 class CreateInstanceConnectEndpointRequest < Struct.new( :dry_run, :subnet_id, :security_group_ids, :preserve_client_ip, :client_token, :tag_specifications, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#subnet_id ⇒ String
The ID of the subnet in which to create the EC2 Instance Connect Endpoint.
10610 10611 10612 10613 10614 10615 10616 10617 10618 10619 10620 |
# File 'lib/aws-sdk-ec2/types.rb', line 10610 class CreateInstanceConnectEndpointRequest < Struct.new( :dry_run, :subnet_id, :security_group_ids, :preserve_client_ip, :client_token, :tag_specifications, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the EC2 Instance Connect Endpoint during creation.
10610 10611 10612 10613 10614 10615 10616 10617 10618 10619 10620 |
# File 'lib/aws-sdk-ec2/types.rb', line 10610 class CreateInstanceConnectEndpointRequest < Struct.new( :dry_run, :subnet_id, :security_group_ids, :preserve_client_ip, :client_token, :tag_specifications, :ip_address_type) SENSITIVE = [] include Aws::Structure end |