Class: Aws::EC2::Types::CreateInternetGatewayRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


11425
11426
11427
11428
11429
11430
# File 'lib/aws-sdk-ec2/types.rb', line 11425

class CreateInternetGatewayRequest < Struct.new(
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to assign to the internet gateway.

Returns:



11425
11426
11427
11428
11429
11430
# File 'lib/aws-sdk-ec2/types.rb', line 11425

class CreateInternetGatewayRequest < Struct.new(
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end