Class: Aws::EC2::Types::CreateInternetGatewayRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


11247
11248
11249
11250
11251
11252
# File 'lib/aws-sdk-ec2/types.rb', line 11247

class CreateInternetGatewayRequest < Struct.new(
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to assign to the internet gateway.

Returns:



11247
11248
11249
11250
11251
11252
# File 'lib/aws-sdk-ec2/types.rb', line 11247

class CreateInternetGatewayRequest < Struct.new(
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end