Class: Aws::EC2::Types::CreateInterruptibleCapacityReservationAllocationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateInterruptibleCapacityReservationAllocationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_reservation_id ⇒ String
The ID of the source Capacity Reservation from which to create the interruptible Capacity Reservation.
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#instance_count ⇒ Integer
The number of instances to allocate from your source reservation.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the interruptible Capacity Reservation during creation.
Instance Attribute Details
#capacity_reservation_id ⇒ String
The ID of the source Capacity Reservation from which to create the interruptible Capacity Reservation. Your Capacity Reservation must be in active state with no end date set and have available capacity for allocation.
11089 11090 11091 11092 11093 11094 11095 11096 11097 |
# File 'lib/aws-sdk-ec2/types.rb', line 11089 class CreateInterruptibleCapacityReservationAllocationRequest < Struct.new( :capacity_reservation_id, :instance_count, :client_token, :dry_run, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
11089 11090 11091 11092 11093 11094 11095 11096 11097 |
# File 'lib/aws-sdk-ec2/types.rb', line 11089 class CreateInterruptibleCapacityReservationAllocationRequest < Struct.new( :capacity_reservation_id, :instance_count, :client_token, :dry_run, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
11089 11090 11091 11092 11093 11094 11095 11096 11097 |
# File 'lib/aws-sdk-ec2/types.rb', line 11089 class CreateInterruptibleCapacityReservationAllocationRequest < Struct.new( :capacity_reservation_id, :instance_count, :client_token, :dry_run, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#instance_count ⇒ Integer
The number of instances to allocate from your source reservation. You can only allocate available instances (also called unused capacity).
11089 11090 11091 11092 11093 11094 11095 11096 11097 |
# File 'lib/aws-sdk-ec2/types.rb', line 11089 class CreateInterruptibleCapacityReservationAllocationRequest < Struct.new( :capacity_reservation_id, :instance_count, :client_token, :dry_run, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the interruptible Capacity Reservation during creation.
11089 11090 11091 11092 11093 11094 11095 11096 11097 |
# File 'lib/aws-sdk-ec2/types.rb', line 11089 class CreateInterruptibleCapacityReservationAllocationRequest < Struct.new( :capacity_reservation_id, :instance_count, :client_token, :dry_run, :tag_specifications) SENSITIVE = [] include Aws::Structure end |