Class: Aws::EC2::Types::CreateIpamExternalResourceVerificationTokenRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [Ensuring idempotency].

**A suitable default value is auto-generated.** You should normally not need to pass this option.

[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html

Returns:

  • (String)


11362
11363
11364
11365
11366
11367
11368
11369
# File 'lib/aws-sdk-ec2/types.rb', line 11362

class CreateIpamExternalResourceVerificationTokenRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :tag_specifications,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


11362
11363
11364
11365
11366
11367
11368
11369
# File 'lib/aws-sdk-ec2/types.rb', line 11362

class CreateIpamExternalResourceVerificationTokenRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :tag_specifications,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_idString

The ID of the IPAM that will create the token.

Returns:

  • (String)


11362
11363
11364
11365
11366
11367
11368
11369
# File 'lib/aws-sdk-ec2/types.rb', line 11362

class CreateIpamExternalResourceVerificationTokenRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :tag_specifications,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

Token tags.

Returns:



11362
11363
11364
11365
11366
11367
11368
11369
# File 'lib/aws-sdk-ec2/types.rb', line 11362

class CreateIpamExternalResourceVerificationTokenRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :tag_specifications,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end