Class: Aws::EC2::Types::CreateIpamExternalResourceVerificationTokenRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateIpamExternalResourceVerificationTokenRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#ipam_id ⇒ String
The ID of the IPAM that will create the token.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
Token tags.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [Ensuring idempotency].
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html
11158 11159 11160 11161 11162 11163 11164 11165 |
# File 'lib/aws-sdk-ec2/types.rb', line 11158 class CreateIpamExternalResourceVerificationTokenRequest < Struct.new( :dry_run, :ipam_id, :tag_specifications, :client_token) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
11158 11159 11160 11161 11162 11163 11164 11165 |
# File 'lib/aws-sdk-ec2/types.rb', line 11158 class CreateIpamExternalResourceVerificationTokenRequest < Struct.new( :dry_run, :ipam_id, :tag_specifications, :client_token) SENSITIVE = [] include Aws::Structure end |
#ipam_id ⇒ String
The ID of the IPAM that will create the token.
11158 11159 11160 11161 11162 11163 11164 11165 |
# File 'lib/aws-sdk-ec2/types.rb', line 11158 class CreateIpamExternalResourceVerificationTokenRequest < Struct.new( :dry_run, :ipam_id, :tag_specifications, :client_token) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
Token tags.
11158 11159 11160 11161 11162 11163 11164 11165 |
# File 'lib/aws-sdk-ec2/types.rb', line 11158 class CreateIpamExternalResourceVerificationTokenRequest < Struct.new( :dry_run, :ipam_id, :tag_specifications, :client_token) SENSITIVE = [] include Aws::Structure end |