Class: Aws::EC2::Types::CreateIpamInternetRegistryAssociationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, the operation ignores the request, but does not return an error.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


12267
12268
12269
12270
12271
12272
12273
12274
12275
12276
12277
# File 'lib/aws-sdk-ec2/types.rb', line 12267

class CreateIpamInternetRegistryAssociationRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :rir,
  :organization_handle,
  :description,
  :tag_specifications,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description for the internet registry association.

Returns:

  • (String)


12267
12268
12269
12270
12271
12272
12273
12274
12275
12276
12277
# File 'lib/aws-sdk-ec2/types.rb', line 12267

class CreateIpamInternetRegistryAssociationRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :rir,
  :organization_handle,
  :description,
  :tag_specifications,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


12267
12268
12269
12270
12271
12272
12273
12274
12275
12276
12277
# File 'lib/aws-sdk-ec2/types.rb', line 12267

class CreateIpamInternetRegistryAssociationRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :rir,
  :organization_handle,
  :description,
  :tag_specifications,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_idString

The ID of the IPAM to associate with the internet registry.

Returns:

  • (String)


12267
12268
12269
12270
12271
12272
12273
12274
12275
12276
12277
# File 'lib/aws-sdk-ec2/types.rb', line 12267

class CreateIpamInternetRegistryAssociationRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :rir,
  :organization_handle,
  :description,
  :tag_specifications,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#organization_handleString

The organization handle at the internet registry (for example, a RIPE NCC organization ID or ARIN Org ID).

Returns:

  • (String)


12267
12268
12269
12270
12271
12272
12273
12274
12275
12276
12277
# File 'lib/aws-sdk-ec2/types.rb', line 12267

class CreateIpamInternetRegistryAssociationRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :rir,
  :organization_handle,
  :description,
  :tag_specifications,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#rirString

The Regional Internet Registry to associate with. Possible values:

  • ripe - RIPE NCC (Europe, the Middle East, and Central Asia).

  • apnic - APNIC (Asia Pacific).

  • arin - ARIN (North America).

  • lacnic - LACNIC (Latin America and the Caribbean).

Returns:

  • (String)


12267
12268
12269
12270
12271
12272
12273
12274
12275
12276
12277
# File 'lib/aws-sdk-ec2/types.rb', line 12267

class CreateIpamInternetRegistryAssociationRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :rir,
  :organization_handle,
  :description,
  :tag_specifications,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to assign to the internet registry association.

Returns:



12267
12268
12269
12270
12271
12272
12273
12274
12275
12276
12277
# File 'lib/aws-sdk-ec2/types.rb', line 12267

class CreateIpamInternetRegistryAssociationRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :rir,
  :organization_handle,
  :description,
  :tag_specifications,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end