Class: Aws::EC2::Types::CreateIpamPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


10946
10947
10948
10949
10950
10951
10952
10953
# File 'lib/aws-sdk-ec2/types.rb', line 10946

class CreateIpamPolicyRequest < Struct.new(
  :dry_run,
  :tag_specifications,
  :client_token,
  :ipam_id)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


10946
10947
10948
10949
10950
10951
10952
10953
# File 'lib/aws-sdk-ec2/types.rb', line 10946

class CreateIpamPolicyRequest < Struct.new(
  :dry_run,
  :tag_specifications,
  :client_token,
  :ipam_id)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_idString

The ID of the IPAM for which you’re creating the policy.

Returns:

  • (String)


10946
10947
10948
10949
10950
10951
10952
10953
# File 'lib/aws-sdk-ec2/types.rb', line 10946

class CreateIpamPolicyRequest < Struct.new(
  :dry_run,
  :tag_specifications,
  :client_token,
  :ipam_id)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to assign to the IPAM policy.

Returns:



10946
10947
10948
10949
10950
10951
10952
10953
# File 'lib/aws-sdk-ec2/types.rb', line 10946

class CreateIpamPolicyRequest < Struct.new(
  :dry_run,
  :tag_specifications,
  :client_token,
  :ipam_id)
  SENSITIVE = []
  include Aws::Structure
end