Class: Aws::EC2::Types::CreateIpamResourceDiscoveryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateIpamResourceDiscoveryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A client token for the IPAM resource discovery.
-
#description ⇒ String
A description for the IPAM resource discovery.
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#operating_regions ⇒ Array<Types::AddIpamOperatingRegion>
Operating Regions for the IPAM resource discovery.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
Tag specifications for the IPAM resource discovery.
Instance Attribute Details
#client_token ⇒ String
A client token for the IPAM resource discovery.
A suitable default value is auto-generated. You should normally not need to pass this option.
12835 12836 12837 12838 12839 12840 12841 12842 12843 |
# File 'lib/aws-sdk-ec2/types.rb', line 12835 class CreateIpamResourceDiscoveryRequest < Struct.new( :dry_run, :description, :operating_regions, :tag_specifications, :client_token) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description for the IPAM resource discovery.
12835 12836 12837 12838 12839 12840 12841 12842 12843 |
# File 'lib/aws-sdk-ec2/types.rb', line 12835 class CreateIpamResourceDiscoveryRequest < Struct.new( :dry_run, :description, :operating_regions, :tag_specifications, :client_token) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action
without actually making the request and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
12835 12836 12837 12838 12839 12840 12841 12842 12843 |
# File 'lib/aws-sdk-ec2/types.rb', line 12835 class CreateIpamResourceDiscoveryRequest < Struct.new( :dry_run, :description, :operating_regions, :tag_specifications, :client_token) SENSITIVE = [] include Aws::Structure end |
#operating_regions ⇒ Array<Types::AddIpamOperatingRegion>
Operating Regions for the IPAM resource discovery. Operating Regions are Amazon Web Services Regions where the IPAM is allowed to manage IP address CIDRs. IPAM only discovers and monitors resources in the Amazon Web Services Regions you select as operating Regions.
12835 12836 12837 12838 12839 12840 12841 12842 12843 |
# File 'lib/aws-sdk-ec2/types.rb', line 12835 class CreateIpamResourceDiscoveryRequest < Struct.new( :dry_run, :description, :operating_regions, :tag_specifications, :client_token) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
Tag specifications for the IPAM resource discovery.
12835 12836 12837 12838 12839 12840 12841 12842 12843 |
# File 'lib/aws-sdk-ec2/types.rb', line 12835 class CreateIpamResourceDiscoveryRequest < Struct.new( :dry_run, :description, :operating_regions, :tag_specifications, :client_token) SENSITIVE = [] include Aws::Structure end |