Class: Aws::EC2::Types::CreateIpamResourceDiscoveryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A client token for the IPAM resource discovery.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


11967
11968
11969
11970
11971
11972
11973
11974
11975
# File 'lib/aws-sdk-ec2/types.rb', line 11967

class CreateIpamResourceDiscoveryRequest < Struct.new(
  :dry_run,
  :description,
  :operating_regions,
  :tag_specifications,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description for the IPAM resource discovery.

Returns:

  • (String)


11967
11968
11969
11970
11971
11972
11973
11974
11975
# File 'lib/aws-sdk-ec2/types.rb', line 11967

class CreateIpamResourceDiscoveryRequest < Struct.new(
  :dry_run,
  :description,
  :operating_regions,
  :tag_specifications,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


11967
11968
11969
11970
11971
11972
11973
11974
11975
# File 'lib/aws-sdk-ec2/types.rb', line 11967

class CreateIpamResourceDiscoveryRequest < Struct.new(
  :dry_run,
  :description,
  :operating_regions,
  :tag_specifications,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#operating_regionsArray<Types::AddIpamOperatingRegion>

Operating Regions for the IPAM resource discovery. Operating Regions are Amazon Web Services Regions where the IPAM is allowed to manage IP address CIDRs. IPAM only discovers and monitors resources in the Amazon Web Services Regions you select as operating Regions.

Returns:



11967
11968
11969
11970
11971
11972
11973
11974
11975
# File 'lib/aws-sdk-ec2/types.rb', line 11967

class CreateIpamResourceDiscoveryRequest < Struct.new(
  :dry_run,
  :description,
  :operating_regions,
  :tag_specifications,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

Tag specifications for the IPAM resource discovery.

Returns:



11967
11968
11969
11970
11971
11972
11973
11974
11975
# File 'lib/aws-sdk-ec2/types.rb', line 11967

class CreateIpamResourceDiscoveryRequest < Struct.new(
  :dry_run,
  :description,
  :operating_regions,
  :tag_specifications,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end