Class: Aws::EC2::Types::CreateIpamRoutingPolicyRegistrationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#asnsArray<String>

The Autonomous System Numbers (ASNs) authorized to originate the prefix.

Returns:

  • (Array<String>)


12915
12916
12917
12918
12919
12920
12921
12922
12923
12924
12925
12926
12927
# File 'lib/aws-sdk-ec2/types.rb', line 12915

class CreateIpamRoutingPolicyRegistrationRequest < Struct.new(
  :dry_run,
  :ipam_internet_registry_association_id,
  :cidr,
  :asns,
  :permit_more_specific_announcements,
  :max_length,
  :description,
  :force,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#cidrString

The IP address prefix in CIDR notation to authorize in the ROA.

Returns:

  • (String)


12915
12916
12917
12918
12919
12920
12921
12922
12923
12924
12925
12926
12927
# File 'lib/aws-sdk-ec2/types.rb', line 12915

class CreateIpamRoutingPolicyRegistrationRequest < Struct.new(
  :dry_run,
  :ipam_internet_registry_association_id,
  :cidr,
  :asns,
  :permit_more_specific_announcements,
  :max_length,
  :description,
  :force,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, the operation ignores the request, but does not return an error.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


12915
12916
12917
12918
12919
12920
12921
12922
12923
12924
12925
12926
12927
# File 'lib/aws-sdk-ec2/types.rb', line 12915

class CreateIpamRoutingPolicyRegistrationRequest < Struct.new(
  :dry_run,
  :ipam_internet_registry_association_id,
  :cidr,
  :asns,
  :permit_more_specific_announcements,
  :max_length,
  :description,
  :force,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description for the routing policy registration.

Returns:

  • (String)


12915
12916
12917
12918
12919
12920
12921
12922
12923
12924
12925
12926
12927
# File 'lib/aws-sdk-ec2/types.rb', line 12915

class CreateIpamRoutingPolicyRegistrationRequest < Struct.new(
  :dry_run,
  :ipam_internet_registry_association_id,
  :cidr,
  :asns,
  :permit_more_specific_announcements,
  :max_length,
  :description,
  :force,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


12915
12916
12917
12918
12919
12920
12921
12922
12923
12924
12925
12926
12927
# File 'lib/aws-sdk-ec2/types.rb', line 12915

class CreateIpamRoutingPolicyRegistrationRequest < Struct.new(
  :dry_run,
  :ipam_internet_registry_association_id,
  :cidr,
  :asns,
  :permit_more_specific_announcements,
  :max_length,
  :description,
  :force,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#forceBoolean

Forces the creation of the routing policy registration even if it conflicts with an announced route. Default: false.

Returns:

  • (Boolean)


12915
12916
12917
12918
12919
12920
12921
12922
12923
12924
12925
12926
12927
# File 'lib/aws-sdk-ec2/types.rb', line 12915

class CreateIpamRoutingPolicyRegistrationRequest < Struct.new(
  :dry_run,
  :ipam_internet_registry_association_id,
  :cidr,
  :asns,
  :permit_more_specific_announcements,
  :max_length,
  :description,
  :force,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_internet_registry_association_idString

The ID of the IPAM internet registry association.

Returns:

  • (String)


12915
12916
12917
12918
12919
12920
12921
12922
12923
12924
12925
12926
12927
# File 'lib/aws-sdk-ec2/types.rb', line 12915

class CreateIpamRoutingPolicyRegistrationRequest < Struct.new(
  :dry_run,
  :ipam_internet_registry_association_id,
  :cidr,
  :asns,
  :permit_more_specific_announcements,
  :max_length,
  :description,
  :force,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_lengthInteger

The maximum prefix length that the ASNs are authorized to announce. Must be greater than or equal to the prefix length of the CIDR. If not specified, defaults to the prefix length of the CIDR (exact match only).

Returns:

  • (Integer)


12915
12916
12917
12918
12919
12920
12921
12922
12923
12924
12925
12926
12927
# File 'lib/aws-sdk-ec2/types.rb', line 12915

class CreateIpamRoutingPolicyRegistrationRequest < Struct.new(
  :dry_run,
  :ipam_internet_registry_association_id,
  :cidr,
  :asns,
  :permit_more_specific_announcements,
  :max_length,
  :description,
  :force,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#permit_more_specific_announcementsBoolean

Specifies whether to permit more specific route announcements than the CIDR prefix. When enabled, ASNs can announce sub-prefixes of the authorized CIDR up to the specified maximum length. Default: false.

Returns:

  • (Boolean)


12915
12916
12917
12918
12919
12920
12921
12922
12923
12924
12925
12926
12927
# File 'lib/aws-sdk-ec2/types.rb', line 12915

class CreateIpamRoutingPolicyRegistrationRequest < Struct.new(
  :dry_run,
  :ipam_internet_registry_association_id,
  :cidr,
  :asns,
  :permit_more_specific_announcements,
  :max_length,
  :description,
  :force,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end