Class: Aws::EC2::Types::CreateKeyPairRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


12065
12066
12067
12068
12069
12070
12071
12072
12073
# File 'lib/aws-sdk-ec2/types.rb', line 12065

class CreateKeyPairRequest < Struct.new(
  :key_name,
  :key_type,
  :tag_specifications,
  :key_format,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#key_formatString

The format of the key pair.

Default: ‘pem`

Returns:

  • (String)


12065
12066
12067
12068
12069
12070
12071
12072
12073
# File 'lib/aws-sdk-ec2/types.rb', line 12065

class CreateKeyPairRequest < Struct.new(
  :key_name,
  :key_type,
  :tag_specifications,
  :key_format,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#key_nameString

A unique name for the key pair.

Constraints: Up to 255 ASCII characters

Returns:

  • (String)


12065
12066
12067
12068
12069
12070
12071
12072
12073
# File 'lib/aws-sdk-ec2/types.rb', line 12065

class CreateKeyPairRequest < Struct.new(
  :key_name,
  :key_type,
  :tag_specifications,
  :key_format,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#key_typeString

The type of key pair. Note that ED25519 keys are not supported for Windows instances.

Default: ‘rsa`

Returns:

  • (String)


12065
12066
12067
12068
12069
12070
12071
12072
12073
# File 'lib/aws-sdk-ec2/types.rb', line 12065

class CreateKeyPairRequest < Struct.new(
  :key_name,
  :key_type,
  :tag_specifications,
  :key_format,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the new key pair.

Returns:



12065
12066
12067
12068
12069
12070
12071
12072
12073
# File 'lib/aws-sdk-ec2/types.rb', line 12065

class CreateKeyPairRequest < Struct.new(
  :key_name,
  :key_type,
  :tag_specifications,
  :key_format,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end