Class: Aws::EC2::Types::CreateKeyPairRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateKeyPairRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#key_format ⇒ String
The format of the key pair.
-
#key_name ⇒ String
A unique name for the key pair.
-
#key_type ⇒ String
The type of key pair.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the new key pair.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
11669 11670 11671 11672 11673 11674 11675 11676 11677 |
# File 'lib/aws-sdk-ec2/types.rb', line 11669 class CreateKeyPairRequest < Struct.new( :key_name, :key_type, :tag_specifications, :key_format, :dry_run) SENSITIVE = [] include Aws::Structure end |
#key_format ⇒ String
The format of the key pair.
Default: ‘pem`
11669 11670 11671 11672 11673 11674 11675 11676 11677 |
# File 'lib/aws-sdk-ec2/types.rb', line 11669 class CreateKeyPairRequest < Struct.new( :key_name, :key_type, :tag_specifications, :key_format, :dry_run) SENSITIVE = [] include Aws::Structure end |
#key_name ⇒ String
A unique name for the key pair.
Constraints: Up to 255 ASCII characters
11669 11670 11671 11672 11673 11674 11675 11676 11677 |
# File 'lib/aws-sdk-ec2/types.rb', line 11669 class CreateKeyPairRequest < Struct.new( :key_name, :key_type, :tag_specifications, :key_format, :dry_run) SENSITIVE = [] include Aws::Structure end |
#key_type ⇒ String
The type of key pair. Note that ED25519 keys are not supported for Windows instances.
Default: ‘rsa`
11669 11670 11671 11672 11673 11674 11675 11676 11677 |
# File 'lib/aws-sdk-ec2/types.rb', line 11669 class CreateKeyPairRequest < Struct.new( :key_name, :key_type, :tag_specifications, :key_format, :dry_run) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the new key pair.
11669 11670 11671 11672 11673 11674 11675 11676 11677 |
# File 'lib/aws-sdk-ec2/types.rb', line 11669 class CreateKeyPairRequest < Struct.new( :key_name, :key_type, :tag_specifications, :key_format, :dry_run) SENSITIVE = [] include Aws::Structure end |