Class: Aws::EC2::Types::CreateLaunchTemplateRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier you provide to ensure the idempotency of the request. If a client token isn’t specified, a randomly generated token is used in the request to ensure idempotency.

For more information, see [Ensuring idempotency].

Constraint: Maximum 128 ASCII characters.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html

Returns:

  • (String)


11735
11736
11737
11738
11739
11740
11741
11742
11743
11744
11745
# File 'lib/aws-sdk-ec2/types.rb', line 11735

class CreateLaunchTemplateRequest < Struct.new(
  :dry_run,
  :client_token,
  :launch_template_name,
  :version_description,
  :launch_template_data,
  :operator,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


11735
11736
11737
11738
11739
11740
11741
11742
11743
11744
11745
# File 'lib/aws-sdk-ec2/types.rb', line 11735

class CreateLaunchTemplateRequest < Struct.new(
  :dry_run,
  :client_token,
  :launch_template_name,
  :version_description,
  :launch_template_data,
  :operator,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#launch_template_dataTypes::RequestLaunchTemplateData

The information for the launch template.



11735
11736
11737
11738
11739
11740
11741
11742
11743
11744
11745
# File 'lib/aws-sdk-ec2/types.rb', line 11735

class CreateLaunchTemplateRequest < Struct.new(
  :dry_run,
  :client_token,
  :launch_template_name,
  :version_description,
  :launch_template_data,
  :operator,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#launch_template_nameString

A name for the launch template.

Returns:

  • (String)


11735
11736
11737
11738
11739
11740
11741
11742
11743
11744
11745
# File 'lib/aws-sdk-ec2/types.rb', line 11735

class CreateLaunchTemplateRequest < Struct.new(
  :dry_run,
  :client_token,
  :launch_template_name,
  :version_description,
  :launch_template_data,
  :operator,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#operatorTypes::OperatorRequest

Reserved for internal use.



11735
11736
11737
11738
11739
11740
11741
11742
11743
11744
11745
# File 'lib/aws-sdk-ec2/types.rb', line 11735

class CreateLaunchTemplateRequest < Struct.new(
  :dry_run,
  :client_token,
  :launch_template_name,
  :version_description,
  :launch_template_data,
  :operator,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the launch template on creation. To tag the launch template, the resource type must be ‘launch-template`.

To specify the tags for the resources that are created when an instance is launched, you must use the ‘TagSpecifications` parameter in the [launch template data] structure.

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RequestLaunchTemplateData.html

Returns:



11735
11736
11737
11738
11739
11740
11741
11742
11743
11744
11745
# File 'lib/aws-sdk-ec2/types.rb', line 11735

class CreateLaunchTemplateRequest < Struct.new(
  :dry_run,
  :client_token,
  :launch_template_name,
  :version_description,
  :launch_template_data,
  :operator,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#version_descriptionString

A description for the first version of the launch template.

Returns:

  • (String)


11735
11736
11737
11738
11739
11740
11741
11742
11743
11744
11745
# File 'lib/aws-sdk-ec2/types.rb', line 11735

class CreateLaunchTemplateRequest < Struct.new(
  :dry_run,
  :client_token,
  :launch_template_name,
  :version_description,
  :launch_template_data,
  :operator,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end