Class: Aws::EC2::Types::CreateLaunchTemplateResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#launch_templateTypes::LaunchTemplate

Information about the launch template.



13152
13153
13154
13155
13156
13157
# File 'lib/aws-sdk-ec2/types.rb', line 13152

class CreateLaunchTemplateResult < Struct.new(
  :launch_template,
  :warning)
  SENSITIVE = []
  include Aws::Structure
end

#warningTypes::ValidationWarning

If the launch template contains parameters or parameter combinations that are not valid, an error code and an error message are returned for each issue that's found.



13152
13153
13154
13155
13156
13157
# File 'lib/aws-sdk-ec2/types.rb', line 13152

class CreateLaunchTemplateResult < Struct.new(
  :launch_template,
  :warning)
  SENSITIVE = []
  include Aws::Structure
end