Class: Aws::EC2::Types::CreateLaunchTemplateResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#launch_templateTypes::LaunchTemplate

Information about the launch template.



13139
13140
13141
13142
13143
13144
# File 'lib/aws-sdk-ec2/types.rb', line 13139

class CreateLaunchTemplateResult < Struct.new(
  :launch_template,
  :warning)
  SENSITIVE = []
  include Aws::Structure
end

#warningTypes::ValidationWarning

If the launch template contains parameters or parameter combinations that are not valid, an error code and an error message are returned for each issue that's found.



13139
13140
13141
13142
13143
13144
# File 'lib/aws-sdk-ec2/types.rb', line 13139

class CreateLaunchTemplateResult < Struct.new(
  :launch_template,
  :warning)
  SENSITIVE = []
  include Aws::Structure
end