Class: Aws::EC2::Types::CreateLaunchTemplateResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateLaunchTemplateResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#launch_template ⇒ Types::LaunchTemplate
Information about the launch template.
-
#warning ⇒ Types::ValidationWarning
If the launch template contains parameters or parameter combinations that are not valid, an error code and an error message are returned for each issue that’s found.
Instance Attribute Details
#launch_template ⇒ Types::LaunchTemplate
Information about the launch template.
11759 11760 11761 11762 11763 11764 |
# File 'lib/aws-sdk-ec2/types.rb', line 11759 class CreateLaunchTemplateResult < Struct.new( :launch_template, :warning) SENSITIVE = [] include Aws::Structure end |
#warning ⇒ Types::ValidationWarning
If the launch template contains parameters or parameter combinations that are not valid, an error code and an error message are returned for each issue that’s found.
11759 11760 11761 11762 11763 11764 |
# File 'lib/aws-sdk-ec2/types.rb', line 11759 class CreateLaunchTemplateResult < Struct.new( :launch_template, :warning) SENSITIVE = [] include Aws::Structure end |