Class: Aws::EC2::Types::CreateLaunchTemplateVersionResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#launch_template_versionTypes::LaunchTemplateVersion

Information about the launch template version.



12441
12442
12443
12444
12445
12446
# File 'lib/aws-sdk-ec2/types.rb', line 12441

class CreateLaunchTemplateVersionResult < Struct.new(
  :launch_template_version,
  :warning)
  SENSITIVE = []
  include Aws::Structure
end

#warningTypes::ValidationWarning

If the new version of the launch template contains parameters or parameter combinations that are not valid, an error code and an error message are returned for each issue that's found.



12441
12442
12443
12444
12445
12446
# File 'lib/aws-sdk-ec2/types.rb', line 12441

class CreateLaunchTemplateVersionResult < Struct.new(
  :launch_template_version,
  :warning)
  SENSITIVE = []
  include Aws::Structure
end