Class: Aws::EC2::Types::CreateLocalGatewayRouteRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#destination_cidr_blockString

The CIDR range used for destination matches. Routing decisions are based on the most specific match.

Returns:

  • (String)


12345
12346
12347
12348
12349
12350
12351
12352
12353
12354
# File 'lib/aws-sdk-ec2/types.rb', line 12345

class CreateLocalGatewayRouteRequest < Struct.new(
  :destination_cidr_block,
  :local_gateway_route_table_id,
  :local_gateway_virtual_interface_group_id,
  :dry_run,
  :network_interface_id,
  :destination_prefix_list_id)
  SENSITIVE = []
  include Aws::Structure
end

#destination_prefix_list_idString

The ID of the prefix list. Use a prefix list in place of ‘DestinationCidrBlock`. You cannot use `DestinationPrefixListId` and `DestinationCidrBlock` in the same request.

Returns:

  • (String)


12345
12346
12347
12348
12349
12350
12351
12352
12353
12354
# File 'lib/aws-sdk-ec2/types.rb', line 12345

class CreateLocalGatewayRouteRequest < Struct.new(
  :destination_cidr_block,
  :local_gateway_route_table_id,
  :local_gateway_virtual_interface_group_id,
  :dry_run,
  :network_interface_id,
  :destination_prefix_list_id)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


12345
12346
12347
12348
12349
12350
12351
12352
12353
12354
# File 'lib/aws-sdk-ec2/types.rb', line 12345

class CreateLocalGatewayRouteRequest < Struct.new(
  :destination_cidr_block,
  :local_gateway_route_table_id,
  :local_gateway_virtual_interface_group_id,
  :dry_run,
  :network_interface_id,
  :destination_prefix_list_id)
  SENSITIVE = []
  include Aws::Structure
end

#local_gateway_route_table_idString

The ID of the local gateway route table.

Returns:

  • (String)


12345
12346
12347
12348
12349
12350
12351
12352
12353
12354
# File 'lib/aws-sdk-ec2/types.rb', line 12345

class CreateLocalGatewayRouteRequest < Struct.new(
  :destination_cidr_block,
  :local_gateway_route_table_id,
  :local_gateway_virtual_interface_group_id,
  :dry_run,
  :network_interface_id,
  :destination_prefix_list_id)
  SENSITIVE = []
  include Aws::Structure
end

#local_gateway_virtual_interface_group_idString

The ID of the virtual interface group.

Returns:

  • (String)


12345
12346
12347
12348
12349
12350
12351
12352
12353
12354
# File 'lib/aws-sdk-ec2/types.rb', line 12345

class CreateLocalGatewayRouteRequest < Struct.new(
  :destination_cidr_block,
  :local_gateway_route_table_id,
  :local_gateway_virtual_interface_group_id,
  :dry_run,
  :network_interface_id,
  :destination_prefix_list_id)
  SENSITIVE = []
  include Aws::Structure
end

#network_interface_idString

The ID of the network interface.

Returns:

  • (String)


12345
12346
12347
12348
12349
12350
12351
12352
12353
12354
# File 'lib/aws-sdk-ec2/types.rb', line 12345

class CreateLocalGatewayRouteRequest < Struct.new(
  :destination_cidr_block,
  :local_gateway_route_table_id,
  :local_gateway_virtual_interface_group_id,
  :dry_run,
  :network_interface_id,
  :destination_prefix_list_id)
  SENSITIVE = []
  include Aws::Structure
end