Class: Aws::EC2::Types::CreateLocalGatewayRouteTableRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


12346
12347
12348
12349
12350
12351
12352
12353
# File 'lib/aws-sdk-ec2/types.rb', line 12346

class CreateLocalGatewayRouteTableRequest < Struct.new(
  :local_gateway_id,
  :mode,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#local_gateway_idString

The ID of the local gateway.

Returns:

  • (String)


12346
12347
12348
12349
12350
12351
12352
12353
# File 'lib/aws-sdk-ec2/types.rb', line 12346

class CreateLocalGatewayRouteTableRequest < Struct.new(
  :local_gateway_id,
  :mode,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#modeString

The mode of the local gateway route table.

Returns:

  • (String)


12346
12347
12348
12349
12350
12351
12352
12353
# File 'lib/aws-sdk-ec2/types.rb', line 12346

class CreateLocalGatewayRouteTableRequest < Struct.new(
  :local_gateway_id,
  :mode,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags assigned to the local gateway route table.

Returns:



12346
12347
12348
12349
12350
12351
12352
12353
# File 'lib/aws-sdk-ec2/types.rb', line 12346

class CreateLocalGatewayRouteTableRequest < Struct.new(
  :local_gateway_id,
  :mode,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end