Class: Aws::EC2::Types::CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


13374
13375
13376
13377
13378
13379
13380
13381
# File 'lib/aws-sdk-ec2/types.rb', line 13374

class CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociationRequest < Struct.new(
  :local_gateway_route_table_id,
  :local_gateway_virtual_interface_group_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#local_gateway_route_table_idString

The ID of the local gateway route table.

Returns:

  • (String)


13374
13375
13376
13377
13378
13379
13380
13381
# File 'lib/aws-sdk-ec2/types.rb', line 13374

class CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociationRequest < Struct.new(
  :local_gateway_route_table_id,
  :local_gateway_virtual_interface_group_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#local_gateway_virtual_interface_group_idString

The ID of the local gateway route table virtual interface group association.

Returns:

  • (String)


13374
13375
13376
13377
13378
13379
13380
13381
# File 'lib/aws-sdk-ec2/types.rb', line 13374

class CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociationRequest < Struct.new(
  :local_gateway_route_table_id,
  :local_gateway_virtual_interface_group_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags assigned to the local gateway route table virtual interface group association.

Returns:



13374
13375
13376
13377
13378
13379
13380
13381
# File 'lib/aws-sdk-ec2/types.rb', line 13374

class CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociationRequest < Struct.new(
  :local_gateway_route_table_id,
  :local_gateway_virtual_interface_group_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end