Class: Aws::EC2::Types::CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#local_gateway_route_table_id ⇒ String
The ID of the local gateway route table.
-
#local_gateway_virtual_interface_group_id ⇒ String
The ID of the local gateway route table virtual interface group association.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags assigned to the local gateway route table virtual interface group association.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
11994 11995 11996 11997 11998 11999 12000 12001 |
# File 'lib/aws-sdk-ec2/types.rb', line 11994 class CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociationRequest < Struct.new( :local_gateway_route_table_id, :local_gateway_virtual_interface_group_id, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#local_gateway_route_table_id ⇒ String
The ID of the local gateway route table.
11994 11995 11996 11997 11998 11999 12000 12001 |
# File 'lib/aws-sdk-ec2/types.rb', line 11994 class CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociationRequest < Struct.new( :local_gateway_route_table_id, :local_gateway_virtual_interface_group_id, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#local_gateway_virtual_interface_group_id ⇒ String
The ID of the local gateway route table virtual interface group association.
11994 11995 11996 11997 11998 11999 12000 12001 |
# File 'lib/aws-sdk-ec2/types.rb', line 11994 class CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociationRequest < Struct.new( :local_gateway_route_table_id, :local_gateway_virtual_interface_group_id, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags assigned to the local gateway route table virtual interface group association.
11994 11995 11996 11997 11998 11999 12000 12001 |
# File 'lib/aws-sdk-ec2/types.rb', line 11994 class CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociationRequest < Struct.new( :local_gateway_route_table_id, :local_gateway_virtual_interface_group_id, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |