Class: Aws::EC2::Types::CreateLocalGatewayRouteTableVpcAssociationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateLocalGatewayRouteTableVpcAssociationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#local_gateway_route_table_id ⇒ String
The ID of the local gateway route table.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the local gateway route table VPC association.
-
#vpc_id ⇒ String
The ID of the VPC.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
13198 13199 13200 13201 13202 13203 13204 13205 |
# File 'lib/aws-sdk-ec2/types.rb', line 13198 class CreateLocalGatewayRouteTableVpcAssociationRequest < Struct.new( :local_gateway_route_table_id, :vpc_id, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#local_gateway_route_table_id ⇒ String
The ID of the local gateway route table.
13198 13199 13200 13201 13202 13203 13204 13205 |
# File 'lib/aws-sdk-ec2/types.rb', line 13198 class CreateLocalGatewayRouteTableVpcAssociationRequest < Struct.new( :local_gateway_route_table_id, :vpc_id, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the local gateway route table VPC association.
13198 13199 13200 13201 13202 13203 13204 13205 |
# File 'lib/aws-sdk-ec2/types.rb', line 13198 class CreateLocalGatewayRouteTableVpcAssociationRequest < Struct.new( :local_gateway_route_table_id, :vpc_id, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC.
13198 13199 13200 13201 13202 13203 13204 13205 |
# File 'lib/aws-sdk-ec2/types.rb', line 13198 class CreateLocalGatewayRouteTableVpcAssociationRequest < Struct.new( :local_gateway_route_table_id, :vpc_id, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |