Class: Aws::EC2::Types::CreateLocalGatewayRouteTableVpcAssociationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


12433
12434
12435
12436
12437
12438
12439
12440
# File 'lib/aws-sdk-ec2/types.rb', line 12433

class CreateLocalGatewayRouteTableVpcAssociationRequest < Struct.new(
  :local_gateway_route_table_id,
  :vpc_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#local_gateway_route_table_idString

The ID of the local gateway route table.

Returns:

  • (String)


12433
12434
12435
12436
12437
12438
12439
12440
# File 'lib/aws-sdk-ec2/types.rb', line 12433

class CreateLocalGatewayRouteTableVpcAssociationRequest < Struct.new(
  :local_gateway_route_table_id,
  :vpc_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to assign to the local gateway route table VPC association.

Returns:



12433
12434
12435
12436
12437
12438
12439
12440
# File 'lib/aws-sdk-ec2/types.rb', line 12433

class CreateLocalGatewayRouteTableVpcAssociationRequest < Struct.new(
  :local_gateway_route_table_id,
  :vpc_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC.

Returns:

  • (String)


12433
12434
12435
12436
12437
12438
12439
12440
# File 'lib/aws-sdk-ec2/types.rb', line 12433

class CreateLocalGatewayRouteTableVpcAssociationRequest < Struct.new(
  :local_gateway_route_table_id,
  :vpc_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end