Class: Aws::EC2::Types::CreateLocalGatewayVirtualInterfaceGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


13465
13466
13467
13468
13469
13470
13471
13472
13473
# File 'lib/aws-sdk-ec2/types.rb', line 13465

class CreateLocalGatewayVirtualInterfaceGroupRequest < Struct.new(
  :local_gateway_id,
  :local_bgp_asn,
  :local_bgp_asn_extended,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#local_bgp_asnInteger

The Autonomous System Number(ASN) for the local Border Gateway Protocol (BGP).

Returns:

  • (Integer)


13465
13466
13467
13468
13469
13470
13471
13472
13473
# File 'lib/aws-sdk-ec2/types.rb', line 13465

class CreateLocalGatewayVirtualInterfaceGroupRequest < Struct.new(
  :local_gateway_id,
  :local_bgp_asn,
  :local_bgp_asn_extended,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#local_bgp_asn_extendedInteger

The extended 32-bit ASN for the local BGP configuration.

Returns:

  • (Integer)


13465
13466
13467
13468
13469
13470
13471
13472
13473
# File 'lib/aws-sdk-ec2/types.rb', line 13465

class CreateLocalGatewayVirtualInterfaceGroupRequest < Struct.new(
  :local_gateway_id,
  :local_bgp_asn,
  :local_bgp_asn_extended,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#local_gateway_idString

The ID of the local gateway.

Returns:

  • (String)


13465
13466
13467
13468
13469
13470
13471
13472
13473
# File 'lib/aws-sdk-ec2/types.rb', line 13465

class CreateLocalGatewayVirtualInterfaceGroupRequest < Struct.new(
  :local_gateway_id,
  :local_bgp_asn,
  :local_bgp_asn_extended,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the local gateway virtual interface group when the resource is being created.

Returns:



13465
13466
13467
13468
13469
13470
13471
13472
13473
# File 'lib/aws-sdk-ec2/types.rb', line 13465

class CreateLocalGatewayVirtualInterfaceGroupRequest < Struct.new(
  :local_gateway_id,
  :local_bgp_asn,
  :local_bgp_asn_extended,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end