Class: Aws::EC2::Types::CreateLocalGatewayVirtualInterfaceGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateLocalGatewayVirtualInterfaceGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#local_bgp_asn ⇒ Integer
The Autonomous System Number(ASN) for the local Border Gateway Protocol (BGP).
-
#local_bgp_asn_extended ⇒ Integer
The extended 32-bit ASN for the local BGP configuration.
-
#local_gateway_id ⇒ String
The ID of the local gateway.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the local gateway virtual interface group when the resource is being created.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
12659 12660 12661 12662 12663 12664 12665 12666 12667 |
# File 'lib/aws-sdk-ec2/types.rb', line 12659 class CreateLocalGatewayVirtualInterfaceGroupRequest < Struct.new( :local_gateway_id, :local_bgp_asn, :local_bgp_asn_extended, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#local_bgp_asn ⇒ Integer
The Autonomous System Number(ASN) for the local Border Gateway Protocol (BGP).
12659 12660 12661 12662 12663 12664 12665 12666 12667 |
# File 'lib/aws-sdk-ec2/types.rb', line 12659 class CreateLocalGatewayVirtualInterfaceGroupRequest < Struct.new( :local_gateway_id, :local_bgp_asn, :local_bgp_asn_extended, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#local_bgp_asn_extended ⇒ Integer
The extended 32-bit ASN for the local BGP configuration.
12659 12660 12661 12662 12663 12664 12665 12666 12667 |
# File 'lib/aws-sdk-ec2/types.rb', line 12659 class CreateLocalGatewayVirtualInterfaceGroupRequest < Struct.new( :local_gateway_id, :local_bgp_asn, :local_bgp_asn_extended, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#local_gateway_id ⇒ String
The ID of the local gateway.
12659 12660 12661 12662 12663 12664 12665 12666 12667 |
# File 'lib/aws-sdk-ec2/types.rb', line 12659 class CreateLocalGatewayVirtualInterfaceGroupRequest < Struct.new( :local_gateway_id, :local_bgp_asn, :local_bgp_asn_extended, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the local gateway virtual interface group when the resource is being created.
12659 12660 12661 12662 12663 12664 12665 12666 12667 |
# File 'lib/aws-sdk-ec2/types.rb', line 12659 class CreateLocalGatewayVirtualInterfaceGroupRequest < Struct.new( :local_gateway_id, :local_bgp_asn, :local_bgp_asn_extended, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |