Class: Aws::EC2::Types::CreateLocalGatewayVirtualInterfaceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateLocalGatewayVirtualInterfaceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#local_address ⇒ String
The IP address assigned to the local gateway virtual interface on the Outpost side.
-
#local_gateway_virtual_interface_group_id ⇒ String
The ID of the local gateway virtual interface group.
-
#outpost_lag_id ⇒ String
References the Link Aggregation Group (LAG) that connects the Outpost to on-premises network devices.
-
#peer_address ⇒ String
The peer IP address for the local gateway virtual interface.
-
#peer_bgp_asn ⇒ Integer
The Autonomous System Number (ASN) of the Border Gateway Protocol (BGP) peer.
-
#peer_bgp_asn_extended ⇒ Integer
The extended 32-bit ASN of the BGP peer for use with larger ASN values.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to a resource when the local gateway virtual interface is being created.
-
#vlan ⇒ Integer
The virtual local area network (VLAN) used for the local gateway virtual interface.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
12341 12342 12343 12344 12345 12346 12347 12348 12349 12350 12351 12352 12353 |
# File 'lib/aws-sdk-ec2/types.rb', line 12341 class CreateLocalGatewayVirtualInterfaceRequest < Struct.new( :local_gateway_virtual_interface_group_id, :outpost_lag_id, :vlan, :local_address, :peer_address, :peer_bgp_asn, :tag_specifications, :dry_run, :peer_bgp_asn_extended) SENSITIVE = [] include Aws::Structure end |
#local_address ⇒ String
The IP address assigned to the local gateway virtual interface on the Outpost side. Only IPv4 is supported.
12341 12342 12343 12344 12345 12346 12347 12348 12349 12350 12351 12352 12353 |
# File 'lib/aws-sdk-ec2/types.rb', line 12341 class CreateLocalGatewayVirtualInterfaceRequest < Struct.new( :local_gateway_virtual_interface_group_id, :outpost_lag_id, :vlan, :local_address, :peer_address, :peer_bgp_asn, :tag_specifications, :dry_run, :peer_bgp_asn_extended) SENSITIVE = [] include Aws::Structure end |
#local_gateway_virtual_interface_group_id ⇒ String
The ID of the local gateway virtual interface group.
12341 12342 12343 12344 12345 12346 12347 12348 12349 12350 12351 12352 12353 |
# File 'lib/aws-sdk-ec2/types.rb', line 12341 class CreateLocalGatewayVirtualInterfaceRequest < Struct.new( :local_gateway_virtual_interface_group_id, :outpost_lag_id, :vlan, :local_address, :peer_address, :peer_bgp_asn, :tag_specifications, :dry_run, :peer_bgp_asn_extended) SENSITIVE = [] include Aws::Structure end |
#outpost_lag_id ⇒ String
References the Link Aggregation Group (LAG) that connects the Outpost to on-premises network devices.
12341 12342 12343 12344 12345 12346 12347 12348 12349 12350 12351 12352 12353 |
# File 'lib/aws-sdk-ec2/types.rb', line 12341 class CreateLocalGatewayVirtualInterfaceRequest < Struct.new( :local_gateway_virtual_interface_group_id, :outpost_lag_id, :vlan, :local_address, :peer_address, :peer_bgp_asn, :tag_specifications, :dry_run, :peer_bgp_asn_extended) SENSITIVE = [] include Aws::Structure end |
#peer_address ⇒ String
The peer IP address for the local gateway virtual interface. Only IPv4 is supported.
12341 12342 12343 12344 12345 12346 12347 12348 12349 12350 12351 12352 12353 |
# File 'lib/aws-sdk-ec2/types.rb', line 12341 class CreateLocalGatewayVirtualInterfaceRequest < Struct.new( :local_gateway_virtual_interface_group_id, :outpost_lag_id, :vlan, :local_address, :peer_address, :peer_bgp_asn, :tag_specifications, :dry_run, :peer_bgp_asn_extended) SENSITIVE = [] include Aws::Structure end |
#peer_bgp_asn ⇒ Integer
The Autonomous System Number (ASN) of the Border Gateway Protocol (BGP) peer.
12341 12342 12343 12344 12345 12346 12347 12348 12349 12350 12351 12352 12353 |
# File 'lib/aws-sdk-ec2/types.rb', line 12341 class CreateLocalGatewayVirtualInterfaceRequest < Struct.new( :local_gateway_virtual_interface_group_id, :outpost_lag_id, :vlan, :local_address, :peer_address, :peer_bgp_asn, :tag_specifications, :dry_run, :peer_bgp_asn_extended) SENSITIVE = [] include Aws::Structure end |
#peer_bgp_asn_extended ⇒ Integer
The extended 32-bit ASN of the BGP peer for use with larger ASN values.
12341 12342 12343 12344 12345 12346 12347 12348 12349 12350 12351 12352 12353 |
# File 'lib/aws-sdk-ec2/types.rb', line 12341 class CreateLocalGatewayVirtualInterfaceRequest < Struct.new( :local_gateway_virtual_interface_group_id, :outpost_lag_id, :vlan, :local_address, :peer_address, :peer_bgp_asn, :tag_specifications, :dry_run, :peer_bgp_asn_extended) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to a resource when the local gateway virtual interface is being created.
12341 12342 12343 12344 12345 12346 12347 12348 12349 12350 12351 12352 12353 |
# File 'lib/aws-sdk-ec2/types.rb', line 12341 class CreateLocalGatewayVirtualInterfaceRequest < Struct.new( :local_gateway_virtual_interface_group_id, :outpost_lag_id, :vlan, :local_address, :peer_address, :peer_bgp_asn, :tag_specifications, :dry_run, :peer_bgp_asn_extended) SENSITIVE = [] include Aws::Structure end |
#vlan ⇒ Integer
The virtual local area network (VLAN) used for the local gateway virtual interface.
12341 12342 12343 12344 12345 12346 12347 12348 12349 12350 12351 12352 12353 |
# File 'lib/aws-sdk-ec2/types.rb', line 12341 class CreateLocalGatewayVirtualInterfaceRequest < Struct.new( :local_gateway_virtual_interface_group_id, :outpost_lag_id, :vlan, :local_address, :peer_address, :peer_bgp_asn, :tag_specifications, :dry_run, :peer_bgp_asn_extended) SENSITIVE = [] include Aws::Structure end |