Class: Aws::EC2::Types::CreateNetworkAclRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateNetworkAclRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the network ACL.
-
#vpc_id ⇒ String
The ID of the VPC.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring idempotency.
A suitable default value is auto-generated. You should normally not need to pass this option.
13170 13171 13172 13173 13174 13175 13176 13177 |
# File 'lib/aws-sdk-ec2/types.rb', line 13170 class CreateNetworkAclRequest < Struct.new( :tag_specifications, :client_token, :dry_run, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
13170 13171 13172 13173 13174 13175 13176 13177 |
# File 'lib/aws-sdk-ec2/types.rb', line 13170 class CreateNetworkAclRequest < Struct.new( :tag_specifications, :client_token, :dry_run, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the network ACL.
13170 13171 13172 13173 13174 13175 13176 13177 |
# File 'lib/aws-sdk-ec2/types.rb', line 13170 class CreateNetworkAclRequest < Struct.new( :tag_specifications, :client_token, :dry_run, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC.
13170 13171 13172 13173 13174 13175 13176 13177 |
# File 'lib/aws-sdk-ec2/types.rb', line 13170 class CreateNetworkAclRequest < Struct.new( :tag_specifications, :client_token, :dry_run, :vpc_id) SENSITIVE = [] include Aws::Structure end |