Class: Aws::EC2::Types::CreateNetworkAclRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateNetworkAclRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the network ACL.
-
#vpc_id ⇒ String
The ID of the VPC.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [Ensuring idempotency].
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html
12621 12622 12623 12624 12625 12626 12627 12628 |
# File 'lib/aws-sdk-ec2/types.rb', line 12621 class CreateNetworkAclRequest < Struct.new( :tag_specifications, :client_token, :dry_run, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
12621 12622 12623 12624 12625 12626 12627 12628 |
# File 'lib/aws-sdk-ec2/types.rb', line 12621 class CreateNetworkAclRequest < Struct.new( :tag_specifications, :client_token, :dry_run, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the network ACL.
12621 12622 12623 12624 12625 12626 12627 12628 |
# File 'lib/aws-sdk-ec2/types.rb', line 12621 class CreateNetworkAclRequest < Struct.new( :tag_specifications, :client_token, :dry_run, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC.
12621 12622 12623 12624 12625 12626 12627 12628 |
# File 'lib/aws-sdk-ec2/types.rb', line 12621 class CreateNetworkAclRequest < Struct.new( :tag_specifications, :client_token, :dry_run, :vpc_id) SENSITIVE = [] include Aws::Structure end |