Class: Aws::EC2::Types::CreateNetworkInsightsAccessScopeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


14072
14073
14074
14075
14076
14077
14078
14079
14080
# File 'lib/aws-sdk-ec2/types.rb', line 14072

class CreateNetworkInsightsAccessScopeRequest < Struct.new(
  :match_paths,
  :exclude_paths,
  :client_token,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


14072
14073
14074
14075
14076
14077
14078
14079
14080
# File 'lib/aws-sdk-ec2/types.rb', line 14072

class CreateNetworkInsightsAccessScopeRequest < Struct.new(
  :match_paths,
  :exclude_paths,
  :client_token,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#exclude_pathsArray<Types::AccessScopePathRequest>

The paths to exclude.

Returns:



14072
14073
14074
14075
14076
14077
14078
14079
14080
# File 'lib/aws-sdk-ec2/types.rb', line 14072

class CreateNetworkInsightsAccessScopeRequest < Struct.new(
  :match_paths,
  :exclude_paths,
  :client_token,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#match_pathsArray<Types::AccessScopePathRequest>

The paths to match.

Returns:



14072
14073
14074
14075
14076
14077
14078
14079
14080
# File 'lib/aws-sdk-ec2/types.rb', line 14072

class CreateNetworkInsightsAccessScopeRequest < Struct.new(
  :match_paths,
  :exclude_paths,
  :client_token,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply.

Returns:



14072
14073
14074
14075
14076
14077
14078
14079
14080
# File 'lib/aws-sdk-ec2/types.rb', line 14072

class CreateNetworkInsightsAccessScopeRequest < Struct.new(
  :match_paths,
  :exclude_paths,
  :client_token,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end