Class: Aws::EC2::Types::CreateNetworkInsightsAccessScopeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateNetworkInsightsAccessScopeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#exclude_paths ⇒ Array<Types::AccessScopePathRequest>
The paths to exclude.
-
#match_paths ⇒ Array<Types::AccessScopePathRequest>
The paths to match.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency.
A suitable default value is auto-generated. You should normally not need to pass this option.
14063 14064 14065 14066 14067 14068 14069 14070 14071 |
# File 'lib/aws-sdk-ec2/types.rb', line 14063 class CreateNetworkInsightsAccessScopeRequest < Struct.new( :match_paths, :exclude_paths, :client_token, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
14063 14064 14065 14066 14067 14068 14069 14070 14071 |
# File 'lib/aws-sdk-ec2/types.rb', line 14063 class CreateNetworkInsightsAccessScopeRequest < Struct.new( :match_paths, :exclude_paths, :client_token, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#exclude_paths ⇒ Array<Types::AccessScopePathRequest>
The paths to exclude.
14063 14064 14065 14066 14067 14068 14069 14070 14071 |
# File 'lib/aws-sdk-ec2/types.rb', line 14063 class CreateNetworkInsightsAccessScopeRequest < Struct.new( :match_paths, :exclude_paths, :client_token, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#match_paths ⇒ Array<Types::AccessScopePathRequest>
The paths to match.
14063 14064 14065 14066 14067 14068 14069 14070 14071 |
# File 'lib/aws-sdk-ec2/types.rb', line 14063 class CreateNetworkInsightsAccessScopeRequest < Struct.new( :match_paths, :exclude_paths, :client_token, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply.
14063 14064 14065 14066 14067 14068 14069 14070 14071 |
# File 'lib/aws-sdk-ec2/types.rb', line 14063 class CreateNetworkInsightsAccessScopeRequest < Struct.new( :match_paths, :exclude_paths, :client_token, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |