Class: Aws::EC2::Types::CreateNetworkInsightsAccessScopeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [How to ensure idempotency].

**A suitable default value is auto-generated.** You should normally not need to pass this option.

[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html

Returns:

  • (String)


12881
12882
12883
12884
12885
12886
12887
12888
12889
# File 'lib/aws-sdk-ec2/types.rb', line 12881

class CreateNetworkInsightsAccessScopeRequest < Struct.new(
  :match_paths,
  :exclude_paths,
  :client_token,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


12881
12882
12883
12884
12885
12886
12887
12888
12889
# File 'lib/aws-sdk-ec2/types.rb', line 12881

class CreateNetworkInsightsAccessScopeRequest < Struct.new(
  :match_paths,
  :exclude_paths,
  :client_token,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#exclude_pathsArray<Types::AccessScopePathRequest>

The paths to exclude.

Returns:



12881
12882
12883
12884
12885
12886
12887
12888
12889
# File 'lib/aws-sdk-ec2/types.rb', line 12881

class CreateNetworkInsightsAccessScopeRequest < Struct.new(
  :match_paths,
  :exclude_paths,
  :client_token,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#match_pathsArray<Types::AccessScopePathRequest>

The paths to match.

Returns:



12881
12882
12883
12884
12885
12886
12887
12888
12889
# File 'lib/aws-sdk-ec2/types.rb', line 12881

class CreateNetworkInsightsAccessScopeRequest < Struct.new(
  :match_paths,
  :exclude_paths,
  :client_token,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply.

Returns:



12881
12882
12883
12884
12885
12886
12887
12888
12889
# File 'lib/aws-sdk-ec2/types.rb', line 12881

class CreateNetworkInsightsAccessScopeRequest < Struct.new(
  :match_paths,
  :exclude_paths,
  :client_token,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end