Class: Aws::EC2::Types::CreateNetworkInsightsPathRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateNetworkInsightsPathRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#destination ⇒ String
The ID or ARN of the destination.
-
#destination_ip ⇒ String
The IP address of the destination.
-
#destination_port ⇒ Integer
The destination port.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filter_at_destination ⇒ Types::PathRequestFilter
Scopes the analysis to network paths that match specific filters at the destination.
-
#filter_at_source ⇒ Types::PathRequestFilter
Scopes the analysis to network paths that match specific filters at the source.
-
#protocol ⇒ String
The protocol.
-
#source ⇒ String
The ID or ARN of the source.
-
#source_ip ⇒ String
The IP address of the source.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to add to the path.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency.
A suitable default value is auto-generated. You should normally not need to pass this option.
13348 13349 13350 13351 13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 13362 |
# File 'lib/aws-sdk-ec2/types.rb', line 13348 class CreateNetworkInsightsPathRequest < Struct.new( :source_ip, :destination_ip, :source, :destination, :protocol, :destination_port, :tag_specifications, :dry_run, :client_token, :filter_at_source, :filter_at_destination) SENSITIVE = [] include Aws::Structure end |
#destination ⇒ String
The ID or ARN of the destination. If the resource is in another account, you must specify an ARN.
13348 13349 13350 13351 13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 13362 |
# File 'lib/aws-sdk-ec2/types.rb', line 13348 class CreateNetworkInsightsPathRequest < Struct.new( :source_ip, :destination_ip, :source, :destination, :protocol, :destination_port, :tag_specifications, :dry_run, :client_token, :filter_at_source, :filter_at_destination) SENSITIVE = [] include Aws::Structure end |
#destination_ip ⇒ String
The IP address of the destination.
13348 13349 13350 13351 13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 13362 |
# File 'lib/aws-sdk-ec2/types.rb', line 13348 class CreateNetworkInsightsPathRequest < Struct.new( :source_ip, :destination_ip, :source, :destination, :protocol, :destination_port, :tag_specifications, :dry_run, :client_token, :filter_at_source, :filter_at_destination) SENSITIVE = [] include Aws::Structure end |
#destination_port ⇒ Integer
The destination port.
13348 13349 13350 13351 13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 13362 |
# File 'lib/aws-sdk-ec2/types.rb', line 13348 class CreateNetworkInsightsPathRequest < Struct.new( :source_ip, :destination_ip, :source, :destination, :protocol, :destination_port, :tag_specifications, :dry_run, :client_token, :filter_at_source, :filter_at_destination) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
13348 13349 13350 13351 13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 13362 |
# File 'lib/aws-sdk-ec2/types.rb', line 13348 class CreateNetworkInsightsPathRequest < Struct.new( :source_ip, :destination_ip, :source, :destination, :protocol, :destination_port, :tag_specifications, :dry_run, :client_token, :filter_at_source, :filter_at_destination) SENSITIVE = [] include Aws::Structure end |
#filter_at_destination ⇒ Types::PathRequestFilter
Scopes the analysis to network paths that match specific filters at the destination. If you specify this parameter, you can't specify the parameter for the destination IP address.
13348 13349 13350 13351 13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 13362 |
# File 'lib/aws-sdk-ec2/types.rb', line 13348 class CreateNetworkInsightsPathRequest < Struct.new( :source_ip, :destination_ip, :source, :destination, :protocol, :destination_port, :tag_specifications, :dry_run, :client_token, :filter_at_source, :filter_at_destination) SENSITIVE = [] include Aws::Structure end |
#filter_at_source ⇒ Types::PathRequestFilter
Scopes the analysis to network paths that match specific filters at the source. If you specify this parameter, you can't specify the parameters for the source IP address or the destination port.
13348 13349 13350 13351 13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 13362 |
# File 'lib/aws-sdk-ec2/types.rb', line 13348 class CreateNetworkInsightsPathRequest < Struct.new( :source_ip, :destination_ip, :source, :destination, :protocol, :destination_port, :tag_specifications, :dry_run, :client_token, :filter_at_source, :filter_at_destination) SENSITIVE = [] include Aws::Structure end |
#protocol ⇒ String
The protocol.
13348 13349 13350 13351 13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 13362 |
# File 'lib/aws-sdk-ec2/types.rb', line 13348 class CreateNetworkInsightsPathRequest < Struct.new( :source_ip, :destination_ip, :source, :destination, :protocol, :destination_port, :tag_specifications, :dry_run, :client_token, :filter_at_source, :filter_at_destination) SENSITIVE = [] include Aws::Structure end |
#source ⇒ String
The ID or ARN of the source. If the resource is in another account, you must specify an ARN.
13348 13349 13350 13351 13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 13362 |
# File 'lib/aws-sdk-ec2/types.rb', line 13348 class CreateNetworkInsightsPathRequest < Struct.new( :source_ip, :destination_ip, :source, :destination, :protocol, :destination_port, :tag_specifications, :dry_run, :client_token, :filter_at_source, :filter_at_destination) SENSITIVE = [] include Aws::Structure end |
#source_ip ⇒ String
The IP address of the source.
13348 13349 13350 13351 13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 13362 |
# File 'lib/aws-sdk-ec2/types.rb', line 13348 class CreateNetworkInsightsPathRequest < Struct.new( :source_ip, :destination_ip, :source, :destination, :protocol, :destination_port, :tag_specifications, :dry_run, :client_token, :filter_at_source, :filter_at_destination) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to add to the path.
13348 13349 13350 13351 13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 13362 |
# File 'lib/aws-sdk-ec2/types.rb', line 13348 class CreateNetworkInsightsPathRequest < Struct.new( :source_ip, :destination_ip, :source, :destination, :protocol, :destination_port, :tag_specifications, :dry_run, :client_token, :filter_at_source, :filter_at_destination) SENSITIVE = [] include Aws::Structure end |