Class: Aws::EC2::Types::CreateNetworkInsightsPathRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [How to ensure idempotency].

**A suitable default value is auto-generated.** You should normally not need to pass this option.

[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html

Returns:

  • (String)


12702
12703
12704
12705
12706
12707
12708
12709
12710
12711
12712
12713
12714
12715
12716
# File 'lib/aws-sdk-ec2/types.rb', line 12702

class CreateNetworkInsightsPathRequest < Struct.new(
  :source_ip,
  :destination_ip,
  :source,
  :destination,
  :protocol,
  :destination_port,
  :tag_specifications,
  :dry_run,
  :client_token,
  :filter_at_source,
  :filter_at_destination)
  SENSITIVE = []
  include Aws::Structure
end

#destinationString

The ID or ARN of the destination. If the resource is in another account, you must specify an ARN.

Returns:

  • (String)


12702
12703
12704
12705
12706
12707
12708
12709
12710
12711
12712
12713
12714
12715
12716
# File 'lib/aws-sdk-ec2/types.rb', line 12702

class CreateNetworkInsightsPathRequest < Struct.new(
  :source_ip,
  :destination_ip,
  :source,
  :destination,
  :protocol,
  :destination_port,
  :tag_specifications,
  :dry_run,
  :client_token,
  :filter_at_source,
  :filter_at_destination)
  SENSITIVE = []
  include Aws::Structure
end

#destination_ipString

The IP address of the destination.

Returns:

  • (String)


12702
12703
12704
12705
12706
12707
12708
12709
12710
12711
12712
12713
12714
12715
12716
# File 'lib/aws-sdk-ec2/types.rb', line 12702

class CreateNetworkInsightsPathRequest < Struct.new(
  :source_ip,
  :destination_ip,
  :source,
  :destination,
  :protocol,
  :destination_port,
  :tag_specifications,
  :dry_run,
  :client_token,
  :filter_at_source,
  :filter_at_destination)
  SENSITIVE = []
  include Aws::Structure
end

#destination_portInteger

The destination port.

Returns:

  • (Integer)


12702
12703
12704
12705
12706
12707
12708
12709
12710
12711
12712
12713
12714
12715
12716
# File 'lib/aws-sdk-ec2/types.rb', line 12702

class CreateNetworkInsightsPathRequest < Struct.new(
  :source_ip,
  :destination_ip,
  :source,
  :destination,
  :protocol,
  :destination_port,
  :tag_specifications,
  :dry_run,
  :client_token,
  :filter_at_source,
  :filter_at_destination)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


12702
12703
12704
12705
12706
12707
12708
12709
12710
12711
12712
12713
12714
12715
12716
# File 'lib/aws-sdk-ec2/types.rb', line 12702

class CreateNetworkInsightsPathRequest < Struct.new(
  :source_ip,
  :destination_ip,
  :source,
  :destination,
  :protocol,
  :destination_port,
  :tag_specifications,
  :dry_run,
  :client_token,
  :filter_at_source,
  :filter_at_destination)
  SENSITIVE = []
  include Aws::Structure
end

#filter_at_destinationTypes::PathRequestFilter

Scopes the analysis to network paths that match specific filters at the destination. If you specify this parameter, you can’t specify the parameter for the destination IP address.



12702
12703
12704
12705
12706
12707
12708
12709
12710
12711
12712
12713
12714
12715
12716
# File 'lib/aws-sdk-ec2/types.rb', line 12702

class CreateNetworkInsightsPathRequest < Struct.new(
  :source_ip,
  :destination_ip,
  :source,
  :destination,
  :protocol,
  :destination_port,
  :tag_specifications,
  :dry_run,
  :client_token,
  :filter_at_source,
  :filter_at_destination)
  SENSITIVE = []
  include Aws::Structure
end

#filter_at_sourceTypes::PathRequestFilter

Scopes the analysis to network paths that match specific filters at the source. If you specify this parameter, you can’t specify the parameters for the source IP address or the destination port.



12702
12703
12704
12705
12706
12707
12708
12709
12710
12711
12712
12713
12714
12715
12716
# File 'lib/aws-sdk-ec2/types.rb', line 12702

class CreateNetworkInsightsPathRequest < Struct.new(
  :source_ip,
  :destination_ip,
  :source,
  :destination,
  :protocol,
  :destination_port,
  :tag_specifications,
  :dry_run,
  :client_token,
  :filter_at_source,
  :filter_at_destination)
  SENSITIVE = []
  include Aws::Structure
end

#protocolString

The protocol.

Returns:

  • (String)


12702
12703
12704
12705
12706
12707
12708
12709
12710
12711
12712
12713
12714
12715
12716
# File 'lib/aws-sdk-ec2/types.rb', line 12702

class CreateNetworkInsightsPathRequest < Struct.new(
  :source_ip,
  :destination_ip,
  :source,
  :destination,
  :protocol,
  :destination_port,
  :tag_specifications,
  :dry_run,
  :client_token,
  :filter_at_source,
  :filter_at_destination)
  SENSITIVE = []
  include Aws::Structure
end

#sourceString

The ID or ARN of the source. If the resource is in another account, you must specify an ARN.

Returns:

  • (String)


12702
12703
12704
12705
12706
12707
12708
12709
12710
12711
12712
12713
12714
12715
12716
# File 'lib/aws-sdk-ec2/types.rb', line 12702

class CreateNetworkInsightsPathRequest < Struct.new(
  :source_ip,
  :destination_ip,
  :source,
  :destination,
  :protocol,
  :destination_port,
  :tag_specifications,
  :dry_run,
  :client_token,
  :filter_at_source,
  :filter_at_destination)
  SENSITIVE = []
  include Aws::Structure
end

#source_ipString

The IP address of the source.

Returns:

  • (String)


12702
12703
12704
12705
12706
12707
12708
12709
12710
12711
12712
12713
12714
12715
12716
# File 'lib/aws-sdk-ec2/types.rb', line 12702

class CreateNetworkInsightsPathRequest < Struct.new(
  :source_ip,
  :destination_ip,
  :source,
  :destination,
  :protocol,
  :destination_port,
  :tag_specifications,
  :dry_run,
  :client_token,
  :filter_at_source,
  :filter_at_destination)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to add to the path.

Returns:



12702
12703
12704
12705
12706
12707
12708
12709
12710
12711
12712
12713
12714
12715
12716
# File 'lib/aws-sdk-ec2/types.rb', line 12702

class CreateNetworkInsightsPathRequest < Struct.new(
  :source_ip,
  :destination_ip,
  :source,
  :destination,
  :protocol,
  :destination_port,
  :tag_specifications,
  :dry_run,
  :client_token,
  :filter_at_source,
  :filter_at_destination)
  SENSITIVE = []
  include Aws::Structure
end