Class: Aws::EC2::Types::CreateNetworkInterfacePermissionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for CreateNetworkInterfacePermission.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The Amazon Web Services account ID.

Returns:

  • (String)


13015
13016
13017
13018
13019
13020
13021
13022
13023
# File 'lib/aws-sdk-ec2/types.rb', line 13015

class CreateNetworkInterfacePermissionRequest < Struct.new(
  :network_interface_id,
  :aws_account_id,
  :aws_service,
  :permission,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#aws_serviceString

The Amazon Web Services service. Currently not supported.

Returns:

  • (String)


13015
13016
13017
13018
13019
13020
13021
13022
13023
# File 'lib/aws-sdk-ec2/types.rb', line 13015

class CreateNetworkInterfacePermissionRequest < Struct.new(
  :network_interface_id,
  :aws_account_id,
  :aws_service,
  :permission,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


13015
13016
13017
13018
13019
13020
13021
13022
13023
# File 'lib/aws-sdk-ec2/types.rb', line 13015

class CreateNetworkInterfacePermissionRequest < Struct.new(
  :network_interface_id,
  :aws_account_id,
  :aws_service,
  :permission,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#network_interface_idString

The ID of the network interface.

Returns:

  • (String)


13015
13016
13017
13018
13019
13020
13021
13022
13023
# File 'lib/aws-sdk-ec2/types.rb', line 13015

class CreateNetworkInterfacePermissionRequest < Struct.new(
  :network_interface_id,
  :aws_account_id,
  :aws_service,
  :permission,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#permissionString

The type of permission to grant.

Returns:

  • (String)


13015
13016
13017
13018
13019
13020
13021
13022
13023
# File 'lib/aws-sdk-ec2/types.rb', line 13015

class CreateNetworkInterfacePermissionRequest < Struct.new(
  :network_interface_id,
  :aws_account_id,
  :aws_service,
  :permission,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end