Class: Aws::EC2::Types::CreateNetworkInterfacePermissionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateNetworkInterfacePermissionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for CreateNetworkInterfacePermission.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The Amazon Web Services account ID.
-
#aws_service ⇒ String
The Amazon Web Services service.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#network_interface_id ⇒ String
The ID of the network interface.
-
#permission ⇒ String
The type of permission to grant.
Instance Attribute Details
#aws_account_id ⇒ String
The Amazon Web Services account ID.
13015 13016 13017 13018 13019 13020 13021 13022 13023 |
# File 'lib/aws-sdk-ec2/types.rb', line 13015 class CreateNetworkInterfacePermissionRequest < Struct.new( :network_interface_id, :aws_account_id, :aws_service, :permission, :dry_run) SENSITIVE = [] include Aws::Structure end |
#aws_service ⇒ String
The Amazon Web Services service. Currently not supported.
13015 13016 13017 13018 13019 13020 13021 13022 13023 |
# File 'lib/aws-sdk-ec2/types.rb', line 13015 class CreateNetworkInterfacePermissionRequest < Struct.new( :network_interface_id, :aws_account_id, :aws_service, :permission, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
13015 13016 13017 13018 13019 13020 13021 13022 13023 |
# File 'lib/aws-sdk-ec2/types.rb', line 13015 class CreateNetworkInterfacePermissionRequest < Struct.new( :network_interface_id, :aws_account_id, :aws_service, :permission, :dry_run) SENSITIVE = [] include Aws::Structure end |
#network_interface_id ⇒ String
The ID of the network interface.
13015 13016 13017 13018 13019 13020 13021 13022 13023 |
# File 'lib/aws-sdk-ec2/types.rb', line 13015 class CreateNetworkInterfacePermissionRequest < Struct.new( :network_interface_id, :aws_account_id, :aws_service, :permission, :dry_run) SENSITIVE = [] include Aws::Structure end |
#permission ⇒ String
The type of permission to grant.
13015 13016 13017 13018 13019 13020 13021 13022 13023 |
# File 'lib/aws-sdk-ec2/types.rb', line 13015 class CreateNetworkInterfacePermissionRequest < Struct.new( :network_interface_id, :aws_account_id, :aws_service, :permission, :dry_run) SENSITIVE = [] include Aws::Structure end |