Class: Aws::EC2::Types::CreateNetworkInterfacePermissionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for CreateNetworkInterfacePermission.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The Amazon Web Services account ID.

Returns:

  • (String)


12829
12830
12831
12832
12833
12834
12835
12836
12837
# File 'lib/aws-sdk-ec2/types.rb', line 12829

class CreateNetworkInterfacePermissionRequest < Struct.new(
  :network_interface_id,
  :aws_account_id,
  :aws_service,
  :permission,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#aws_serviceString

The Amazon Web Services service. Currently not supported.

Returns:

  • (String)


12829
12830
12831
12832
12833
12834
12835
12836
12837
# File 'lib/aws-sdk-ec2/types.rb', line 12829

class CreateNetworkInterfacePermissionRequest < Struct.new(
  :network_interface_id,
  :aws_account_id,
  :aws_service,
  :permission,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


12829
12830
12831
12832
12833
12834
12835
12836
12837
# File 'lib/aws-sdk-ec2/types.rb', line 12829

class CreateNetworkInterfacePermissionRequest < Struct.new(
  :network_interface_id,
  :aws_account_id,
  :aws_service,
  :permission,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#network_interface_idString

The ID of the network interface.

Returns:

  • (String)


12829
12830
12831
12832
12833
12834
12835
12836
12837
# File 'lib/aws-sdk-ec2/types.rb', line 12829

class CreateNetworkInterfacePermissionRequest < Struct.new(
  :network_interface_id,
  :aws_account_id,
  :aws_service,
  :permission,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#permissionString

The type of permission to grant.

Returns:

  • (String)


12829
12830
12831
12832
12833
12834
12835
12836
12837
# File 'lib/aws-sdk-ec2/types.rb', line 12829

class CreateNetworkInterfacePermissionRequest < Struct.new(
  :network_interface_id,
  :aws_account_id,
  :aws_service,
  :permission,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end