Class: Aws::EC2::Types::CreatePlacementGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreatePlacementGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#group_name ⇒ String
A name for the placement group.
-
#linked_group_id ⇒ String
Reserved for future use.
-
#operator ⇒ Types::OperatorRequest
Reserved for internal use.
-
#partition_count ⇒ Integer
The number of partitions.
-
#spread_level ⇒ String
Determines how placement groups spread instances.
-
#strategy ⇒ String
The placement strategy.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the new placement group.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
13489 13490 13491 13492 13493 13494 13495 13496 13497 13498 13499 13500 |
# File 'lib/aws-sdk-ec2/types.rb', line 13489 class CreatePlacementGroupRequest < Struct.new( :partition_count, :tag_specifications, :spread_level, :linked_group_id, :operator, :dry_run, :group_name, :strategy) SENSITIVE = [] include Aws::Structure end |
#group_name ⇒ String
A name for the placement group. Must be unique within the scope of your account for the Region.
Constraints: Up to 255 ASCII characters
13489 13490 13491 13492 13493 13494 13495 13496 13497 13498 13499 13500 |
# File 'lib/aws-sdk-ec2/types.rb', line 13489 class CreatePlacementGroupRequest < Struct.new( :partition_count, :tag_specifications, :spread_level, :linked_group_id, :operator, :dry_run, :group_name, :strategy) SENSITIVE = [] include Aws::Structure end |
#linked_group_id ⇒ String
Reserved for future use.
13489 13490 13491 13492 13493 13494 13495 13496 13497 13498 13499 13500 |
# File 'lib/aws-sdk-ec2/types.rb', line 13489 class CreatePlacementGroupRequest < Struct.new( :partition_count, :tag_specifications, :spread_level, :linked_group_id, :operator, :dry_run, :group_name, :strategy) SENSITIVE = [] include Aws::Structure end |
#operator ⇒ Types::OperatorRequest
Reserved for internal use.
13489 13490 13491 13492 13493 13494 13495 13496 13497 13498 13499 13500 |
# File 'lib/aws-sdk-ec2/types.rb', line 13489 class CreatePlacementGroupRequest < Struct.new( :partition_count, :tag_specifications, :spread_level, :linked_group_id, :operator, :dry_run, :group_name, :strategy) SENSITIVE = [] include Aws::Structure end |
#partition_count ⇒ Integer
The number of partitions. Valid only when Strategy is set to ‘partition`.
13489 13490 13491 13492 13493 13494 13495 13496 13497 13498 13499 13500 |
# File 'lib/aws-sdk-ec2/types.rb', line 13489 class CreatePlacementGroupRequest < Struct.new( :partition_count, :tag_specifications, :spread_level, :linked_group_id, :operator, :dry_run, :group_name, :strategy) SENSITIVE = [] include Aws::Structure end |
#spread_level ⇒ String
Determines how placement groups spread instances.
-
Host – You can use ‘host` only with Outpost placement groups.
-
Rack – No usage restrictions.
13489 13490 13491 13492 13493 13494 13495 13496 13497 13498 13499 13500 |
# File 'lib/aws-sdk-ec2/types.rb', line 13489 class CreatePlacementGroupRequest < Struct.new( :partition_count, :tag_specifications, :spread_level, :linked_group_id, :operator, :dry_run, :group_name, :strategy) SENSITIVE = [] include Aws::Structure end |
#strategy ⇒ String
The placement strategy.
13489 13490 13491 13492 13493 13494 13495 13496 13497 13498 13499 13500 |
# File 'lib/aws-sdk-ec2/types.rb', line 13489 class CreatePlacementGroupRequest < Struct.new( :partition_count, :tag_specifications, :spread_level, :linked_group_id, :operator, :dry_run, :group_name, :strategy) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the new placement group.
13489 13490 13491 13492 13493 13494 13495 13496 13497 13498 13499 13500 |
# File 'lib/aws-sdk-ec2/types.rb', line 13489 class CreatePlacementGroupRequest < Struct.new( :partition_count, :tag_specifications, :spread_level, :linked_group_id, :operator, :dry_run, :group_name, :strategy) SENSITIVE = [] include Aws::Structure end |