Class: Aws::EC2::Types::CreatePlacementGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


13297
13298
13299
13300
13301
13302
13303
13304
13305
13306
13307
13308
# File 'lib/aws-sdk-ec2/types.rb', line 13297

class CreatePlacementGroupRequest < Struct.new(
  :partition_count,
  :tag_specifications,
  :spread_level,
  :linked_group_id,
  :operator,
  :dry_run,
  :group_name,
  :strategy)
  SENSITIVE = []
  include Aws::Structure
end

#group_nameString

A name for the placement group. Must be unique within the scope of your account for the Region.

Constraints: Up to 255 ASCII characters

Returns:

  • (String)


13297
13298
13299
13300
13301
13302
13303
13304
13305
13306
13307
13308
# File 'lib/aws-sdk-ec2/types.rb', line 13297

class CreatePlacementGroupRequest < Struct.new(
  :partition_count,
  :tag_specifications,
  :spread_level,
  :linked_group_id,
  :operator,
  :dry_run,
  :group_name,
  :strategy)
  SENSITIVE = []
  include Aws::Structure
end

#linked_group_idString

Reserved for future use.

Returns:

  • (String)


13297
13298
13299
13300
13301
13302
13303
13304
13305
13306
13307
13308
# File 'lib/aws-sdk-ec2/types.rb', line 13297

class CreatePlacementGroupRequest < Struct.new(
  :partition_count,
  :tag_specifications,
  :spread_level,
  :linked_group_id,
  :operator,
  :dry_run,
  :group_name,
  :strategy)
  SENSITIVE = []
  include Aws::Structure
end

#operatorTypes::OperatorRequest

Reserved for internal use.



13297
13298
13299
13300
13301
13302
13303
13304
13305
13306
13307
13308
# File 'lib/aws-sdk-ec2/types.rb', line 13297

class CreatePlacementGroupRequest < Struct.new(
  :partition_count,
  :tag_specifications,
  :spread_level,
  :linked_group_id,
  :operator,
  :dry_run,
  :group_name,
  :strategy)
  SENSITIVE = []
  include Aws::Structure
end

#partition_countInteger

The number of partitions. Valid only when Strategy is set to ‘partition`.

Returns:

  • (Integer)


13297
13298
13299
13300
13301
13302
13303
13304
13305
13306
13307
13308
# File 'lib/aws-sdk-ec2/types.rb', line 13297

class CreatePlacementGroupRequest < Struct.new(
  :partition_count,
  :tag_specifications,
  :spread_level,
  :linked_group_id,
  :operator,
  :dry_run,
  :group_name,
  :strategy)
  SENSITIVE = []
  include Aws::Structure
end

#spread_levelString

Determines how placement groups spread instances.

  • Host – You can use ‘host` only with Outpost placement groups.

  • Rack – No usage restrictions.

Returns:

  • (String)


13297
13298
13299
13300
13301
13302
13303
13304
13305
13306
13307
13308
# File 'lib/aws-sdk-ec2/types.rb', line 13297

class CreatePlacementGroupRequest < Struct.new(
  :partition_count,
  :tag_specifications,
  :spread_level,
  :linked_group_id,
  :operator,
  :dry_run,
  :group_name,
  :strategy)
  SENSITIVE = []
  include Aws::Structure
end

#strategyString

The placement strategy.

Returns:

  • (String)


13297
13298
13299
13300
13301
13302
13303
13304
13305
13306
13307
13308
# File 'lib/aws-sdk-ec2/types.rb', line 13297

class CreatePlacementGroupRequest < Struct.new(
  :partition_count,
  :tag_specifications,
  :spread_level,
  :linked_group_id,
  :operator,
  :dry_run,
  :group_name,
  :strategy)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the new placement group.

Returns:



13297
13298
13299
13300
13301
13302
13303
13304
13305
13306
13307
13308
# File 'lib/aws-sdk-ec2/types.rb', line 13297

class CreatePlacementGroupRequest < Struct.new(
  :partition_count,
  :tag_specifications,
  :spread_level,
  :linked_group_id,
  :operator,
  :dry_run,
  :group_name,
  :strategy)
  SENSITIVE = []
  include Aws::Structure
end