Class: Aws::EC2::Types::CreateRestoreImageTaskRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The name of the Amazon S3 bucket that contains the stored AMI object.

Returns:

  • (String)


13948
13949
13950
13951
13952
13953
13954
13955
13956
# File 'lib/aws-sdk-ec2/types.rb', line 13948

class CreateRestoreImageTaskRequest < Struct.new(
  :bucket,
  :object_key,
  :name,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


13948
13949
13950
13951
13952
13953
13954
13955
13956
# File 'lib/aws-sdk-ec2/types.rb', line 13948

class CreateRestoreImageTaskRequest < Struct.new(
  :bucket,
  :object_key,
  :name,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name for the restored AMI. The name must be unique for AMIs in the Region for this account. If you do not provide a name, the new AMI gets the same name as the original AMI.

Returns:

  • (String)


13948
13949
13950
13951
13952
13953
13954
13955
13956
# File 'lib/aws-sdk-ec2/types.rb', line 13948

class CreateRestoreImageTaskRequest < Struct.new(
  :bucket,
  :object_key,
  :name,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#object_keyString

The name of the stored AMI object in the bucket.

Returns:

  • (String)


13948
13949
13950
13951
13952
13953
13954
13955
13956
# File 'lib/aws-sdk-ec2/types.rb', line 13948

class CreateRestoreImageTaskRequest < Struct.new(
  :bucket,
  :object_key,
  :name,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the AMI and snapshots on restoration. You can tag the AMI, the snapshots, or both.

  • To tag the AMI, the value for ResourceType must be image.

  • To tag the snapshots, the value for ResourceType must be snapshot. The same tag is applied to all of the snapshots that are created.

Returns:



13948
13949
13950
13951
13952
13953
13954
13955
13956
# File 'lib/aws-sdk-ec2/types.rb', line 13948

class CreateRestoreImageTaskRequest < Struct.new(
  :bucket,
  :object_key,
  :name,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end