Class: Aws::EC2::Types::CreateRestoreImageTaskRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateRestoreImageTaskRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The name of the Amazon S3 bucket that contains the stored AMI object.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#name ⇒ String
The name for the restored AMI.
-
#object_key ⇒ String
The name of the stored AMI object in the bucket.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the AMI and snapshots on restoration.
Instance Attribute Details
#bucket ⇒ String
The name of the Amazon S3 bucket that contains the stored AMI object.
13379 13380 13381 13382 13383 13384 13385 13386 13387 |
# File 'lib/aws-sdk-ec2/types.rb', line 13379 class CreateRestoreImageTaskRequest < Struct.new( :bucket, :object_key, :name, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
13379 13380 13381 13382 13383 13384 13385 13386 13387 |
# File 'lib/aws-sdk-ec2/types.rb', line 13379 class CreateRestoreImageTaskRequest < Struct.new( :bucket, :object_key, :name, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name for the restored AMI. The name must be unique for AMIs in the Region for this account. If you do not provide a name, the new AMI gets the same name as the original AMI.
13379 13380 13381 13382 13383 13384 13385 13386 13387 |
# File 'lib/aws-sdk-ec2/types.rb', line 13379 class CreateRestoreImageTaskRequest < Struct.new( :bucket, :object_key, :name, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#object_key ⇒ String
The name of the stored AMI object in the bucket.
13379 13380 13381 13382 13383 13384 13385 13386 13387 |
# File 'lib/aws-sdk-ec2/types.rb', line 13379 class CreateRestoreImageTaskRequest < Struct.new( :bucket, :object_key, :name, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the AMI and snapshots on restoration. You can tag the AMI, the snapshots, or both.
-
To tag the AMI, the value for ‘ResourceType` must be `image`.
-
To tag the snapshots, the value for ‘ResourceType` must be `snapshot`. The same tag is applied to all of the snapshots that are created.
13379 13380 13381 13382 13383 13384 13385 13386 13387 |
# File 'lib/aws-sdk-ec2/types.rb', line 13379 class CreateRestoreImageTaskRequest < Struct.new( :bucket, :object_key, :name, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |