Class: Aws::EC2::Types::CreateRouteRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateRouteRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#carrier_gateway_id ⇒ String
The ID of the carrier gateway.
-
#core_network_arn ⇒ String
The Amazon Resource Name (ARN) of the core network.
-
#destination_cidr_block ⇒ String
The IPv4 CIDR address block used for the destination match.
-
#destination_ipv_6_cidr_block ⇒ String
The IPv6 CIDR block used for the destination match.
-
#destination_prefix_list_id ⇒ String
The ID of a prefix list used for the destination match.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#egress_only_internet_gateway_id ⇒ String
[IPv6 traffic only] The ID of an egress-only internet gateway.
-
#gateway_id ⇒ String
The ID of an internet gateway or virtual private gateway attached to your VPC.
-
#instance_id ⇒ String
The ID of a NAT instance in your VPC.
-
#local_gateway_id ⇒ String
The ID of the local gateway.
-
#nat_gateway_id ⇒ String
[IPv4 traffic only] The ID of a NAT gateway.
-
#network_interface_id ⇒ String
The ID of a network interface.
-
#odb_network_arn ⇒ String
The Amazon Resource Name (ARN) of the ODB network.
-
#route_table_id ⇒ String
The ID of the route table for the route.
-
#transit_gateway_id ⇒ String
The ID of a transit gateway.
-
#vpc_endpoint_id ⇒ String
The ID of a VPC endpoint.
-
#vpc_peering_connection_id ⇒ String
The ID of a VPC peering connection.
Instance Attribute Details
#carrier_gateway_id ⇒ String
The ID of the carrier gateway.
You can only use this option when the VPC contains a subnet which is associated with a Wavelength Zone.
13924 13925 13926 13927 13928 13929 13930 13931 13932 13933 13934 13935 13936 13937 13938 13939 13940 13941 13942 13943 13944 |
# File 'lib/aws-sdk-ec2/types.rb', line 13924 class CreateRouteRequest < Struct.new( :destination_prefix_list_id, :vpc_endpoint_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :core_network_arn, :odb_network_arn, :dry_run, :route_table_id, :destination_cidr_block, :gateway_id, :destination_ipv_6_cidr_block, :egress_only_internet_gateway_id, :instance_id, :network_interface_id, :vpc_peering_connection_id, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |
#core_network_arn ⇒ String
The Amazon Resource Name (ARN) of the core network.
13924 13925 13926 13927 13928 13929 13930 13931 13932 13933 13934 13935 13936 13937 13938 13939 13940 13941 13942 13943 13944 |
# File 'lib/aws-sdk-ec2/types.rb', line 13924 class CreateRouteRequest < Struct.new( :destination_prefix_list_id, :vpc_endpoint_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :core_network_arn, :odb_network_arn, :dry_run, :route_table_id, :destination_cidr_block, :gateway_id, :destination_ipv_6_cidr_block, :egress_only_internet_gateway_id, :instance_id, :network_interface_id, :vpc_peering_connection_id, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |
#destination_cidr_block ⇒ String
The IPv4 CIDR address block used for the destination match. Routing decisions are based on the most specific match. We modify the specified CIDR block to its canonical form; for example, if you specify ‘100.68.0.18/18`, we modify it to `100.68.0.0/18`.
13924 13925 13926 13927 13928 13929 13930 13931 13932 13933 13934 13935 13936 13937 13938 13939 13940 13941 13942 13943 13944 |
# File 'lib/aws-sdk-ec2/types.rb', line 13924 class CreateRouteRequest < Struct.new( :destination_prefix_list_id, :vpc_endpoint_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :core_network_arn, :odb_network_arn, :dry_run, :route_table_id, :destination_cidr_block, :gateway_id, :destination_ipv_6_cidr_block, :egress_only_internet_gateway_id, :instance_id, :network_interface_id, :vpc_peering_connection_id, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |
#destination_ipv_6_cidr_block ⇒ String
The IPv6 CIDR block used for the destination match. Routing decisions are based on the most specific match.
13924 13925 13926 13927 13928 13929 13930 13931 13932 13933 13934 13935 13936 13937 13938 13939 13940 13941 13942 13943 13944 |
# File 'lib/aws-sdk-ec2/types.rb', line 13924 class CreateRouteRequest < Struct.new( :destination_prefix_list_id, :vpc_endpoint_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :core_network_arn, :odb_network_arn, :dry_run, :route_table_id, :destination_cidr_block, :gateway_id, :destination_ipv_6_cidr_block, :egress_only_internet_gateway_id, :instance_id, :network_interface_id, :vpc_peering_connection_id, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |
#destination_prefix_list_id ⇒ String
The ID of a prefix list used for the destination match.
13924 13925 13926 13927 13928 13929 13930 13931 13932 13933 13934 13935 13936 13937 13938 13939 13940 13941 13942 13943 13944 |
# File 'lib/aws-sdk-ec2/types.rb', line 13924 class CreateRouteRequest < Struct.new( :destination_prefix_list_id, :vpc_endpoint_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :core_network_arn, :odb_network_arn, :dry_run, :route_table_id, :destination_cidr_block, :gateway_id, :destination_ipv_6_cidr_block, :egress_only_internet_gateway_id, :instance_id, :network_interface_id, :vpc_peering_connection_id, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
13924 13925 13926 13927 13928 13929 13930 13931 13932 13933 13934 13935 13936 13937 13938 13939 13940 13941 13942 13943 13944 |
# File 'lib/aws-sdk-ec2/types.rb', line 13924 class CreateRouteRequest < Struct.new( :destination_prefix_list_id, :vpc_endpoint_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :core_network_arn, :odb_network_arn, :dry_run, :route_table_id, :destination_cidr_block, :gateway_id, :destination_ipv_6_cidr_block, :egress_only_internet_gateway_id, :instance_id, :network_interface_id, :vpc_peering_connection_id, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |
#egress_only_internet_gateway_id ⇒ String
[IPv6 traffic only] The ID of an egress-only internet gateway.
13924 13925 13926 13927 13928 13929 13930 13931 13932 13933 13934 13935 13936 13937 13938 13939 13940 13941 13942 13943 13944 |
# File 'lib/aws-sdk-ec2/types.rb', line 13924 class CreateRouteRequest < Struct.new( :destination_prefix_list_id, :vpc_endpoint_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :core_network_arn, :odb_network_arn, :dry_run, :route_table_id, :destination_cidr_block, :gateway_id, :destination_ipv_6_cidr_block, :egress_only_internet_gateway_id, :instance_id, :network_interface_id, :vpc_peering_connection_id, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |
#gateway_id ⇒ String
The ID of an internet gateway or virtual private gateway attached to your VPC.
13924 13925 13926 13927 13928 13929 13930 13931 13932 13933 13934 13935 13936 13937 13938 13939 13940 13941 13942 13943 13944 |
# File 'lib/aws-sdk-ec2/types.rb', line 13924 class CreateRouteRequest < Struct.new( :destination_prefix_list_id, :vpc_endpoint_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :core_network_arn, :odb_network_arn, :dry_run, :route_table_id, :destination_cidr_block, :gateway_id, :destination_ipv_6_cidr_block, :egress_only_internet_gateway_id, :instance_id, :network_interface_id, :vpc_peering_connection_id, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of a NAT instance in your VPC. The operation fails if you specify an instance ID unless exactly one network interface is attached.
13924 13925 13926 13927 13928 13929 13930 13931 13932 13933 13934 13935 13936 13937 13938 13939 13940 13941 13942 13943 13944 |
# File 'lib/aws-sdk-ec2/types.rb', line 13924 class CreateRouteRequest < Struct.new( :destination_prefix_list_id, :vpc_endpoint_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :core_network_arn, :odb_network_arn, :dry_run, :route_table_id, :destination_cidr_block, :gateway_id, :destination_ipv_6_cidr_block, :egress_only_internet_gateway_id, :instance_id, :network_interface_id, :vpc_peering_connection_id, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |
#local_gateway_id ⇒ String
The ID of the local gateway.
13924 13925 13926 13927 13928 13929 13930 13931 13932 13933 13934 13935 13936 13937 13938 13939 13940 13941 13942 13943 13944 |
# File 'lib/aws-sdk-ec2/types.rb', line 13924 class CreateRouteRequest < Struct.new( :destination_prefix_list_id, :vpc_endpoint_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :core_network_arn, :odb_network_arn, :dry_run, :route_table_id, :destination_cidr_block, :gateway_id, :destination_ipv_6_cidr_block, :egress_only_internet_gateway_id, :instance_id, :network_interface_id, :vpc_peering_connection_id, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |
#nat_gateway_id ⇒ String
[IPv4 traffic only] The ID of a NAT gateway.
13924 13925 13926 13927 13928 13929 13930 13931 13932 13933 13934 13935 13936 13937 13938 13939 13940 13941 13942 13943 13944 |
# File 'lib/aws-sdk-ec2/types.rb', line 13924 class CreateRouteRequest < Struct.new( :destination_prefix_list_id, :vpc_endpoint_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :core_network_arn, :odb_network_arn, :dry_run, :route_table_id, :destination_cidr_block, :gateway_id, :destination_ipv_6_cidr_block, :egress_only_internet_gateway_id, :instance_id, :network_interface_id, :vpc_peering_connection_id, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |
#network_interface_id ⇒ String
The ID of a network interface.
13924 13925 13926 13927 13928 13929 13930 13931 13932 13933 13934 13935 13936 13937 13938 13939 13940 13941 13942 13943 13944 |
# File 'lib/aws-sdk-ec2/types.rb', line 13924 class CreateRouteRequest < Struct.new( :destination_prefix_list_id, :vpc_endpoint_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :core_network_arn, :odb_network_arn, :dry_run, :route_table_id, :destination_cidr_block, :gateway_id, :destination_ipv_6_cidr_block, :egress_only_internet_gateway_id, :instance_id, :network_interface_id, :vpc_peering_connection_id, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |
#odb_network_arn ⇒ String
The Amazon Resource Name (ARN) of the ODB network.
13924 13925 13926 13927 13928 13929 13930 13931 13932 13933 13934 13935 13936 13937 13938 13939 13940 13941 13942 13943 13944 |
# File 'lib/aws-sdk-ec2/types.rb', line 13924 class CreateRouteRequest < Struct.new( :destination_prefix_list_id, :vpc_endpoint_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :core_network_arn, :odb_network_arn, :dry_run, :route_table_id, :destination_cidr_block, :gateway_id, :destination_ipv_6_cidr_block, :egress_only_internet_gateway_id, :instance_id, :network_interface_id, :vpc_peering_connection_id, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |
#route_table_id ⇒ String
The ID of the route table for the route.
13924 13925 13926 13927 13928 13929 13930 13931 13932 13933 13934 13935 13936 13937 13938 13939 13940 13941 13942 13943 13944 |
# File 'lib/aws-sdk-ec2/types.rb', line 13924 class CreateRouteRequest < Struct.new( :destination_prefix_list_id, :vpc_endpoint_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :core_network_arn, :odb_network_arn, :dry_run, :route_table_id, :destination_cidr_block, :gateway_id, :destination_ipv_6_cidr_block, :egress_only_internet_gateway_id, :instance_id, :network_interface_id, :vpc_peering_connection_id, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_id ⇒ String
The ID of a transit gateway.
13924 13925 13926 13927 13928 13929 13930 13931 13932 13933 13934 13935 13936 13937 13938 13939 13940 13941 13942 13943 13944 |
# File 'lib/aws-sdk-ec2/types.rb', line 13924 class CreateRouteRequest < Struct.new( :destination_prefix_list_id, :vpc_endpoint_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :core_network_arn, :odb_network_arn, :dry_run, :route_table_id, :destination_cidr_block, :gateway_id, :destination_ipv_6_cidr_block, :egress_only_internet_gateway_id, :instance_id, :network_interface_id, :vpc_peering_connection_id, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |
#vpc_endpoint_id ⇒ String
The ID of a VPC endpoint. Supported for Gateway Load Balancer endpoints only.
13924 13925 13926 13927 13928 13929 13930 13931 13932 13933 13934 13935 13936 13937 13938 13939 13940 13941 13942 13943 13944 |
# File 'lib/aws-sdk-ec2/types.rb', line 13924 class CreateRouteRequest < Struct.new( :destination_prefix_list_id, :vpc_endpoint_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :core_network_arn, :odb_network_arn, :dry_run, :route_table_id, :destination_cidr_block, :gateway_id, :destination_ipv_6_cidr_block, :egress_only_internet_gateway_id, :instance_id, :network_interface_id, :vpc_peering_connection_id, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |
#vpc_peering_connection_id ⇒ String
The ID of a VPC peering connection.
13924 13925 13926 13927 13928 13929 13930 13931 13932 13933 13934 13935 13936 13937 13938 13939 13940 13941 13942 13943 13944 |
# File 'lib/aws-sdk-ec2/types.rb', line 13924 class CreateRouteRequest < Struct.new( :destination_prefix_list_id, :vpc_endpoint_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :core_network_arn, :odb_network_arn, :dry_run, :route_table_id, :destination_cidr_block, :gateway_id, :destination_ipv_6_cidr_block, :egress_only_internet_gateway_id, :instance_id, :network_interface_id, :vpc_peering_connection_id, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |