Class: Aws::EC2::Types::CreateRouteRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#carrier_gateway_idString

The ID of the carrier gateway.

You can only use this option when the VPC contains a subnet which is associated with a Wavelength Zone.

Returns:

  • (String)


13485
13486
13487
13488
13489
13490
13491
13492
13493
13494
13495
13496
13497
13498
13499
13500
13501
13502
13503
13504
13505
# File 'lib/aws-sdk-ec2/types.rb', line 13485

class CreateRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :vpc_endpoint_id,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :core_network_arn,
  :odb_network_arn,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :gateway_id,
  :destination_ipv_6_cidr_block,
  :egress_only_internet_gateway_id,
  :instance_id,
  :network_interface_id,
  :vpc_peering_connection_id,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end

#core_network_arnString

The Amazon Resource Name (ARN) of the core network.

Returns:

  • (String)


13485
13486
13487
13488
13489
13490
13491
13492
13493
13494
13495
13496
13497
13498
13499
13500
13501
13502
13503
13504
13505
# File 'lib/aws-sdk-ec2/types.rb', line 13485

class CreateRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :vpc_endpoint_id,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :core_network_arn,
  :odb_network_arn,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :gateway_id,
  :destination_ipv_6_cidr_block,
  :egress_only_internet_gateway_id,
  :instance_id,
  :network_interface_id,
  :vpc_peering_connection_id,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end

#destination_cidr_blockString

The IPv4 CIDR address block used for the destination match. Routing decisions are based on the most specific match. We modify the specified CIDR block to its canonical form; for example, if you specify ‘100.68.0.18/18`, we modify it to `100.68.0.0/18`.

Returns:

  • (String)


13485
13486
13487
13488
13489
13490
13491
13492
13493
13494
13495
13496
13497
13498
13499
13500
13501
13502
13503
13504
13505
# File 'lib/aws-sdk-ec2/types.rb', line 13485

class CreateRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :vpc_endpoint_id,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :core_network_arn,
  :odb_network_arn,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :gateway_id,
  :destination_ipv_6_cidr_block,
  :egress_only_internet_gateway_id,
  :instance_id,
  :network_interface_id,
  :vpc_peering_connection_id,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end

#destination_ipv_6_cidr_blockString

The IPv6 CIDR block used for the destination match. Routing decisions are based on the most specific match.

Returns:

  • (String)


13485
13486
13487
13488
13489
13490
13491
13492
13493
13494
13495
13496
13497
13498
13499
13500
13501
13502
13503
13504
13505
# File 'lib/aws-sdk-ec2/types.rb', line 13485

class CreateRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :vpc_endpoint_id,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :core_network_arn,
  :odb_network_arn,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :gateway_id,
  :destination_ipv_6_cidr_block,
  :egress_only_internet_gateway_id,
  :instance_id,
  :network_interface_id,
  :vpc_peering_connection_id,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end

#destination_prefix_list_idString

The ID of a prefix list used for the destination match.

Returns:

  • (String)


13485
13486
13487
13488
13489
13490
13491
13492
13493
13494
13495
13496
13497
13498
13499
13500
13501
13502
13503
13504
13505
# File 'lib/aws-sdk-ec2/types.rb', line 13485

class CreateRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :vpc_endpoint_id,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :core_network_arn,
  :odb_network_arn,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :gateway_id,
  :destination_ipv_6_cidr_block,
  :egress_only_internet_gateway_id,
  :instance_id,
  :network_interface_id,
  :vpc_peering_connection_id,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


13485
13486
13487
13488
13489
13490
13491
13492
13493
13494
13495
13496
13497
13498
13499
13500
13501
13502
13503
13504
13505
# File 'lib/aws-sdk-ec2/types.rb', line 13485

class CreateRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :vpc_endpoint_id,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :core_network_arn,
  :odb_network_arn,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :gateway_id,
  :destination_ipv_6_cidr_block,
  :egress_only_internet_gateway_id,
  :instance_id,
  :network_interface_id,
  :vpc_peering_connection_id,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end

#egress_only_internet_gateway_idString

[IPv6 traffic only] The ID of an egress-only internet gateway.

Returns:

  • (String)


13485
13486
13487
13488
13489
13490
13491
13492
13493
13494
13495
13496
13497
13498
13499
13500
13501
13502
13503
13504
13505
# File 'lib/aws-sdk-ec2/types.rb', line 13485

class CreateRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :vpc_endpoint_id,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :core_network_arn,
  :odb_network_arn,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :gateway_id,
  :destination_ipv_6_cidr_block,
  :egress_only_internet_gateway_id,
  :instance_id,
  :network_interface_id,
  :vpc_peering_connection_id,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end

#gateway_idString

The ID of an internet gateway or virtual private gateway attached to your VPC.

Returns:

  • (String)


13485
13486
13487
13488
13489
13490
13491
13492
13493
13494
13495
13496
13497
13498
13499
13500
13501
13502
13503
13504
13505
# File 'lib/aws-sdk-ec2/types.rb', line 13485

class CreateRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :vpc_endpoint_id,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :core_network_arn,
  :odb_network_arn,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :gateway_id,
  :destination_ipv_6_cidr_block,
  :egress_only_internet_gateway_id,
  :instance_id,
  :network_interface_id,
  :vpc_peering_connection_id,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The ID of a NAT instance in your VPC. The operation fails if you specify an instance ID unless exactly one network interface is attached.

Returns:

  • (String)


13485
13486
13487
13488
13489
13490
13491
13492
13493
13494
13495
13496
13497
13498
13499
13500
13501
13502
13503
13504
13505
# File 'lib/aws-sdk-ec2/types.rb', line 13485

class CreateRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :vpc_endpoint_id,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :core_network_arn,
  :odb_network_arn,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :gateway_id,
  :destination_ipv_6_cidr_block,
  :egress_only_internet_gateway_id,
  :instance_id,
  :network_interface_id,
  :vpc_peering_connection_id,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end

#local_gateway_idString

The ID of the local gateway.

Returns:

  • (String)


13485
13486
13487
13488
13489
13490
13491
13492
13493
13494
13495
13496
13497
13498
13499
13500
13501
13502
13503
13504
13505
# File 'lib/aws-sdk-ec2/types.rb', line 13485

class CreateRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :vpc_endpoint_id,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :core_network_arn,
  :odb_network_arn,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :gateway_id,
  :destination_ipv_6_cidr_block,
  :egress_only_internet_gateway_id,
  :instance_id,
  :network_interface_id,
  :vpc_peering_connection_id,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end

#nat_gateway_idString

[IPv4 traffic only] The ID of a NAT gateway.

Returns:

  • (String)


13485
13486
13487
13488
13489
13490
13491
13492
13493
13494
13495
13496
13497
13498
13499
13500
13501
13502
13503
13504
13505
# File 'lib/aws-sdk-ec2/types.rb', line 13485

class CreateRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :vpc_endpoint_id,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :core_network_arn,
  :odb_network_arn,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :gateway_id,
  :destination_ipv_6_cidr_block,
  :egress_only_internet_gateway_id,
  :instance_id,
  :network_interface_id,
  :vpc_peering_connection_id,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end

#network_interface_idString

The ID of a network interface.

Returns:

  • (String)


13485
13486
13487
13488
13489
13490
13491
13492
13493
13494
13495
13496
13497
13498
13499
13500
13501
13502
13503
13504
13505
# File 'lib/aws-sdk-ec2/types.rb', line 13485

class CreateRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :vpc_endpoint_id,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :core_network_arn,
  :odb_network_arn,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :gateway_id,
  :destination_ipv_6_cidr_block,
  :egress_only_internet_gateway_id,
  :instance_id,
  :network_interface_id,
  :vpc_peering_connection_id,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end

#odb_network_arnString

The Amazon Resource Name (ARN) of the ODB network.

Returns:

  • (String)


13485
13486
13487
13488
13489
13490
13491
13492
13493
13494
13495
13496
13497
13498
13499
13500
13501
13502
13503
13504
13505
# File 'lib/aws-sdk-ec2/types.rb', line 13485

class CreateRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :vpc_endpoint_id,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :core_network_arn,
  :odb_network_arn,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :gateway_id,
  :destination_ipv_6_cidr_block,
  :egress_only_internet_gateway_id,
  :instance_id,
  :network_interface_id,
  :vpc_peering_connection_id,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end

#route_table_idString

The ID of the route table for the route.

Returns:

  • (String)


13485
13486
13487
13488
13489
13490
13491
13492
13493
13494
13495
13496
13497
13498
13499
13500
13501
13502
13503
13504
13505
# File 'lib/aws-sdk-ec2/types.rb', line 13485

class CreateRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :vpc_endpoint_id,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :core_network_arn,
  :odb_network_arn,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :gateway_id,
  :destination_ipv_6_cidr_block,
  :egress_only_internet_gateway_id,
  :instance_id,
  :network_interface_id,
  :vpc_peering_connection_id,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_idString

The ID of a transit gateway.

Returns:

  • (String)


13485
13486
13487
13488
13489
13490
13491
13492
13493
13494
13495
13496
13497
13498
13499
13500
13501
13502
13503
13504
13505
# File 'lib/aws-sdk-ec2/types.rb', line 13485

class CreateRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :vpc_endpoint_id,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :core_network_arn,
  :odb_network_arn,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :gateway_id,
  :destination_ipv_6_cidr_block,
  :egress_only_internet_gateway_id,
  :instance_id,
  :network_interface_id,
  :vpc_peering_connection_id,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_endpoint_idString

The ID of a VPC endpoint. Supported for Gateway Load Balancer endpoints only.

Returns:

  • (String)


13485
13486
13487
13488
13489
13490
13491
13492
13493
13494
13495
13496
13497
13498
13499
13500
13501
13502
13503
13504
13505
# File 'lib/aws-sdk-ec2/types.rb', line 13485

class CreateRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :vpc_endpoint_id,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :core_network_arn,
  :odb_network_arn,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :gateway_id,
  :destination_ipv_6_cidr_block,
  :egress_only_internet_gateway_id,
  :instance_id,
  :network_interface_id,
  :vpc_peering_connection_id,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_peering_connection_idString

The ID of a VPC peering connection.

Returns:

  • (String)


13485
13486
13487
13488
13489
13490
13491
13492
13493
13494
13495
13496
13497
13498
13499
13500
13501
13502
13503
13504
13505
# File 'lib/aws-sdk-ec2/types.rb', line 13485

class CreateRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :vpc_endpoint_id,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :core_network_arn,
  :odb_network_arn,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :gateway_id,
  :destination_ipv_6_cidr_block,
  :egress_only_internet_gateway_id,
  :instance_id,
  :network_interface_id,
  :vpc_peering_connection_id,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end