Class: Aws::EC2::Types::CreateRouteServerEndpointRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier to ensure idempotency of the request.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


13994
13995
13996
13997
13998
13999
14000
14001
14002
# File 'lib/aws-sdk-ec2/types.rb', line 13994

class CreateRouteServerEndpointRequest < Struct.new(
  :route_server_id,
  :subnet_id,
  :client_token,
  :dry_run,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


13994
13995
13996
13997
13998
13999
14000
14001
14002
# File 'lib/aws-sdk-ec2/types.rb', line 13994

class CreateRouteServerEndpointRequest < Struct.new(
  :route_server_id,
  :subnet_id,
  :client_token,
  :dry_run,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#route_server_idString

The ID of the route server for which to create an endpoint.

Returns:

  • (String)


13994
13995
13996
13997
13998
13999
14000
14001
14002
# File 'lib/aws-sdk-ec2/types.rb', line 13994

class CreateRouteServerEndpointRequest < Struct.new(
  :route_server_id,
  :subnet_id,
  :client_token,
  :dry_run,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idString

The ID of the subnet in which to create the route server endpoint.

Returns:

  • (String)


13994
13995
13996
13997
13998
13999
14000
14001
14002
# File 'lib/aws-sdk-ec2/types.rb', line 13994

class CreateRouteServerEndpointRequest < Struct.new(
  :route_server_id,
  :subnet_id,
  :client_token,
  :dry_run,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the route server endpoint during creation.

Returns:



13994
13995
13996
13997
13998
13999
14000
14001
14002
# File 'lib/aws-sdk-ec2/types.rb', line 13994

class CreateRouteServerEndpointRequest < Struct.new(
  :route_server_id,
  :subnet_id,
  :client_token,
  :dry_run,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end