Class: Aws::EC2::Types::CreateRouteServerEndpointRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateRouteServerEndpointRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier to ensure idempotency of the request.
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#route_server_id ⇒ String
The ID of the route server for which to create an endpoint.
-
#subnet_id ⇒ String
The ID of the subnet in which to create the route server endpoint.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the route server endpoint during creation.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier to ensure idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
13735 13736 13737 13738 13739 13740 13741 13742 13743 |
# File 'lib/aws-sdk-ec2/types.rb', line 13735 class CreateRouteServerEndpointRequest < Struct.new( :route_server_id, :subnet_id, :client_token, :dry_run, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
13735 13736 13737 13738 13739 13740 13741 13742 13743 |
# File 'lib/aws-sdk-ec2/types.rb', line 13735 class CreateRouteServerEndpointRequest < Struct.new( :route_server_id, :subnet_id, :client_token, :dry_run, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#route_server_id ⇒ String
The ID of the route server for which to create an endpoint.
13735 13736 13737 13738 13739 13740 13741 13742 13743 |
# File 'lib/aws-sdk-ec2/types.rb', line 13735 class CreateRouteServerEndpointRequest < Struct.new( :route_server_id, :subnet_id, :client_token, :dry_run, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#subnet_id ⇒ String
The ID of the subnet in which to create the route server endpoint.
13735 13736 13737 13738 13739 13740 13741 13742 13743 |
# File 'lib/aws-sdk-ec2/types.rb', line 13735 class CreateRouteServerEndpointRequest < Struct.new( :route_server_id, :subnet_id, :client_token, :dry_run, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the route server endpoint during creation.
13735 13736 13737 13738 13739 13740 13741 13742 13743 |
# File 'lib/aws-sdk-ec2/types.rb', line 13735 class CreateRouteServerEndpointRequest < Struct.new( :route_server_id, :subnet_id, :client_token, :dry_run, :tag_specifications) SENSITIVE = [] include Aws::Structure end |