Class: Aws::EC2::Types::CreateRouteServerPeerRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bgp_optionsTypes::RouteServerBgpOptionsRequest

The BGP options for the peer, including ASN (Autonomous System Number) and BFD (Bidrectional Forwarding Detection) settings.



14042
14043
14044
14045
14046
14047
14048
14049
14050
# File 'lib/aws-sdk-ec2/types.rb', line 14042

class CreateRouteServerPeerRequest < Struct.new(
  :route_server_endpoint_id,
  :peer_address,
  :bgp_options,
  :dry_run,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


14042
14043
14044
14045
14046
14047
14048
14049
14050
# File 'lib/aws-sdk-ec2/types.rb', line 14042

class CreateRouteServerPeerRequest < Struct.new(
  :route_server_endpoint_id,
  :peer_address,
  :bgp_options,
  :dry_run,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#peer_addressString

The IPv4 address of the peer device.

Returns:

  • (String)


14042
14043
14044
14045
14046
14047
14048
14049
14050
# File 'lib/aws-sdk-ec2/types.rb', line 14042

class CreateRouteServerPeerRequest < Struct.new(
  :route_server_endpoint_id,
  :peer_address,
  :bgp_options,
  :dry_run,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#route_server_endpoint_idString

The ID of the route server endpoint for which to create a peer.

Returns:

  • (String)


14042
14043
14044
14045
14046
14047
14048
14049
14050
# File 'lib/aws-sdk-ec2/types.rb', line 14042

class CreateRouteServerPeerRequest < Struct.new(
  :route_server_endpoint_id,
  :peer_address,
  :bgp_options,
  :dry_run,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the route server peer during creation.

Returns:



14042
14043
14044
14045
14046
14047
14048
14049
14050
# File 'lib/aws-sdk-ec2/types.rb', line 14042

class CreateRouteServerPeerRequest < Struct.new(
  :route_server_endpoint_id,
  :peer_address,
  :bgp_options,
  :dry_run,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end