Class: Aws::EC2::Types::CreateRouteServerPeerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateRouteServerPeerRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bgp_options ⇒ Types::RouteServerBgpOptionsRequest
The BGP options for the peer, including ASN (Autonomous System Number) and BFD (Bidrectional Forwarding Detection) settings.
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#peer_address ⇒ String
The IPv4 address of the peer device.
-
#route_server_endpoint_id ⇒ String
The ID of the route server endpoint for which to create a peer.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the route server peer during creation.
Instance Attribute Details
#bgp_options ⇒ Types::RouteServerBgpOptionsRequest
The BGP options for the peer, including ASN (Autonomous System Number) and BFD (Bidrectional Forwarding Detection) settings.
13783 13784 13785 13786 13787 13788 13789 13790 13791 |
# File 'lib/aws-sdk-ec2/types.rb', line 13783 class CreateRouteServerPeerRequest < Struct.new( :route_server_endpoint_id, :peer_address, :bgp_options, :dry_run, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
13783 13784 13785 13786 13787 13788 13789 13790 13791 |
# File 'lib/aws-sdk-ec2/types.rb', line 13783 class CreateRouteServerPeerRequest < Struct.new( :route_server_endpoint_id, :peer_address, :bgp_options, :dry_run, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#peer_address ⇒ String
The IPv4 address of the peer device.
13783 13784 13785 13786 13787 13788 13789 13790 13791 |
# File 'lib/aws-sdk-ec2/types.rb', line 13783 class CreateRouteServerPeerRequest < Struct.new( :route_server_endpoint_id, :peer_address, :bgp_options, :dry_run, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#route_server_endpoint_id ⇒ String
The ID of the route server endpoint for which to create a peer.
13783 13784 13785 13786 13787 13788 13789 13790 13791 |
# File 'lib/aws-sdk-ec2/types.rb', line 13783 class CreateRouteServerPeerRequest < Struct.new( :route_server_endpoint_id, :peer_address, :bgp_options, :dry_run, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the route server peer during creation.
13783 13784 13785 13786 13787 13788 13789 13790 13791 |
# File 'lib/aws-sdk-ec2/types.rb', line 13783 class CreateRouteServerPeerRequest < Struct.new( :route_server_endpoint_id, :peer_address, :bgp_options, :dry_run, :tag_specifications) SENSITIVE = [] include Aws::Structure end |