Class: Aws::EC2::Types::CreateRouteTableRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


15127
15128
15129
15130
15131
15132
15133
15134
# File 'lib/aws-sdk-ec2/types.rb', line 15127

class CreateRouteTableRequest < Struct.new(
  :tag_specifications,
  :client_token,
  :dry_run,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


15127
15128
15129
15130
15131
15132
15133
15134
# File 'lib/aws-sdk-ec2/types.rb', line 15127

class CreateRouteTableRequest < Struct.new(
  :tag_specifications,
  :client_token,
  :dry_run,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to assign to the route table.

Returns:



15127
15128
15129
15130
15131
15132
15133
15134
# File 'lib/aws-sdk-ec2/types.rb', line 15127

class CreateRouteTableRequest < Struct.new(
  :tag_specifications,
  :client_token,
  :dry_run,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC.

Returns:

  • (String)


15127
15128
15129
15130
15131
15132
15133
15134
# File 'lib/aws-sdk-ec2/types.rb', line 15127

class CreateRouteTableRequest < Struct.new(
  :tag_specifications,
  :client_token,
  :dry_run,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end