Class: Aws::EC2::Types::CreateRouteTableRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [Ensuring idempotency].

**A suitable default value is auto-generated.** You should normally not need to pass this option.

[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html

Returns:

  • (String)


14117
14118
14119
14120
14121
14122
14123
14124
# File 'lib/aws-sdk-ec2/types.rb', line 14117

class CreateRouteTableRequest < Struct.new(
  :tag_specifications,
  :client_token,
  :dry_run,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


14117
14118
14119
14120
14121
14122
14123
14124
# File 'lib/aws-sdk-ec2/types.rb', line 14117

class CreateRouteTableRequest < Struct.new(
  :tag_specifications,
  :client_token,
  :dry_run,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to assign to the route table.

Returns:



14117
14118
14119
14120
14121
14122
14123
14124
# File 'lib/aws-sdk-ec2/types.rb', line 14117

class CreateRouteTableRequest < Struct.new(
  :tag_specifications,
  :client_token,
  :dry_run,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC.

Returns:

  • (String)


14117
14118
14119
14120
14121
14122
14123
14124
# File 'lib/aws-sdk-ec2/types.rb', line 14117

class CreateRouteTableRequest < Struct.new(
  :tag_specifications,
  :client_token,
  :dry_run,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end