Class: Aws::EC2::Types::CreateSecondaryNetworkRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateSecondaryNetworkRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#ipv_4_cidr_block ⇒ String
The IPv4 CIDR block for the secondary network.
-
#network_type ⇒ String
The type of secondary network.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the secondary network.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [Ensure Idempotency].
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html
14186 14187 14188 14189 14190 14191 14192 14193 14194 |
# File 'lib/aws-sdk-ec2/types.rb', line 14186 class CreateSecondaryNetworkRequest < Struct.new( :client_token, :dry_run, :ipv_4_cidr_block, :network_type, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
14186 14187 14188 14189 14190 14191 14192 14193 14194 |
# File 'lib/aws-sdk-ec2/types.rb', line 14186 class CreateSecondaryNetworkRequest < Struct.new( :client_token, :dry_run, :ipv_4_cidr_block, :network_type, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#ipv_4_cidr_block ⇒ String
The IPv4 CIDR block for the secondary network. The CIDR block size must be between /12 and /28.
14186 14187 14188 14189 14190 14191 14192 14193 14194 |
# File 'lib/aws-sdk-ec2/types.rb', line 14186 class CreateSecondaryNetworkRequest < Struct.new( :client_token, :dry_run, :ipv_4_cidr_block, :network_type, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#network_type ⇒ String
The type of secondary network.
14186 14187 14188 14189 14190 14191 14192 14193 14194 |
# File 'lib/aws-sdk-ec2/types.rb', line 14186 class CreateSecondaryNetworkRequest < Struct.new( :client_token, :dry_run, :ipv_4_cidr_block, :network_type, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the secondary network.
14186 14187 14188 14189 14190 14191 14192 14193 14194 |
# File 'lib/aws-sdk-ec2/types.rb', line 14186 class CreateSecondaryNetworkRequest < Struct.new( :client_token, :dry_run, :ipv_4_cidr_block, :network_type, :tag_specifications) SENSITIVE = [] include Aws::Structure end |