Class: Aws::EC2::Types::CreateSecondaryNetworkRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [Ensure Idempotency].

**A suitable default value is auto-generated.** You should normally not need to pass this option.

[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html

Returns:

  • (String)


13790
13791
13792
13793
13794
13795
13796
13797
13798
# File 'lib/aws-sdk-ec2/types.rb', line 13790

class CreateSecondaryNetworkRequest < Struct.new(
  :client_token,
  :dry_run,
  :ipv_4_cidr_block,
  :network_type,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


13790
13791
13792
13793
13794
13795
13796
13797
13798
# File 'lib/aws-sdk-ec2/types.rb', line 13790

class CreateSecondaryNetworkRequest < Struct.new(
  :client_token,
  :dry_run,
  :ipv_4_cidr_block,
  :network_type,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#ipv_4_cidr_blockString

The IPv4 CIDR block for the secondary network. The CIDR block size must be between /12 and /28.

Returns:

  • (String)


13790
13791
13792
13793
13794
13795
13796
13797
13798
# File 'lib/aws-sdk-ec2/types.rb', line 13790

class CreateSecondaryNetworkRequest < Struct.new(
  :client_token,
  :dry_run,
  :ipv_4_cidr_block,
  :network_type,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#network_typeString

The type of secondary network.

Returns:

  • (String)


13790
13791
13792
13793
13794
13795
13796
13797
13798
# File 'lib/aws-sdk-ec2/types.rb', line 13790

class CreateSecondaryNetworkRequest < Struct.new(
  :client_token,
  :dry_run,
  :ipv_4_cidr_block,
  :network_type,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to assign to the secondary network.

Returns:



13790
13791
13792
13793
13794
13795
13796
13797
13798
# File 'lib/aws-sdk-ec2/types.rb', line 13790

class CreateSecondaryNetworkRequest < Struct.new(
  :client_token,
  :dry_run,
  :ipv_4_cidr_block,
  :network_type,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end