Class: Aws::EC2::Types::CreateSecondaryNetworkResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateSecondaryNetworkResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier to ensure the idempotency of the request.
-
#secondary_network ⇒ Types::SecondaryNetwork
Information about the secondary network.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier to ensure the idempotency of the request. Only returned if a client token was provided in the request.
13812 13813 13814 13815 13816 13817 |
# File 'lib/aws-sdk-ec2/types.rb', line 13812 class CreateSecondaryNetworkResult < Struct.new( :secondary_network, :client_token) SENSITIVE = [] include Aws::Structure end |
#secondary_network ⇒ Types::SecondaryNetwork
Information about the secondary network.
13812 13813 13814 13815 13816 13817 |
# File 'lib/aws-sdk-ec2/types.rb', line 13812 class CreateSecondaryNetworkResult < Struct.new( :secondary_network, :client_token) SENSITIVE = [] include Aws::Structure end |