Class: Aws::EC2::Types::CreateSecondarySubnetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateSecondarySubnetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone ⇒ String
The Availability Zone for the secondary subnet.
-
#availability_zone_id ⇒ String
The ID of the Availability Zone for the secondary subnet.
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#ipv_4_cidr_block ⇒ String
The IPv4 CIDR block for the secondary subnet.
-
#secondary_network_id ⇒ String
The ID of the secondary network in which to create the secondary subnet.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the secondary subnet.
Instance Attribute Details
#availability_zone ⇒ String
The Availability Zone for the secondary subnet. You cannot specify
both AvailabilityZone and AvailabilityZoneId in the same
request.
14463 14464 14465 14466 14467 14468 14469 14470 14471 14472 14473 |
# File 'lib/aws-sdk-ec2/types.rb', line 14463 class CreateSecondarySubnetRequest < Struct.new( :client_token, :availability_zone, :availability_zone_id, :dry_run, :ipv_4_cidr_block, :secondary_network_id, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
The ID of the Availability Zone for the secondary subnet. This
option is preferred over AvailabilityZone as it provides a
consistent identifier across Amazon Web Services accounts. You
cannot specify both AvailabilityZone and AvailabilityZoneId in
the same request.
14463 14464 14465 14466 14467 14468 14469 14470 14471 14472 14473 |
# File 'lib/aws-sdk-ec2/types.rb', line 14463 class CreateSecondarySubnetRequest < Struct.new( :client_token, :availability_zone, :availability_zone_id, :dry_run, :ipv_4_cidr_block, :secondary_network_id, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensure Idempotency.
A suitable default value is auto-generated. You should normally not need to pass this option.
14463 14464 14465 14466 14467 14468 14469 14470 14471 14472 14473 |
# File 'lib/aws-sdk-ec2/types.rb', line 14463 class CreateSecondarySubnetRequest < Struct.new( :client_token, :availability_zone, :availability_zone_id, :dry_run, :ipv_4_cidr_block, :secondary_network_id, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
14463 14464 14465 14466 14467 14468 14469 14470 14471 14472 14473 |
# File 'lib/aws-sdk-ec2/types.rb', line 14463 class CreateSecondarySubnetRequest < Struct.new( :client_token, :availability_zone, :availability_zone_id, :dry_run, :ipv_4_cidr_block, :secondary_network_id, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#ipv_4_cidr_block ⇒ String
The IPv4 CIDR block for the secondary subnet. The CIDR block size must be between /12 and /28.
14463 14464 14465 14466 14467 14468 14469 14470 14471 14472 14473 |
# File 'lib/aws-sdk-ec2/types.rb', line 14463 class CreateSecondarySubnetRequest < Struct.new( :client_token, :availability_zone, :availability_zone_id, :dry_run, :ipv_4_cidr_block, :secondary_network_id, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#secondary_network_id ⇒ String
The ID of the secondary network in which to create the secondary subnet.
14463 14464 14465 14466 14467 14468 14469 14470 14471 14472 14473 |
# File 'lib/aws-sdk-ec2/types.rb', line 14463 class CreateSecondarySubnetRequest < Struct.new( :client_token, :availability_zone, :availability_zone_id, :dry_run, :ipv_4_cidr_block, :secondary_network_id, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the secondary subnet.
14463 14464 14465 14466 14467 14468 14469 14470 14471 14472 14473 |
# File 'lib/aws-sdk-ec2/types.rb', line 14463 class CreateSecondarySubnetRequest < Struct.new( :client_token, :availability_zone, :availability_zone_id, :dry_run, :ipv_4_cidr_block, :secondary_network_id, :tag_specifications) SENSITIVE = [] include Aws::Structure end |