Class: Aws::EC2::Types::CreateSecondarySubnetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_zoneString

The Availability Zone for the secondary subnet. You cannot specify both ‘AvailabilityZone` and `AvailabilityZoneId` in the same request.

Returns:

  • (String)


14067
14068
14069
14070
14071
14072
14073
14074
14075
14076
14077
# File 'lib/aws-sdk-ec2/types.rb', line 14067

class CreateSecondarySubnetRequest < Struct.new(
  :client_token,
  :availability_zone,
  :availability_zone_id,
  :dry_run,
  :ipv_4_cidr_block,
  :secondary_network_id,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zone_idString

The ID of the Availability Zone for the secondary subnet. This option is preferred over ‘AvailabilityZone` as it provides a consistent identifier across Amazon Web Services accounts. You cannot specify both `AvailabilityZone` and `AvailabilityZoneId` in the same request.

Returns:

  • (String)


14067
14068
14069
14070
14071
14072
14073
14074
14075
14076
14077
# File 'lib/aws-sdk-ec2/types.rb', line 14067

class CreateSecondarySubnetRequest < Struct.new(
  :client_token,
  :availability_zone,
  :availability_zone_id,
  :dry_run,
  :ipv_4_cidr_block,
  :secondary_network_id,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [Ensure Idempotency].

**A suitable default value is auto-generated.** You should normally not need to pass this option.

[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html

Returns:

  • (String)


14067
14068
14069
14070
14071
14072
14073
14074
14075
14076
14077
# File 'lib/aws-sdk-ec2/types.rb', line 14067

class CreateSecondarySubnetRequest < Struct.new(
  :client_token,
  :availability_zone,
  :availability_zone_id,
  :dry_run,
  :ipv_4_cidr_block,
  :secondary_network_id,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


14067
14068
14069
14070
14071
14072
14073
14074
14075
14076
14077
# File 'lib/aws-sdk-ec2/types.rb', line 14067

class CreateSecondarySubnetRequest < Struct.new(
  :client_token,
  :availability_zone,
  :availability_zone_id,
  :dry_run,
  :ipv_4_cidr_block,
  :secondary_network_id,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#ipv_4_cidr_blockString

The IPv4 CIDR block for the secondary subnet. The CIDR block size must be between /12 and /28.

Returns:

  • (String)


14067
14068
14069
14070
14071
14072
14073
14074
14075
14076
14077
# File 'lib/aws-sdk-ec2/types.rb', line 14067

class CreateSecondarySubnetRequest < Struct.new(
  :client_token,
  :availability_zone,
  :availability_zone_id,
  :dry_run,
  :ipv_4_cidr_block,
  :secondary_network_id,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#secondary_network_idString

The ID of the secondary network in which to create the secondary subnet.

Returns:

  • (String)


14067
14068
14069
14070
14071
14072
14073
14074
14075
14076
14077
# File 'lib/aws-sdk-ec2/types.rb', line 14067

class CreateSecondarySubnetRequest < Struct.new(
  :client_token,
  :availability_zone,
  :availability_zone_id,
  :dry_run,
  :ipv_4_cidr_block,
  :secondary_network_id,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to assign to the secondary subnet.

Returns:



14067
14068
14069
14070
14071
14072
14073
14074
14075
14076
14077
# File 'lib/aws-sdk-ec2/types.rb', line 14067

class CreateSecondarySubnetRequest < Struct.new(
  :client_token,
  :availability_zone,
  :availability_zone_id,
  :dry_run,
  :ipv_4_cidr_block,
  :secondary_network_id,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end