Class: Aws::EC2::Types::CreateSecurityGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description for the security group.

Constraints: Up to 255 characters in length

Valid characters: a-z, A-Z, 0-9, spaces, and ._-:/()#,@+=&;{}!$*

Returns:

  • (String)


14123
14124
14125
14126
14127
14128
14129
14130
14131
# File 'lib/aws-sdk-ec2/types.rb', line 14123

class CreateSecurityGroupRequest < Struct.new(
  :description,
  :group_name,
  :vpc_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


14123
14124
14125
14126
14127
14128
14129
14130
14131
# File 'lib/aws-sdk-ec2/types.rb', line 14123

class CreateSecurityGroupRequest < Struct.new(
  :description,
  :group_name,
  :vpc_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#group_nameString

The name of the security group. Names are case-insensitive and must be unique within the VPC.

Constraints: Up to 255 characters in length. Can’t start with ‘sg-`.

Valid characters: a-z, A-Z, 0-9, spaces, and ._-:/()#,@+=&amp;;{}!$*

Returns:

  • (String)


14123
14124
14125
14126
14127
14128
14129
14130
14131
# File 'lib/aws-sdk-ec2/types.rb', line 14123

class CreateSecurityGroupRequest < Struct.new(
  :description,
  :group_name,
  :vpc_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to assign to the security group.

Returns:



14123
14124
14125
14126
14127
14128
14129
14130
14131
# File 'lib/aws-sdk-ec2/types.rb', line 14123

class CreateSecurityGroupRequest < Struct.new(
  :description,
  :group_name,
  :vpc_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC. Required for a nondefault VPC.

Returns:

  • (String)


14123
14124
14125
14126
14127
14128
14129
14130
14131
# File 'lib/aws-sdk-ec2/types.rb', line 14123

class CreateSecurityGroupRequest < Struct.new(
  :description,
  :group_name,
  :vpc_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end