Class: Aws::EC2::Types::CreateSecurityGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateSecurityGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description for the security group.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#group_name ⇒ String
The name of the security group.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the security group.
-
#vpc_id ⇒ String
The ID of the VPC.
Instance Attribute Details
#description ⇒ String
A description for the security group.
Constraints: Up to 255 characters in length
Valid characters: a-z, A-Z, 0-9, spaces, and ._-:/()#,@+=&;{}!$*
13937 13938 13939 13940 13941 13942 13943 13944 13945 |
# File 'lib/aws-sdk-ec2/types.rb', line 13937 class CreateSecurityGroupRequest < Struct.new( :description, :group_name, :vpc_id, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
13937 13938 13939 13940 13941 13942 13943 13944 13945 |
# File 'lib/aws-sdk-ec2/types.rb', line 13937 class CreateSecurityGroupRequest < Struct.new( :description, :group_name, :vpc_id, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#group_name ⇒ String
The name of the security group. Names are case-insensitive and must be unique within the VPC.
Constraints: Up to 255 characters in length. Can’t start with ‘sg-`.
Valid characters: a-z, A-Z, 0-9, spaces, and ._-:/()#,@+=&;{}!$*
13937 13938 13939 13940 13941 13942 13943 13944 13945 |
# File 'lib/aws-sdk-ec2/types.rb', line 13937 class CreateSecurityGroupRequest < Struct.new( :description, :group_name, :vpc_id, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the security group.
13937 13938 13939 13940 13941 13942 13943 13944 13945 |
# File 'lib/aws-sdk-ec2/types.rb', line 13937 class CreateSecurityGroupRequest < Struct.new( :description, :group_name, :vpc_id, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC. Required for a nondefault VPC.
13937 13938 13939 13940 13941 13942 13943 13944 13945 |
# File 'lib/aws-sdk-ec2/types.rb', line 13937 class CreateSecurityGroupRequest < Struct.new( :description, :group_name, :vpc_id, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |