Class: Aws::EC2::Types::CreateSnapshotRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateSnapshotRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description for the snapshot.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#location ⇒ String
Only supported for volumes in Local Zones. -
#outpost_arn ⇒ String
Only supported for volumes on Outposts. -
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the snapshot during creation.
-
#volume_id ⇒ String
The ID of the Amazon EBS volume.
Instance Attribute Details
#description ⇒ String
A description for the snapshot.
15426 15427 15428 15429 15430 15431 15432 15433 15434 15435 |
# File 'lib/aws-sdk-ec2/types.rb', line 15426 class CreateSnapshotRequest < Struct.new( :description, :outpost_arn, :volume_id, :tag_specifications, :location, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
15426 15427 15428 15429 15430 15431 15432 15433 15434 15435 |
# File 'lib/aws-sdk-ec2/types.rb', line 15426 class CreateSnapshotRequest < Struct.new( :description, :outpost_arn, :volume_id, :tag_specifications, :location, :dry_run) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
-
To create a local snapshot in the same Local Zone as the source volume, specify
local. -
To create a regional snapshot in the parent Region of the Local Zone, specify
regionalor omit this parameter.
Default value: regional
15426 15427 15428 15429 15430 15431 15432 15433 15434 15435 |
# File 'lib/aws-sdk-ec2/types.rb', line 15426 class CreateSnapshotRequest < Struct.new( :description, :outpost_arn, :volume_id, :tag_specifications, :location, :dry_run) SENSITIVE = [] include Aws::Structure end |
#outpost_arn ⇒ String
-
To create the snapshot on the same Outpost as the source volume, specify the ARN of that Outpost. The snapshot must be created on the same Outpost as the volume.
-
To create the snapshot in the parent Region of the Outpost, omit this parameter.
For more information, see Create local snapshots from volumes on an Outpost in the Amazon EBS User Guide.
15426 15427 15428 15429 15430 15431 15432 15433 15434 15435 |
# File 'lib/aws-sdk-ec2/types.rb', line 15426 class CreateSnapshotRequest < Struct.new( :description, :outpost_arn, :volume_id, :tag_specifications, :location, :dry_run) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the snapshot during creation.
15426 15427 15428 15429 15430 15431 15432 15433 15434 15435 |
# File 'lib/aws-sdk-ec2/types.rb', line 15426 class CreateSnapshotRequest < Struct.new( :description, :outpost_arn, :volume_id, :tag_specifications, :location, :dry_run) SENSITIVE = [] include Aws::Structure end |
#volume_id ⇒ String
The ID of the Amazon EBS volume.
15426 15427 15428 15429 15430 15431 15432 15433 15434 15435 |
# File 'lib/aws-sdk-ec2/types.rb', line 15426 class CreateSnapshotRequest < Struct.new( :description, :outpost_arn, :volume_id, :tag_specifications, :location, :dry_run) SENSITIVE = [] include Aws::Structure end |