Class: Aws::EC2::Types::CreateSnapshotsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateSnapshotsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#copy_tags_from_source ⇒ String
Copies the tags from the specified volume to corresponding snapshot.
-
#description ⇒ String
A description propagated to every snapshot specified by the instance.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#instance_specification ⇒ Types::InstanceSpecification
The instance to specify which volumes should be included in the snapshots.
-
#location ⇒ String
<note markdown=“1”> Only supported for instances in Local Zones.
-
#outpost_arn ⇒ String
<note markdown=“1”> Only supported for instances on Outposts.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
Tags to apply to every snapshot specified by the instance.
Instance Attribute Details
#copy_tags_from_source ⇒ String
Copies the tags from the specified volume to corresponding snapshot.
13878 13879 13880 13881 13882 13883 13884 13885 13886 13887 13888 |
# File 'lib/aws-sdk-ec2/types.rb', line 13878 class CreateSnapshotsRequest < Struct.new( :description, :instance_specification, :outpost_arn, :tag_specifications, :dry_run, :copy_tags_from_source, :location) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description propagated to every snapshot specified by the instance.
13878 13879 13880 13881 13882 13883 13884 13885 13886 13887 13888 |
# File 'lib/aws-sdk-ec2/types.rb', line 13878 class CreateSnapshotsRequest < Struct.new( :description, :instance_specification, :outpost_arn, :tag_specifications, :dry_run, :copy_tags_from_source, :location) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
13878 13879 13880 13881 13882 13883 13884 13885 13886 13887 13888 |
# File 'lib/aws-sdk-ec2/types.rb', line 13878 class CreateSnapshotsRequest < Struct.new( :description, :instance_specification, :outpost_arn, :tag_specifications, :dry_run, :copy_tags_from_source, :location) SENSITIVE = [] include Aws::Structure end |
#instance_specification ⇒ Types::InstanceSpecification
The instance to specify which volumes should be included in the snapshots.
13878 13879 13880 13881 13882 13883 13884 13885 13886 13887 13888 |
# File 'lib/aws-sdk-ec2/types.rb', line 13878 class CreateSnapshotsRequest < Struct.new( :description, :instance_specification, :outpost_arn, :tag_specifications, :dry_run, :copy_tags_from_source, :location) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
<note markdown=“1”> Only supported for instances in Local Zones. If the source instance is not in a Local Zone, omit this parameter.
</note>
-
To create local snapshots in the same Local Zone as the source instance, specify ‘local`.
-
To create regional snapshots in the parent Region of the Local Zone, specify ‘regional` or omit this parameter.
Default value: ‘regional`
13878 13879 13880 13881 13882 13883 13884 13885 13886 13887 13888 |
# File 'lib/aws-sdk-ec2/types.rb', line 13878 class CreateSnapshotsRequest < Struct.new( :description, :instance_specification, :outpost_arn, :tag_specifications, :dry_run, :copy_tags_from_source, :location) SENSITIVE = [] include Aws::Structure end |
#outpost_arn ⇒ String
<note markdown=“1”> Only supported for instances on Outposts. If the source instance is not on an Outpost, omit this parameter.
</note>
-
To create the snapshots on the same Outpost as the source instance, specify the ARN of that Outpost. The snapshots must be created on the same Outpost as the instance.
-
To create the snapshots in the parent Region of the Outpost, omit this parameter.
For more information, see [ Create local snapshots from volumes on an Outpost] in the *Amazon EBS User Guide*.
[1]: docs.aws.amazon.com/ebs/latest/userguide/snapshots-outposts.html#create-snapshot
13878 13879 13880 13881 13882 13883 13884 13885 13886 13887 13888 |
# File 'lib/aws-sdk-ec2/types.rb', line 13878 class CreateSnapshotsRequest < Struct.new( :description, :instance_specification, :outpost_arn, :tag_specifications, :dry_run, :copy_tags_from_source, :location) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
Tags to apply to every snapshot specified by the instance.
13878 13879 13880 13881 13882 13883 13884 13885 13886 13887 13888 |
# File 'lib/aws-sdk-ec2/types.rb', line 13878 class CreateSnapshotsRequest < Struct.new( :description, :instance_specification, :outpost_arn, :tag_specifications, :dry_run, :copy_tags_from_source, :location) SENSITIVE = [] include Aws::Structure end |