Class: Aws::EC2::Types::CreateSpotDatafeedSubscriptionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateSpotDatafeedSubscriptionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for CreateSpotDatafeedSubscription.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The name of the Amazon S3 bucket in which to store the Spot Instance data feed.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#prefix ⇒ String
The prefix for the data feed file names.
Instance Attribute Details
#bucket ⇒ String
The name of the Amazon S3 bucket in which to store the Spot Instance data feed. For more information about bucket names, see Bucket naming rules in the Amazon S3 User Guide.
15549 15550 15551 15552 15553 15554 15555 |
# File 'lib/aws-sdk-ec2/types.rb', line 15549 class CreateSpotDatafeedSubscriptionRequest < Struct.new( :dry_run, :bucket, :prefix) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
15549 15550 15551 15552 15553 15554 15555 |
# File 'lib/aws-sdk-ec2/types.rb', line 15549 class CreateSpotDatafeedSubscriptionRequest < Struct.new( :dry_run, :bucket, :prefix) SENSITIVE = [] include Aws::Structure end |
#prefix ⇒ String
The prefix for the data feed file names.
15549 15550 15551 15552 15553 15554 15555 |
# File 'lib/aws-sdk-ec2/types.rb', line 15549 class CreateSpotDatafeedSubscriptionRequest < Struct.new( :dry_run, :bucket, :prefix) SENSITIVE = [] include Aws::Structure end |