Class: Aws::EC2::Types::CreateSpotDatafeedSubscriptionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for CreateSpotDatafeedSubscription.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The name of the Amazon S3 bucket in which to store the Spot Instance data feed. For more information about bucket names, see Bucket naming rules in the Amazon S3 User Guide.

Returns:

  • (String)


15330
15331
15332
15333
15334
15335
15336
# File 'lib/aws-sdk-ec2/types.rb', line 15330

class CreateSpotDatafeedSubscriptionRequest < Struct.new(
  :dry_run,
  :bucket,
  :prefix)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


15330
15331
15332
15333
15334
15335
15336
# File 'lib/aws-sdk-ec2/types.rb', line 15330

class CreateSpotDatafeedSubscriptionRequest < Struct.new(
  :dry_run,
  :bucket,
  :prefix)
  SENSITIVE = []
  include Aws::Structure
end

#prefixString

The prefix for the data feed file names.

Returns:

  • (String)


15330
15331
15332
15333
15334
15335
15336
# File 'lib/aws-sdk-ec2/types.rb', line 15330

class CreateSpotDatafeedSubscriptionRequest < Struct.new(
  :dry_run,
  :bucket,
  :prefix)
  SENSITIVE = []
  include Aws::Structure
end