Class: Aws::EC2::Types::CreateSpotDatafeedSubscriptionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for CreateSpotDatafeedSubscription.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The name of the Amazon S3 bucket in which to store the Spot Instance data feed. For more information about bucket names, see [Bucket naming rules] in the *Amazon S3 User Guide*.

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/bucketnamingrules.html

Returns:

  • (String)


14588
14589
14590
14591
14592
14593
14594
# File 'lib/aws-sdk-ec2/types.rb', line 14588

class CreateSpotDatafeedSubscriptionRequest < Struct.new(
  :dry_run,
  :bucket,
  :prefix)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


14588
14589
14590
14591
14592
14593
14594
# File 'lib/aws-sdk-ec2/types.rb', line 14588

class CreateSpotDatafeedSubscriptionRequest < Struct.new(
  :dry_run,
  :bucket,
  :prefix)
  SENSITIVE = []
  include Aws::Structure
end

#prefixString

The prefix for the data feed file names.

Returns:

  • (String)


14588
14589
14590
14591
14592
14593
14594
# File 'lib/aws-sdk-ec2/types.rb', line 14588

class CreateSpotDatafeedSubscriptionRequest < Struct.new(
  :dry_run,
  :bucket,
  :prefix)
  SENSITIVE = []
  include Aws::Structure
end