Class: Aws::EC2::Types::CreateStoreImageTaskRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateStoreImageTaskRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The name of the Amazon S3 bucket in which the AMI object will be stored.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#image_id ⇒ String
The ID of the AMI.
-
#s3_object_tags ⇒ Array<Types::S3ObjectTag>
The tags to apply to the AMI object that will be stored in the Amazon S3 bucket.
Instance Attribute Details
#bucket ⇒ String
The name of the Amazon S3 bucket in which the AMI object will be stored. The bucket must be in the Region in which the request is being made. The AMI object appears in the bucket only after the upload task has completed.
14382 14383 14384 14385 14386 14387 14388 14389 |
# File 'lib/aws-sdk-ec2/types.rb', line 14382 class CreateStoreImageTaskRequest < Struct.new( :image_id, :bucket, :s3_object_tags, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
14382 14383 14384 14385 14386 14387 14388 14389 |
# File 'lib/aws-sdk-ec2/types.rb', line 14382 class CreateStoreImageTaskRequest < Struct.new( :image_id, :bucket, :s3_object_tags, :dry_run) SENSITIVE = [] include Aws::Structure end |
#image_id ⇒ String
The ID of the AMI.
14382 14383 14384 14385 14386 14387 14388 14389 |
# File 'lib/aws-sdk-ec2/types.rb', line 14382 class CreateStoreImageTaskRequest < Struct.new( :image_id, :bucket, :s3_object_tags, :dry_run) SENSITIVE = [] include Aws::Structure end |
#s3_object_tags ⇒ Array<Types::S3ObjectTag>
The tags to apply to the AMI object that will be stored in the Amazon S3 bucket.
14382 14383 14384 14385 14386 14387 14388 14389 |
# File 'lib/aws-sdk-ec2/types.rb', line 14382 class CreateStoreImageTaskRequest < Struct.new( :image_id, :bucket, :s3_object_tags, :dry_run) SENSITIVE = [] include Aws::Structure end |