Class: Aws::EC2::Types::CreateStoreImageTaskRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The name of the Amazon S3 bucket in which the AMI object will be stored. The bucket must be in the Region in which the request is being made. The AMI object appears in the bucket only after the upload task has completed.

Returns:

  • (String)


14196
14197
14198
14199
14200
14201
14202
14203
# File 'lib/aws-sdk-ec2/types.rb', line 14196

class CreateStoreImageTaskRequest < Struct.new(
  :image_id,
  :bucket,
  :s3_object_tags,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


14196
14197
14198
14199
14200
14201
14202
14203
# File 'lib/aws-sdk-ec2/types.rb', line 14196

class CreateStoreImageTaskRequest < Struct.new(
  :image_id,
  :bucket,
  :s3_object_tags,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#image_idString

The ID of the AMI.

Returns:

  • (String)


14196
14197
14198
14199
14200
14201
14202
14203
# File 'lib/aws-sdk-ec2/types.rb', line 14196

class CreateStoreImageTaskRequest < Struct.new(
  :image_id,
  :bucket,
  :s3_object_tags,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#s3_object_tagsArray<Types::S3ObjectTag>

The tags to apply to the AMI object that will be stored in the Amazon S3 bucket.

Returns:



14196
14197
14198
14199
14200
14201
14202
14203
# File 'lib/aws-sdk-ec2/types.rb', line 14196

class CreateStoreImageTaskRequest < Struct.new(
  :image_id,
  :bucket,
  :s3_object_tags,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end