Class: Aws::EC2::Types::CreateSubnetCidrReservationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateSubnetCidrReservationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cidr ⇒ String
The IPv4 or IPV6 CIDR range to reserve.
-
#description ⇒ String
The description to assign to the subnet CIDR reservation.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#reservation_type ⇒ String
The type of reservation.
-
#subnet_id ⇒ String
The ID of the subnet.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the subnet CIDR reservation.
Instance Attribute Details
#cidr ⇒ String
The IPv4 or IPV6 CIDR range to reserve.
14649 14650 14651 14652 14653 14654 14655 14656 14657 14658 |
# File 'lib/aws-sdk-ec2/types.rb', line 14649 class CreateSubnetCidrReservationRequest < Struct.new( :subnet_id, :cidr, :reservation_type, :description, :dry_run, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description to assign to the subnet CIDR reservation.
14649 14650 14651 14652 14653 14654 14655 14656 14657 14658 |
# File 'lib/aws-sdk-ec2/types.rb', line 14649 class CreateSubnetCidrReservationRequest < Struct.new( :subnet_id, :cidr, :reservation_type, :description, :dry_run, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
14649 14650 14651 14652 14653 14654 14655 14656 14657 14658 |
# File 'lib/aws-sdk-ec2/types.rb', line 14649 class CreateSubnetCidrReservationRequest < Struct.new( :subnet_id, :cidr, :reservation_type, :description, :dry_run, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#reservation_type ⇒ String
The type of reservation. The reservation type determines how the reserved IP addresses are assigned to resources.
-
‘prefix` - Amazon Web Services assigns the reserved IP addresses to network interfaces.
-
‘explicit` - You assign the reserved IP addresses to network interfaces.
14649 14650 14651 14652 14653 14654 14655 14656 14657 14658 |
# File 'lib/aws-sdk-ec2/types.rb', line 14649 class CreateSubnetCidrReservationRequest < Struct.new( :subnet_id, :cidr, :reservation_type, :description, :dry_run, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#subnet_id ⇒ String
The ID of the subnet.
14649 14650 14651 14652 14653 14654 14655 14656 14657 14658 |
# File 'lib/aws-sdk-ec2/types.rb', line 14649 class CreateSubnetCidrReservationRequest < Struct.new( :subnet_id, :cidr, :reservation_type, :description, :dry_run, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the subnet CIDR reservation.
14649 14650 14651 14652 14653 14654 14655 14656 14657 14658 |
# File 'lib/aws-sdk-ec2/types.rb', line 14649 class CreateSubnetCidrReservationRequest < Struct.new( :subnet_id, :cidr, :reservation_type, :description, :dry_run, :tag_specifications) SENSITIVE = [] include Aws::Structure end |