Class: Aws::EC2::Types::CreateTrafficMirrorTargetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


15198
15199
15200
15201
15202
15203
15204
15205
15206
15207
15208
# File 'lib/aws-sdk-ec2/types.rb', line 15198

class CreateTrafficMirrorTargetRequest < Struct.new(
  :network_interface_id,
  :network_load_balancer_arn,
  :description,
  :tag_specifications,
  :dry_run,
  :client_token,
  :gateway_load_balancer_endpoint_id)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the Traffic Mirror target.

Returns:

  • (String)


15198
15199
15200
15201
15202
15203
15204
15205
15206
15207
15208
# File 'lib/aws-sdk-ec2/types.rb', line 15198

class CreateTrafficMirrorTargetRequest < Struct.new(
  :network_interface_id,
  :network_load_balancer_arn,
  :description,
  :tag_specifications,
  :dry_run,
  :client_token,
  :gateway_load_balancer_endpoint_id)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


15198
15199
15200
15201
15202
15203
15204
15205
15206
15207
15208
# File 'lib/aws-sdk-ec2/types.rb', line 15198

class CreateTrafficMirrorTargetRequest < Struct.new(
  :network_interface_id,
  :network_load_balancer_arn,
  :description,
  :tag_specifications,
  :dry_run,
  :client_token,
  :gateway_load_balancer_endpoint_id)
  SENSITIVE = []
  include Aws::Structure
end

#gateway_load_balancer_endpoint_idString

The ID of the Gateway Load Balancer endpoint.

Returns:

  • (String)


15198
15199
15200
15201
15202
15203
15204
15205
15206
15207
15208
# File 'lib/aws-sdk-ec2/types.rb', line 15198

class CreateTrafficMirrorTargetRequest < Struct.new(
  :network_interface_id,
  :network_load_balancer_arn,
  :description,
  :tag_specifications,
  :dry_run,
  :client_token,
  :gateway_load_balancer_endpoint_id)
  SENSITIVE = []
  include Aws::Structure
end

#network_interface_idString

The network interface ID that is associated with the target.

Returns:

  • (String)


15198
15199
15200
15201
15202
15203
15204
15205
15206
15207
15208
# File 'lib/aws-sdk-ec2/types.rb', line 15198

class CreateTrafficMirrorTargetRequest < Struct.new(
  :network_interface_id,
  :network_load_balancer_arn,
  :description,
  :tag_specifications,
  :dry_run,
  :client_token,
  :gateway_load_balancer_endpoint_id)
  SENSITIVE = []
  include Aws::Structure
end

#network_load_balancer_arnString

The Amazon Resource Name (ARN) of the Network Load Balancer that is associated with the target.

Returns:

  • (String)


15198
15199
15200
15201
15202
15203
15204
15205
15206
15207
15208
# File 'lib/aws-sdk-ec2/types.rb', line 15198

class CreateTrafficMirrorTargetRequest < Struct.new(
  :network_interface_id,
  :network_load_balancer_arn,
  :description,
  :tag_specifications,
  :dry_run,
  :client_token,
  :gateway_load_balancer_endpoint_id)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to assign to the Traffic Mirror target.

Returns:



15198
15199
15200
15201
15202
15203
15204
15205
15206
15207
15208
# File 'lib/aws-sdk-ec2/types.rb', line 15198

class CreateTrafficMirrorTargetRequest < Struct.new(
  :network_interface_id,
  :network_load_balancer_arn,
  :description,
  :tag_specifications,
  :dry_run,
  :client_token,
  :gateway_load_balancer_endpoint_id)
  SENSITIVE = []
  include Aws::Structure
end