Class: Aws::EC2::Types::CreateTrafficMirrorTargetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateTrafficMirrorTargetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#description ⇒ String
The description of the Traffic Mirror target.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#gateway_load_balancer_endpoint_id ⇒ String
The ID of the Gateway Load Balancer endpoint.
-
#network_interface_id ⇒ String
The network interface ID that is associated with the target.
-
#network_load_balancer_arn ⇒ String
The Amazon Resource Name (ARN) of the Network Load Balancer that is associated with the target.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the Traffic Mirror target.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [How to ensure idempotency].
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html
14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 |
# File 'lib/aws-sdk-ec2/types.rb', line 14531 class CreateTrafficMirrorTargetRequest < Struct.new( :network_interface_id, :network_load_balancer_arn, :description, :tag_specifications, :dry_run, :client_token, :gateway_load_balancer_endpoint_id) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the Traffic Mirror target.
14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 |
# File 'lib/aws-sdk-ec2/types.rb', line 14531 class CreateTrafficMirrorTargetRequest < Struct.new( :network_interface_id, :network_load_balancer_arn, :description, :tag_specifications, :dry_run, :client_token, :gateway_load_balancer_endpoint_id) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 |
# File 'lib/aws-sdk-ec2/types.rb', line 14531 class CreateTrafficMirrorTargetRequest < Struct.new( :network_interface_id, :network_load_balancer_arn, :description, :tag_specifications, :dry_run, :client_token, :gateway_load_balancer_endpoint_id) SENSITIVE = [] include Aws::Structure end |
#gateway_load_balancer_endpoint_id ⇒ String
The ID of the Gateway Load Balancer endpoint.
14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 |
# File 'lib/aws-sdk-ec2/types.rb', line 14531 class CreateTrafficMirrorTargetRequest < Struct.new( :network_interface_id, :network_load_balancer_arn, :description, :tag_specifications, :dry_run, :client_token, :gateway_load_balancer_endpoint_id) SENSITIVE = [] include Aws::Structure end |
#network_interface_id ⇒ String
The network interface ID that is associated with the target.
14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 |
# File 'lib/aws-sdk-ec2/types.rb', line 14531 class CreateTrafficMirrorTargetRequest < Struct.new( :network_interface_id, :network_load_balancer_arn, :description, :tag_specifications, :dry_run, :client_token, :gateway_load_balancer_endpoint_id) SENSITIVE = [] include Aws::Structure end |
#network_load_balancer_arn ⇒ String
The Amazon Resource Name (ARN) of the Network Load Balancer that is associated with the target.
14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 |
# File 'lib/aws-sdk-ec2/types.rb', line 14531 class CreateTrafficMirrorTargetRequest < Struct.new( :network_interface_id, :network_load_balancer_arn, :description, :tag_specifications, :dry_run, :client_token, :gateway_load_balancer_endpoint_id) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the Traffic Mirror target.
14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 |
# File 'lib/aws-sdk-ec2/types.rb', line 14531 class CreateTrafficMirrorTargetRequest < Struct.new( :network_interface_id, :network_load_balancer_arn, :description, :tag_specifications, :dry_run, :client_token, :gateway_load_balancer_endpoint_id) SENSITIVE = [] include Aws::Structure end |