Class: Aws::EC2::Types::CreateTransitGatewayConnectPeerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateTransitGatewayConnectPeerRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bgp_options ⇒ Types::TransitGatewayConnectRequestBgpOptions
The BGP options for the Connect peer.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#inside_cidr_blocks ⇒ Array<String>
The range of inside IP addresses that are used for BGP peering.
-
#peer_address ⇒ String
The peer IP address (GRE outer IP address) on the appliance side of the Connect peer.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the Connect peer.
-
#transit_gateway_address ⇒ String
The peer IP address (GRE outer IP address) on the transit gateway side of the Connect peer, which must be specified from a transit gateway CIDR block.
-
#transit_gateway_attachment_id ⇒ String
The ID of the Connect attachment.
Instance Attribute Details
#bgp_options ⇒ Types::TransitGatewayConnectRequestBgpOptions
The BGP options for the Connect peer.
15027 15028 15029 15030 15031 15032 15033 15034 15035 15036 15037 |
# File 'lib/aws-sdk-ec2/types.rb', line 15027 class CreateTransitGatewayConnectPeerRequest < Struct.new( :transit_gateway_attachment_id, :transit_gateway_address, :peer_address, :bgp_options, :inside_cidr_blocks, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
15027 15028 15029 15030 15031 15032 15033 15034 15035 15036 15037 |
# File 'lib/aws-sdk-ec2/types.rb', line 15027 class CreateTransitGatewayConnectPeerRequest < Struct.new( :transit_gateway_attachment_id, :transit_gateway_address, :peer_address, :bgp_options, :inside_cidr_blocks, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#inside_cidr_blocks ⇒ Array<String>
The range of inside IP addresses that are used for BGP peering. You must specify a size /29 IPv4 CIDR block from the ‘169.254.0.0/16` range. The first address from the range must be configured on the appliance as the BGP IP address. You can also optionally specify a size /125 IPv6 CIDR block from the `fd00::/8` range.
15027 15028 15029 15030 15031 15032 15033 15034 15035 15036 15037 |
# File 'lib/aws-sdk-ec2/types.rb', line 15027 class CreateTransitGatewayConnectPeerRequest < Struct.new( :transit_gateway_attachment_id, :transit_gateway_address, :peer_address, :bgp_options, :inside_cidr_blocks, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#peer_address ⇒ String
The peer IP address (GRE outer IP address) on the appliance side of the Connect peer.
15027 15028 15029 15030 15031 15032 15033 15034 15035 15036 15037 |
# File 'lib/aws-sdk-ec2/types.rb', line 15027 class CreateTransitGatewayConnectPeerRequest < Struct.new( :transit_gateway_attachment_id, :transit_gateway_address, :peer_address, :bgp_options, :inside_cidr_blocks, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the Connect peer.
15027 15028 15029 15030 15031 15032 15033 15034 15035 15036 15037 |
# File 'lib/aws-sdk-ec2/types.rb', line 15027 class CreateTransitGatewayConnectPeerRequest < Struct.new( :transit_gateway_attachment_id, :transit_gateway_address, :peer_address, :bgp_options, :inside_cidr_blocks, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_address ⇒ String
The peer IP address (GRE outer IP address) on the transit gateway side of the Connect peer, which must be specified from a transit gateway CIDR block. If not specified, Amazon automatically assigns the first available IP address from the transit gateway CIDR block.
15027 15028 15029 15030 15031 15032 15033 15034 15035 15036 15037 |
# File 'lib/aws-sdk-ec2/types.rb', line 15027 class CreateTransitGatewayConnectPeerRequest < Struct.new( :transit_gateway_attachment_id, :transit_gateway_address, :peer_address, :bgp_options, :inside_cidr_blocks, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_attachment_id ⇒ String
The ID of the Connect attachment.
15027 15028 15029 15030 15031 15032 15033 15034 15035 15036 15037 |
# File 'lib/aws-sdk-ec2/types.rb', line 15027 class CreateTransitGatewayConnectPeerRequest < Struct.new( :transit_gateway_attachment_id, :transit_gateway_address, :peer_address, :bgp_options, :inside_cidr_blocks, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |