Class: Aws::EC2::Types::CreateTransitGatewayConnectRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


16284
16285
16286
16287
16288
16289
16290
16291
# File 'lib/aws-sdk-ec2/types.rb', line 16284

class CreateTransitGatewayConnectRequest < Struct.new(
  :transport_transit_gateway_attachment_id,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#optionsTypes::CreateTransitGatewayConnectRequestOptions

The Connect attachment options.



16284
16285
16286
16287
16288
16289
16290
16291
# File 'lib/aws-sdk-ec2/types.rb', line 16284

class CreateTransitGatewayConnectRequest < Struct.new(
  :transport_transit_gateway_attachment_id,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the Connect attachment.

Returns:



16284
16285
16286
16287
16288
16289
16290
16291
# File 'lib/aws-sdk-ec2/types.rb', line 16284

class CreateTransitGatewayConnectRequest < Struct.new(
  :transport_transit_gateway_attachment_id,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transport_transit_gateway_attachment_idString

The ID of the transit gateway attachment. You can specify a VPC attachment or Amazon Web Services Direct Connect attachment.

Returns:

  • (String)


16284
16285
16286
16287
16288
16289
16290
16291
# File 'lib/aws-sdk-ec2/types.rb', line 16284

class CreateTransitGatewayConnectRequest < Struct.new(
  :transport_transit_gateway_attachment_id,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end