Class: Aws::EC2::Types::CreateTransitGatewayConnectRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateTransitGatewayConnectRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#options ⇒ Types::CreateTransitGatewayConnectRequestOptions
The Connect attachment options.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the Connect attachment.
-
#transport_transit_gateway_attachment_id ⇒ String
The ID of the transit gateway attachment.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
16275 16276 16277 16278 16279 16280 16281 16282 |
# File 'lib/aws-sdk-ec2/types.rb', line 16275 class CreateTransitGatewayConnectRequest < Struct.new( :transport_transit_gateway_attachment_id, :options, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#options ⇒ Types::CreateTransitGatewayConnectRequestOptions
The Connect attachment options.
16275 16276 16277 16278 16279 16280 16281 16282 |
# File 'lib/aws-sdk-ec2/types.rb', line 16275 class CreateTransitGatewayConnectRequest < Struct.new( :transport_transit_gateway_attachment_id, :options, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the Connect attachment.
16275 16276 16277 16278 16279 16280 16281 16282 |
# File 'lib/aws-sdk-ec2/types.rb', line 16275 class CreateTransitGatewayConnectRequest < Struct.new( :transport_transit_gateway_attachment_id, :options, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transport_transit_gateway_attachment_id ⇒ String
The ID of the transit gateway attachment. You can specify a VPC attachment or Amazon Web Services Direct Connect attachment.
16275 16276 16277 16278 16279 16280 16281 16282 |
# File 'lib/aws-sdk-ec2/types.rb', line 16275 class CreateTransitGatewayConnectRequest < Struct.new( :transport_transit_gateway_attachment_id, :options, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |