Class: Aws::EC2::Types::CreateTransitGatewayConnectRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


15320
15321
15322
15323
15324
15325
15326
15327
# File 'lib/aws-sdk-ec2/types.rb', line 15320

class CreateTransitGatewayConnectRequest < Struct.new(
  :transport_transit_gateway_attachment_id,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#optionsTypes::CreateTransitGatewayConnectRequestOptions

The Connect attachment options.



15320
15321
15322
15323
15324
15325
15326
15327
# File 'lib/aws-sdk-ec2/types.rb', line 15320

class CreateTransitGatewayConnectRequest < Struct.new(
  :transport_transit_gateway_attachment_id,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the Connect attachment.

Returns:



15320
15321
15322
15323
15324
15325
15326
15327
# File 'lib/aws-sdk-ec2/types.rb', line 15320

class CreateTransitGatewayConnectRequest < Struct.new(
  :transport_transit_gateway_attachment_id,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transport_transit_gateway_attachment_idString

The ID of the transit gateway attachment. You can specify a VPC attachment or Amazon Web Services Direct Connect attachment.

Returns:

  • (String)


15320
15321
15322
15323
15324
15325
15326
15327
# File 'lib/aws-sdk-ec2/types.rb', line 15320

class CreateTransitGatewayConnectRequest < Struct.new(
  :transport_transit_gateway_attachment_id,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end