Class: Aws::EC2::Types::CreateTransitGatewayMeteringPolicyEntryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#destination_cidr_blockString

The destination CIDR block for traffic matching.

Returns:

  • (String)


15367
15368
15369
15370
15371
15372
15373
15374
15375
15376
15377
15378
15379
15380
15381
15382
15383
# File 'lib/aws-sdk-ec2/types.rb', line 15367

class CreateTransitGatewayMeteringPolicyEntryRequest < Struct.new(
  :transit_gateway_metering_policy_id,
  :policy_rule_number,
  :source_transit_gateway_attachment_id,
  :source_transit_gateway_attachment_type,
  :source_cidr_block,
  :source_port_range,
  :destination_transit_gateway_attachment_id,
  :destination_transit_gateway_attachment_type,
  :destination_cidr_block,
  :destination_port_range,
  :protocol,
  :metered_account,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#destination_port_rangeString

The destination port range for traffic matching.

Returns:

  • (String)


15367
15368
15369
15370
15371
15372
15373
15374
15375
15376
15377
15378
15379
15380
15381
15382
15383
# File 'lib/aws-sdk-ec2/types.rb', line 15367

class CreateTransitGatewayMeteringPolicyEntryRequest < Struct.new(
  :transit_gateway_metering_policy_id,
  :policy_rule_number,
  :source_transit_gateway_attachment_id,
  :source_transit_gateway_attachment_type,
  :source_cidr_block,
  :source_port_range,
  :destination_transit_gateway_attachment_id,
  :destination_transit_gateway_attachment_type,
  :destination_cidr_block,
  :destination_port_range,
  :protocol,
  :metered_account,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#destination_transit_gateway_attachment_idString

The ID of the destination transit gateway attachment for traffic matching.

Returns:

  • (String)


15367
15368
15369
15370
15371
15372
15373
15374
15375
15376
15377
15378
15379
15380
15381
15382
15383
# File 'lib/aws-sdk-ec2/types.rb', line 15367

class CreateTransitGatewayMeteringPolicyEntryRequest < Struct.new(
  :transit_gateway_metering_policy_id,
  :policy_rule_number,
  :source_transit_gateway_attachment_id,
  :source_transit_gateway_attachment_type,
  :source_cidr_block,
  :source_port_range,
  :destination_transit_gateway_attachment_id,
  :destination_transit_gateway_attachment_type,
  :destination_cidr_block,
  :destination_port_range,
  :protocol,
  :metered_account,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#destination_transit_gateway_attachment_typeString

The type of the destination transit gateway attachment for traffic matching. Note that the ‘tgw-peering` resource type has been deprecated. To configure metering policies for Connect, use the transport attachment type.

Returns:

  • (String)


15367
15368
15369
15370
15371
15372
15373
15374
15375
15376
15377
15378
15379
15380
15381
15382
15383
# File 'lib/aws-sdk-ec2/types.rb', line 15367

class CreateTransitGatewayMeteringPolicyEntryRequest < Struct.new(
  :transit_gateway_metering_policy_id,
  :policy_rule_number,
  :source_transit_gateway_attachment_id,
  :source_transit_gateway_attachment_type,
  :source_cidr_block,
  :source_port_range,
  :destination_transit_gateway_attachment_id,
  :destination_transit_gateway_attachment_type,
  :destination_cidr_block,
  :destination_port_range,
  :protocol,
  :metered_account,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


15367
15368
15369
15370
15371
15372
15373
15374
15375
15376
15377
15378
15379
15380
15381
15382
15383
# File 'lib/aws-sdk-ec2/types.rb', line 15367

class CreateTransitGatewayMeteringPolicyEntryRequest < Struct.new(
  :transit_gateway_metering_policy_id,
  :policy_rule_number,
  :source_transit_gateway_attachment_id,
  :source_transit_gateway_attachment_type,
  :source_cidr_block,
  :source_port_range,
  :destination_transit_gateway_attachment_id,
  :destination_transit_gateway_attachment_type,
  :destination_cidr_block,
  :destination_port_range,
  :protocol,
  :metered_account,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#metered_accountString

The Amazon Web Services account ID to which the metered traffic should be attributed.

Returns:

  • (String)


15367
15368
15369
15370
15371
15372
15373
15374
15375
15376
15377
15378
15379
15380
15381
15382
15383
# File 'lib/aws-sdk-ec2/types.rb', line 15367

class CreateTransitGatewayMeteringPolicyEntryRequest < Struct.new(
  :transit_gateway_metering_policy_id,
  :policy_rule_number,
  :source_transit_gateway_attachment_id,
  :source_transit_gateway_attachment_type,
  :source_cidr_block,
  :source_port_range,
  :destination_transit_gateway_attachment_id,
  :destination_transit_gateway_attachment_type,
  :destination_cidr_block,
  :destination_port_range,
  :protocol,
  :metered_account,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#policy_rule_numberInteger

The rule number for the metering policy entry. Rules are processed in order from lowest to highest number.

Returns:

  • (Integer)


15367
15368
15369
15370
15371
15372
15373
15374
15375
15376
15377
15378
15379
15380
15381
15382
15383
# File 'lib/aws-sdk-ec2/types.rb', line 15367

class CreateTransitGatewayMeteringPolicyEntryRequest < Struct.new(
  :transit_gateway_metering_policy_id,
  :policy_rule_number,
  :source_transit_gateway_attachment_id,
  :source_transit_gateway_attachment_type,
  :source_cidr_block,
  :source_port_range,
  :destination_transit_gateway_attachment_id,
  :destination_transit_gateway_attachment_type,
  :destination_cidr_block,
  :destination_port_range,
  :protocol,
  :metered_account,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#protocolString

The protocol for traffic matching (1, 6, 17, etc.).

Returns:

  • (String)


15367
15368
15369
15370
15371
15372
15373
15374
15375
15376
15377
15378
15379
15380
15381
15382
15383
# File 'lib/aws-sdk-ec2/types.rb', line 15367

class CreateTransitGatewayMeteringPolicyEntryRequest < Struct.new(
  :transit_gateway_metering_policy_id,
  :policy_rule_number,
  :source_transit_gateway_attachment_id,
  :source_transit_gateway_attachment_type,
  :source_cidr_block,
  :source_port_range,
  :destination_transit_gateway_attachment_id,
  :destination_transit_gateway_attachment_type,
  :destination_cidr_block,
  :destination_port_range,
  :protocol,
  :metered_account,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#source_cidr_blockString

The source CIDR block for traffic matching.

Returns:

  • (String)


15367
15368
15369
15370
15371
15372
15373
15374
15375
15376
15377
15378
15379
15380
15381
15382
15383
# File 'lib/aws-sdk-ec2/types.rb', line 15367

class CreateTransitGatewayMeteringPolicyEntryRequest < Struct.new(
  :transit_gateway_metering_policy_id,
  :policy_rule_number,
  :source_transit_gateway_attachment_id,
  :source_transit_gateway_attachment_type,
  :source_cidr_block,
  :source_port_range,
  :destination_transit_gateway_attachment_id,
  :destination_transit_gateway_attachment_type,
  :destination_cidr_block,
  :destination_port_range,
  :protocol,
  :metered_account,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#source_port_rangeString

The source port range for traffic matching.

Returns:

  • (String)


15367
15368
15369
15370
15371
15372
15373
15374
15375
15376
15377
15378
15379
15380
15381
15382
15383
# File 'lib/aws-sdk-ec2/types.rb', line 15367

class CreateTransitGatewayMeteringPolicyEntryRequest < Struct.new(
  :transit_gateway_metering_policy_id,
  :policy_rule_number,
  :source_transit_gateway_attachment_id,
  :source_transit_gateway_attachment_type,
  :source_cidr_block,
  :source_port_range,
  :destination_transit_gateway_attachment_id,
  :destination_transit_gateway_attachment_type,
  :destination_cidr_block,
  :destination_port_range,
  :protocol,
  :metered_account,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#source_transit_gateway_attachment_idString

The ID of the source transit gateway attachment for traffic matching.

Returns:

  • (String)


15367
15368
15369
15370
15371
15372
15373
15374
15375
15376
15377
15378
15379
15380
15381
15382
15383
# File 'lib/aws-sdk-ec2/types.rb', line 15367

class CreateTransitGatewayMeteringPolicyEntryRequest < Struct.new(
  :transit_gateway_metering_policy_id,
  :policy_rule_number,
  :source_transit_gateway_attachment_id,
  :source_transit_gateway_attachment_type,
  :source_cidr_block,
  :source_port_range,
  :destination_transit_gateway_attachment_id,
  :destination_transit_gateway_attachment_type,
  :destination_cidr_block,
  :destination_port_range,
  :protocol,
  :metered_account,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#source_transit_gateway_attachment_typeString

The type of the source transit gateway attachment for traffic matching. Note that the ‘tgw-peering` resource type has been deprecated. To configure metering policies for Connect, use the transport attachment type.

Returns:

  • (String)


15367
15368
15369
15370
15371
15372
15373
15374
15375
15376
15377
15378
15379
15380
15381
15382
15383
# File 'lib/aws-sdk-ec2/types.rb', line 15367

class CreateTransitGatewayMeteringPolicyEntryRequest < Struct.new(
  :transit_gateway_metering_policy_id,
  :policy_rule_number,
  :source_transit_gateway_attachment_id,
  :source_transit_gateway_attachment_type,
  :source_cidr_block,
  :source_port_range,
  :destination_transit_gateway_attachment_id,
  :destination_transit_gateway_attachment_type,
  :destination_cidr_block,
  :destination_port_range,
  :protocol,
  :metered_account,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_metering_policy_idString

The ID of the transit gateway metering policy to add the entry to.

Returns:

  • (String)


15367
15368
15369
15370
15371
15372
15373
15374
15375
15376
15377
15378
15379
15380
15381
15382
15383
# File 'lib/aws-sdk-ec2/types.rb', line 15367

class CreateTransitGatewayMeteringPolicyEntryRequest < Struct.new(
  :transit_gateway_metering_policy_id,
  :policy_rule_number,
  :source_transit_gateway_attachment_id,
  :source_transit_gateway_attachment_type,
  :source_cidr_block,
  :source_port_range,
  :destination_transit_gateway_attachment_id,
  :destination_transit_gateway_attachment_type,
  :destination_cidr_block,
  :destination_port_range,
  :protocol,
  :metered_account,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end