Class: Aws::EC2::Types::CreateTransitGatewayMeteringPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateTransitGatewayMeteringPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#middlebox_attachment_ids ⇒ Array<String>
The IDs of the middlebox attachments to include in the metering policy.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the metering policy.
-
#transit_gateway_id ⇒ String
The ID of the transit gateway for which to create the metering policy.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
16439 16440 16441 16442 16443 16444 16445 16446 |
# File 'lib/aws-sdk-ec2/types.rb', line 16439 class CreateTransitGatewayMeteringPolicyRequest < Struct.new( :transit_gateway_id, :middlebox_attachment_ids, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#middlebox_attachment_ids ⇒ Array<String>
The IDs of the middlebox attachments to include in the metering policy.
16439 16440 16441 16442 16443 16444 16445 16446 |
# File 'lib/aws-sdk-ec2/types.rb', line 16439 class CreateTransitGatewayMeteringPolicyRequest < Struct.new( :transit_gateway_id, :middlebox_attachment_ids, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the metering policy.
16439 16440 16441 16442 16443 16444 16445 16446 |
# File 'lib/aws-sdk-ec2/types.rb', line 16439 class CreateTransitGatewayMeteringPolicyRequest < Struct.new( :transit_gateway_id, :middlebox_attachment_ids, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_id ⇒ String
The ID of the transit gateway for which to create the metering policy.
16439 16440 16441 16442 16443 16444 16445 16446 |
# File 'lib/aws-sdk-ec2/types.rb', line 16439 class CreateTransitGatewayMeteringPolicyRequest < Struct.new( :transit_gateway_id, :middlebox_attachment_ids, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |