Class: Aws::EC2::Types::CreateTransitGatewayMeteringPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


15420
15421
15422
15423
15424
15425
15426
15427
# File 'lib/aws-sdk-ec2/types.rb', line 15420

class CreateTransitGatewayMeteringPolicyRequest < Struct.new(
  :transit_gateway_id,
  :middlebox_attachment_ids,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#middlebox_attachment_idsArray<String>

The IDs of the middlebox attachments to include in the metering policy.

Returns:

  • (Array<String>)


15420
15421
15422
15423
15424
15425
15426
15427
# File 'lib/aws-sdk-ec2/types.rb', line 15420

class CreateTransitGatewayMeteringPolicyRequest < Struct.new(
  :transit_gateway_id,
  :middlebox_attachment_ids,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to assign to the metering policy.

Returns:



15420
15421
15422
15423
15424
15425
15426
15427
# File 'lib/aws-sdk-ec2/types.rb', line 15420

class CreateTransitGatewayMeteringPolicyRequest < Struct.new(
  :transit_gateway_id,
  :middlebox_attachment_ids,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_idString

The ID of the transit gateway for which to create the metering policy.

Returns:

  • (String)


15420
15421
15422
15423
15424
15425
15426
15427
# File 'lib/aws-sdk-ec2/types.rb', line 15420

class CreateTransitGatewayMeteringPolicyRequest < Struct.new(
  :transit_gateway_id,
  :middlebox_attachment_ids,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end