Class: Aws::EC2::Types::CreateTransitGatewayMulticastDomainRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateTransitGatewayMulticastDomainRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#options ⇒ Types::CreateTransitGatewayMulticastDomainRequestOptions
The options for the transit gateway multicast domain.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags for the transit gateway multicast domain.
-
#transit_gateway_id ⇒ String
The ID of the transit gateway.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
15468 15469 15470 15471 15472 15473 15474 15475 |
# File 'lib/aws-sdk-ec2/types.rb', line 15468 class CreateTransitGatewayMulticastDomainRequest < Struct.new( :transit_gateway_id, :options, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#options ⇒ Types::CreateTransitGatewayMulticastDomainRequestOptions
The options for the transit gateway multicast domain.
15468 15469 15470 15471 15472 15473 15474 15475 |
# File 'lib/aws-sdk-ec2/types.rb', line 15468 class CreateTransitGatewayMulticastDomainRequest < Struct.new( :transit_gateway_id, :options, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags for the transit gateway multicast domain.
15468 15469 15470 15471 15472 15473 15474 15475 |
# File 'lib/aws-sdk-ec2/types.rb', line 15468 class CreateTransitGatewayMulticastDomainRequest < Struct.new( :transit_gateway_id, :options, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_id ⇒ String
The ID of the transit gateway.
15468 15469 15470 15471 15472 15473 15474 15475 |
# File 'lib/aws-sdk-ec2/types.rb', line 15468 class CreateTransitGatewayMulticastDomainRequest < Struct.new( :transit_gateway_id, :options, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |