Class: Aws::EC2::Types::CreateTransitGatewayPeeringAttachmentRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


15595
15596
15597
15598
15599
15600
15601
15602
15603
15604
15605
# File 'lib/aws-sdk-ec2/types.rb', line 15595

class CreateTransitGatewayPeeringAttachmentRequest < Struct.new(
  :transit_gateway_id,
  :peer_transit_gateway_id,
  :peer_account_id,
  :peer_region,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#optionsTypes::CreateTransitGatewayPeeringAttachmentRequestOptions

Requests a transit gateway peering attachment.



15595
15596
15597
15598
15599
15600
15601
15602
15603
15604
15605
# File 'lib/aws-sdk-ec2/types.rb', line 15595

class CreateTransitGatewayPeeringAttachmentRequest < Struct.new(
  :transit_gateway_id,
  :peer_transit_gateway_id,
  :peer_account_id,
  :peer_region,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#peer_account_idString

The ID of the Amazon Web Services account that owns the peer transit gateway.

Returns:

  • (String)


15595
15596
15597
15598
15599
15600
15601
15602
15603
15604
15605
# File 'lib/aws-sdk-ec2/types.rb', line 15595

class CreateTransitGatewayPeeringAttachmentRequest < Struct.new(
  :transit_gateway_id,
  :peer_transit_gateway_id,
  :peer_account_id,
  :peer_region,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#peer_regionString

The Region where the peer transit gateway is located.

Returns:

  • (String)


15595
15596
15597
15598
15599
15600
15601
15602
15603
15604
15605
# File 'lib/aws-sdk-ec2/types.rb', line 15595

class CreateTransitGatewayPeeringAttachmentRequest < Struct.new(
  :transit_gateway_id,
  :peer_transit_gateway_id,
  :peer_account_id,
  :peer_region,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#peer_transit_gateway_idString

The ID of the peer transit gateway with which to create the peering attachment.

Returns:

  • (String)


15595
15596
15597
15598
15599
15600
15601
15602
15603
15604
15605
# File 'lib/aws-sdk-ec2/types.rb', line 15595

class CreateTransitGatewayPeeringAttachmentRequest < Struct.new(
  :transit_gateway_id,
  :peer_transit_gateway_id,
  :peer_account_id,
  :peer_region,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the transit gateway peering attachment.

Returns:



15595
15596
15597
15598
15599
15600
15601
15602
15603
15604
15605
# File 'lib/aws-sdk-ec2/types.rb', line 15595

class CreateTransitGatewayPeeringAttachmentRequest < Struct.new(
  :transit_gateway_id,
  :peer_transit_gateway_id,
  :peer_account_id,
  :peer_region,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_idString

The ID of the transit gateway.

Returns:

  • (String)


15595
15596
15597
15598
15599
15600
15601
15602
15603
15604
15605
# File 'lib/aws-sdk-ec2/types.rb', line 15595

class CreateTransitGatewayPeeringAttachmentRequest < Struct.new(
  :transit_gateway_id,
  :peer_transit_gateway_id,
  :peer_account_id,
  :peer_region,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end