Class: Aws::EC2::Types::CreateTransitGatewayPeeringAttachmentRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


15546
15547
15548
15549
15550
15551
15552
15553
15554
15555
15556
# File 'lib/aws-sdk-ec2/types.rb', line 15546

class CreateTransitGatewayPeeringAttachmentRequest < Struct.new(
  :transit_gateway_id,
  :peer_transit_gateway_id,
  :peer_account_id,
  :peer_region,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#optionsTypes::CreateTransitGatewayPeeringAttachmentRequestOptions

Requests a transit gateway peering attachment.



15546
15547
15548
15549
15550
15551
15552
15553
15554
15555
15556
# File 'lib/aws-sdk-ec2/types.rb', line 15546

class CreateTransitGatewayPeeringAttachmentRequest < Struct.new(
  :transit_gateway_id,
  :peer_transit_gateway_id,
  :peer_account_id,
  :peer_region,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#peer_account_idString

The ID of the Amazon Web Services account that owns the peer transit gateway.

Returns:

  • (String)


15546
15547
15548
15549
15550
15551
15552
15553
15554
15555
15556
# File 'lib/aws-sdk-ec2/types.rb', line 15546

class CreateTransitGatewayPeeringAttachmentRequest < Struct.new(
  :transit_gateway_id,
  :peer_transit_gateway_id,
  :peer_account_id,
  :peer_region,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#peer_regionString

The Region where the peer transit gateway is located.

Returns:

  • (String)


15546
15547
15548
15549
15550
15551
15552
15553
15554
15555
15556
# File 'lib/aws-sdk-ec2/types.rb', line 15546

class CreateTransitGatewayPeeringAttachmentRequest < Struct.new(
  :transit_gateway_id,
  :peer_transit_gateway_id,
  :peer_account_id,
  :peer_region,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#peer_transit_gateway_idString

The ID of the peer transit gateway with which to create the peering attachment.

Returns:

  • (String)


15546
15547
15548
15549
15550
15551
15552
15553
15554
15555
15556
# File 'lib/aws-sdk-ec2/types.rb', line 15546

class CreateTransitGatewayPeeringAttachmentRequest < Struct.new(
  :transit_gateway_id,
  :peer_transit_gateway_id,
  :peer_account_id,
  :peer_region,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the transit gateway peering attachment.

Returns:



15546
15547
15548
15549
15550
15551
15552
15553
15554
15555
15556
# File 'lib/aws-sdk-ec2/types.rb', line 15546

class CreateTransitGatewayPeeringAttachmentRequest < Struct.new(
  :transit_gateway_id,
  :peer_transit_gateway_id,
  :peer_account_id,
  :peer_region,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_idString

The ID of the transit gateway.

Returns:

  • (String)


15546
15547
15548
15549
15550
15551
15552
15553
15554
15555
15556
# File 'lib/aws-sdk-ec2/types.rb', line 15546

class CreateTransitGatewayPeeringAttachmentRequest < Struct.new(
  :transit_gateway_id,
  :peer_transit_gateway_id,
  :peer_account_id,
  :peer_region,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end