Class: Aws::EC2::Types::CreateTransitGatewayPeeringAttachmentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateTransitGatewayPeeringAttachmentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#options ⇒ Types::CreateTransitGatewayPeeringAttachmentRequestOptions
Requests a transit gateway peering attachment.
-
#peer_account_id ⇒ String
The ID of the Amazon Web Services account that owns the peer transit gateway.
-
#peer_region ⇒ String
The Region where the peer transit gateway is located.
-
#peer_transit_gateway_id ⇒ String
The ID of the peer transit gateway with which to create the peering attachment.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the transit gateway peering attachment.
-
#transit_gateway_id ⇒ String
The ID of the transit gateway.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
14928 14929 14930 14931 14932 14933 14934 14935 14936 14937 14938 |
# File 'lib/aws-sdk-ec2/types.rb', line 14928 class CreateTransitGatewayPeeringAttachmentRequest < Struct.new( :transit_gateway_id, :peer_transit_gateway_id, :peer_account_id, :peer_region, :options, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#options ⇒ Types::CreateTransitGatewayPeeringAttachmentRequestOptions
Requests a transit gateway peering attachment.
14928 14929 14930 14931 14932 14933 14934 14935 14936 14937 14938 |
# File 'lib/aws-sdk-ec2/types.rb', line 14928 class CreateTransitGatewayPeeringAttachmentRequest < Struct.new( :transit_gateway_id, :peer_transit_gateway_id, :peer_account_id, :peer_region, :options, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#peer_account_id ⇒ String
The ID of the Amazon Web Services account that owns the peer transit gateway.
14928 14929 14930 14931 14932 14933 14934 14935 14936 14937 14938 |
# File 'lib/aws-sdk-ec2/types.rb', line 14928 class CreateTransitGatewayPeeringAttachmentRequest < Struct.new( :transit_gateway_id, :peer_transit_gateway_id, :peer_account_id, :peer_region, :options, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#peer_region ⇒ String
The Region where the peer transit gateway is located.
14928 14929 14930 14931 14932 14933 14934 14935 14936 14937 14938 |
# File 'lib/aws-sdk-ec2/types.rb', line 14928 class CreateTransitGatewayPeeringAttachmentRequest < Struct.new( :transit_gateway_id, :peer_transit_gateway_id, :peer_account_id, :peer_region, :options, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#peer_transit_gateway_id ⇒ String
The ID of the peer transit gateway with which to create the peering attachment.
14928 14929 14930 14931 14932 14933 14934 14935 14936 14937 14938 |
# File 'lib/aws-sdk-ec2/types.rb', line 14928 class CreateTransitGatewayPeeringAttachmentRequest < Struct.new( :transit_gateway_id, :peer_transit_gateway_id, :peer_account_id, :peer_region, :options, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the transit gateway peering attachment.
14928 14929 14930 14931 14932 14933 14934 14935 14936 14937 14938 |
# File 'lib/aws-sdk-ec2/types.rb', line 14928 class CreateTransitGatewayPeeringAttachmentRequest < Struct.new( :transit_gateway_id, :peer_transit_gateway_id, :peer_account_id, :peer_region, :options, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_id ⇒ String
The ID of the transit gateway.
14928 14929 14930 14931 14932 14933 14934 14935 14936 14937 14938 |
# File 'lib/aws-sdk-ec2/types.rb', line 14928 class CreateTransitGatewayPeeringAttachmentRequest < Struct.new( :transit_gateway_id, :peer_transit_gateway_id, :peer_account_id, :peer_region, :options, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |