Class: Aws::EC2::Types::CreateTransitGatewayPolicyTableEntryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateTransitGatewayPolicyTableEntryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#policy_rule ⇒ Types::TransitGatewayRequestPolicyRule
The matching criteria for the policy table entry.
-
#policy_rule_number ⇒ String
The rule number for the policy table entry.
-
#target_route_table_id ⇒ String
The ID of the transit gateway route table to use for traffic matching this rule.
-
#transit_gateway_policy_table_id ⇒ String
The ID of the transit gateway policy table.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
16622 16623 16624 16625 16626 16627 16628 16629 16630 |
# File 'lib/aws-sdk-ec2/types.rb', line 16622 class CreateTransitGatewayPolicyTableEntryRequest < Struct.new( :transit_gateway_policy_table_id, :policy_rule_number, :policy_rule, :target_route_table_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#policy_rule ⇒ Types::TransitGatewayRequestPolicyRule
The matching criteria for the policy table entry.
16622 16623 16624 16625 16626 16627 16628 16629 16630 |
# File 'lib/aws-sdk-ec2/types.rb', line 16622 class CreateTransitGatewayPolicyTableEntryRequest < Struct.new( :transit_gateway_policy_table_id, :policy_rule_number, :policy_rule, :target_route_table_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#policy_rule_number ⇒ String
The rule number for the policy table entry. Lower rule numbers are evaluated first and take precedence.
16622 16623 16624 16625 16626 16627 16628 16629 16630 |
# File 'lib/aws-sdk-ec2/types.rb', line 16622 class CreateTransitGatewayPolicyTableEntryRequest < Struct.new( :transit_gateway_policy_table_id, :policy_rule_number, :policy_rule, :target_route_table_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#target_route_table_id ⇒ String
The ID of the transit gateway route table to use for traffic matching this rule.
16622 16623 16624 16625 16626 16627 16628 16629 16630 |
# File 'lib/aws-sdk-ec2/types.rb', line 16622 class CreateTransitGatewayPolicyTableEntryRequest < Struct.new( :transit_gateway_policy_table_id, :policy_rule_number, :policy_rule, :target_route_table_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_policy_table_id ⇒ String
The ID of the transit gateway policy table.
16622 16623 16624 16625 16626 16627 16628 16629 16630 |
# File 'lib/aws-sdk-ec2/types.rb', line 16622 class CreateTransitGatewayPolicyTableEntryRequest < Struct.new( :transit_gateway_policy_table_id, :policy_rule_number, :policy_rule, :target_route_table_id, :dry_run) SENSITIVE = [] include Aws::Structure end |