Class: Aws::EC2::Types::CreateTransitGatewayPolicyTableEntryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


16403
16404
16405
16406
16407
16408
16409
16410
16411
# File 'lib/aws-sdk-ec2/types.rb', line 16403

class CreateTransitGatewayPolicyTableEntryRequest < Struct.new(
  :transit_gateway_policy_table_id,
  :policy_rule_number,
  :policy_rule,
  :target_route_table_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#policy_ruleTypes::TransitGatewayRequestPolicyRule

The matching criteria for the policy table entry.



16403
16404
16405
16406
16407
16408
16409
16410
16411
# File 'lib/aws-sdk-ec2/types.rb', line 16403

class CreateTransitGatewayPolicyTableEntryRequest < Struct.new(
  :transit_gateway_policy_table_id,
  :policy_rule_number,
  :policy_rule,
  :target_route_table_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#policy_rule_numberString

The rule number for the policy table entry. Lower rule numbers are evaluated first and take precedence.

Returns:

  • (String)


16403
16404
16405
16406
16407
16408
16409
16410
16411
# File 'lib/aws-sdk-ec2/types.rb', line 16403

class CreateTransitGatewayPolicyTableEntryRequest < Struct.new(
  :transit_gateway_policy_table_id,
  :policy_rule_number,
  :policy_rule,
  :target_route_table_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#target_route_table_idString

The ID of the transit gateway route table to use for traffic matching this rule.

Returns:

  • (String)


16403
16404
16405
16406
16407
16408
16409
16410
16411
# File 'lib/aws-sdk-ec2/types.rb', line 16403

class CreateTransitGatewayPolicyTableEntryRequest < Struct.new(
  :transit_gateway_policy_table_id,
  :policy_rule_number,
  :policy_rule,
  :target_route_table_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_policy_table_idString

The ID of the transit gateway policy table.

Returns:

  • (String)


16403
16404
16405
16406
16407
16408
16409
16410
16411
# File 'lib/aws-sdk-ec2/types.rb', line 16403

class CreateTransitGatewayPolicyTableEntryRequest < Struct.new(
  :transit_gateway_policy_table_id,
  :policy_rule_number,
  :policy_rule,
  :target_route_table_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end