Class: Aws::EC2::Types::CreateTransitGatewayPolicyTableRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateTransitGatewayPolicyTableRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags specification for the transit gateway policy table created during the request.
-
#transit_gateway_id ⇒ String
The ID of the transit gateway used for the policy table.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
15782 15783 15784 15785 15786 15787 15788 |
# File 'lib/aws-sdk-ec2/types.rb', line 15782 class CreateTransitGatewayPolicyTableRequest < Struct.new( :transit_gateway_id, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags specification for the transit gateway policy table created during the request.
15782 15783 15784 15785 15786 15787 15788 |
# File 'lib/aws-sdk-ec2/types.rb', line 15782 class CreateTransitGatewayPolicyTableRequest < Struct.new( :transit_gateway_id, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_id ⇒ String
The ID of the transit gateway used for the policy table.
15782 15783 15784 15785 15786 15787 15788 |
# File 'lib/aws-sdk-ec2/types.rb', line 15782 class CreateTransitGatewayPolicyTableRequest < Struct.new( :transit_gateway_id, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |