Class: Aws::EC2::Types::CreateTransitGatewayPolicyTableRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


15399
15400
15401
15402
15403
15404
15405
# File 'lib/aws-sdk-ec2/types.rb', line 15399

class CreateTransitGatewayPolicyTableRequest < Struct.new(
  :transit_gateway_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags specification for the transit gateway policy table created during the request.

Returns:



15399
15400
15401
15402
15403
15404
15405
# File 'lib/aws-sdk-ec2/types.rb', line 15399

class CreateTransitGatewayPolicyTableRequest < Struct.new(
  :transit_gateway_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_idString

The ID of the transit gateway used for the policy table.

Returns:

  • (String)


15399
15400
15401
15402
15403
15404
15405
# File 'lib/aws-sdk-ec2/types.rb', line 15399

class CreateTransitGatewayPolicyTableRequest < Struct.new(
  :transit_gateway_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end