Class: Aws::EC2::Types::CreateTransitGatewayRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateTransitGatewayRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the transit gateway.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#options ⇒ Types::TransitGatewayRequestOptions
The transit gateway options.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the transit gateway.
Instance Attribute Details
#description ⇒ String
A description of the transit gateway.
15746 15747 15748 15749 15750 15751 15752 15753 |
# File 'lib/aws-sdk-ec2/types.rb', line 15746 class CreateTransitGatewayRequest < Struct.new( :description, :options, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
15746 15747 15748 15749 15750 15751 15752 15753 |
# File 'lib/aws-sdk-ec2/types.rb', line 15746 class CreateTransitGatewayRequest < Struct.new( :description, :options, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#options ⇒ Types::TransitGatewayRequestOptions
The transit gateway options.
15746 15747 15748 15749 15750 15751 15752 15753 |
# File 'lib/aws-sdk-ec2/types.rb', line 15746 class CreateTransitGatewayRequest < Struct.new( :description, :options, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the transit gateway.
15746 15747 15748 15749 15750 15751 15752 15753 |
# File 'lib/aws-sdk-ec2/types.rb', line 15746 class CreateTransitGatewayRequest < Struct.new( :description, :options, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |