Class: Aws::EC2::Types::CreateTransitGatewayRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description of the transit gateway.

Returns:

  • (String)


15697
15698
15699
15700
15701
15702
15703
15704
# File 'lib/aws-sdk-ec2/types.rb', line 15697

class CreateTransitGatewayRequest < Struct.new(
  :description,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


15697
15698
15699
15700
15701
15702
15703
15704
# File 'lib/aws-sdk-ec2/types.rb', line 15697

class CreateTransitGatewayRequest < Struct.new(
  :description,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#optionsTypes::TransitGatewayRequestOptions

The transit gateway options.



15697
15698
15699
15700
15701
15702
15703
15704
# File 'lib/aws-sdk-ec2/types.rb', line 15697

class CreateTransitGatewayRequest < Struct.new(
  :description,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the transit gateway.

Returns:



15697
15698
15699
15700
15701
15702
15703
15704
# File 'lib/aws-sdk-ec2/types.rb', line 15697

class CreateTransitGatewayRequest < Struct.new(
  :description,
  :options,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end