Class: Aws::EC2::Types::CreateTransitGatewayRouteRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateTransitGatewayRouteRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#blackhole ⇒ Boolean
Indicates whether to drop traffic that matches this route.
-
#destination_cidr_block ⇒ String
The CIDR range used for destination matches.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#transit_gateway_attachment_id ⇒ String
The ID of the attachment.
-
#transit_gateway_route_table_id ⇒ String
The ID of the transit gateway route table.
Instance Attribute Details
#blackhole ⇒ Boolean
Indicates whether to drop traffic that matches this route.
15787 15788 15789 15790 15791 15792 15793 15794 15795 |
# File 'lib/aws-sdk-ec2/types.rb', line 15787 class CreateTransitGatewayRouteRequest < Struct.new( :destination_cidr_block, :transit_gateway_route_table_id, :transit_gateway_attachment_id, :blackhole, :dry_run) SENSITIVE = [] include Aws::Structure end |
#destination_cidr_block ⇒ String
The CIDR range used for destination matches. Routing decisions are based on the most specific match.
15787 15788 15789 15790 15791 15792 15793 15794 15795 |
# File 'lib/aws-sdk-ec2/types.rb', line 15787 class CreateTransitGatewayRouteRequest < Struct.new( :destination_cidr_block, :transit_gateway_route_table_id, :transit_gateway_attachment_id, :blackhole, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
15787 15788 15789 15790 15791 15792 15793 15794 15795 |
# File 'lib/aws-sdk-ec2/types.rb', line 15787 class CreateTransitGatewayRouteRequest < Struct.new( :destination_cidr_block, :transit_gateway_route_table_id, :transit_gateway_attachment_id, :blackhole, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_attachment_id ⇒ String
The ID of the attachment.
15787 15788 15789 15790 15791 15792 15793 15794 15795 |
# File 'lib/aws-sdk-ec2/types.rb', line 15787 class CreateTransitGatewayRouteRequest < Struct.new( :destination_cidr_block, :transit_gateway_route_table_id, :transit_gateway_attachment_id, :blackhole, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_route_table_id ⇒ String
The ID of the transit gateway route table.
15787 15788 15789 15790 15791 15792 15793 15794 15795 |
# File 'lib/aws-sdk-ec2/types.rb', line 15787 class CreateTransitGatewayRouteRequest < Struct.new( :destination_cidr_block, :transit_gateway_route_table_id, :transit_gateway_attachment_id, :blackhole, :dry_run) SENSITIVE = [] include Aws::Structure end |