Class: Aws::EC2::Types::CreateTransitGatewayRouteRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#blackholeBoolean

Indicates whether to drop traffic that matches this route.

Returns:

  • (Boolean)


15744
15745
15746
15747
15748
15749
15750
15751
15752
# File 'lib/aws-sdk-ec2/types.rb', line 15744

class CreateTransitGatewayRouteRequest < Struct.new(
  :destination_cidr_block,
  :transit_gateway_route_table_id,
  :transit_gateway_attachment_id,
  :blackhole,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#destination_cidr_blockString

The CIDR range used for destination matches. Routing decisions are based on the most specific match.

Returns:

  • (String)


15744
15745
15746
15747
15748
15749
15750
15751
15752
# File 'lib/aws-sdk-ec2/types.rb', line 15744

class CreateTransitGatewayRouteRequest < Struct.new(
  :destination_cidr_block,
  :transit_gateway_route_table_id,
  :transit_gateway_attachment_id,
  :blackhole,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


15744
15745
15746
15747
15748
15749
15750
15751
15752
# File 'lib/aws-sdk-ec2/types.rb', line 15744

class CreateTransitGatewayRouteRequest < Struct.new(
  :destination_cidr_block,
  :transit_gateway_route_table_id,
  :transit_gateway_attachment_id,
  :blackhole,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_attachment_idString

The ID of the attachment.

Returns:

  • (String)


15744
15745
15746
15747
15748
15749
15750
15751
15752
# File 'lib/aws-sdk-ec2/types.rb', line 15744

class CreateTransitGatewayRouteRequest < Struct.new(
  :destination_cidr_block,
  :transit_gateway_route_table_id,
  :transit_gateway_attachment_id,
  :blackhole,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_route_table_idString

The ID of the transit gateway route table.

Returns:

  • (String)


15744
15745
15746
15747
15748
15749
15750
15751
15752
# File 'lib/aws-sdk-ec2/types.rb', line 15744

class CreateTransitGatewayRouteRequest < Struct.new(
  :destination_cidr_block,
  :transit_gateway_route_table_id,
  :transit_gateway_attachment_id,
  :blackhole,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end