Class: Aws::EC2::Types::CreateTransitGatewayRouteTableAnnouncementRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


16841
16842
16843
16844
16845
16846
16847
16848
# File 'lib/aws-sdk-ec2/types.rb', line 16841

class CreateTransitGatewayRouteTableAnnouncementRequest < Struct.new(
  :transit_gateway_route_table_id,
  :peering_attachment_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#peering_attachment_idString

The ID of the peering attachment.

Returns:

  • (String)


16841
16842
16843
16844
16845
16846
16847
16848
# File 'lib/aws-sdk-ec2/types.rb', line 16841

class CreateTransitGatewayRouteTableAnnouncementRequest < Struct.new(
  :transit_gateway_route_table_id,
  :peering_attachment_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags specifications applied to the transit gateway route table announcement.

Returns:



16841
16842
16843
16844
16845
16846
16847
16848
# File 'lib/aws-sdk-ec2/types.rb', line 16841

class CreateTransitGatewayRouteTableAnnouncementRequest < Struct.new(
  :transit_gateway_route_table_id,
  :peering_attachment_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_route_table_idString

The ID of the transit gateway route table.

Returns:

  • (String)


16841
16842
16843
16844
16845
16846
16847
16848
# File 'lib/aws-sdk-ec2/types.rb', line 16841

class CreateTransitGatewayRouteTableAnnouncementRequest < Struct.new(
  :transit_gateway_route_table_id,
  :peering_attachment_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end