Class: Aws::EC2::Types::CreateTransitGatewayRouteTableAnnouncementRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


15986
15987
15988
15989
15990
15991
15992
15993
# File 'lib/aws-sdk-ec2/types.rb', line 15986

class CreateTransitGatewayRouteTableAnnouncementRequest < Struct.new(
  :transit_gateway_route_table_id,
  :peering_attachment_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#peering_attachment_idString

The ID of the peering attachment.

Returns:

  • (String)


15986
15987
15988
15989
15990
15991
15992
15993
# File 'lib/aws-sdk-ec2/types.rb', line 15986

class CreateTransitGatewayRouteTableAnnouncementRequest < Struct.new(
  :transit_gateway_route_table_id,
  :peering_attachment_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags specifications applied to the transit gateway route table announcement.

Returns:



15986
15987
15988
15989
15990
15991
15992
15993
# File 'lib/aws-sdk-ec2/types.rb', line 15986

class CreateTransitGatewayRouteTableAnnouncementRequest < Struct.new(
  :transit_gateway_route_table_id,
  :peering_attachment_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_route_table_idString

The ID of the transit gateway route table.

Returns:

  • (String)


15986
15987
15988
15989
15990
15991
15992
15993
# File 'lib/aws-sdk-ec2/types.rb', line 15986

class CreateTransitGatewayRouteTableAnnouncementRequest < Struct.new(
  :transit_gateway_route_table_id,
  :peering_attachment_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end