Class: Aws::EC2::Types::CreateTransitGatewayRouteTableAnnouncementRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


15831
15832
15833
15834
15835
15836
15837
15838
# File 'lib/aws-sdk-ec2/types.rb', line 15831

class CreateTransitGatewayRouteTableAnnouncementRequest < Struct.new(
  :transit_gateway_route_table_id,
  :peering_attachment_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#peering_attachment_idString

The ID of the peering attachment.

Returns:

  • (String)


15831
15832
15833
15834
15835
15836
15837
15838
# File 'lib/aws-sdk-ec2/types.rb', line 15831

class CreateTransitGatewayRouteTableAnnouncementRequest < Struct.new(
  :transit_gateway_route_table_id,
  :peering_attachment_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags specifications applied to the transit gateway route table announcement.

Returns:



15831
15832
15833
15834
15835
15836
15837
15838
# File 'lib/aws-sdk-ec2/types.rb', line 15831

class CreateTransitGatewayRouteTableAnnouncementRequest < Struct.new(
  :transit_gateway_route_table_id,
  :peering_attachment_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_route_table_idString

The ID of the transit gateway route table.

Returns:

  • (String)


15831
15832
15833
15834
15835
15836
15837
15838
# File 'lib/aws-sdk-ec2/types.rb', line 15831

class CreateTransitGatewayRouteTableAnnouncementRequest < Struct.new(
  :transit_gateway_route_table_id,
  :peering_attachment_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end