Class: Aws::EC2::Types::CreateTransitGatewayRouteTableAnnouncementRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateTransitGatewayRouteTableAnnouncementRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#peering_attachment_id ⇒ String
The ID of the peering attachment.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags specifications applied to the transit gateway route table announcement.
-
#transit_gateway_route_table_id ⇒ String
The ID of the transit gateway route table.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
15392 15393 15394 15395 15396 15397 15398 15399 |
# File 'lib/aws-sdk-ec2/types.rb', line 15392 class CreateTransitGatewayRouteTableAnnouncementRequest < Struct.new( :transit_gateway_route_table_id, :peering_attachment_id, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#peering_attachment_id ⇒ String
The ID of the peering attachment.
15392 15393 15394 15395 15396 15397 15398 15399 |
# File 'lib/aws-sdk-ec2/types.rb', line 15392 class CreateTransitGatewayRouteTableAnnouncementRequest < Struct.new( :transit_gateway_route_table_id, :peering_attachment_id, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags specifications applied to the transit gateway route table announcement.
15392 15393 15394 15395 15396 15397 15398 15399 |
# File 'lib/aws-sdk-ec2/types.rb', line 15392 class CreateTransitGatewayRouteTableAnnouncementRequest < Struct.new( :transit_gateway_route_table_id, :peering_attachment_id, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_route_table_id ⇒ String
The ID of the transit gateway route table.
15392 15393 15394 15395 15396 15397 15398 15399 |
# File 'lib/aws-sdk-ec2/types.rb', line 15392 class CreateTransitGatewayRouteTableAnnouncementRequest < Struct.new( :transit_gateway_route_table_id, :peering_attachment_id, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |