Class: Aws::EC2::Types::CreateTransitGatewayRouteTableRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


15999
16000
16001
16002
16003
16004
16005
# File 'lib/aws-sdk-ec2/types.rb', line 15999

class CreateTransitGatewayRouteTableRequest < Struct.new(
  :transit_gateway_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the transit gateway route table.

Returns:



15999
16000
16001
16002
16003
16004
16005
# File 'lib/aws-sdk-ec2/types.rb', line 15999

class CreateTransitGatewayRouteTableRequest < Struct.new(
  :transit_gateway_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_idString

The ID of the transit gateway.

Returns:

  • (String)


15999
16000
16001
16002
16003
16004
16005
# File 'lib/aws-sdk-ec2/types.rb', line 15999

class CreateTransitGatewayRouteTableRequest < Struct.new(
  :transit_gateway_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end