Class: Aws::EC2::Types::CreateTransitGatewayVpcAttachmentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateTransitGatewayVpcAttachmentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#options ⇒ Types::CreateTransitGatewayVpcAttachmentRequestOptions
The VPC attachment options.
-
#subnet_ids ⇒ Array<String>
The IDs of one or more subnets.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the VPC attachment.
-
#transit_gateway_id ⇒ String
The ID of the transit gateway.
-
#vpc_id ⇒ String
The ID of the VPC.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
15680 15681 15682 15683 15684 15685 15686 15687 15688 15689 |
# File 'lib/aws-sdk-ec2/types.rb', line 15680 class CreateTransitGatewayVpcAttachmentRequest < Struct.new( :transit_gateway_id, :vpc_id, :subnet_ids, :options, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#options ⇒ Types::CreateTransitGatewayVpcAttachmentRequestOptions
The VPC attachment options.
15680 15681 15682 15683 15684 15685 15686 15687 15688 15689 |
# File 'lib/aws-sdk-ec2/types.rb', line 15680 class CreateTransitGatewayVpcAttachmentRequest < Struct.new( :transit_gateway_id, :vpc_id, :subnet_ids, :options, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#subnet_ids ⇒ Array<String>
The IDs of one or more subnets. You can specify only one subnet per Availability Zone. You must specify at least one subnet, but we recommend that you specify two subnets for better availability. The transit gateway uses one IP address from each specified subnet.
15680 15681 15682 15683 15684 15685 15686 15687 15688 15689 |
# File 'lib/aws-sdk-ec2/types.rb', line 15680 class CreateTransitGatewayVpcAttachmentRequest < Struct.new( :transit_gateway_id, :vpc_id, :subnet_ids, :options, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the VPC attachment.
15680 15681 15682 15683 15684 15685 15686 15687 15688 15689 |
# File 'lib/aws-sdk-ec2/types.rb', line 15680 class CreateTransitGatewayVpcAttachmentRequest < Struct.new( :transit_gateway_id, :vpc_id, :subnet_ids, :options, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_id ⇒ String
The ID of the transit gateway.
15680 15681 15682 15683 15684 15685 15686 15687 15688 15689 |
# File 'lib/aws-sdk-ec2/types.rb', line 15680 class CreateTransitGatewayVpcAttachmentRequest < Struct.new( :transit_gateway_id, :vpc_id, :subnet_ids, :options, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC.
15680 15681 15682 15683 15684 15685 15686 15687 15688 15689 |
# File 'lib/aws-sdk-ec2/types.rb', line 15680 class CreateTransitGatewayVpcAttachmentRequest < Struct.new( :transit_gateway_id, :vpc_id, :subnet_ids, :options, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |