Class: Aws::EC2::Types::CreateTransitGatewayVpcAttachmentRequestOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateTransitGatewayVpcAttachmentRequestOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the options for a VPC attachment.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#appliance_mode_support ⇒ String
Enable or disable support for appliance mode.
-
#dns_support ⇒ String
Enable or disable DNS support.
-
#ipv_6_support ⇒ String
Specifies whether IPv6 support is enabled for the attachment.
-
#security_group_referencing_support ⇒ String
Enables you to reference a security group across VPCs attached to a transit gateway to simplify security group management.
Instance Attribute Details
#appliance_mode_support ⇒ String
Enable or disable support for appliance mode. If enabled, a traffic
flow between a source and destination uses the same Availability
Zone for the VPC attachment for the lifetime of that flow. The
default is disable.
16177 16178 16179 16180 16181 16182 16183 16184 |
# File 'lib/aws-sdk-ec2/types.rb', line 16177 class CreateTransitGatewayVpcAttachmentRequestOptions < Struct.new( :dns_support, :security_group_referencing_support, :ipv_6_support, :appliance_mode_support) SENSITIVE = [] include Aws::Structure end |
#dns_support ⇒ String
Enable or disable DNS support. The default is enable.
16177 16178 16179 16180 16181 16182 16183 16184 |
# File 'lib/aws-sdk-ec2/types.rb', line 16177 class CreateTransitGatewayVpcAttachmentRequestOptions < Struct.new( :dns_support, :security_group_referencing_support, :ipv_6_support, :appliance_mode_support) SENSITIVE = [] include Aws::Structure end |
#ipv_6_support ⇒ String
Specifies whether IPv6 support is enabled for the attachment. When
enabled, the transit gateway network interface receives an IPv6
address. When you enable route propagation, IPv6 VPC CIDRs propagate
to the transit gateway route tables. When disabled, the network
interface does not receive an IPv6 address, and IPv6 routes do not
propagate. The setting does not filter IPv6 traffic. The default is
disable.
16177 16178 16179 16180 16181 16182 16183 16184 |
# File 'lib/aws-sdk-ec2/types.rb', line 16177 class CreateTransitGatewayVpcAttachmentRequestOptions < Struct.new( :dns_support, :security_group_referencing_support, :ipv_6_support, :appliance_mode_support) SENSITIVE = [] include Aws::Structure end |
#security_group_referencing_support ⇒ String
Enables you to reference a security group across VPCs attached to a transit gateway to simplify security group management.
This option is set to enable by default. However, at the transit
gateway level the default is set to disable.
For more information about security group referencing, see Security group referencing in the Amazon Web Services Transit Gateways Guide.
16177 16178 16179 16180 16181 16182 16183 16184 |
# File 'lib/aws-sdk-ec2/types.rb', line 16177 class CreateTransitGatewayVpcAttachmentRequestOptions < Struct.new( :dns_support, :security_group_referencing_support, :ipv_6_support, :appliance_mode_support) SENSITIVE = [] include Aws::Structure end |