Class: Aws::EC2::Types::CreateVerifiedAccessEndpointRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_domainString

The DNS name for users to reach your application.

Returns:

  • (String)


16244
16245
16246
16247
16248
16249
16250
16251
16252
16253
16254
16255
16256
16257
16258
16259
16260
16261
16262
16263
16264
# File 'lib/aws-sdk-ec2/types.rb', line 16244

class CreateVerifiedAccessEndpointRequest < Struct.new(
  :verified_access_group_id,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :application_domain,
  :endpoint_domain_prefix,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :description,
  :policy_document,
  :tag_specifications,
  :client_token,
  :dry_run,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#attachment_typeString

The type of attachment.

Returns:

  • (String)


16244
16245
16246
16247
16248
16249
16250
16251
16252
16253
16254
16255
16256
16257
16258
16259
16260
16261
16262
16263
16264
# File 'lib/aws-sdk-ec2/types.rb', line 16244

class CreateVerifiedAccessEndpointRequest < Struct.new(
  :verified_access_group_id,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :application_domain,
  :endpoint_domain_prefix,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :description,
  :policy_document,
  :tag_specifications,
  :client_token,
  :dry_run,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#cidr_optionsTypes::CreateVerifiedAccessEndpointCidrOptions

The CIDR options. This parameter is required if the endpoint type is cidr.



16244
16245
16246
16247
16248
16249
16250
16251
16252
16253
16254
16255
16256
16257
16258
16259
16260
16261
16262
16263
16264
# File 'lib/aws-sdk-ec2/types.rb', line 16244

class CreateVerifiedAccessEndpointRequest < Struct.new(
  :verified_access_group_id,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :application_domain,
  :endpoint_domain_prefix,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :description,
  :policy_document,
  :tag_specifications,
  :client_token,
  :dry_run,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


16244
16245
16246
16247
16248
16249
16250
16251
16252
16253
16254
16255
16256
16257
16258
16259
16260
16261
16262
16263
16264
# File 'lib/aws-sdk-ec2/types.rb', line 16244

class CreateVerifiedAccessEndpointRequest < Struct.new(
  :verified_access_group_id,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :application_domain,
  :endpoint_domain_prefix,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :description,
  :policy_document,
  :tag_specifications,
  :client_token,
  :dry_run,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description for the Verified Access endpoint.

Returns:

  • (String)


16244
16245
16246
16247
16248
16249
16250
16251
16252
16253
16254
16255
16256
16257
16258
16259
16260
16261
16262
16263
16264
# File 'lib/aws-sdk-ec2/types.rb', line 16244

class CreateVerifiedAccessEndpointRequest < Struct.new(
  :verified_access_group_id,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :application_domain,
  :endpoint_domain_prefix,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :description,
  :policy_document,
  :tag_specifications,
  :client_token,
  :dry_run,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#domain_certificate_arnString

The ARN of the public TLS/SSL certificate in Amazon Web Services Certificate Manager to associate with the endpoint. The CN in the certificate must match the DNS name your end users will use to reach your application.

Returns:

  • (String)


16244
16245
16246
16247
16248
16249
16250
16251
16252
16253
16254
16255
16256
16257
16258
16259
16260
16261
16262
16263
16264
# File 'lib/aws-sdk-ec2/types.rb', line 16244

class CreateVerifiedAccessEndpointRequest < Struct.new(
  :verified_access_group_id,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :application_domain,
  :endpoint_domain_prefix,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :description,
  :policy_document,
  :tag_specifications,
  :client_token,
  :dry_run,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


16244
16245
16246
16247
16248
16249
16250
16251
16252
16253
16254
16255
16256
16257
16258
16259
16260
16261
16262
16263
16264
# File 'lib/aws-sdk-ec2/types.rb', line 16244

class CreateVerifiedAccessEndpointRequest < Struct.new(
  :verified_access_group_id,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :application_domain,
  :endpoint_domain_prefix,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :description,
  :policy_document,
  :tag_specifications,
  :client_token,
  :dry_run,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_domain_prefixString

A custom identifier that is prepended to the DNS name that is generated for the endpoint.

Returns:

  • (String)


16244
16245
16246
16247
16248
16249
16250
16251
16252
16253
16254
16255
16256
16257
16258
16259
16260
16261
16262
16263
16264
# File 'lib/aws-sdk-ec2/types.rb', line 16244

class CreateVerifiedAccessEndpointRequest < Struct.new(
  :verified_access_group_id,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :application_domain,
  :endpoint_domain_prefix,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :description,
  :policy_document,
  :tag_specifications,
  :client_token,
  :dry_run,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_typeString

The type of Verified Access endpoint to create.

Returns:

  • (String)


16244
16245
16246
16247
16248
16249
16250
16251
16252
16253
16254
16255
16256
16257
16258
16259
16260
16261
16262
16263
16264
# File 'lib/aws-sdk-ec2/types.rb', line 16244

class CreateVerifiedAccessEndpointRequest < Struct.new(
  :verified_access_group_id,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :application_domain,
  :endpoint_domain_prefix,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :description,
  :policy_document,
  :tag_specifications,
  :client_token,
  :dry_run,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#load_balancer_optionsTypes::CreateVerifiedAccessEndpointLoadBalancerOptions

The load balancer details. This parameter is required if the endpoint type is load-balancer.



16244
16245
16246
16247
16248
16249
16250
16251
16252
16253
16254
16255
16256
16257
16258
16259
16260
16261
16262
16263
16264
# File 'lib/aws-sdk-ec2/types.rb', line 16244

class CreateVerifiedAccessEndpointRequest < Struct.new(
  :verified_access_group_id,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :application_domain,
  :endpoint_domain_prefix,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :description,
  :policy_document,
  :tag_specifications,
  :client_token,
  :dry_run,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#network_interface_optionsTypes::CreateVerifiedAccessEndpointEniOptions

The network interface details. This parameter is required if the endpoint type is network-interface.



16244
16245
16246
16247
16248
16249
16250
16251
16252
16253
16254
16255
16256
16257
16258
16259
16260
16261
16262
16263
16264
# File 'lib/aws-sdk-ec2/types.rb', line 16244

class CreateVerifiedAccessEndpointRequest < Struct.new(
  :verified_access_group_id,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :application_domain,
  :endpoint_domain_prefix,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :description,
  :policy_document,
  :tag_specifications,
  :client_token,
  :dry_run,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#policy_documentString

The Verified Access policy document.

Returns:

  • (String)


16244
16245
16246
16247
16248
16249
16250
16251
16252
16253
16254
16255
16256
16257
16258
16259
16260
16261
16262
16263
16264
# File 'lib/aws-sdk-ec2/types.rb', line 16244

class CreateVerifiedAccessEndpointRequest < Struct.new(
  :verified_access_group_id,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :application_domain,
  :endpoint_domain_prefix,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :description,
  :policy_document,
  :tag_specifications,
  :client_token,
  :dry_run,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#rds_optionsTypes::CreateVerifiedAccessEndpointRdsOptions

The RDS details. This parameter is required if the endpoint type is rds.



16244
16245
16246
16247
16248
16249
16250
16251
16252
16253
16254
16255
16256
16257
16258
16259
16260
16261
16262
16263
16264
# File 'lib/aws-sdk-ec2/types.rb', line 16244

class CreateVerifiedAccessEndpointRequest < Struct.new(
  :verified_access_group_id,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :application_domain,
  :endpoint_domain_prefix,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :description,
  :policy_document,
  :tag_specifications,
  :client_token,
  :dry_run,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#security_group_idsArray<String>

The IDs of the security groups to associate with the Verified Access endpoint. Required if AttachmentType is set to vpc.

Returns:

  • (Array<String>)


16244
16245
16246
16247
16248
16249
16250
16251
16252
16253
16254
16255
16256
16257
16258
16259
16260
16261
16262
16263
16264
# File 'lib/aws-sdk-ec2/types.rb', line 16244

class CreateVerifiedAccessEndpointRequest < Struct.new(
  :verified_access_group_id,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :application_domain,
  :endpoint_domain_prefix,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :description,
  :policy_document,
  :tag_specifications,
  :client_token,
  :dry_run,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#sse_specificationTypes::VerifiedAccessSseSpecificationRequest

The options for server side encryption.



16244
16245
16246
16247
16248
16249
16250
16251
16252
16253
16254
16255
16256
16257
16258
16259
16260
16261
16262
16263
16264
# File 'lib/aws-sdk-ec2/types.rb', line 16244

class CreateVerifiedAccessEndpointRequest < Struct.new(
  :verified_access_group_id,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :application_domain,
  :endpoint_domain_prefix,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :description,
  :policy_document,
  :tag_specifications,
  :client_token,
  :dry_run,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to assign to the Verified Access endpoint.

Returns:



16244
16245
16246
16247
16248
16249
16250
16251
16252
16253
16254
16255
16256
16257
16258
16259
16260
16261
16262
16263
16264
# File 'lib/aws-sdk-ec2/types.rb', line 16244

class CreateVerifiedAccessEndpointRequest < Struct.new(
  :verified_access_group_id,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :application_domain,
  :endpoint_domain_prefix,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :description,
  :policy_document,
  :tag_specifications,
  :client_token,
  :dry_run,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#verified_access_group_idString

The ID of the Verified Access group to associate the endpoint with.

Returns:

  • (String)


16244
16245
16246
16247
16248
16249
16250
16251
16252
16253
16254
16255
16256
16257
16258
16259
16260
16261
16262
16263
16264
# File 'lib/aws-sdk-ec2/types.rb', line 16244

class CreateVerifiedAccessEndpointRequest < Struct.new(
  :verified_access_group_id,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :application_domain,
  :endpoint_domain_prefix,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :description,
  :policy_document,
  :tag_specifications,
  :client_token,
  :dry_run,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end