Class: Aws::EC2::Types::CreateVerifiedAccessEndpointRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateVerifiedAccessEndpointRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_domain ⇒ String
The DNS name for users to reach your application.
-
#attachment_type ⇒ String
The type of attachment.
-
#cidr_options ⇒ Types::CreateVerifiedAccessEndpointCidrOptions
The CIDR options.
-
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request.
-
#description ⇒ String
A description for the Verified Access endpoint.
-
#domain_certificate_arn ⇒ String
The ARN of the public TLS/SSL certificate in Amazon Web Services Certificate Manager to associate with the endpoint.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#endpoint_domain_prefix ⇒ String
A custom identifier that is prepended to the DNS name that is generated for the endpoint.
-
#endpoint_type ⇒ String
The type of Verified Access endpoint to create.
-
#load_balancer_options ⇒ Types::CreateVerifiedAccessEndpointLoadBalancerOptions
The load balancer details.
-
#network_interface_options ⇒ Types::CreateVerifiedAccessEndpointEniOptions
The network interface details.
-
#policy_document ⇒ String
The Verified Access policy document.
-
#rds_options ⇒ Types::CreateVerifiedAccessEndpointRdsOptions
The RDS details.
-
#security_group_ids ⇒ Array<String>
The IDs of the security groups to associate with the Verified Access endpoint.
-
#sse_specification ⇒ Types::VerifiedAccessSseSpecificationRequest
The options for server side encryption.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the Verified Access endpoint.
-
#verified_access_group_id ⇒ String
The ID of the Verified Access group to associate the endpoint with.
Instance Attribute Details
#application_domain ⇒ String
The DNS name for users to reach your application.
15799 15800 15801 15802 15803 15804 15805 15806 15807 15808 15809 15810 15811 15812 15813 15814 15815 15816 15817 15818 15819 |
# File 'lib/aws-sdk-ec2/types.rb', line 15799 class CreateVerifiedAccessEndpointRequest < Struct.new( :verified_access_group_id, :endpoint_type, :attachment_type, :domain_certificate_arn, :application_domain, :endpoint_domain_prefix, :security_group_ids, :load_balancer_options, :network_interface_options, :description, :policy_document, :tag_specifications, :client_token, :dry_run, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#attachment_type ⇒ String
The type of attachment.
15799 15800 15801 15802 15803 15804 15805 15806 15807 15808 15809 15810 15811 15812 15813 15814 15815 15816 15817 15818 15819 |
# File 'lib/aws-sdk-ec2/types.rb', line 15799 class CreateVerifiedAccessEndpointRequest < Struct.new( :verified_access_group_id, :endpoint_type, :attachment_type, :domain_certificate_arn, :application_domain, :endpoint_domain_prefix, :security_group_ids, :load_balancer_options, :network_interface_options, :description, :policy_document, :tag_specifications, :client_token, :dry_run, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#cidr_options ⇒ Types::CreateVerifiedAccessEndpointCidrOptions
The CIDR options. This parameter is required if the endpoint type is ‘cidr`.
15799 15800 15801 15802 15803 15804 15805 15806 15807 15808 15809 15810 15811 15812 15813 15814 15815 15816 15817 15818 15819 |
# File 'lib/aws-sdk-ec2/types.rb', line 15799 class CreateVerifiedAccessEndpointRequest < Struct.new( :verified_access_group_id, :endpoint_type, :attachment_type, :domain_certificate_arn, :application_domain, :endpoint_domain_prefix, :security_group_ids, :load_balancer_options, :network_interface_options, :description, :policy_document, :tag_specifications, :client_token, :dry_run, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see [Ensuring idempotency].
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html
15799 15800 15801 15802 15803 15804 15805 15806 15807 15808 15809 15810 15811 15812 15813 15814 15815 15816 15817 15818 15819 |
# File 'lib/aws-sdk-ec2/types.rb', line 15799 class CreateVerifiedAccessEndpointRequest < Struct.new( :verified_access_group_id, :endpoint_type, :attachment_type, :domain_certificate_arn, :application_domain, :endpoint_domain_prefix, :security_group_ids, :load_balancer_options, :network_interface_options, :description, :policy_document, :tag_specifications, :client_token, :dry_run, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description for the Verified Access endpoint.
15799 15800 15801 15802 15803 15804 15805 15806 15807 15808 15809 15810 15811 15812 15813 15814 15815 15816 15817 15818 15819 |
# File 'lib/aws-sdk-ec2/types.rb', line 15799 class CreateVerifiedAccessEndpointRequest < Struct.new( :verified_access_group_id, :endpoint_type, :attachment_type, :domain_certificate_arn, :application_domain, :endpoint_domain_prefix, :security_group_ids, :load_balancer_options, :network_interface_options, :description, :policy_document, :tag_specifications, :client_token, :dry_run, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#domain_certificate_arn ⇒ String
The ARN of the public TLS/SSL certificate in Amazon Web Services Certificate Manager to associate with the endpoint. The CN in the certificate must match the DNS name your end users will use to reach your application.
15799 15800 15801 15802 15803 15804 15805 15806 15807 15808 15809 15810 15811 15812 15813 15814 15815 15816 15817 15818 15819 |
# File 'lib/aws-sdk-ec2/types.rb', line 15799 class CreateVerifiedAccessEndpointRequest < Struct.new( :verified_access_group_id, :endpoint_type, :attachment_type, :domain_certificate_arn, :application_domain, :endpoint_domain_prefix, :security_group_ids, :load_balancer_options, :network_interface_options, :description, :policy_document, :tag_specifications, :client_token, :dry_run, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
15799 15800 15801 15802 15803 15804 15805 15806 15807 15808 15809 15810 15811 15812 15813 15814 15815 15816 15817 15818 15819 |
# File 'lib/aws-sdk-ec2/types.rb', line 15799 class CreateVerifiedAccessEndpointRequest < Struct.new( :verified_access_group_id, :endpoint_type, :attachment_type, :domain_certificate_arn, :application_domain, :endpoint_domain_prefix, :security_group_ids, :load_balancer_options, :network_interface_options, :description, :policy_document, :tag_specifications, :client_token, :dry_run, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#endpoint_domain_prefix ⇒ String
A custom identifier that is prepended to the DNS name that is generated for the endpoint.
15799 15800 15801 15802 15803 15804 15805 15806 15807 15808 15809 15810 15811 15812 15813 15814 15815 15816 15817 15818 15819 |
# File 'lib/aws-sdk-ec2/types.rb', line 15799 class CreateVerifiedAccessEndpointRequest < Struct.new( :verified_access_group_id, :endpoint_type, :attachment_type, :domain_certificate_arn, :application_domain, :endpoint_domain_prefix, :security_group_ids, :load_balancer_options, :network_interface_options, :description, :policy_document, :tag_specifications, :client_token, :dry_run, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#endpoint_type ⇒ String
The type of Verified Access endpoint to create.
15799 15800 15801 15802 15803 15804 15805 15806 15807 15808 15809 15810 15811 15812 15813 15814 15815 15816 15817 15818 15819 |
# File 'lib/aws-sdk-ec2/types.rb', line 15799 class CreateVerifiedAccessEndpointRequest < Struct.new( :verified_access_group_id, :endpoint_type, :attachment_type, :domain_certificate_arn, :application_domain, :endpoint_domain_prefix, :security_group_ids, :load_balancer_options, :network_interface_options, :description, :policy_document, :tag_specifications, :client_token, :dry_run, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#load_balancer_options ⇒ Types::CreateVerifiedAccessEndpointLoadBalancerOptions
The load balancer details. This parameter is required if the endpoint type is ‘load-balancer`.
15799 15800 15801 15802 15803 15804 15805 15806 15807 15808 15809 15810 15811 15812 15813 15814 15815 15816 15817 15818 15819 |
# File 'lib/aws-sdk-ec2/types.rb', line 15799 class CreateVerifiedAccessEndpointRequest < Struct.new( :verified_access_group_id, :endpoint_type, :attachment_type, :domain_certificate_arn, :application_domain, :endpoint_domain_prefix, :security_group_ids, :load_balancer_options, :network_interface_options, :description, :policy_document, :tag_specifications, :client_token, :dry_run, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#network_interface_options ⇒ Types::CreateVerifiedAccessEndpointEniOptions
The network interface details. This parameter is required if the endpoint type is ‘network-interface`.
15799 15800 15801 15802 15803 15804 15805 15806 15807 15808 15809 15810 15811 15812 15813 15814 15815 15816 15817 15818 15819 |
# File 'lib/aws-sdk-ec2/types.rb', line 15799 class CreateVerifiedAccessEndpointRequest < Struct.new( :verified_access_group_id, :endpoint_type, :attachment_type, :domain_certificate_arn, :application_domain, :endpoint_domain_prefix, :security_group_ids, :load_balancer_options, :network_interface_options, :description, :policy_document, :tag_specifications, :client_token, :dry_run, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#policy_document ⇒ String
The Verified Access policy document.
15799 15800 15801 15802 15803 15804 15805 15806 15807 15808 15809 15810 15811 15812 15813 15814 15815 15816 15817 15818 15819 |
# File 'lib/aws-sdk-ec2/types.rb', line 15799 class CreateVerifiedAccessEndpointRequest < Struct.new( :verified_access_group_id, :endpoint_type, :attachment_type, :domain_certificate_arn, :application_domain, :endpoint_domain_prefix, :security_group_ids, :load_balancer_options, :network_interface_options, :description, :policy_document, :tag_specifications, :client_token, :dry_run, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#rds_options ⇒ Types::CreateVerifiedAccessEndpointRdsOptions
The RDS details. This parameter is required if the endpoint type is ‘rds`.
15799 15800 15801 15802 15803 15804 15805 15806 15807 15808 15809 15810 15811 15812 15813 15814 15815 15816 15817 15818 15819 |
# File 'lib/aws-sdk-ec2/types.rb', line 15799 class CreateVerifiedAccessEndpointRequest < Struct.new( :verified_access_group_id, :endpoint_type, :attachment_type, :domain_certificate_arn, :application_domain, :endpoint_domain_prefix, :security_group_ids, :load_balancer_options, :network_interface_options, :description, :policy_document, :tag_specifications, :client_token, :dry_run, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
The IDs of the security groups to associate with the Verified Access endpoint. Required if ‘AttachmentType` is set to `vpc`.
15799 15800 15801 15802 15803 15804 15805 15806 15807 15808 15809 15810 15811 15812 15813 15814 15815 15816 15817 15818 15819 |
# File 'lib/aws-sdk-ec2/types.rb', line 15799 class CreateVerifiedAccessEndpointRequest < Struct.new( :verified_access_group_id, :endpoint_type, :attachment_type, :domain_certificate_arn, :application_domain, :endpoint_domain_prefix, :security_group_ids, :load_balancer_options, :network_interface_options, :description, :policy_document, :tag_specifications, :client_token, :dry_run, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#sse_specification ⇒ Types::VerifiedAccessSseSpecificationRequest
The options for server side encryption.
15799 15800 15801 15802 15803 15804 15805 15806 15807 15808 15809 15810 15811 15812 15813 15814 15815 15816 15817 15818 15819 |
# File 'lib/aws-sdk-ec2/types.rb', line 15799 class CreateVerifiedAccessEndpointRequest < Struct.new( :verified_access_group_id, :endpoint_type, :attachment_type, :domain_certificate_arn, :application_domain, :endpoint_domain_prefix, :security_group_ids, :load_balancer_options, :network_interface_options, :description, :policy_document, :tag_specifications, :client_token, :dry_run, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the Verified Access endpoint.
15799 15800 15801 15802 15803 15804 15805 15806 15807 15808 15809 15810 15811 15812 15813 15814 15815 15816 15817 15818 15819 |
# File 'lib/aws-sdk-ec2/types.rb', line 15799 class CreateVerifiedAccessEndpointRequest < Struct.new( :verified_access_group_id, :endpoint_type, :attachment_type, :domain_certificate_arn, :application_domain, :endpoint_domain_prefix, :security_group_ids, :load_balancer_options, :network_interface_options, :description, :policy_document, :tag_specifications, :client_token, :dry_run, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#verified_access_group_id ⇒ String
The ID of the Verified Access group to associate the endpoint with.
15799 15800 15801 15802 15803 15804 15805 15806 15807 15808 15809 15810 15811 15812 15813 15814 15815 15816 15817 15818 15819 |
# File 'lib/aws-sdk-ec2/types.rb', line 15799 class CreateVerifiedAccessEndpointRequest < Struct.new( :verified_access_group_id, :endpoint_type, :attachment_type, :domain_certificate_arn, :application_domain, :endpoint_domain_prefix, :security_group_ids, :load_balancer_options, :network_interface_options, :description, :policy_document, :tag_specifications, :client_token, :dry_run, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |