Class: Aws::EC2::Types::CreateVerifiedAccessGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateVerifiedAccessGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request.
-
#description ⇒ String
A description for the Verified Access group.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#policy_document ⇒ String
The Verified Access policy document.
-
#sse_specification ⇒ Types::VerifiedAccessSseSpecificationRequest
The options for server side encryption.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the Verified Access group.
-
#verified_access_instance_id ⇒ String
The ID of the Verified Access instance.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring idempotency.
A suitable default value is auto-generated. You should normally not need to pass this option.
17330 17331 17332 17333 17334 17335 17336 17337 17338 17339 17340 |
# File 'lib/aws-sdk-ec2/types.rb', line 17330 class CreateVerifiedAccessGroupRequest < Struct.new( :verified_access_instance_id, :description, :policy_document, :tag_specifications, :client_token, :dry_run, :sse_specification) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description for the Verified Access group.
17330 17331 17332 17333 17334 17335 17336 17337 17338 17339 17340 |
# File 'lib/aws-sdk-ec2/types.rb', line 17330 class CreateVerifiedAccessGroupRequest < Struct.new( :verified_access_instance_id, :description, :policy_document, :tag_specifications, :client_token, :dry_run, :sse_specification) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
17330 17331 17332 17333 17334 17335 17336 17337 17338 17339 17340 |
# File 'lib/aws-sdk-ec2/types.rb', line 17330 class CreateVerifiedAccessGroupRequest < Struct.new( :verified_access_instance_id, :description, :policy_document, :tag_specifications, :client_token, :dry_run, :sse_specification) SENSITIVE = [] include Aws::Structure end |
#policy_document ⇒ String
The Verified Access policy document.
17330 17331 17332 17333 17334 17335 17336 17337 17338 17339 17340 |
# File 'lib/aws-sdk-ec2/types.rb', line 17330 class CreateVerifiedAccessGroupRequest < Struct.new( :verified_access_instance_id, :description, :policy_document, :tag_specifications, :client_token, :dry_run, :sse_specification) SENSITIVE = [] include Aws::Structure end |
#sse_specification ⇒ Types::VerifiedAccessSseSpecificationRequest
The options for server side encryption.
17330 17331 17332 17333 17334 17335 17336 17337 17338 17339 17340 |
# File 'lib/aws-sdk-ec2/types.rb', line 17330 class CreateVerifiedAccessGroupRequest < Struct.new( :verified_access_instance_id, :description, :policy_document, :tag_specifications, :client_token, :dry_run, :sse_specification) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the Verified Access group.
17330 17331 17332 17333 17334 17335 17336 17337 17338 17339 17340 |
# File 'lib/aws-sdk-ec2/types.rb', line 17330 class CreateVerifiedAccessGroupRequest < Struct.new( :verified_access_instance_id, :description, :policy_document, :tag_specifications, :client_token, :dry_run, :sse_specification) SENSITIVE = [] include Aws::Structure end |
#verified_access_instance_id ⇒ String
The ID of the Verified Access instance.
17330 17331 17332 17333 17334 17335 17336 17337 17338 17339 17340 |
# File 'lib/aws-sdk-ec2/types.rb', line 17330 class CreateVerifiedAccessGroupRequest < Struct.new( :verified_access_instance_id, :description, :policy_document, :tag_specifications, :client_token, :dry_run, :sse_specification) SENSITIVE = [] include Aws::Structure end |