Class: Aws::EC2::Types::CreateVerifiedAccessInstanceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cidr_endpoints_custom_sub_domainString

The custom subdomain.

Returns:

  • (String)


17393
17394
17395
17396
17397
17398
17399
17400
17401
17402
# File 'lib/aws-sdk-ec2/types.rb', line 17393

class CreateVerifiedAccessInstanceRequest < Struct.new(
  :description,
  :tag_specifications,
  :client_token,
  :dry_run,
  :fips_enabled,
  :cidr_endpoints_custom_sub_domain)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


17393
17394
17395
17396
17397
17398
17399
17400
17401
17402
# File 'lib/aws-sdk-ec2/types.rb', line 17393

class CreateVerifiedAccessInstanceRequest < Struct.new(
  :description,
  :tag_specifications,
  :client_token,
  :dry_run,
  :fips_enabled,
  :cidr_endpoints_custom_sub_domain)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description for the Verified Access instance.

Returns:

  • (String)


17393
17394
17395
17396
17397
17398
17399
17400
17401
17402
# File 'lib/aws-sdk-ec2/types.rb', line 17393

class CreateVerifiedAccessInstanceRequest < Struct.new(
  :description,
  :tag_specifications,
  :client_token,
  :dry_run,
  :fips_enabled,
  :cidr_endpoints_custom_sub_domain)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


17393
17394
17395
17396
17397
17398
17399
17400
17401
17402
# File 'lib/aws-sdk-ec2/types.rb', line 17393

class CreateVerifiedAccessInstanceRequest < Struct.new(
  :description,
  :tag_specifications,
  :client_token,
  :dry_run,
  :fips_enabled,
  :cidr_endpoints_custom_sub_domain)
  SENSITIVE = []
  include Aws::Structure
end

#fips_enabledBoolean

Enable or disable support for Federal Information Processing Standards (FIPS) on the instance.

Returns:

  • (Boolean)


17393
17394
17395
17396
17397
17398
17399
17400
17401
17402
# File 'lib/aws-sdk-ec2/types.rb', line 17393

class CreateVerifiedAccessInstanceRequest < Struct.new(
  :description,
  :tag_specifications,
  :client_token,
  :dry_run,
  :fips_enabled,
  :cidr_endpoints_custom_sub_domain)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to assign to the Verified Access instance.

Returns:



17393
17394
17395
17396
17397
17398
17399
17400
17401
17402
# File 'lib/aws-sdk-ec2/types.rb', line 17393

class CreateVerifiedAccessInstanceRequest < Struct.new(
  :description,
  :tag_specifications,
  :client_token,
  :dry_run,
  :fips_enabled,
  :cidr_endpoints_custom_sub_domain)
  SENSITIVE = []
  include Aws::Structure
end