Class: Aws::EC2::Types::CreateVerifiedAccessInstanceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateVerifiedAccessInstanceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cidr_endpoints_custom_sub_domain ⇒ String
The custom subdomain.
-
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request.
-
#description ⇒ String
A description for the Verified Access instance.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#fips_enabled ⇒ Boolean
Enable or disable support for Federal Information Processing Standards (FIPS) on the instance.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the Verified Access instance.
Instance Attribute Details
#cidr_endpoints_custom_sub_domain ⇒ String
The custom subdomain.
16532 16533 16534 16535 16536 16537 16538 16539 16540 16541 |
# File 'lib/aws-sdk-ec2/types.rb', line 16532 class CreateVerifiedAccessInstanceRequest < Struct.new( :description, :tag_specifications, :client_token, :dry_run, :fips_enabled, :cidr_endpoints_custom_sub_domain) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring idempotency.
A suitable default value is auto-generated. You should normally not need to pass this option.
16532 16533 16534 16535 16536 16537 16538 16539 16540 16541 |
# File 'lib/aws-sdk-ec2/types.rb', line 16532 class CreateVerifiedAccessInstanceRequest < Struct.new( :description, :tag_specifications, :client_token, :dry_run, :fips_enabled, :cidr_endpoints_custom_sub_domain) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description for the Verified Access instance.
16532 16533 16534 16535 16536 16537 16538 16539 16540 16541 |
# File 'lib/aws-sdk-ec2/types.rb', line 16532 class CreateVerifiedAccessInstanceRequest < Struct.new( :description, :tag_specifications, :client_token, :dry_run, :fips_enabled, :cidr_endpoints_custom_sub_domain) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
16532 16533 16534 16535 16536 16537 16538 16539 16540 16541 |
# File 'lib/aws-sdk-ec2/types.rb', line 16532 class CreateVerifiedAccessInstanceRequest < Struct.new( :description, :tag_specifications, :client_token, :dry_run, :fips_enabled, :cidr_endpoints_custom_sub_domain) SENSITIVE = [] include Aws::Structure end |
#fips_enabled ⇒ Boolean
Enable or disable support for Federal Information Processing Standards (FIPS) on the instance.
16532 16533 16534 16535 16536 16537 16538 16539 16540 16541 |
# File 'lib/aws-sdk-ec2/types.rb', line 16532 class CreateVerifiedAccessInstanceRequest < Struct.new( :description, :tag_specifications, :client_token, :dry_run, :fips_enabled, :cidr_endpoints_custom_sub_domain) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the Verified Access instance.
16532 16533 16534 16535 16536 16537 16538 16539 16540 16541 |
# File 'lib/aws-sdk-ec2/types.rb', line 16532 class CreateVerifiedAccessInstanceRequest < Struct.new( :description, :tag_specifications, :client_token, :dry_run, :fips_enabled, :cidr_endpoints_custom_sub_domain) SENSITIVE = [] include Aws::Structure end |