Class: Aws::EC2::Types::CreateVerifiedAccessTrustProviderRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


16794
16795
16796
16797
16798
16799
16800
16801
16802
16803
16804
16805
16806
16807
16808
16809
# File 'lib/aws-sdk-ec2/types.rb', line 16794

class CreateVerifiedAccessTrustProviderRequest < Struct.new(
  :trust_provider_type,
  :user_trust_provider_type,
  :device_trust_provider_type,
  :oidc_options,
  :device_options,
  :policy_reference_name,
  :description,
  :tag_specifications,
  :client_token,
  :dry_run,
  :sse_specification,
  :native_application_oidc_options)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description for the Verified Access trust provider.

Returns:

  • (String)


16794
16795
16796
16797
16798
16799
16800
16801
16802
16803
16804
16805
16806
16807
16808
16809
# File 'lib/aws-sdk-ec2/types.rb', line 16794

class CreateVerifiedAccessTrustProviderRequest < Struct.new(
  :trust_provider_type,
  :user_trust_provider_type,
  :device_trust_provider_type,
  :oidc_options,
  :device_options,
  :policy_reference_name,
  :description,
  :tag_specifications,
  :client_token,
  :dry_run,
  :sse_specification,
  :native_application_oidc_options)
  SENSITIVE = []
  include Aws::Structure
end

#device_optionsTypes::CreateVerifiedAccessTrustProviderDeviceOptions

The options for a device-based trust provider. This parameter is required when the provider type is device.



16794
16795
16796
16797
16798
16799
16800
16801
16802
16803
16804
16805
16806
16807
16808
16809
# File 'lib/aws-sdk-ec2/types.rb', line 16794

class CreateVerifiedAccessTrustProviderRequest < Struct.new(
  :trust_provider_type,
  :user_trust_provider_type,
  :device_trust_provider_type,
  :oidc_options,
  :device_options,
  :policy_reference_name,
  :description,
  :tag_specifications,
  :client_token,
  :dry_run,
  :sse_specification,
  :native_application_oidc_options)
  SENSITIVE = []
  include Aws::Structure
end

#device_trust_provider_typeString

The type of device-based trust provider. This parameter is required when the provider type is device.

Returns:

  • (String)


16794
16795
16796
16797
16798
16799
16800
16801
16802
16803
16804
16805
16806
16807
16808
16809
# File 'lib/aws-sdk-ec2/types.rb', line 16794

class CreateVerifiedAccessTrustProviderRequest < Struct.new(
  :trust_provider_type,
  :user_trust_provider_type,
  :device_trust_provider_type,
  :oidc_options,
  :device_options,
  :policy_reference_name,
  :description,
  :tag_specifications,
  :client_token,
  :dry_run,
  :sse_specification,
  :native_application_oidc_options)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


16794
16795
16796
16797
16798
16799
16800
16801
16802
16803
16804
16805
16806
16807
16808
16809
# File 'lib/aws-sdk-ec2/types.rb', line 16794

class CreateVerifiedAccessTrustProviderRequest < Struct.new(
  :trust_provider_type,
  :user_trust_provider_type,
  :device_trust_provider_type,
  :oidc_options,
  :device_options,
  :policy_reference_name,
  :description,
  :tag_specifications,
  :client_token,
  :dry_run,
  :sse_specification,
  :native_application_oidc_options)
  SENSITIVE = []
  include Aws::Structure
end

#native_application_oidc_optionsTypes::CreateVerifiedAccessNativeApplicationOidcOptions

The OpenID Connect (OIDC) options.



16794
16795
16796
16797
16798
16799
16800
16801
16802
16803
16804
16805
16806
16807
16808
16809
# File 'lib/aws-sdk-ec2/types.rb', line 16794

class CreateVerifiedAccessTrustProviderRequest < Struct.new(
  :trust_provider_type,
  :user_trust_provider_type,
  :device_trust_provider_type,
  :oidc_options,
  :device_options,
  :policy_reference_name,
  :description,
  :tag_specifications,
  :client_token,
  :dry_run,
  :sse_specification,
  :native_application_oidc_options)
  SENSITIVE = []
  include Aws::Structure
end

#oidc_optionsTypes::CreateVerifiedAccessTrustProviderOidcOptions

The options for a OpenID Connect-compatible user-identity trust provider. This parameter is required when the provider type is user.



16794
16795
16796
16797
16798
16799
16800
16801
16802
16803
16804
16805
16806
16807
16808
16809
# File 'lib/aws-sdk-ec2/types.rb', line 16794

class CreateVerifiedAccessTrustProviderRequest < Struct.new(
  :trust_provider_type,
  :user_trust_provider_type,
  :device_trust_provider_type,
  :oidc_options,
  :device_options,
  :policy_reference_name,
  :description,
  :tag_specifications,
  :client_token,
  :dry_run,
  :sse_specification,
  :native_application_oidc_options)
  SENSITIVE = []
  include Aws::Structure
end

#policy_reference_nameString

The identifier to be used when working with policy rules.

Returns:

  • (String)


16794
16795
16796
16797
16798
16799
16800
16801
16802
16803
16804
16805
16806
16807
16808
16809
# File 'lib/aws-sdk-ec2/types.rb', line 16794

class CreateVerifiedAccessTrustProviderRequest < Struct.new(
  :trust_provider_type,
  :user_trust_provider_type,
  :device_trust_provider_type,
  :oidc_options,
  :device_options,
  :policy_reference_name,
  :description,
  :tag_specifications,
  :client_token,
  :dry_run,
  :sse_specification,
  :native_application_oidc_options)
  SENSITIVE = []
  include Aws::Structure
end

#sse_specificationTypes::VerifiedAccessSseSpecificationRequest

The options for server side encryption.



16794
16795
16796
16797
16798
16799
16800
16801
16802
16803
16804
16805
16806
16807
16808
16809
# File 'lib/aws-sdk-ec2/types.rb', line 16794

class CreateVerifiedAccessTrustProviderRequest < Struct.new(
  :trust_provider_type,
  :user_trust_provider_type,
  :device_trust_provider_type,
  :oidc_options,
  :device_options,
  :policy_reference_name,
  :description,
  :tag_specifications,
  :client_token,
  :dry_run,
  :sse_specification,
  :native_application_oidc_options)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to assign to the Verified Access trust provider.

Returns:



16794
16795
16796
16797
16798
16799
16800
16801
16802
16803
16804
16805
16806
16807
16808
16809
# File 'lib/aws-sdk-ec2/types.rb', line 16794

class CreateVerifiedAccessTrustProviderRequest < Struct.new(
  :trust_provider_type,
  :user_trust_provider_type,
  :device_trust_provider_type,
  :oidc_options,
  :device_options,
  :policy_reference_name,
  :description,
  :tag_specifications,
  :client_token,
  :dry_run,
  :sse_specification,
  :native_application_oidc_options)
  SENSITIVE = []
  include Aws::Structure
end

#trust_provider_typeString

The type of trust provider.

Returns:

  • (String)


16794
16795
16796
16797
16798
16799
16800
16801
16802
16803
16804
16805
16806
16807
16808
16809
# File 'lib/aws-sdk-ec2/types.rb', line 16794

class CreateVerifiedAccessTrustProviderRequest < Struct.new(
  :trust_provider_type,
  :user_trust_provider_type,
  :device_trust_provider_type,
  :oidc_options,
  :device_options,
  :policy_reference_name,
  :description,
  :tag_specifications,
  :client_token,
  :dry_run,
  :sse_specification,
  :native_application_oidc_options)
  SENSITIVE = []
  include Aws::Structure
end

#user_trust_provider_typeString

The type of user-based trust provider. This parameter is required when the provider type is user.

Returns:

  • (String)


16794
16795
16796
16797
16798
16799
16800
16801
16802
16803
16804
16805
16806
16807
16808
16809
# File 'lib/aws-sdk-ec2/types.rb', line 16794

class CreateVerifiedAccessTrustProviderRequest < Struct.new(
  :trust_provider_type,
  :user_trust_provider_type,
  :device_trust_provider_type,
  :oidc_options,
  :device_options,
  :policy_reference_name,
  :description,
  :tag_specifications,
  :client_token,
  :dry_run,
  :sse_specification,
  :native_application_oidc_options)
  SENSITIVE = []
  include Aws::Structure
end