Class: Aws::EC2::Types::CreateVerifiedAccessTrustProviderRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateVerifiedAccessTrustProviderRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request.
-
#description ⇒ String
A description for the Verified Access trust provider.
-
#device_options ⇒ Types::CreateVerifiedAccessTrustProviderDeviceOptions
The options for a device-based trust provider.
-
#device_trust_provider_type ⇒ String
The type of device-based trust provider.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#native_application_oidc_options ⇒ Types::CreateVerifiedAccessNativeApplicationOidcOptions
The OpenID Connect (OIDC) options.
-
#oidc_options ⇒ Types::CreateVerifiedAccessTrustProviderOidcOptions
The options for a OpenID Connect-compatible user-identity trust provider.
-
#policy_reference_name ⇒ String
The identifier to be used when working with policy rules.
-
#sse_specification ⇒ Types::VerifiedAccessSseSpecificationRequest
The options for server side encryption.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the Verified Access trust provider.
-
#trust_provider_type ⇒ String
The type of trust provider.
-
#user_trust_provider_type ⇒ String
The type of user-based trust provider.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see [Ensuring idempotency].
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html
16145 16146 16147 16148 16149 16150 16151 16152 16153 16154 16155 16156 16157 16158 16159 16160 |
# File 'lib/aws-sdk-ec2/types.rb', line 16145 class CreateVerifiedAccessTrustProviderRequest < Struct.new( :trust_provider_type, :user_trust_provider_type, :device_trust_provider_type, :oidc_options, :device_options, :policy_reference_name, :description, :tag_specifications, :client_token, :dry_run, :sse_specification, :native_application_oidc_options) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description for the Verified Access trust provider.
16145 16146 16147 16148 16149 16150 16151 16152 16153 16154 16155 16156 16157 16158 16159 16160 |
# File 'lib/aws-sdk-ec2/types.rb', line 16145 class CreateVerifiedAccessTrustProviderRequest < Struct.new( :trust_provider_type, :user_trust_provider_type, :device_trust_provider_type, :oidc_options, :device_options, :policy_reference_name, :description, :tag_specifications, :client_token, :dry_run, :sse_specification, :native_application_oidc_options) SENSITIVE = [] include Aws::Structure end |
#device_options ⇒ Types::CreateVerifiedAccessTrustProviderDeviceOptions
The options for a device-based trust provider. This parameter is required when the provider type is ‘device`.
16145 16146 16147 16148 16149 16150 16151 16152 16153 16154 16155 16156 16157 16158 16159 16160 |
# File 'lib/aws-sdk-ec2/types.rb', line 16145 class CreateVerifiedAccessTrustProviderRequest < Struct.new( :trust_provider_type, :user_trust_provider_type, :device_trust_provider_type, :oidc_options, :device_options, :policy_reference_name, :description, :tag_specifications, :client_token, :dry_run, :sse_specification, :native_application_oidc_options) SENSITIVE = [] include Aws::Structure end |
#device_trust_provider_type ⇒ String
The type of device-based trust provider. This parameter is required when the provider type is ‘device`.
16145 16146 16147 16148 16149 16150 16151 16152 16153 16154 16155 16156 16157 16158 16159 16160 |
# File 'lib/aws-sdk-ec2/types.rb', line 16145 class CreateVerifiedAccessTrustProviderRequest < Struct.new( :trust_provider_type, :user_trust_provider_type, :device_trust_provider_type, :oidc_options, :device_options, :policy_reference_name, :description, :tag_specifications, :client_token, :dry_run, :sse_specification, :native_application_oidc_options) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
16145 16146 16147 16148 16149 16150 16151 16152 16153 16154 16155 16156 16157 16158 16159 16160 |
# File 'lib/aws-sdk-ec2/types.rb', line 16145 class CreateVerifiedAccessTrustProviderRequest < Struct.new( :trust_provider_type, :user_trust_provider_type, :device_trust_provider_type, :oidc_options, :device_options, :policy_reference_name, :description, :tag_specifications, :client_token, :dry_run, :sse_specification, :native_application_oidc_options) SENSITIVE = [] include Aws::Structure end |
#native_application_oidc_options ⇒ Types::CreateVerifiedAccessNativeApplicationOidcOptions
The OpenID Connect (OIDC) options.
16145 16146 16147 16148 16149 16150 16151 16152 16153 16154 16155 16156 16157 16158 16159 16160 |
# File 'lib/aws-sdk-ec2/types.rb', line 16145 class CreateVerifiedAccessTrustProviderRequest < Struct.new( :trust_provider_type, :user_trust_provider_type, :device_trust_provider_type, :oidc_options, :device_options, :policy_reference_name, :description, :tag_specifications, :client_token, :dry_run, :sse_specification, :native_application_oidc_options) SENSITIVE = [] include Aws::Structure end |
#oidc_options ⇒ Types::CreateVerifiedAccessTrustProviderOidcOptions
The options for a OpenID Connect-compatible user-identity trust provider. This parameter is required when the provider type is ‘user`.
16145 16146 16147 16148 16149 16150 16151 16152 16153 16154 16155 16156 16157 16158 16159 16160 |
# File 'lib/aws-sdk-ec2/types.rb', line 16145 class CreateVerifiedAccessTrustProviderRequest < Struct.new( :trust_provider_type, :user_trust_provider_type, :device_trust_provider_type, :oidc_options, :device_options, :policy_reference_name, :description, :tag_specifications, :client_token, :dry_run, :sse_specification, :native_application_oidc_options) SENSITIVE = [] include Aws::Structure end |
#policy_reference_name ⇒ String
The identifier to be used when working with policy rules.
16145 16146 16147 16148 16149 16150 16151 16152 16153 16154 16155 16156 16157 16158 16159 16160 |
# File 'lib/aws-sdk-ec2/types.rb', line 16145 class CreateVerifiedAccessTrustProviderRequest < Struct.new( :trust_provider_type, :user_trust_provider_type, :device_trust_provider_type, :oidc_options, :device_options, :policy_reference_name, :description, :tag_specifications, :client_token, :dry_run, :sse_specification, :native_application_oidc_options) SENSITIVE = [] include Aws::Structure end |
#sse_specification ⇒ Types::VerifiedAccessSseSpecificationRequest
The options for server side encryption.
16145 16146 16147 16148 16149 16150 16151 16152 16153 16154 16155 16156 16157 16158 16159 16160 |
# File 'lib/aws-sdk-ec2/types.rb', line 16145 class CreateVerifiedAccessTrustProviderRequest < Struct.new( :trust_provider_type, :user_trust_provider_type, :device_trust_provider_type, :oidc_options, :device_options, :policy_reference_name, :description, :tag_specifications, :client_token, :dry_run, :sse_specification, :native_application_oidc_options) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to assign to the Verified Access trust provider.
16145 16146 16147 16148 16149 16150 16151 16152 16153 16154 16155 16156 16157 16158 16159 16160 |
# File 'lib/aws-sdk-ec2/types.rb', line 16145 class CreateVerifiedAccessTrustProviderRequest < Struct.new( :trust_provider_type, :user_trust_provider_type, :device_trust_provider_type, :oidc_options, :device_options, :policy_reference_name, :description, :tag_specifications, :client_token, :dry_run, :sse_specification, :native_application_oidc_options) SENSITIVE = [] include Aws::Structure end |
#trust_provider_type ⇒ String
The type of trust provider.
16145 16146 16147 16148 16149 16150 16151 16152 16153 16154 16155 16156 16157 16158 16159 16160 |
# File 'lib/aws-sdk-ec2/types.rb', line 16145 class CreateVerifiedAccessTrustProviderRequest < Struct.new( :trust_provider_type, :user_trust_provider_type, :device_trust_provider_type, :oidc_options, :device_options, :policy_reference_name, :description, :tag_specifications, :client_token, :dry_run, :sse_specification, :native_application_oidc_options) SENSITIVE = [] include Aws::Structure end |
#user_trust_provider_type ⇒ String
The type of user-based trust provider. This parameter is required when the provider type is ‘user`.
16145 16146 16147 16148 16149 16150 16151 16152 16153 16154 16155 16156 16157 16158 16159 16160 |
# File 'lib/aws-sdk-ec2/types.rb', line 16145 class CreateVerifiedAccessTrustProviderRequest < Struct.new( :trust_provider_type, :user_trust_provider_type, :device_trust_provider_type, :oidc_options, :device_options, :policy_reference_name, :description, :tag_specifications, :client_token, :dry_run, :sse_specification, :native_application_oidc_options) SENSITIVE = [] include Aws::Structure end |