Class: Aws::EC2::Types::CreateVolumeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateVolumeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone ⇒ String
The ID of the Availability Zone in which to create the volume.
-
#availability_zone_id ⇒ String
The ID of the Availability Zone in which to create the volume.
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#encrypted ⇒ Boolean
Indicates whether the volume should be encrypted.
-
#iops ⇒ Integer
The number of I/O operations per second (IOPS) to provision for the volume.
-
#kms_key_id ⇒ String
The identifier of the KMS key to use for Amazon EBS encryption.
-
#multi_attach_enabled ⇒ Boolean
Indicates whether to enable Amazon EBS Multi-Attach.
-
#operator ⇒ Types::OperatorRequest
Reserved for internal use.
-
#outpost_arn ⇒ String
The Amazon Resource Name (ARN) of the Outpost on which to create the volume.
-
#size ⇒ Integer
The size of the volume, in GiBs.
-
#snapshot_id ⇒ String
The snapshot from which to create the volume.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the volume during creation.
-
#throughput ⇒ Integer
The throughput to provision for the volume, in MiB/s.
-
#volume_initialization_rate ⇒ Integer
Specifies the Amazon EBS Provisioned Rate for Volume Initialization (volume initialization rate), in MiB/s, at which to download the snapshot blocks from Amazon S3 to the volume.
-
#volume_type ⇒ String
The volume type.
Instance Attribute Details
#availability_zone ⇒ String
The ID of the Availability Zone in which to create the volume. For example, ‘us-east-1a`.
Either ‘AvailabilityZone` or `AvailabilityZoneId` must be specified, but not both.
16216 16217 16218 16219 16220 16221 16222 16223 16224 16225 16226 16227 16228 16229 16230 16231 16232 16233 16234 16235 |
# File 'lib/aws-sdk-ec2/types.rb', line 16216 class CreateVolumeRequest < Struct.new( :availability_zone, :availability_zone_id, :encrypted, :iops, :kms_key_id, :outpost_arn, :size, :snapshot_id, :volume_type, :tag_specifications, :multi_attach_enabled, :throughput, :client_token, :volume_initialization_rate, :operator, :dry_run) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
The ID of the Availability Zone in which to create the volume. For example, ‘use1-az1`.
Either ‘AvailabilityZone` or `AvailabilityZoneId` must be specified, but not both.
16216 16217 16218 16219 16220 16221 16222 16223 16224 16225 16226 16227 16228 16229 16230 16231 16232 16233 16234 16235 |
# File 'lib/aws-sdk-ec2/types.rb', line 16216 class CreateVolumeRequest < Struct.new( :availability_zone, :availability_zone_id, :encrypted, :iops, :kms_key_id, :outpost_arn, :size, :snapshot_id, :volume_type, :tag_specifications, :multi_attach_enabled, :throughput, :client_token, :volume_initialization_rate, :operator, :dry_run) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [Ensure Idempotency].
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html
16216 16217 16218 16219 16220 16221 16222 16223 16224 16225 16226 16227 16228 16229 16230 16231 16232 16233 16234 16235 |
# File 'lib/aws-sdk-ec2/types.rb', line 16216 class CreateVolumeRequest < Struct.new( :availability_zone, :availability_zone_id, :encrypted, :iops, :kms_key_id, :outpost_arn, :size, :snapshot_id, :volume_type, :tag_specifications, :multi_attach_enabled, :throughput, :client_token, :volume_initialization_rate, :operator, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
16216 16217 16218 16219 16220 16221 16222 16223 16224 16225 16226 16227 16228 16229 16230 16231 16232 16233 16234 16235 |
# File 'lib/aws-sdk-ec2/types.rb', line 16216 class CreateVolumeRequest < Struct.new( :availability_zone, :availability_zone_id, :encrypted, :iops, :kms_key_id, :outpost_arn, :size, :snapshot_id, :volume_type, :tag_specifications, :multi_attach_enabled, :throughput, :client_token, :volume_initialization_rate, :operator, :dry_run) SENSITIVE = [] include Aws::Structure end |
#encrypted ⇒ Boolean
Indicates whether the volume should be encrypted. The effect of setting the encryption state to ‘true` depends on the volume origin (new or from a snapshot), starting encryption state, ownership, and whether encryption by default is enabled. For more information, see
- Encryption by default][1
-
in the *Amazon EBS User Guide*.
Encrypted Amazon EBS volumes must be attached to instances that support Amazon EBS encryption. For more information, see [Supported instance types].
[1]: docs.aws.amazon.com/ebs/latest/userguide/work-with-ebs-encr.html#encryption-by-default [2]: docs.aws.amazon.com/ebs/latest/userguide/ebs-encryption-requirements.html#ebs-encryption_supported_instances
16216 16217 16218 16219 16220 16221 16222 16223 16224 16225 16226 16227 16228 16229 16230 16231 16232 16233 16234 16235 |
# File 'lib/aws-sdk-ec2/types.rb', line 16216 class CreateVolumeRequest < Struct.new( :availability_zone, :availability_zone_id, :encrypted, :iops, :kms_key_id, :outpost_arn, :size, :snapshot_id, :volume_type, :tag_specifications, :multi_attach_enabled, :throughput, :client_token, :volume_initialization_rate, :operator, :dry_run) SENSITIVE = [] include Aws::Structure end |
#iops ⇒ Integer
The number of I/O operations per second (IOPS) to provision for the volume. Required for ‘io1` and `io2` volumes. Optional for `gp3` volumes. Omit for all other volume types.
Valid ranges:
-
gp3: ‘3,000 `(default)` - 80,000` IOPS
-
io1: ‘100 - 64,000` IOPS
-
io2: ‘100 - 256,000` IOPS
<note markdown=“1”> [ Instances built on the Nitro System] can support up to 256,000 IOPS. Other instances can support up to 32,000 IOPS.
</note>
[1]: docs.aws.amazon.com/ec2/latest/instancetypes/ec2-nitro-instances.html
16216 16217 16218 16219 16220 16221 16222 16223 16224 16225 16226 16227 16228 16229 16230 16231 16232 16233 16234 16235 |
# File 'lib/aws-sdk-ec2/types.rb', line 16216 class CreateVolumeRequest < Struct.new( :availability_zone, :availability_zone_id, :encrypted, :iops, :kms_key_id, :outpost_arn, :size, :snapshot_id, :volume_type, :tag_specifications, :multi_attach_enabled, :throughput, :client_token, :volume_initialization_rate, :operator, :dry_run) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The identifier of the KMS key to use for Amazon EBS encryption. If this parameter is not specified, your KMS key for Amazon EBS is used. If ‘KmsKeyId` is specified, the encrypted state must be `true`.
You can specify the KMS key using any of the following:
-
Key ID. For example, 1234abcd-12ab-34cd-56ef-1234567890ab.
-
Key alias. For example, alias/ExampleAlias.
-
Key ARN. For example, arn:aws:kms:us-east-1:012345678910:key/1234abcd-12ab-34cd-56ef-1234567890ab.
-
Alias ARN. For example, arn:aws:kms:us-east-1:012345678910:alias/ExampleAlias.
Amazon Web Services authenticates the KMS key asynchronously. Therefore, if you specify an ID, alias, or ARN that is not valid, the action can appear to complete, but eventually fails.
16216 16217 16218 16219 16220 16221 16222 16223 16224 16225 16226 16227 16228 16229 16230 16231 16232 16233 16234 16235 |
# File 'lib/aws-sdk-ec2/types.rb', line 16216 class CreateVolumeRequest < Struct.new( :availability_zone, :availability_zone_id, :encrypted, :iops, :kms_key_id, :outpost_arn, :size, :snapshot_id, :volume_type, :tag_specifications, :multi_attach_enabled, :throughput, :client_token, :volume_initialization_rate, :operator, :dry_run) SENSITIVE = [] include Aws::Structure end |
#multi_attach_enabled ⇒ Boolean
Indicates whether to enable Amazon EBS Multi-Attach. If you enable Multi-Attach, you can attach the volume to up to 16 [Instances built on the Nitro System] in the same Availability Zone. This parameter is supported with ‘io1` and `io2` volumes only. For more information, see [ Amazon EBS Multi-Attach] in the *Amazon EBS User Guide*.
[1]: docs.aws.amazon.com/ec2/latest/instancetypes/ec2-nitro-instances.html [2]: docs.aws.amazon.com/ebs/latest/userguide/ebs-volumes-multi.html
16216 16217 16218 16219 16220 16221 16222 16223 16224 16225 16226 16227 16228 16229 16230 16231 16232 16233 16234 16235 |
# File 'lib/aws-sdk-ec2/types.rb', line 16216 class CreateVolumeRequest < Struct.new( :availability_zone, :availability_zone_id, :encrypted, :iops, :kms_key_id, :outpost_arn, :size, :snapshot_id, :volume_type, :tag_specifications, :multi_attach_enabled, :throughput, :client_token, :volume_initialization_rate, :operator, :dry_run) SENSITIVE = [] include Aws::Structure end |
#operator ⇒ Types::OperatorRequest
Reserved for internal use.
16216 16217 16218 16219 16220 16221 16222 16223 16224 16225 16226 16227 16228 16229 16230 16231 16232 16233 16234 16235 |
# File 'lib/aws-sdk-ec2/types.rb', line 16216 class CreateVolumeRequest < Struct.new( :availability_zone, :availability_zone_id, :encrypted, :iops, :kms_key_id, :outpost_arn, :size, :snapshot_id, :volume_type, :tag_specifications, :multi_attach_enabled, :throughput, :client_token, :volume_initialization_rate, :operator, :dry_run) SENSITIVE = [] include Aws::Structure end |
#outpost_arn ⇒ String
The Amazon Resource Name (ARN) of the Outpost on which to create the volume.
If you intend to use a volume with an instance running on an outpost, then you must create the volume on the same outpost as the instance. You can’t use a volume created in an Amazon Web Services Region with an instance on an Amazon Web Services outpost, or the other way around.
16216 16217 16218 16219 16220 16221 16222 16223 16224 16225 16226 16227 16228 16229 16230 16231 16232 16233 16234 16235 |
# File 'lib/aws-sdk-ec2/types.rb', line 16216 class CreateVolumeRequest < Struct.new( :availability_zone, :availability_zone_id, :encrypted, :iops, :kms_key_id, :outpost_arn, :size, :snapshot_id, :volume_type, :tag_specifications, :multi_attach_enabled, :throughput, :client_token, :volume_initialization_rate, :operator, :dry_run) SENSITIVE = [] include Aws::Structure end |
#size ⇒ Integer
The size of the volume, in GiBs. You must specify either a snapshot ID or a volume size. If you specify a snapshot, the default is the snapshot size, and you can specify a volume size that is equal to or larger than the snapshot size.
Valid sizes:
-
gp2: ‘1 - 16,384` GiB
-
gp3: ‘1 - 65,536` GiB
-
io1: ‘4 - 16,384` GiB
-
io2: ‘4 - 65,536` GiB
-
st1 and sc1: ‘125 - 16,384` GiB
-
standard: ‘1 - 1024` GiB
16216 16217 16218 16219 16220 16221 16222 16223 16224 16225 16226 16227 16228 16229 16230 16231 16232 16233 16234 16235 |
# File 'lib/aws-sdk-ec2/types.rb', line 16216 class CreateVolumeRequest < Struct.new( :availability_zone, :availability_zone_id, :encrypted, :iops, :kms_key_id, :outpost_arn, :size, :snapshot_id, :volume_type, :tag_specifications, :multi_attach_enabled, :throughput, :client_token, :volume_initialization_rate, :operator, :dry_run) SENSITIVE = [] include Aws::Structure end |
#snapshot_id ⇒ String
The snapshot from which to create the volume. You must specify either a snapshot ID or a volume size.
16216 16217 16218 16219 16220 16221 16222 16223 16224 16225 16226 16227 16228 16229 16230 16231 16232 16233 16234 16235 |
# File 'lib/aws-sdk-ec2/types.rb', line 16216 class CreateVolumeRequest < Struct.new( :availability_zone, :availability_zone_id, :encrypted, :iops, :kms_key_id, :outpost_arn, :size, :snapshot_id, :volume_type, :tag_specifications, :multi_attach_enabled, :throughput, :client_token, :volume_initialization_rate, :operator, :dry_run) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the volume during creation.
16216 16217 16218 16219 16220 16221 16222 16223 16224 16225 16226 16227 16228 16229 16230 16231 16232 16233 16234 16235 |
# File 'lib/aws-sdk-ec2/types.rb', line 16216 class CreateVolumeRequest < Struct.new( :availability_zone, :availability_zone_id, :encrypted, :iops, :kms_key_id, :outpost_arn, :size, :snapshot_id, :volume_type, :tag_specifications, :multi_attach_enabled, :throughput, :client_token, :volume_initialization_rate, :operator, :dry_run) SENSITIVE = [] include Aws::Structure end |
#throughput ⇒ Integer
The throughput to provision for the volume, in MiB/s. Supported for ‘gp3` volumes only. Omit for all other volume types.
Valid Range: ‘125 - 2000` MiB/s
16216 16217 16218 16219 16220 16221 16222 16223 16224 16225 16226 16227 16228 16229 16230 16231 16232 16233 16234 16235 |
# File 'lib/aws-sdk-ec2/types.rb', line 16216 class CreateVolumeRequest < Struct.new( :availability_zone, :availability_zone_id, :encrypted, :iops, :kms_key_id, :outpost_arn, :size, :snapshot_id, :volume_type, :tag_specifications, :multi_attach_enabled, :throughput, :client_token, :volume_initialization_rate, :operator, :dry_run) SENSITIVE = [] include Aws::Structure end |
#volume_initialization_rate ⇒ Integer
Specifies the Amazon EBS Provisioned Rate for Volume Initialization (volume initialization rate), in MiB/s, at which to download the snapshot blocks from Amazon S3 to the volume. This is also known as *volume initialization*. Specifying a volume initialization rate ensures that the volume is initialized at a predictable and consistent rate after creation.
This parameter is supported only for volumes created from snapshots. Omit this parameter if:
-
You want to create the volume using fast snapshot restore. You must specify a snapshot that is enabled for fast snapshot restore. In this case, the volume is fully initialized at creation.
<note markdown=“1”> If you specify a snapshot that is enabled for fast snapshot restore and a volume initialization rate, the volume will be initialized at the specified rate instead of fast snapshot restore.
</note> -
You want to create a volume that is initialized at the default rate.
For more information, see [ Initialize Amazon EBS volumes] in the *Amazon EC2 User Guide*.
Valid range: 100 - 300 MiB/s
[1]: docs.aws.amazon.com/ebs/latest/userguide/initalize-volume.html
16216 16217 16218 16219 16220 16221 16222 16223 16224 16225 16226 16227 16228 16229 16230 16231 16232 16233 16234 16235 |
# File 'lib/aws-sdk-ec2/types.rb', line 16216 class CreateVolumeRequest < Struct.new( :availability_zone, :availability_zone_id, :encrypted, :iops, :kms_key_id, :outpost_arn, :size, :snapshot_id, :volume_type, :tag_specifications, :multi_attach_enabled, :throughput, :client_token, :volume_initialization_rate, :operator, :dry_run) SENSITIVE = [] include Aws::Structure end |
#volume_type ⇒ String
The volume type. This parameter can be one of the following values:
-
General Purpose SSD: ‘gp2` | `gp3`
-
Provisioned IOPS SSD: ‘io1` | `io2`
-
Throughput Optimized HDD: ‘st1`
-
Cold HDD: ‘sc1`
-
Magnetic: ‘standard`
Throughput Optimized HDD (‘st1`) and Cold HDD (`sc1`) volumes can’t be used as boot volumes.
For more information, see [Amazon EBS volume types] in the *Amazon EBS User Guide*.
Default: ‘gp2`
[1]: docs.aws.amazon.com/ebs/latest/userguide/ebs-volume-types.html
16216 16217 16218 16219 16220 16221 16222 16223 16224 16225 16226 16227 16228 16229 16230 16231 16232 16233 16234 16235 |
# File 'lib/aws-sdk-ec2/types.rb', line 16216 class CreateVolumeRequest < Struct.new( :availability_zone, :availability_zone_id, :encrypted, :iops, :kms_key_id, :outpost_arn, :size, :snapshot_id, :volume_type, :tag_specifications, :multi_attach_enabled, :throughput, :client_token, :volume_initialization_rate, :operator, :dry_run) SENSITIVE = [] include Aws::Structure end |