Class: Aws::EC2::Types::CreateVpcBlockPublicAccessExclusionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateVpcBlockPublicAccessExclusionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#internet_gateway_exclusion_mode ⇒ String
The exclusion mode for internet gateway traffic.
-
#subnet_id ⇒ String
A subnet ID.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
‘tag` - The key/value combination of a tag assigned to the resource.
-
#vpc_id ⇒ String
A VPC ID.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
16502 16503 16504 16505 16506 16507 16508 16509 16510 |
# File 'lib/aws-sdk-ec2/types.rb', line 16502 class CreateVpcBlockPublicAccessExclusionRequest < Struct.new( :dry_run, :subnet_id, :vpc_id, :internet_gateway_exclusion_mode, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#internet_gateway_exclusion_mode ⇒ String
The exclusion mode for internet gateway traffic.
-
‘allow-bidirectional`: Allow all internet traffic to and from the excluded VPCs and subnets.
-
‘allow-egress`: Allow outbound internet traffic from the excluded VPCs and subnets. Block inbound internet traffic to the excluded VPCs and subnets. Only applies when VPC Block Public Access is set to Bidirectional.
16502 16503 16504 16505 16506 16507 16508 16509 16510 |
# File 'lib/aws-sdk-ec2/types.rb', line 16502 class CreateVpcBlockPublicAccessExclusionRequest < Struct.new( :dry_run, :subnet_id, :vpc_id, :internet_gateway_exclusion_mode, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#subnet_id ⇒ String
A subnet ID.
16502 16503 16504 16505 16506 16507 16508 16509 16510 |
# File 'lib/aws-sdk-ec2/types.rb', line 16502 class CreateVpcBlockPublicAccessExclusionRequest < Struct.new( :dry_run, :subnet_id, :vpc_id, :internet_gateway_exclusion_mode, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
‘tag` - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key `Owner` and the value `TeamA`, specify `tag:Owner` for the filter name and `TeamA` for the filter value.
16502 16503 16504 16505 16506 16507 16508 16509 16510 |
# File 'lib/aws-sdk-ec2/types.rb', line 16502 class CreateVpcBlockPublicAccessExclusionRequest < Struct.new( :dry_run, :subnet_id, :vpc_id, :internet_gateway_exclusion_mode, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
A VPC ID.
16502 16503 16504 16505 16506 16507 16508 16509 16510 |
# File 'lib/aws-sdk-ec2/types.rb', line 16502 class CreateVpcBlockPublicAccessExclusionRequest < Struct.new( :dry_run, :subnet_id, :vpc_id, :internet_gateway_exclusion_mode, :tag_specifications) SENSITIVE = [] include Aws::Structure end |