Class: Aws::EC2::Types::CreateVpcEncryptionControlRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


16938
16939
16940
16941
16942
16943
16944
# File 'lib/aws-sdk-ec2/types.rb', line 16938

class CreateVpcEncryptionControlRequest < Struct.new(
  :dry_run,
  :vpc_id,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the VPC Encryption Control resource.

Returns:



16938
16939
16940
16941
16942
16943
16944
# File 'lib/aws-sdk-ec2/types.rb', line 16938

class CreateVpcEncryptionControlRequest < Struct.new(
  :dry_run,
  :vpc_id,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC for which to create the encryption control configuration.

Returns:

  • (String)


16938
16939
16940
16941
16942
16943
16944
# File 'lib/aws-sdk-ec2/types.rb', line 16938

class CreateVpcEncryptionControlRequest < Struct.new(
  :dry_run,
  :vpc_id,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end