Class: Aws::EC2::Types::CreateVpcEncryptionControlRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


16932
16933
16934
16935
16936
16937
16938
# File 'lib/aws-sdk-ec2/types.rb', line 16932

class CreateVpcEncryptionControlRequest < Struct.new(
  :dry_run,
  :vpc_id,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the VPC Encryption Control resource.

Returns:



16932
16933
16934
16935
16936
16937
16938
# File 'lib/aws-sdk-ec2/types.rb', line 16932

class CreateVpcEncryptionControlRequest < Struct.new(
  :dry_run,
  :vpc_id,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC for which to create the encryption control configuration.

Returns:

  • (String)


16932
16933
16934
16935
16936
16937
16938
# File 'lib/aws-sdk-ec2/types.rb', line 16932

class CreateVpcEncryptionControlRequest < Struct.new(
  :dry_run,
  :vpc_id,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end