Class: Aws::EC2::Types::CreateVpcEndpointConnectionNotificationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateVpcEndpointConnectionNotificationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#connection_events ⇒ Array<String>
The endpoint events for which to receive notifications.
-
#connection_notification_arn ⇒ String
The ARN of the SNS topic for the notifications.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#service_id ⇒ String
The ID of the endpoint service.
-
#vpc_endpoint_id ⇒ String
The ID of the endpoint.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency.
18053 18054 18055 18056 18057 18058 18059 18060 18061 18062 |
# File 'lib/aws-sdk-ec2/types.rb', line 18053 class CreateVpcEndpointConnectionNotificationRequest < Struct.new( :dry_run, :service_id, :vpc_endpoint_id, :connection_notification_arn, :connection_events, :client_token) SENSITIVE = [] include Aws::Structure end |
#connection_events ⇒ Array<String>
The endpoint events for which to receive notifications. Valid values
are Accept, Connect, Delete, and Reject.
18053 18054 18055 18056 18057 18058 18059 18060 18061 18062 |
# File 'lib/aws-sdk-ec2/types.rb', line 18053 class CreateVpcEndpointConnectionNotificationRequest < Struct.new( :dry_run, :service_id, :vpc_endpoint_id, :connection_notification_arn, :connection_events, :client_token) SENSITIVE = [] include Aws::Structure end |
#connection_notification_arn ⇒ String
The ARN of the SNS topic for the notifications.
18053 18054 18055 18056 18057 18058 18059 18060 18061 18062 |
# File 'lib/aws-sdk-ec2/types.rb', line 18053 class CreateVpcEndpointConnectionNotificationRequest < Struct.new( :dry_run, :service_id, :vpc_endpoint_id, :connection_notification_arn, :connection_events, :client_token) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
18053 18054 18055 18056 18057 18058 18059 18060 18061 18062 |
# File 'lib/aws-sdk-ec2/types.rb', line 18053 class CreateVpcEndpointConnectionNotificationRequest < Struct.new( :dry_run, :service_id, :vpc_endpoint_id, :connection_notification_arn, :connection_events, :client_token) SENSITIVE = [] include Aws::Structure end |
#service_id ⇒ String
The ID of the endpoint service.
18053 18054 18055 18056 18057 18058 18059 18060 18061 18062 |
# File 'lib/aws-sdk-ec2/types.rb', line 18053 class CreateVpcEndpointConnectionNotificationRequest < Struct.new( :dry_run, :service_id, :vpc_endpoint_id, :connection_notification_arn, :connection_events, :client_token) SENSITIVE = [] include Aws::Structure end |
#vpc_endpoint_id ⇒ String
The ID of the endpoint.
18053 18054 18055 18056 18057 18058 18059 18060 18061 18062 |
# File 'lib/aws-sdk-ec2/types.rb', line 18053 class CreateVpcEndpointConnectionNotificationRequest < Struct.new( :dry_run, :service_id, :vpc_endpoint_id, :connection_notification_arn, :connection_events, :client_token) SENSITIVE = [] include Aws::Structure end |