Class: Aws::EC2::Types::CreateVpcEndpointConnectionNotificationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency.

Returns:

  • (String)


17192
17193
17194
17195
17196
17197
17198
17199
17200
17201
# File 'lib/aws-sdk-ec2/types.rb', line 17192

class CreateVpcEndpointConnectionNotificationRequest < Struct.new(
  :dry_run,
  :service_id,
  :vpc_endpoint_id,
  :connection_notification_arn,
  :connection_events,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#connection_eventsArray<String>

The endpoint events for which to receive notifications. Valid values are Accept, Connect, Delete, and Reject.

Returns:

  • (Array<String>)


17192
17193
17194
17195
17196
17197
17198
17199
17200
17201
# File 'lib/aws-sdk-ec2/types.rb', line 17192

class CreateVpcEndpointConnectionNotificationRequest < Struct.new(
  :dry_run,
  :service_id,
  :vpc_endpoint_id,
  :connection_notification_arn,
  :connection_events,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#connection_notification_arnString

The ARN of the SNS topic for the notifications.

Returns:

  • (String)


17192
17193
17194
17195
17196
17197
17198
17199
17200
17201
# File 'lib/aws-sdk-ec2/types.rb', line 17192

class CreateVpcEndpointConnectionNotificationRequest < Struct.new(
  :dry_run,
  :service_id,
  :vpc_endpoint_id,
  :connection_notification_arn,
  :connection_events,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


17192
17193
17194
17195
17196
17197
17198
17199
17200
17201
# File 'lib/aws-sdk-ec2/types.rb', line 17192

class CreateVpcEndpointConnectionNotificationRequest < Struct.new(
  :dry_run,
  :service_id,
  :vpc_endpoint_id,
  :connection_notification_arn,
  :connection_events,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#service_idString

The ID of the endpoint service.

Returns:

  • (String)


17192
17193
17194
17195
17196
17197
17198
17199
17200
17201
# File 'lib/aws-sdk-ec2/types.rb', line 17192

class CreateVpcEndpointConnectionNotificationRequest < Struct.new(
  :dry_run,
  :service_id,
  :vpc_endpoint_id,
  :connection_notification_arn,
  :connection_events,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_endpoint_idString

The ID of the endpoint.

Returns:

  • (String)


17192
17193
17194
17195
17196
17197
17198
17199
17200
17201
# File 'lib/aws-sdk-ec2/types.rb', line 17192

class CreateVpcEndpointConnectionNotificationRequest < Struct.new(
  :dry_run,
  :service_id,
  :vpc_endpoint_id,
  :connection_notification_arn,
  :connection_events,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end