Class: Aws::EC2::Types::CreateVpcEndpointServiceConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateVpcEndpointServiceConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#acceptance_required ⇒ Boolean
Indicates whether requests from service consumers to create an endpoint to your service must be accepted manually.
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#gateway_load_balancer_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the Gateway Load Balancers.
-
#network_load_balancer_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the Network Load Balancers.
-
#private_dns_name ⇒ String
(Interface endpoint configuration) The private DNS name to assign to the VPC endpoint service.
-
#supported_ip_address_types ⇒ Array<String>
The supported IP address types.
-
#supported_regions ⇒ Array<String>
The Regions from which service consumers can access the service.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to associate with the service.
Instance Attribute Details
#acceptance_required ⇒ Boolean
Indicates whether requests from service consumers to create an endpoint to your service must be accepted manually.
17264 17265 17266 17267 17268 17269 17270 17271 17272 17273 17274 17275 17276 |
# File 'lib/aws-sdk-ec2/types.rb', line 17264 class CreateVpcEndpointServiceConfigurationRequest < Struct.new( :dry_run, :acceptance_required, :private_dns_name, :network_load_balancer_arns, :gateway_load_balancer_arns, :supported_ip_address_types, :supported_regions, :client_token, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency.
17264 17265 17266 17267 17268 17269 17270 17271 17272 17273 17274 17275 17276 |
# File 'lib/aws-sdk-ec2/types.rb', line 17264 class CreateVpcEndpointServiceConfigurationRequest < Struct.new( :dry_run, :acceptance_required, :private_dns_name, :network_load_balancer_arns, :gateway_load_balancer_arns, :supported_ip_address_types, :supported_regions, :client_token, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
17264 17265 17266 17267 17268 17269 17270 17271 17272 17273 17274 17275 17276 |
# File 'lib/aws-sdk-ec2/types.rb', line 17264 class CreateVpcEndpointServiceConfigurationRequest < Struct.new( :dry_run, :acceptance_required, :private_dns_name, :network_load_balancer_arns, :gateway_load_balancer_arns, :supported_ip_address_types, :supported_regions, :client_token, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#gateway_load_balancer_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the Gateway Load Balancers.
17264 17265 17266 17267 17268 17269 17270 17271 17272 17273 17274 17275 17276 |
# File 'lib/aws-sdk-ec2/types.rb', line 17264 class CreateVpcEndpointServiceConfigurationRequest < Struct.new( :dry_run, :acceptance_required, :private_dns_name, :network_load_balancer_arns, :gateway_load_balancer_arns, :supported_ip_address_types, :supported_regions, :client_token, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#network_load_balancer_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the Network Load Balancers.
17264 17265 17266 17267 17268 17269 17270 17271 17272 17273 17274 17275 17276 |
# File 'lib/aws-sdk-ec2/types.rb', line 17264 class CreateVpcEndpointServiceConfigurationRequest < Struct.new( :dry_run, :acceptance_required, :private_dns_name, :network_load_balancer_arns, :gateway_load_balancer_arns, :supported_ip_address_types, :supported_regions, :client_token, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#private_dns_name ⇒ String
(Interface endpoint configuration) The private DNS name to assign to the VPC endpoint service.
17264 17265 17266 17267 17268 17269 17270 17271 17272 17273 17274 17275 17276 |
# File 'lib/aws-sdk-ec2/types.rb', line 17264 class CreateVpcEndpointServiceConfigurationRequest < Struct.new( :dry_run, :acceptance_required, :private_dns_name, :network_load_balancer_arns, :gateway_load_balancer_arns, :supported_ip_address_types, :supported_regions, :client_token, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#supported_ip_address_types ⇒ Array<String>
The supported IP address types. The possible values are ipv4 and
ipv6.
17264 17265 17266 17267 17268 17269 17270 17271 17272 17273 17274 17275 17276 |
# File 'lib/aws-sdk-ec2/types.rb', line 17264 class CreateVpcEndpointServiceConfigurationRequest < Struct.new( :dry_run, :acceptance_required, :private_dns_name, :network_load_balancer_arns, :gateway_load_balancer_arns, :supported_ip_address_types, :supported_regions, :client_token, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#supported_regions ⇒ Array<String>
The Regions from which service consumers can access the service.
17264 17265 17266 17267 17268 17269 17270 17271 17272 17273 17274 17275 17276 |
# File 'lib/aws-sdk-ec2/types.rb', line 17264 class CreateVpcEndpointServiceConfigurationRequest < Struct.new( :dry_run, :acceptance_required, :private_dns_name, :network_load_balancer_arns, :gateway_load_balancer_arns, :supported_ip_address_types, :supported_regions, :client_token, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to associate with the service.
17264 17265 17266 17267 17268 17269 17270 17271 17272 17273 17274 17275 17276 |
# File 'lib/aws-sdk-ec2/types.rb', line 17264 class CreateVpcEndpointServiceConfigurationRequest < Struct.new( :dry_run, :acceptance_required, :private_dns_name, :network_load_balancer_arns, :gateway_load_balancer_arns, :supported_ip_address_types, :supported_regions, :client_token, :tag_specifications) SENSITIVE = [] include Aws::Structure end |