Class: Aws::EC2::Types::CreateVpcEndpointServiceConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#acceptance_requiredBoolean

Indicates whether requests from service consumers to create an endpoint to your service must be accepted manually.

Returns:

  • (Boolean)


17258
17259
17260
17261
17262
17263
17264
17265
17266
17267
17268
17269
17270
# File 'lib/aws-sdk-ec2/types.rb', line 17258

class CreateVpcEndpointServiceConfigurationRequest < Struct.new(
  :dry_run,
  :acceptance_required,
  :private_dns_name,
  :network_load_balancer_arns,
  :gateway_load_balancer_arns,
  :supported_ip_address_types,
  :supported_regions,
  :client_token,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [How to ensure idempotency].

[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html

Returns:

  • (String)


17258
17259
17260
17261
17262
17263
17264
17265
17266
17267
17268
17269
17270
# File 'lib/aws-sdk-ec2/types.rb', line 17258

class CreateVpcEndpointServiceConfigurationRequest < Struct.new(
  :dry_run,
  :acceptance_required,
  :private_dns_name,
  :network_load_balancer_arns,
  :gateway_load_balancer_arns,
  :supported_ip_address_types,
  :supported_regions,
  :client_token,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


17258
17259
17260
17261
17262
17263
17264
17265
17266
17267
17268
17269
17270
# File 'lib/aws-sdk-ec2/types.rb', line 17258

class CreateVpcEndpointServiceConfigurationRequest < Struct.new(
  :dry_run,
  :acceptance_required,
  :private_dns_name,
  :network_load_balancer_arns,
  :gateway_load_balancer_arns,
  :supported_ip_address_types,
  :supported_regions,
  :client_token,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#gateway_load_balancer_arnsArray<String>

The Amazon Resource Names (ARNs) of the Gateway Load Balancers.

Returns:

  • (Array<String>)


17258
17259
17260
17261
17262
17263
17264
17265
17266
17267
17268
17269
17270
# File 'lib/aws-sdk-ec2/types.rb', line 17258

class CreateVpcEndpointServiceConfigurationRequest < Struct.new(
  :dry_run,
  :acceptance_required,
  :private_dns_name,
  :network_load_balancer_arns,
  :gateway_load_balancer_arns,
  :supported_ip_address_types,
  :supported_regions,
  :client_token,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#network_load_balancer_arnsArray<String>

The Amazon Resource Names (ARNs) of the Network Load Balancers.

Returns:

  • (Array<String>)


17258
17259
17260
17261
17262
17263
17264
17265
17266
17267
17268
17269
17270
# File 'lib/aws-sdk-ec2/types.rb', line 17258

class CreateVpcEndpointServiceConfigurationRequest < Struct.new(
  :dry_run,
  :acceptance_required,
  :private_dns_name,
  :network_load_balancer_arns,
  :gateway_load_balancer_arns,
  :supported_ip_address_types,
  :supported_regions,
  :client_token,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#private_dns_nameString

(Interface endpoint configuration) The private DNS name to assign to the VPC endpoint service.

Returns:

  • (String)


17258
17259
17260
17261
17262
17263
17264
17265
17266
17267
17268
17269
17270
# File 'lib/aws-sdk-ec2/types.rb', line 17258

class CreateVpcEndpointServiceConfigurationRequest < Struct.new(
  :dry_run,
  :acceptance_required,
  :private_dns_name,
  :network_load_balancer_arns,
  :gateway_load_balancer_arns,
  :supported_ip_address_types,
  :supported_regions,
  :client_token,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#supported_ip_address_typesArray<String>

The supported IP address types. The possible values are ‘ipv4` and `ipv6`.

Returns:

  • (Array<String>)


17258
17259
17260
17261
17262
17263
17264
17265
17266
17267
17268
17269
17270
# File 'lib/aws-sdk-ec2/types.rb', line 17258

class CreateVpcEndpointServiceConfigurationRequest < Struct.new(
  :dry_run,
  :acceptance_required,
  :private_dns_name,
  :network_load_balancer_arns,
  :gateway_load_balancer_arns,
  :supported_ip_address_types,
  :supported_regions,
  :client_token,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#supported_regionsArray<String>

The Regions from which service consumers can access the service.

Returns:

  • (Array<String>)


17258
17259
17260
17261
17262
17263
17264
17265
17266
17267
17268
17269
17270
# File 'lib/aws-sdk-ec2/types.rb', line 17258

class CreateVpcEndpointServiceConfigurationRequest < Struct.new(
  :dry_run,
  :acceptance_required,
  :private_dns_name,
  :network_load_balancer_arns,
  :gateway_load_balancer_arns,
  :supported_ip_address_types,
  :supported_regions,
  :client_token,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to associate with the service.

Returns:



17258
17259
17260
17261
17262
17263
17264
17265
17266
17267
17268
17269
17270
# File 'lib/aws-sdk-ec2/types.rb', line 17258

class CreateVpcEndpointServiceConfigurationRequest < Struct.new(
  :dry_run,
  :acceptance_required,
  :private_dns_name,
  :network_load_balancer_arns,
  :gateway_load_balancer_arns,
  :supported_ip_address_types,
  :supported_regions,
  :client_token,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end