Class: Aws::EC2::Types::CreateVpnConcentratorRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateVpnConcentratorRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the VPN concentrator during creation.
-
#transit_gateway_id ⇒ String
The ID of the transit gateway to attach the VPN concentrator to.
-
#type ⇒ String
The type of VPN concentrator to create.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
17527 17528 17529 17530 17531 17532 17533 17534 |
# File 'lib/aws-sdk-ec2/types.rb', line 17527 class CreateVpnConcentratorRequest < Struct.new( :type, :transit_gateway_id, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the VPN concentrator during creation.
17527 17528 17529 17530 17531 17532 17533 17534 |
# File 'lib/aws-sdk-ec2/types.rb', line 17527 class CreateVpnConcentratorRequest < Struct.new( :type, :transit_gateway_id, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_id ⇒ String
The ID of the transit gateway to attach the VPN concentrator to.
17527 17528 17529 17530 17531 17532 17533 17534 |
# File 'lib/aws-sdk-ec2/types.rb', line 17527 class CreateVpnConcentratorRequest < Struct.new( :type, :transit_gateway_id, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of VPN concentrator to create.
17527 17528 17529 17530 17531 17532 17533 17534 |
# File 'lib/aws-sdk-ec2/types.rb', line 17527 class CreateVpnConcentratorRequest < Struct.new( :type, :transit_gateway_id, :tag_specifications, :dry_run) SENSITIVE = [] include Aws::Structure end |