Class: Aws::EC2::Types::CreateVpnConcentratorRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


17082
17083
17084
17085
17086
17087
17088
17089
# File 'lib/aws-sdk-ec2/types.rb', line 17082

class CreateVpnConcentratorRequest < Struct.new(
  :type,
  :transit_gateway_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the VPN concentrator during creation.

Returns:



17082
17083
17084
17085
17086
17087
17088
17089
# File 'lib/aws-sdk-ec2/types.rb', line 17082

class CreateVpnConcentratorRequest < Struct.new(
  :type,
  :transit_gateway_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_idString

The ID of the transit gateway to attach the VPN concentrator to.

Returns:

  • (String)


17082
17083
17084
17085
17086
17087
17088
17089
# File 'lib/aws-sdk-ec2/types.rb', line 17082

class CreateVpnConcentratorRequest < Struct.new(
  :type,
  :transit_gateway_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of VPN concentrator to create.

Returns:

  • (String)


17082
17083
17084
17085
17086
17087
17088
17089
# File 'lib/aws-sdk-ec2/types.rb', line 17082

class CreateVpnConcentratorRequest < Struct.new(
  :type,
  :transit_gateway_id,
  :tag_specifications,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end