Class: Aws::EC2::Types::CreateVpnConnectionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateVpnConnectionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for CreateVpnConnection.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#customer_gateway_id ⇒ String
The ID of the customer gateway.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#options ⇒ Types::VpnConnectionOptionsSpecification
The options for the VPN connection.
-
#pre_shared_key_storage ⇒ String
Specifies the storage mode for the pre-shared key (PSK).
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the VPN connection.
-
#transit_gateway_id ⇒ String
The ID of the transit gateway.
-
#type ⇒ String
The type of VPN connection (‘ipsec.1`).
-
#vpn_concentrator_id ⇒ String
The ID of the VPN concentrator to associate with the VPN connection.
-
#vpn_gateway_id ⇒ String
The ID of the virtual private gateway.
Instance Attribute Details
#customer_gateway_id ⇒ String
The ID of the customer gateway.
17540 17541 17542 17543 17544 17545 17546 17547 17548 17549 17550 17551 17552 |
# File 'lib/aws-sdk-ec2/types.rb', line 17540 class CreateVpnConnectionRequest < Struct.new( :customer_gateway_id, :type, :vpn_gateway_id, :transit_gateway_id, :vpn_concentrator_id, :tag_specifications, :pre_shared_key_storage, :dry_run, :options) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
17540 17541 17542 17543 17544 17545 17546 17547 17548 17549 17550 17551 17552 |
# File 'lib/aws-sdk-ec2/types.rb', line 17540 class CreateVpnConnectionRequest < Struct.new( :customer_gateway_id, :type, :vpn_gateway_id, :transit_gateway_id, :vpn_concentrator_id, :tag_specifications, :pre_shared_key_storage, :dry_run, :options) SENSITIVE = [] include Aws::Structure end |
#options ⇒ Types::VpnConnectionOptionsSpecification
The options for the VPN connection.
17540 17541 17542 17543 17544 17545 17546 17547 17548 17549 17550 17551 17552 |
# File 'lib/aws-sdk-ec2/types.rb', line 17540 class CreateVpnConnectionRequest < Struct.new( :customer_gateway_id, :type, :vpn_gateway_id, :transit_gateway_id, :vpn_concentrator_id, :tag_specifications, :pre_shared_key_storage, :dry_run, :options) SENSITIVE = [] include Aws::Structure end |
#pre_shared_key_storage ⇒ String
Specifies the storage mode for the pre-shared key (PSK). Valid values are ‘Standard`“ (stored in the Site-to-Site VPN service) or `SecretsManager` (stored in Amazon Web Services Secrets Manager).
17540 17541 17542 17543 17544 17545 17546 17547 17548 17549 17550 17551 17552 |
# File 'lib/aws-sdk-ec2/types.rb', line 17540 class CreateVpnConnectionRequest < Struct.new( :customer_gateway_id, :type, :vpn_gateway_id, :transit_gateway_id, :vpn_concentrator_id, :tag_specifications, :pre_shared_key_storage, :dry_run, :options) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the VPN connection.
17540 17541 17542 17543 17544 17545 17546 17547 17548 17549 17550 17551 17552 |
# File 'lib/aws-sdk-ec2/types.rb', line 17540 class CreateVpnConnectionRequest < Struct.new( :customer_gateway_id, :type, :vpn_gateway_id, :transit_gateway_id, :vpn_concentrator_id, :tag_specifications, :pre_shared_key_storage, :dry_run, :options) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_id ⇒ String
The ID of the transit gateway. If you specify a transit gateway, you cannot specify a virtual private gateway.
17540 17541 17542 17543 17544 17545 17546 17547 17548 17549 17550 17551 17552 |
# File 'lib/aws-sdk-ec2/types.rb', line 17540 class CreateVpnConnectionRequest < Struct.new( :customer_gateway_id, :type, :vpn_gateway_id, :transit_gateway_id, :vpn_concentrator_id, :tag_specifications, :pre_shared_key_storage, :dry_run, :options) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of VPN connection (‘ipsec.1`).
17540 17541 17542 17543 17544 17545 17546 17547 17548 17549 17550 17551 17552 |
# File 'lib/aws-sdk-ec2/types.rb', line 17540 class CreateVpnConnectionRequest < Struct.new( :customer_gateway_id, :type, :vpn_gateway_id, :transit_gateway_id, :vpn_concentrator_id, :tag_specifications, :pre_shared_key_storage, :dry_run, :options) SENSITIVE = [] include Aws::Structure end |
#vpn_concentrator_id ⇒ String
The ID of the VPN concentrator to associate with the VPN connection.
17540 17541 17542 17543 17544 17545 17546 17547 17548 17549 17550 17551 17552 |
# File 'lib/aws-sdk-ec2/types.rb', line 17540 class CreateVpnConnectionRequest < Struct.new( :customer_gateway_id, :type, :vpn_gateway_id, :transit_gateway_id, :vpn_concentrator_id, :tag_specifications, :pre_shared_key_storage, :dry_run, :options) SENSITIVE = [] include Aws::Structure end |
#vpn_gateway_id ⇒ String
The ID of the virtual private gateway. If you specify a virtual private gateway, you cannot specify a transit gateway.
17540 17541 17542 17543 17544 17545 17546 17547 17548 17549 17550 17551 17552 |
# File 'lib/aws-sdk-ec2/types.rb', line 17540 class CreateVpnConnectionRequest < Struct.new( :customer_gateway_id, :type, :vpn_gateway_id, :transit_gateway_id, :vpn_concentrator_id, :tag_specifications, :pre_shared_key_storage, :dry_run, :options) SENSITIVE = [] include Aws::Structure end |