Class: Aws::EC2::Types::CreateVpnGatewayRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::CreateVpnGatewayRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for CreateVpnGateway.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#amazon_side_asn ⇒ Integer
A private Autonomous System Number (ASN) for the Amazon side of a BGP session.
-
#availability_zone ⇒ String
The Availability Zone for the virtual private gateway.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the virtual private gateway.
-
#type ⇒ String
The type of VPN connection this virtual private gateway supports.
Instance Attribute Details
#amazon_side_asn ⇒ Integer
A private Autonomous System Number (ASN) for the Amazon side of a BGP session. If you’re using a 16-bit ASN, it must be in the 64512 to 65534 range. If you’re using a 32-bit ASN, it must be in the 4200000000 to 4294967294 range.
Default: 64512
17002 17003 17004 17005 17006 17007 17008 17009 17010 |
# File 'lib/aws-sdk-ec2/types.rb', line 17002 class CreateVpnGatewayRequest < Struct.new( :availability_zone, :type, :tag_specifications, :amazon_side_asn, :dry_run) SENSITIVE = [] include Aws::Structure end |
#availability_zone ⇒ String
The Availability Zone for the virtual private gateway.
17002 17003 17004 17005 17006 17007 17008 17009 17010 |
# File 'lib/aws-sdk-ec2/types.rb', line 17002 class CreateVpnGatewayRequest < Struct.new( :availability_zone, :type, :tag_specifications, :amazon_side_asn, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
17002 17003 17004 17005 17006 17007 17008 17009 17010 |
# File 'lib/aws-sdk-ec2/types.rb', line 17002 class CreateVpnGatewayRequest < Struct.new( :availability_zone, :type, :tag_specifications, :amazon_side_asn, :dry_run) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the virtual private gateway.
17002 17003 17004 17005 17006 17007 17008 17009 17010 |
# File 'lib/aws-sdk-ec2/types.rb', line 17002 class CreateVpnGatewayRequest < Struct.new( :availability_zone, :type, :tag_specifications, :amazon_side_asn, :dry_run) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of VPN connection this virtual private gateway supports.
17002 17003 17004 17005 17006 17007 17008 17009 17010 |
# File 'lib/aws-sdk-ec2/types.rb', line 17002 class CreateVpnGatewayRequest < Struct.new( :availability_zone, :type, :tag_specifications, :amazon_side_asn, :dry_run) SENSITIVE = [] include Aws::Structure end |