Class: Aws::EC2::Types::DeleteApplicationStatusCheckRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteApplicationStatusCheckRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_status_check_id ⇒ String
The ID of the application status check to delete.
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
Instance Attribute Details
#application_status_check_id ⇒ String
The ID of the application status check to delete.
19091 19092 19093 19094 19095 19096 19097 |
# File 'lib/aws-sdk-ec2/types.rb', line 19091 class DeleteApplicationStatusCheckRequest < Struct.new( :application_status_check_id, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring idempotency.
A suitable default value is auto-generated. You should normally not need to pass this option.
19091 19092 19093 19094 19095 19096 19097 |
# File 'lib/aws-sdk-ec2/types.rb', line 19091 class DeleteApplicationStatusCheckRequest < Struct.new( :application_status_check_id, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
19091 19092 19093 19094 19095 19096 19097 |
# File 'lib/aws-sdk-ec2/types.rb', line 19091 class DeleteApplicationStatusCheckRequest < Struct.new( :application_status_check_id, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |