Class: Aws::EC2::Types::DeleteApplicationStatusCheckRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_status_check_idString

The ID of the application status check to delete.

Returns:

  • (String)


18872
18873
18874
18875
18876
18877
18878
# File 'lib/aws-sdk-ec2/types.rb', line 18872

class DeleteApplicationStatusCheckRequest < Struct.new(
  :application_status_check_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


18872
18873
18874
18875
18876
18877
18878
# File 'lib/aws-sdk-ec2/types.rb', line 18872

class DeleteApplicationStatusCheckRequest < Struct.new(
  :application_status_check_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


18872
18873
18874
18875
18876
18877
18878
# File 'lib/aws-sdk-ec2/types.rb', line 18872

class DeleteApplicationStatusCheckRequest < Struct.new(
  :application_status_check_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end