Class: Aws::EC2::Types::DeleteCapacityManagerDataExportRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteCapacityManagerDataExportRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_manager_data_export_id ⇒ String
The unique identifier of the data export configuration to delete.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#capacity_manager_data_export_id ⇒ String
The unique identifier of the data export configuration to delete.
18905 18906 18907 18908 18909 18910 |
# File 'lib/aws-sdk-ec2/types.rb', line 18905 class DeleteCapacityManagerDataExportRequest < Struct.new( :capacity_manager_data_export_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
18905 18906 18907 18908 18909 18910 |
# File 'lib/aws-sdk-ec2/types.rb', line 18905 class DeleteCapacityManagerDataExportRequest < Struct.new( :capacity_manager_data_export_id, :dry_run) SENSITIVE = [] include Aws::Structure end |