Class: Aws::EC2::Types::DeleteCapacityManagerDataExportRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_manager_data_export_idString

The unique identifier of the data export configuration to delete.

Returns:

  • (String)


17769
17770
17771
17772
17773
17774
# File 'lib/aws-sdk-ec2/types.rb', line 17769

class DeleteCapacityManagerDataExportRequest < Struct.new(
  :capacity_manager_data_export_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


17769
17770
17771
17772
17773
17774
# File 'lib/aws-sdk-ec2/types.rb', line 17769

class DeleteCapacityManagerDataExportRequest < Struct.new(
  :capacity_manager_data_export_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end