Class: Aws::EC2::Types::DeleteCapacityManagerDataExportResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteCapacityManagerDataExportResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_manager_data_export_id ⇒ String
The unique identifier of the deleted data export configuration.
Instance Attribute Details
#capacity_manager_data_export_id ⇒ String
The unique identifier of the deleted data export configuration.
17334 17335 17336 17337 17338 |
# File 'lib/aws-sdk-ec2/types.rb', line 17334 class DeleteCapacityManagerDataExportResult < Struct.new( :capacity_manager_data_export_id) SENSITIVE = [] include Aws::Structure end |