Class: Aws::EC2::Types::DeleteCarrierGatewayRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteCarrierGatewayRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#carrier_gateway_id ⇒ String
The ID of the carrier gateway.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#carrier_gateway_id ⇒ String
The ID of the carrier gateway.
18264 18265 18266 18267 18268 18269 |
# File 'lib/aws-sdk-ec2/types.rb', line 18264 class DeleteCarrierGatewayRequest < Struct.new( :carrier_gateway_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
18264 18265 18266 18267 18268 18269 |
# File 'lib/aws-sdk-ec2/types.rb', line 18264 class DeleteCarrierGatewayRequest < Struct.new( :carrier_gateway_id, :dry_run) SENSITIVE = [] include Aws::Structure end |