Class: Aws::EC2::Types::DeleteCarrierGatewayRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#carrier_gateway_idString

The ID of the carrier gateway.

Returns:

  • (String)


18005
18006
18007
18008
18009
18010
# File 'lib/aws-sdk-ec2/types.rb', line 18005

class DeleteCarrierGatewayRequest < Struct.new(
  :carrier_gateway_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


18005
18006
18007
18008
18009
18010
# File 'lib/aws-sdk-ec2/types.rb', line 18005

class DeleteCarrierGatewayRequest < Struct.new(
  :carrier_gateway_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end