Class: Aws::EC2::Types::DeleteCarrierGatewayRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#carrier_gateway_idString

The ID of the carrier gateway.

Returns:

  • (String)


17801
17802
17803
17804
17805
17806
# File 'lib/aws-sdk-ec2/types.rb', line 17801

class DeleteCarrierGatewayRequest < Struct.new(
  :carrier_gateway_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


17801
17802
17803
17804
17805
17806
# File 'lib/aws-sdk-ec2/types.rb', line 17801

class DeleteCarrierGatewayRequest < Struct.new(
  :carrier_gateway_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end