Class: Aws::EC2::Types::DeleteClientVpnEndpointRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_vpn_endpoint_idString

The ID of the Client VPN to be deleted.

Returns:

  • (String)


18043
18044
18045
18046
18047
18048
# File 'lib/aws-sdk-ec2/types.rb', line 18043

class DeleteClientVpnEndpointRequest < Struct.new(
  :client_vpn_endpoint_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


18043
18044
18045
18046
18047
18048
# File 'lib/aws-sdk-ec2/types.rb', line 18043

class DeleteClientVpnEndpointRequest < Struct.new(
  :client_vpn_endpoint_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end