Class: Aws::EC2::Types::DeleteClientVpnEndpointRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteClientVpnEndpointRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_vpn_endpoint_id ⇒ String
The ID of the Client VPN to be deleted.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#client_vpn_endpoint_id ⇒ String
The ID of the Client VPN to be deleted.
17845 17846 17847 17848 17849 17850 |
# File 'lib/aws-sdk-ec2/types.rb', line 17845 class DeleteClientVpnEndpointRequest < Struct.new( :client_vpn_endpoint_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
17845 17846 17847 17848 17849 17850 |
# File 'lib/aws-sdk-ec2/types.rb', line 17845 class DeleteClientVpnEndpointRequest < Struct.new( :client_vpn_endpoint_id, :dry_run) SENSITIVE = [] include Aws::Structure end |