Class: Aws::EC2::Types::DeleteClientVpnRouteRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_vpn_endpoint_idString

The ID of the Client VPN endpoint from which the route is to be deleted.

Returns:

  • (String)


17433
17434
17435
17436
17437
17438
17439
17440
# File 'lib/aws-sdk-ec2/types.rb', line 17433

class DeleteClientVpnRouteRequest < Struct.new(
  :client_vpn_endpoint_id,
  :target_vpc_subnet_id,
  :destination_cidr_block,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#destination_cidr_blockString

The IPv4 address range, in CIDR notation, of the route to be deleted.

Returns:

  • (String)


17433
17434
17435
17436
17437
17438
17439
17440
# File 'lib/aws-sdk-ec2/types.rb', line 17433

class DeleteClientVpnRouteRequest < Struct.new(
  :client_vpn_endpoint_id,
  :target_vpc_subnet_id,
  :destination_cidr_block,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


17433
17434
17435
17436
17437
17438
17439
17440
# File 'lib/aws-sdk-ec2/types.rb', line 17433

class DeleteClientVpnRouteRequest < Struct.new(
  :client_vpn_endpoint_id,
  :target_vpc_subnet_id,
  :destination_cidr_block,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#target_vpc_subnet_idString

The ID of the target subnet used by the route.

Returns:

  • (String)


17433
17434
17435
17436
17437
17438
17439
17440
# File 'lib/aws-sdk-ec2/types.rb', line 17433

class DeleteClientVpnRouteRequest < Struct.new(
  :client_vpn_endpoint_id,
  :target_vpc_subnet_id,
  :destination_cidr_block,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end