Class: Aws::EC2::Types::DeleteCoipCidrRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteCoipCidrRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cidr ⇒ String
A customer-owned IP address range that you want to delete.
-
#coip_pool_id ⇒ String
The ID of the customer-owned address pool.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#cidr ⇒ String
A customer-owned IP address range that you want to delete.
17913 17914 17915 17916 17917 17918 17919 |
# File 'lib/aws-sdk-ec2/types.rb', line 17913 class DeleteCoipCidrRequest < Struct.new( :cidr, :coip_pool_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#coip_pool_id ⇒ String
The ID of the customer-owned address pool.
17913 17914 17915 17916 17917 17918 17919 |
# File 'lib/aws-sdk-ec2/types.rb', line 17913 class DeleteCoipCidrRequest < Struct.new( :cidr, :coip_pool_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
17913 17914 17915 17916 17917 17918 17919 |
# File 'lib/aws-sdk-ec2/types.rb', line 17913 class DeleteCoipCidrRequest < Struct.new( :cidr, :coip_pool_id, :dry_run) SENSITIVE = [] include Aws::Structure end |