Class: Aws::EC2::Types::DeleteCoipCidrRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cidrString

A customer-owned IP address range that you want to delete.

Returns:

  • (String)


17471
17472
17473
17474
17475
17476
17477
# File 'lib/aws-sdk-ec2/types.rb', line 17471

class DeleteCoipCidrRequest < Struct.new(
  :cidr,
  :coip_pool_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#coip_pool_idString

The ID of the customer-owned address pool.

Returns:

  • (String)


17471
17472
17473
17474
17475
17476
17477
# File 'lib/aws-sdk-ec2/types.rb', line 17471

class DeleteCoipCidrRequest < Struct.new(
  :cidr,
  :coip_pool_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


17471
17472
17473
17474
17475
17476
17477
# File 'lib/aws-sdk-ec2/types.rb', line 17471

class DeleteCoipCidrRequest < Struct.new(
  :cidr,
  :coip_pool_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end