Class: Aws::EC2::Types::DeleteCoipPoolRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#coip_pool_idString

The ID of the CoIP pool that you want to delete.

Returns:

  • (String)


19301
19302
19303
19304
19305
19306
# File 'lib/aws-sdk-ec2/types.rb', line 19301

class DeleteCoipPoolRequest < Struct.new(
  :coip_pool_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


19301
19302
19303
19304
19305
19306
# File 'lib/aws-sdk-ec2/types.rb', line 19301

class DeleteCoipPoolRequest < Struct.new(
  :coip_pool_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end