Class: Aws::EC2::Types::DeleteCoipPoolRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteCoipPoolRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#coip_pool_id ⇒ String
The ID of the CoIP pool that you want to delete.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#coip_pool_id ⇒ String
The ID of the CoIP pool that you want to delete.
19301 19302 19303 19304 19305 19306 |
# File 'lib/aws-sdk-ec2/types.rb', line 19301 class DeleteCoipPoolRequest < Struct.new( :coip_pool_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
19301 19302 19303 19304 19305 19306 |
# File 'lib/aws-sdk-ec2/types.rb', line 19301 class DeleteCoipPoolRequest < Struct.new( :coip_pool_id, :dry_run) SENSITIVE = [] include Aws::Structure end |