Class: Aws::EC2::Types::DeleteCoipPoolRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#coip_pool_idString

The ID of the CoIP pool that you want to delete.

Returns:

  • (String)


17726
17727
17728
17729
17730
17731
# File 'lib/aws-sdk-ec2/types.rb', line 17726

class DeleteCoipPoolRequest < Struct.new(
  :coip_pool_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


17726
17727
17728
17729
17730
17731
# File 'lib/aws-sdk-ec2/types.rb', line 17726

class DeleteCoipPoolRequest < Struct.new(
  :coip_pool_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end