Class: Aws::EC2::Types::DeleteCustomerGatewayRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for DeleteCustomerGateway.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#customer_gateway_idString

The ID of the customer gateway.

Returns:

  • (String)


19116
19117
19118
19119
19120
19121
# File 'lib/aws-sdk-ec2/types.rb', line 19116

class DeleteCustomerGatewayRequest < Struct.new(
  :customer_gateway_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


19116
19117
19118
19119
19120
19121
# File 'lib/aws-sdk-ec2/types.rb', line 19116

class DeleteCustomerGatewayRequest < Struct.new(
  :customer_gateway_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end