Class: Aws::EC2::Types::DeleteCustomerGatewayRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteCustomerGatewayRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for DeleteCustomerGateway.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#customer_gateway_id ⇒ String
The ID of the customer gateway.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#customer_gateway_id ⇒ String
The ID of the customer gateway.
18190 18191 18192 18193 18194 18195 |
# File 'lib/aws-sdk-ec2/types.rb', line 18190 class DeleteCustomerGatewayRequest < Struct.new( :customer_gateway_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
18190 18191 18192 18193 18194 18195 |
# File 'lib/aws-sdk-ec2/types.rb', line 18190 class DeleteCustomerGatewayRequest < Struct.new( :customer_gateway_id, :dry_run) SENSITIVE = [] include Aws::Structure end |