Class: Aws::EC2::Types::DeleteDhcpOptionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dhcp_options_idString

The ID of the DHCP options set.

Returns:

  • (String)


18259
18260
18261
18262
18263
18264
# File 'lib/aws-sdk-ec2/types.rb', line 18259

class DeleteDhcpOptionsRequest < Struct.new(
  :dhcp_options_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


18259
18260
18261
18262
18263
18264
# File 'lib/aws-sdk-ec2/types.rb', line 18259

class DeleteDhcpOptionsRequest < Struct.new(
  :dhcp_options_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end