Class: Aws::EC2::Types::DeleteDhcpOptionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dhcp_options_idString

The ID of the DHCP options set.

Returns:

  • (String)


18210
18211
18212
18213
18214
18215
# File 'lib/aws-sdk-ec2/types.rb', line 18210

class DeleteDhcpOptionsRequest < Struct.new(
  :dhcp_options_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


18210
18211
18212
18213
18214
18215
# File 'lib/aws-sdk-ec2/types.rb', line 18210

class DeleteDhcpOptionsRequest < Struct.new(
  :dhcp_options_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end