Class: Aws::EC2::Types::DeleteDhcpOptionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteDhcpOptionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dhcp_options_id ⇒ String
The ID of the DHCP options set.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#dhcp_options_id ⇒ String
The ID of the DHCP options set.
17780 17781 17782 17783 17784 17785 |
# File 'lib/aws-sdk-ec2/types.rb', line 17780 class DeleteDhcpOptionsRequest < Struct.new( :dhcp_options_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
17780 17781 17782 17783 17784 17785 |
# File 'lib/aws-sdk-ec2/types.rb', line 17780 class DeleteDhcpOptionsRequest < Struct.new( :dhcp_options_id, :dry_run) SENSITIVE = [] include Aws::Structure end |