Class: Aws::EC2::Types::DeleteEgressOnlyInternetGatewayRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


18389
18390
18391
18392
18393
18394
# File 'lib/aws-sdk-ec2/types.rb', line 18389

class DeleteEgressOnlyInternetGatewayRequest < Struct.new(
  :dry_run,
  :egress_only_internet_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end

#egress_only_internet_gateway_idString

The ID of the egress-only internet gateway.

Returns:

  • (String)


18389
18390
18391
18392
18393
18394
# File 'lib/aws-sdk-ec2/types.rb', line 18389

class DeleteEgressOnlyInternetGatewayRequest < Struct.new(
  :dry_run,
  :egress_only_internet_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end