Class: Aws::EC2::Types::DeleteEgressOnlyInternetGatewayRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteEgressOnlyInternetGatewayRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#egress_only_internet_gateway_id ⇒ String
The ID of the egress-only internet gateway.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
18273 18274 18275 18276 18277 18278 |
# File 'lib/aws-sdk-ec2/types.rb', line 18273 class DeleteEgressOnlyInternetGatewayRequest < Struct.new( :dry_run, :egress_only_internet_gateway_id) SENSITIVE = [] include Aws::Structure end |
#egress_only_internet_gateway_id ⇒ String
The ID of the egress-only internet gateway.
18273 18274 18275 18276 18277 18278 |
# File 'lib/aws-sdk-ec2/types.rb', line 18273 class DeleteEgressOnlyInternetGatewayRequest < Struct.new( :dry_run, :egress_only_internet_gateway_id) SENSITIVE = [] include Aws::Structure end |