Class: Aws::EC2::Types::DeleteFleetsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


18130
18131
18132
18133
18134
18135
18136
# File 'lib/aws-sdk-ec2/types.rb', line 18130

class DeleteFleetsRequest < Struct.new(
  :dry_run,
  :fleet_ids,
  :terminate_instances)
  SENSITIVE = []
  include Aws::Structure
end

#fleet_idsArray<String>

The IDs of the EC2 Fleets.

Constraints: In a single request, you can specify up to 25 ‘instant` fleet IDs and up to 100 `maintain` or `request` fleet IDs.

Returns:

  • (Array<String>)


18130
18131
18132
18133
18134
18135
18136
# File 'lib/aws-sdk-ec2/types.rb', line 18130

class DeleteFleetsRequest < Struct.new(
  :dry_run,
  :fleet_ids,
  :terminate_instances)
  SENSITIVE = []
  include Aws::Structure
end

#terminate_instancesBoolean

Indicates whether to terminate the associated instances when the EC2 Fleet is deleted. The default is to terminate the instances.

To let the instances continue to run after the EC2 Fleet is deleted, specify ‘no-terminate-instances`. Supported only for fleets of type `maintain` and `request`.

For ‘instant` fleets, you cannot specify `NoTerminateInstances`. A deleted `instant` fleet with running instances is not supported.

Returns:

  • (Boolean)


18130
18131
18132
18133
18134
18135
18136
# File 'lib/aws-sdk-ec2/types.rb', line 18130

class DeleteFleetsRequest < Struct.new(
  :dry_run,
  :fleet_ids,
  :terminate_instances)
  SENSITIVE = []
  include Aws::Structure
end