Class: Aws::EC2::Types::DeleteFlowLogsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteFlowLogsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#flow_log_ids ⇒ Array<String>
One or more flow log IDs.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
18553 18554 18555 18556 18557 18558 |
# File 'lib/aws-sdk-ec2/types.rb', line 18553 class DeleteFlowLogsRequest < Struct.new( :dry_run, :flow_log_ids) SENSITIVE = [] include Aws::Structure end |
#flow_log_ids ⇒ Array<String>
One or more flow log IDs.
Constraint: Maximum of 1000 flow log IDs.
18553 18554 18555 18556 18557 18558 |
# File 'lib/aws-sdk-ec2/types.rb', line 18553 class DeleteFlowLogsRequest < Struct.new( :dry_run, :flow_log_ids) SENSITIVE = [] include Aws::Structure end |