Class: Aws::EC2::Types::DeleteFlowLogsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


18374
18375
18376
18377
18378
18379
# File 'lib/aws-sdk-ec2/types.rb', line 18374

class DeleteFlowLogsRequest < Struct.new(
  :dry_run,
  :flow_log_ids)
  SENSITIVE = []
  include Aws::Structure
end

#flow_log_idsArray<String>

One or more flow log IDs.

Constraint: Maximum of 1000 flow log IDs.

Returns:

  • (Array<String>)


18374
18375
18376
18377
18378
18379
# File 'lib/aws-sdk-ec2/types.rb', line 18374

class DeleteFlowLogsRequest < Struct.new(
  :dry_run,
  :flow_log_ids)
  SENSITIVE = []
  include Aws::Structure
end