Class: Aws::EC2::Types::DeleteFlowLogsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteFlowLogsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#flow_log_ids ⇒ Array<String>
One or more flow log IDs.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
18170 18171 18172 18173 18174 18175 |
# File 'lib/aws-sdk-ec2/types.rb', line 18170 class DeleteFlowLogsRequest < Struct.new( :dry_run, :flow_log_ids) SENSITIVE = [] include Aws::Structure end |
#flow_log_ids ⇒ Array<String>
One or more flow log IDs.
Constraint: Maximum of 1000 flow log IDs.
18170 18171 18172 18173 18174 18175 |
# File 'lib/aws-sdk-ec2/types.rb', line 18170 class DeleteFlowLogsRequest < Struct.new( :dry_run, :flow_log_ids) SENSITIVE = [] include Aws::Structure end |