Class: Aws::EC2::Types::DeleteFpgaImageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteFpgaImageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#fpga_image_id ⇒ String
The ID of the AFI.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
18456 18457 18458 18459 18460 18461 |
# File 'lib/aws-sdk-ec2/types.rb', line 18456 class DeleteFpgaImageRequest < Struct.new( :dry_run, :fpga_image_id) SENSITIVE = [] include Aws::Structure end |
#fpga_image_id ⇒ String
The ID of the AFI.
18456 18457 18458 18459 18460 18461 |
# File 'lib/aws-sdk-ec2/types.rb', line 18456 class DeleteFpgaImageRequest < Struct.new( :dry_run, :fpga_image_id) SENSITIVE = [] include Aws::Structure end |