Class: Aws::EC2::Types::DeleteFpgaImageRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


18413
18414
18415
18416
18417
18418
# File 'lib/aws-sdk-ec2/types.rb', line 18413

class DeleteFpgaImageRequest < Struct.new(
  :dry_run,
  :fpga_image_id)
  SENSITIVE = []
  include Aws::Structure
end

#fpga_image_idString

The ID of the AFI.

Returns:

  • (String)


18413
18414
18415
18416
18417
18418
# File 'lib/aws-sdk-ec2/types.rb', line 18413

class DeleteFpgaImageRequest < Struct.new(
  :dry_run,
  :fpga_image_id)
  SENSITIVE = []
  include Aws::Structure
end