Class: Aws::EC2::Types::DeleteImageUsageReportRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


19371
19372
19373
19374
19375
19376
# File 'lib/aws-sdk-ec2/types.rb', line 19371

class DeleteImageUsageReportRequest < Struct.new(
  :report_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#report_idString

The ID of the report to delete.

Returns:

  • (String)


19371
19372
19373
19374
19375
19376
# File 'lib/aws-sdk-ec2/types.rb', line 19371

class DeleteImageUsageReportRequest < Struct.new(
  :report_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end