Class: Aws::EC2::Types::DeleteImageUsageReportRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteImageUsageReportRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#report_id ⇒ String
The ID of the report to delete.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
18247 18248 18249 18250 18251 18252 |
# File 'lib/aws-sdk-ec2/types.rb', line 18247 class DeleteImageUsageReportRequest < Struct.new( :report_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#report_id ⇒ String
The ID of the report to delete.
18247 18248 18249 18250 18251 18252 |
# File 'lib/aws-sdk-ec2/types.rb', line 18247 class DeleteImageUsageReportRequest < Struct.new( :report_id, :dry_run) SENSITIVE = [] include Aws::Structure end |