Class: Aws::EC2::Types::DeleteImageUsageReportRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


18235
18236
18237
18238
18239
18240
# File 'lib/aws-sdk-ec2/types.rb', line 18235

class DeleteImageUsageReportRequest < Struct.new(
  :report_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#report_idString

The ID of the report to delete.

Returns:

  • (String)


18235
18236
18237
18238
18239
18240
# File 'lib/aws-sdk-ec2/types.rb', line 18235

class DeleteImageUsageReportRequest < Struct.new(
  :report_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end