Class: Aws::EC2::Types::DeleteInstanceConnectEndpointRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteInstanceConnectEndpointRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#instance_connect_endpoint_id ⇒ String
The ID of the EC2 Instance Connect Endpoint to delete.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
18521 18522 18523 18524 18525 18526 |
# File 'lib/aws-sdk-ec2/types.rb', line 18521 class DeleteInstanceConnectEndpointRequest < Struct.new( :dry_run, :instance_connect_endpoint_id) SENSITIVE = [] include Aws::Structure end |
#instance_connect_endpoint_id ⇒ String
The ID of the EC2 Instance Connect Endpoint to delete.
18521 18522 18523 18524 18525 18526 |
# File 'lib/aws-sdk-ec2/types.rb', line 18521 class DeleteInstanceConnectEndpointRequest < Struct.new( :dry_run, :instance_connect_endpoint_id) SENSITIVE = [] include Aws::Structure end |