Class: Aws::EC2::Types::DeleteInstanceEventWindowRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteInstanceEventWindowRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#force_delete ⇒ Boolean
Specify
trueto force delete the event window. -
#instance_event_window_id ⇒ String
The ID of the event window.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
19670 19671 19672 19673 19674 19675 19676 |
# File 'lib/aws-sdk-ec2/types.rb', line 19670 class DeleteInstanceEventWindowRequest < Struct.new( :dry_run, :force_delete, :instance_event_window_id) SENSITIVE = [] include Aws::Structure end |
#force_delete ⇒ Boolean
Specify true to force delete the event window. Use the force
delete parameter if the event window is currently associated with
targets.
19670 19671 19672 19673 19674 19675 19676 |
# File 'lib/aws-sdk-ec2/types.rb', line 19670 class DeleteInstanceEventWindowRequest < Struct.new( :dry_run, :force_delete, :instance_event_window_id) SENSITIVE = [] include Aws::Structure end |
#instance_event_window_id ⇒ String
The ID of the event window.
19670 19671 19672 19673 19674 19675 19676 |
# File 'lib/aws-sdk-ec2/types.rb', line 19670 class DeleteInstanceEventWindowRequest < Struct.new( :dry_run, :force_delete, :instance_event_window_id) SENSITIVE = [] include Aws::Structure end |