Class: Aws::EC2::Types::DeleteInstanceEventWindowRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteInstanceEventWindowRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#force_delete ⇒ Boolean
Specify ‘true` to force delete the event window.
-
#instance_event_window_id ⇒ String
The ID of the event window.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
18516 18517 18518 18519 18520 18521 18522 |
# File 'lib/aws-sdk-ec2/types.rb', line 18516 class DeleteInstanceEventWindowRequest < Struct.new( :dry_run, :force_delete, :instance_event_window_id) SENSITIVE = [] include Aws::Structure end |
#force_delete ⇒ Boolean
Specify ‘true` to force delete the event window. Use the force delete parameter if the event window is currently associated with targets.
18516 18517 18518 18519 18520 18521 18522 |
# File 'lib/aws-sdk-ec2/types.rb', line 18516 class DeleteInstanceEventWindowRequest < Struct.new( :dry_run, :force_delete, :instance_event_window_id) SENSITIVE = [] include Aws::Structure end |
#instance_event_window_id ⇒ String
The ID of the event window.
18516 18517 18518 18519 18520 18521 18522 |
# File 'lib/aws-sdk-ec2/types.rb', line 18516 class DeleteInstanceEventWindowRequest < Struct.new( :dry_run, :force_delete, :instance_event_window_id) SENSITIVE = [] include Aws::Structure end |