Class: Aws::EC2::Types::DeleteInternetGatewayRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteInternetGatewayRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#internet_gateway_id ⇒ String
The ID of the internet gateway.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
18543 18544 18545 18546 18547 18548 |
# File 'lib/aws-sdk-ec2/types.rb', line 18543 class DeleteInternetGatewayRequest < Struct.new( :dry_run, :internet_gateway_id) SENSITIVE = [] include Aws::Structure end |
#internet_gateway_id ⇒ String
The ID of the internet gateway.
18543 18544 18545 18546 18547 18548 |
# File 'lib/aws-sdk-ec2/types.rb', line 18543 class DeleteInternetGatewayRequest < Struct.new( :dry_run, :internet_gateway_id) SENSITIVE = [] include Aws::Structure end |