Class: Aws::EC2::Types::DeleteInternetGatewayRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


17897
17898
17899
17900
17901
17902
# File 'lib/aws-sdk-ec2/types.rb', line 17897

class DeleteInternetGatewayRequest < Struct.new(
  :dry_run,
  :internet_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end

#internet_gateway_idString

The ID of the internet gateway.

Returns:

  • (String)


17897
17898
17899
17900
17901
17902
# File 'lib/aws-sdk-ec2/types.rb', line 17897

class DeleteInternetGatewayRequest < Struct.new(
  :dry_run,
  :internet_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end