Class: Aws::EC2::Types::DeleteIpamExternalResourceVerificationTokenRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteIpamExternalResourceVerificationTokenRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#ipam_external_resource_verification_token_id ⇒ String
The token ID.
Instance Attribute Details
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
18563 18564 18565 18566 18567 18568 |
# File 'lib/aws-sdk-ec2/types.rb', line 18563 class DeleteIpamExternalResourceVerificationTokenRequest < Struct.new( :dry_run, :ipam_external_resource_verification_token_id) SENSITIVE = [] include Aws::Structure end |
#ipam_external_resource_verification_token_id ⇒ String
The token ID.
18563 18564 18565 18566 18567 18568 |
# File 'lib/aws-sdk-ec2/types.rb', line 18563 class DeleteIpamExternalResourceVerificationTokenRequest < Struct.new( :dry_run, :ipam_external_resource_verification_token_id) SENSITIVE = [] include Aws::Structure end |