Class: Aws::EC2::Types::DeleteIpamExternalResourceVerificationTokenRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


18359
18360
18361
18362
18363
18364
# File 'lib/aws-sdk-ec2/types.rb', line 18359

class DeleteIpamExternalResourceVerificationTokenRequest < Struct.new(
  :dry_run,
  :ipam_external_resource_verification_token_id)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_external_resource_verification_token_idString

The token ID.

Returns:

  • (String)


18359
18360
18361
18362
18363
18364
# File 'lib/aws-sdk-ec2/types.rb', line 18359

class DeleteIpamExternalResourceVerificationTokenRequest < Struct.new(
  :dry_run,
  :ipam_external_resource_verification_token_id)
  SENSITIVE = []
  include Aws::Structure
end