Class: Aws::EC2::Types::DeleteIpamInternetRegistryAssociationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteIpamInternetRegistryAssociationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#ipam_internet_registry_association_id ⇒ String
The ID of the IPAM internet registry association to delete.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
19755 19756 19757 19758 19759 19760 |
# File 'lib/aws-sdk-ec2/types.rb', line 19755 class DeleteIpamInternetRegistryAssociationRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id) SENSITIVE = [] include Aws::Structure end |
#ipam_internet_registry_association_id ⇒ String
The ID of the IPAM internet registry association to delete.
19755 19756 19757 19758 19759 19760 |
# File 'lib/aws-sdk-ec2/types.rb', line 19755 class DeleteIpamInternetRegistryAssociationRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id) SENSITIVE = [] include Aws::Structure end |