Class: Aws::EC2::Types::DeleteIpamPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


18799
18800
18801
18802
18803
18804
# File 'lib/aws-sdk-ec2/types.rb', line 18799

class DeleteIpamPolicyRequest < Struct.new(
  :dry_run,
  :ipam_policy_id)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_policy_idString

The ID of the IPAM policy to delete.

Returns:

  • (String)


18799
18800
18801
18802
18803
18804
# File 'lib/aws-sdk-ec2/types.rb', line 18799

class DeleteIpamPolicyRequest < Struct.new(
  :dry_run,
  :ipam_policy_id)
  SENSITIVE = []
  include Aws::Structure
end