Class: Aws::EC2::Types::DeleteIpamPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteIpamPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#ipam_policy_id ⇒ String
The ID of the IPAM policy to delete.
Instance Attribute Details
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
18644 18645 18646 18647 18648 18649 |
# File 'lib/aws-sdk-ec2/types.rb', line 18644 class DeleteIpamPolicyRequest < Struct.new( :dry_run, :ipam_policy_id) SENSITIVE = [] include Aws::Structure end |
#ipam_policy_id ⇒ String
The ID of the IPAM policy to delete.
18644 18645 18646 18647 18648 18649 |
# File 'lib/aws-sdk-ec2/types.rb', line 18644 class DeleteIpamPolicyRequest < Struct.new( :dry_run, :ipam_policy_id) SENSITIVE = [] include Aws::Structure end |