Class: Aws::EC2::Types::DeleteIpamPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


18403
18404
18405
18406
18407
18408
# File 'lib/aws-sdk-ec2/types.rb', line 18403

class DeleteIpamPolicyRequest < Struct.new(
  :dry_run,
  :ipam_policy_id)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_policy_idString

The ID of the IPAM policy to delete.

Returns:

  • (String)


18403
18404
18405
18406
18407
18408
# File 'lib/aws-sdk-ec2/types.rb', line 18403

class DeleteIpamPolicyRequest < Struct.new(
  :dry_run,
  :ipam_policy_id)
  SENSITIVE = []
  include Aws::Structure
end