Class: Aws::EC2::Types::DeleteIpamResourceDiscoveryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


18846
18847
18848
18849
18850
18851
# File 'lib/aws-sdk-ec2/types.rb', line 18846

class DeleteIpamResourceDiscoveryRequest < Struct.new(
  :dry_run,
  :ipam_resource_discovery_id)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_resource_discovery_idString

The IPAM resource discovery ID.

Returns:

  • (String)


18846
18847
18848
18849
18850
18851
# File 'lib/aws-sdk-ec2/types.rb', line 18846

class DeleteIpamResourceDiscoveryRequest < Struct.new(
  :dry_run,
  :ipam_resource_discovery_id)
  SENSITIVE = []
  include Aws::Structure
end