Class: Aws::EC2::Types::DeleteIpamResourceDiscoveryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteIpamResourceDiscoveryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#ipam_resource_discovery_id ⇒ String
The IPAM resource discovery ID.
Instance Attribute Details
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action
without actually making the request and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
18846 18847 18848 18849 18850 18851 |
# File 'lib/aws-sdk-ec2/types.rb', line 18846 class DeleteIpamResourceDiscoveryRequest < Struct.new( :dry_run, :ipam_resource_discovery_id) SENSITIVE = [] include Aws::Structure end |
#ipam_resource_discovery_id ⇒ String
The IPAM resource discovery ID.
18846 18847 18848 18849 18850 18851 |
# File 'lib/aws-sdk-ec2/types.rb', line 18846 class DeleteIpamResourceDiscoveryRequest < Struct.new( :dry_run, :ipam_resource_discovery_id) SENSITIVE = [] include Aws::Structure end |