Class: Aws::EC2::Types::DeleteIpamResourceDiscoveryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


18145
18146
18147
18148
18149
18150
# File 'lib/aws-sdk-ec2/types.rb', line 18145

class DeleteIpamResourceDiscoveryRequest < Struct.new(
  :dry_run,
  :ipam_resource_discovery_id)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_resource_discovery_idString

The IPAM resource discovery ID.

Returns:

  • (String)


18145
18146
18147
18148
18149
18150
# File 'lib/aws-sdk-ec2/types.rb', line 18145

class DeleteIpamResourceDiscoveryRequest < Struct.new(
  :dry_run,
  :ipam_resource_discovery_id)
  SENSITIVE = []
  include Aws::Structure
end