Class: Aws::EC2::Types::DeleteIpamRoutingPolicyRegistrationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteIpamRoutingPolicyRegistrationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cidr ⇒ String
The IP address prefix in CIDR notation identifying the routing policy registration to delete.
-
#client_token ⇒ String
A unique, case-sensitive identifier to ensure that the operation completes no more than one time.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#force ⇒ Boolean
Forces the deletion even if it conflicts with an announced route.
-
#ipam_internet_registry_association_id ⇒ String
The ID of the IPAM internet registry association.
Instance Attribute Details
#cidr ⇒ String
The IP address prefix in CIDR notation identifying the routing policy registration to delete.
20038 20039 20040 20041 20042 20043 20044 20045 20046 |
# File 'lib/aws-sdk-ec2/types.rb', line 20038 class DeleteIpamRoutingPolicyRegistrationRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id, :cidr, :force, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, the operation ignores the request, but does not return an error.
A suitable default value is auto-generated. You should normally not need to pass this option.
20038 20039 20040 20041 20042 20043 20044 20045 20046 |
# File 'lib/aws-sdk-ec2/types.rb', line 20038 class DeleteIpamRoutingPolicyRegistrationRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id, :cidr, :force, :client_token) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
20038 20039 20040 20041 20042 20043 20044 20045 20046 |
# File 'lib/aws-sdk-ec2/types.rb', line 20038 class DeleteIpamRoutingPolicyRegistrationRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id, :cidr, :force, :client_token) SENSITIVE = [] include Aws::Structure end |
#force ⇒ Boolean
Forces the deletion even if it conflicts with an announced route.
Default: false.
20038 20039 20040 20041 20042 20043 20044 20045 20046 |
# File 'lib/aws-sdk-ec2/types.rb', line 20038 class DeleteIpamRoutingPolicyRegistrationRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id, :cidr, :force, :client_token) SENSITIVE = [] include Aws::Structure end |
#ipam_internet_registry_association_id ⇒ String
The ID of the IPAM internet registry association.
20038 20039 20040 20041 20042 20043 20044 20045 20046 |
# File 'lib/aws-sdk-ec2/types.rb', line 20038 class DeleteIpamRoutingPolicyRegistrationRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id, :cidr, :force, :client_token) SENSITIVE = [] include Aws::Structure end |