Class: Aws::EC2::Types::DeleteIpamScopeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteIpamScopeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#ipam_scope_id ⇒ String
The ID of the scope to delete.
Instance Attribute Details
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action
without actually making the request and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
20083 20084 20085 20086 20087 20088 |
# File 'lib/aws-sdk-ec2/types.rb', line 20083 class DeleteIpamScopeRequest < Struct.new( :dry_run, :ipam_scope_id) SENSITIVE = [] include Aws::Structure end |
#ipam_scope_id ⇒ String
The ID of the scope to delete.
20083 20084 20085 20086 20087 20088 |
# File 'lib/aws-sdk-ec2/types.rb', line 20083 class DeleteIpamScopeRequest < Struct.new( :dry_run, :ipam_scope_id) SENSITIVE = [] include Aws::Structure end |