Class: Aws::EC2::Types::DeleteIpamScopeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteIpamScopeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#ipam_scope_id ⇒ String
The ID of the scope to delete.
Instance Attribute Details
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action
without actually making the request and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
19094 19095 19096 19097 19098 19099 |
# File 'lib/aws-sdk-ec2/types.rb', line 19094 class DeleteIpamScopeRequest < Struct.new( :dry_run, :ipam_scope_id) SENSITIVE = [] include Aws::Structure end |
#ipam_scope_id ⇒ String
The ID of the scope to delete.
19094 19095 19096 19097 19098 19099 |
# File 'lib/aws-sdk-ec2/types.rb', line 19094 class DeleteIpamScopeRequest < Struct.new( :dry_run, :ipam_scope_id) SENSITIVE = [] include Aws::Structure end |