Class: Aws::EC2::Types::DeleteIpamScopeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteIpamScopeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#ipam_scope_id ⇒ String
The ID of the scope to delete.
Instance Attribute Details
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
18884 18885 18886 18887 18888 18889 |
# File 'lib/aws-sdk-ec2/types.rb', line 18884 class DeleteIpamScopeRequest < Struct.new( :dry_run, :ipam_scope_id) SENSITIVE = [] include Aws::Structure end |
#ipam_scope_id ⇒ String
The ID of the scope to delete.
18884 18885 18886 18887 18888 18889 |
# File 'lib/aws-sdk-ec2/types.rb', line 18884 class DeleteIpamScopeRequest < Struct.new( :dry_run, :ipam_scope_id) SENSITIVE = [] include Aws::Structure end |