Class: Aws::EC2::Types::DeleteKeyPairRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteKeyPairRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#key_name ⇒ String
The name of the key pair.
-
#key_pair_id ⇒ String
The ID of the key pair.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
19130 19131 19132 19133 19134 19135 19136 |
# File 'lib/aws-sdk-ec2/types.rb', line 19130 class DeleteKeyPairRequest < Struct.new( :key_name, :key_pair_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#key_name ⇒ String
The name of the key pair.
19130 19131 19132 19133 19134 19135 19136 |
# File 'lib/aws-sdk-ec2/types.rb', line 19130 class DeleteKeyPairRequest < Struct.new( :key_name, :key_pair_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#key_pair_id ⇒ String
The ID of the key pair.
19130 19131 19132 19133 19134 19135 19136 |
# File 'lib/aws-sdk-ec2/types.rb', line 19130 class DeleteKeyPairRequest < Struct.new( :key_name, :key_pair_id, :dry_run) SENSITIVE = [] include Aws::Structure end |