Class: Aws::EC2::Types::DeleteKeyPairRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


18679
18680
18681
18682
18683
18684
18685
# File 'lib/aws-sdk-ec2/types.rb', line 18679

class DeleteKeyPairRequest < Struct.new(
  :key_name,
  :key_pair_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#key_nameString

The name of the key pair.

Returns:

  • (String)


18679
18680
18681
18682
18683
18684
18685
# File 'lib/aws-sdk-ec2/types.rb', line 18679

class DeleteKeyPairRequest < Struct.new(
  :key_name,
  :key_pair_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#key_pair_idString

The ID of the key pair.

Returns:

  • (String)


18679
18680
18681
18682
18683
18684
18685
# File 'lib/aws-sdk-ec2/types.rb', line 18679

class DeleteKeyPairRequest < Struct.new(
  :key_name,
  :key_pair_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end