Class: Aws::EC2::Types::DeleteLaunchTemplateRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


18925
18926
18927
18928
18929
18930
18931
# File 'lib/aws-sdk-ec2/types.rb', line 18925

class DeleteLaunchTemplateRequest < Struct.new(
  :dry_run,
  :launch_template_id,
  :launch_template_name)
  SENSITIVE = []
  include Aws::Structure
end

#launch_template_idString

The ID of the launch template.

You must specify either the launch template ID or the launch template name, but not both.

Returns:

  • (String)


18925
18926
18927
18928
18929
18930
18931
# File 'lib/aws-sdk-ec2/types.rb', line 18925

class DeleteLaunchTemplateRequest < Struct.new(
  :dry_run,
  :launch_template_id,
  :launch_template_name)
  SENSITIVE = []
  include Aws::Structure
end

#launch_template_nameString

The name of the launch template.

You must specify either the launch template ID or the launch template name, but not both.

Returns:

  • (String)


18925
18926
18927
18928
18929
18930
18931
# File 'lib/aws-sdk-ec2/types.rb', line 18925

class DeleteLaunchTemplateRequest < Struct.new(
  :dry_run,
  :launch_template_id,
  :launch_template_name)
  SENSITIVE = []
  include Aws::Structure
end