Class: Aws::EC2::Types::DeleteLaunchTemplateVersionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteLaunchTemplateVersionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#launch_template_id ⇒ String
The ID of the launch template.
-
#launch_template_name ⇒ String
The name of the launch template.
-
#versions ⇒ Array<String>
The version numbers of one or more launch template versions to delete.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
19146 19147 19148 19149 19150 19151 19152 19153 |
# File 'lib/aws-sdk-ec2/types.rb', line 19146 class DeleteLaunchTemplateVersionsRequest < Struct.new( :dry_run, :launch_template_id, :launch_template_name, :versions) SENSITIVE = [] include Aws::Structure end |
#launch_template_id ⇒ String
The ID of the launch template.
You must specify either the launch template ID or the launch template name, but not both.
19146 19147 19148 19149 19150 19151 19152 19153 |
# File 'lib/aws-sdk-ec2/types.rb', line 19146 class DeleteLaunchTemplateVersionsRequest < Struct.new( :dry_run, :launch_template_id, :launch_template_name, :versions) SENSITIVE = [] include Aws::Structure end |
#launch_template_name ⇒ String
The name of the launch template.
You must specify either the launch template ID or the launch template name, but not both.
19146 19147 19148 19149 19150 19151 19152 19153 |
# File 'lib/aws-sdk-ec2/types.rb', line 19146 class DeleteLaunchTemplateVersionsRequest < Struct.new( :dry_run, :launch_template_id, :launch_template_name, :versions) SENSITIVE = [] include Aws::Structure end |
#versions ⇒ Array<String>
The version numbers of one or more launch template versions to delete. You can specify up to 200 launch template version numbers.
19146 19147 19148 19149 19150 19151 19152 19153 |
# File 'lib/aws-sdk-ec2/types.rb', line 19146 class DeleteLaunchTemplateVersionsRequest < Struct.new( :dry_run, :launch_template_id, :launch_template_name, :versions) SENSITIVE = [] include Aws::Structure end |