Class: Aws::EC2::Types::DeleteLocalGatewayRouteRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#destination_cidr_blockString

The CIDR range for the route. This must match the CIDR for the route exactly.

Returns:

  • (String)


20004
20005
20006
20007
20008
20009
20010
20011
# File 'lib/aws-sdk-ec2/types.rb', line 20004

class DeleteLocalGatewayRouteRequest < Struct.new(
  :destination_cidr_block,
  :local_gateway_route_table_id,
  :dry_run,
  :destination_prefix_list_id)
  SENSITIVE = []
  include Aws::Structure
end

#destination_prefix_list_idString

Use a prefix list in place of DestinationCidrBlock. You cannot use DestinationPrefixListId and DestinationCidrBlock in the same request.

Returns:

  • (String)


20004
20005
20006
20007
20008
20009
20010
20011
# File 'lib/aws-sdk-ec2/types.rb', line 20004

class DeleteLocalGatewayRouteRequest < Struct.new(
  :destination_cidr_block,
  :local_gateway_route_table_id,
  :dry_run,
  :destination_prefix_list_id)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


20004
20005
20006
20007
20008
20009
20010
20011
# File 'lib/aws-sdk-ec2/types.rb', line 20004

class DeleteLocalGatewayRouteRequest < Struct.new(
  :destination_cidr_block,
  :local_gateway_route_table_id,
  :dry_run,
  :destination_prefix_list_id)
  SENSITIVE = []
  include Aws::Structure
end

#local_gateway_route_table_idString

The ID of the local gateway route table.

Returns:

  • (String)


20004
20005
20006
20007
20008
20009
20010
20011
# File 'lib/aws-sdk-ec2/types.rb', line 20004

class DeleteLocalGatewayRouteRequest < Struct.new(
  :destination_cidr_block,
  :local_gateway_route_table_id,
  :dry_run,
  :destination_prefix_list_id)
  SENSITIVE = []
  include Aws::Structure
end