Class: Aws::EC2::Types::DeleteLocalGatewayRouteRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteLocalGatewayRouteRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination_cidr_block ⇒ String
The CIDR range for the route.
-
#destination_prefix_list_id ⇒ String
Use a prefix list in place of
DestinationCidrBlock. -
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#local_gateway_route_table_id ⇒ String
The ID of the local gateway route table.
Instance Attribute Details
#destination_cidr_block ⇒ String
The CIDR range for the route. This must match the CIDR for the route exactly.
20004 20005 20006 20007 20008 20009 20010 20011 |
# File 'lib/aws-sdk-ec2/types.rb', line 20004 class DeleteLocalGatewayRouteRequest < Struct.new( :destination_cidr_block, :local_gateway_route_table_id, :dry_run, :destination_prefix_list_id) SENSITIVE = [] include Aws::Structure end |
#destination_prefix_list_id ⇒ String
Use a prefix list in place of DestinationCidrBlock. You cannot use
DestinationPrefixListId and DestinationCidrBlock in the same
request.
20004 20005 20006 20007 20008 20009 20010 20011 |
# File 'lib/aws-sdk-ec2/types.rb', line 20004 class DeleteLocalGatewayRouteRequest < Struct.new( :destination_cidr_block, :local_gateway_route_table_id, :dry_run, :destination_prefix_list_id) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
20004 20005 20006 20007 20008 20009 20010 20011 |
# File 'lib/aws-sdk-ec2/types.rb', line 20004 class DeleteLocalGatewayRouteRequest < Struct.new( :destination_cidr_block, :local_gateway_route_table_id, :dry_run, :destination_prefix_list_id) SENSITIVE = [] include Aws::Structure end |
#local_gateway_route_table_id ⇒ String
The ID of the local gateway route table.
20004 20005 20006 20007 20008 20009 20010 20011 |
# File 'lib/aws-sdk-ec2/types.rb', line 20004 class DeleteLocalGatewayRouteRequest < Struct.new( :destination_cidr_block, :local_gateway_route_table_id, :dry_run, :destination_prefix_list_id) SENSITIVE = [] include Aws::Structure end |