Class: Aws::EC2::Types::DeleteLocalGatewayRouteTableRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteLocalGatewayRouteTableRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#local_gateway_route_table_id ⇒ String
The ID of the local gateway route table.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
20345 20346 20347 20348 20349 20350 |
# File 'lib/aws-sdk-ec2/types.rb', line 20345 class DeleteLocalGatewayRouteTableRequest < Struct.new( :local_gateway_route_table_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#local_gateway_route_table_id ⇒ String
The ID of the local gateway route table.
20345 20346 20347 20348 20349 20350 |
# File 'lib/aws-sdk-ec2/types.rb', line 20345 class DeleteLocalGatewayRouteTableRequest < Struct.new( :local_gateway_route_table_id, :dry_run) SENSITIVE = [] include Aws::Structure end |