Class: Aws::EC2::Types::DeleteLocalGatewayRouteTableRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


19285
19286
19287
19288
19289
19290
# File 'lib/aws-sdk-ec2/types.rb', line 19285

class DeleteLocalGatewayRouteTableRequest < Struct.new(
  :local_gateway_route_table_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#local_gateway_route_table_idString

The ID of the local gateway route table.

Returns:

  • (String)


19285
19286
19287
19288
19289
19290
# File 'lib/aws-sdk-ec2/types.rb', line 19285

class DeleteLocalGatewayRouteTableRequest < Struct.new(
  :local_gateway_route_table_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end