Class: Aws::EC2::Types::DeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


20071
20072
20073
20074
20075
20076
# File 'lib/aws-sdk-ec2/types.rb', line 20071

class DeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociationRequest < Struct.new(
  :local_gateway_route_table_virtual_interface_group_association_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#local_gateway_route_table_virtual_interface_group_association_idString

The ID of the local gateway route table virtual interface group association.

Returns:

  • (String)


20071
20072
20073
20074
20075
20076
# File 'lib/aws-sdk-ec2/types.rb', line 20071

class DeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociationRequest < Struct.new(
  :local_gateway_route_table_virtual_interface_group_association_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end