Class: Aws::EC2::Types::DeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#local_gateway_route_table_virtual_interface_group_association_id ⇒ String
The ID of the local gateway route table virtual interface group association.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
19188 19189 19190 19191 19192 19193 |
# File 'lib/aws-sdk-ec2/types.rb', line 19188 class DeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociationRequest < Struct.new( :local_gateway_route_table_virtual_interface_group_association_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#local_gateway_route_table_virtual_interface_group_association_id ⇒ String
The ID of the local gateway route table virtual interface group association.
19188 19189 19190 19191 19192 19193 |
# File 'lib/aws-sdk-ec2/types.rb', line 19188 class DeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociationRequest < Struct.new( :local_gateway_route_table_virtual_interface_group_association_id, :dry_run) SENSITIVE = [] include Aws::Structure end |