Class: Aws::EC2::Types::DeleteLocalGatewayRouteTableVpcAssociationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteLocalGatewayRouteTableVpcAssociationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#local_gateway_route_table_vpc_association_id ⇒ String
The ID of the association.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
19430 19431 19432 19433 19434 19435 |
# File 'lib/aws-sdk-ec2/types.rb', line 19430 class DeleteLocalGatewayRouteTableVpcAssociationRequest < Struct.new( :local_gateway_route_table_vpc_association_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#local_gateway_route_table_vpc_association_id ⇒ String
The ID of the association.
19430 19431 19432 19433 19434 19435 |
# File 'lib/aws-sdk-ec2/types.rb', line 19430 class DeleteLocalGatewayRouteTableVpcAssociationRequest < Struct.new( :local_gateway_route_table_vpc_association_id, :dry_run) SENSITIVE = [] include Aws::Structure end |