Class: Aws::EC2::Types::DeleteLocalGatewayRouteTableVpcAssociationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


18979
18980
18981
18982
18983
18984
# File 'lib/aws-sdk-ec2/types.rb', line 18979

class DeleteLocalGatewayRouteTableVpcAssociationRequest < Struct.new(
  :local_gateway_route_table_vpc_association_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#local_gateway_route_table_vpc_association_idString

The ID of the association.

Returns:

  • (String)


18979
18980
18981
18982
18983
18984
# File 'lib/aws-sdk-ec2/types.rb', line 18979

class DeleteLocalGatewayRouteTableVpcAssociationRequest < Struct.new(
  :local_gateway_route_table_vpc_association_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end