Class: Aws::EC2::Types::DeleteLocalGatewayRouteTableVpcAssociationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


18525
18526
18527
18528
18529
18530
# File 'lib/aws-sdk-ec2/types.rb', line 18525

class DeleteLocalGatewayRouteTableVpcAssociationRequest < Struct.new(
  :local_gateway_route_table_vpc_association_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#local_gateway_route_table_vpc_association_idString

The ID of the association.

Returns:

  • (String)


18525
18526
18527
18528
18529
18530
# File 'lib/aws-sdk-ec2/types.rb', line 18525

class DeleteLocalGatewayRouteTableVpcAssociationRequest < Struct.new(
  :local_gateway_route_table_vpc_association_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end