Class: Aws::EC2::Types::DeleteLocalGatewayVirtualInterfaceGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteLocalGatewayVirtualInterfaceGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#local_gateway_virtual_interface_group_id ⇒ String
The ID of the local gateway virtual interface group to delete.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
20451 20452 20453 20454 20455 20456 |
# File 'lib/aws-sdk-ec2/types.rb', line 20451 class DeleteLocalGatewayVirtualInterfaceGroupRequest < Struct.new( :local_gateway_virtual_interface_group_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#local_gateway_virtual_interface_group_id ⇒ String
The ID of the local gateway virtual interface group to delete.
20451 20452 20453 20454 20455 20456 |
# File 'lib/aws-sdk-ec2/types.rb', line 20451 class DeleteLocalGatewayVirtualInterfaceGroupRequest < Struct.new( :local_gateway_virtual_interface_group_id, :dry_run) SENSITIVE = [] include Aws::Structure end |