Class: Aws::EC2::Types::DeleteLocalGatewayVirtualInterfaceGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


18551
18552
18553
18554
18555
18556
# File 'lib/aws-sdk-ec2/types.rb', line 18551

class DeleteLocalGatewayVirtualInterfaceGroupRequest < Struct.new(
  :local_gateway_virtual_interface_group_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#local_gateway_virtual_interface_group_idString

The ID of the local gateway virtual interface group to delete.

Returns:

  • (String)


18551
18552
18553
18554
18555
18556
# File 'lib/aws-sdk-ec2/types.rb', line 18551

class DeleteLocalGatewayVirtualInterfaceGroupRequest < Struct.new(
  :local_gateway_virtual_interface_group_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end