Class: Aws::EC2::Types::DeleteLocalGatewayVirtualInterfaceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


18811
18812
18813
18814
18815
18816
# File 'lib/aws-sdk-ec2/types.rb', line 18811

class DeleteLocalGatewayVirtualInterfaceRequest < Struct.new(
  :local_gateway_virtual_interface_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#local_gateway_virtual_interface_idString

The ID of the local virtual interface to delete.

Returns:

  • (String)


18811
18812
18813
18814
18815
18816
# File 'lib/aws-sdk-ec2/types.rb', line 18811

class DeleteLocalGatewayVirtualInterfaceRequest < Struct.new(
  :local_gateway_virtual_interface_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end