Class: Aws::EC2::Types::DeleteNatGatewayRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteNatGatewayRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#nat_gateway_id ⇒ String
The ID of the NAT gateway.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
20231 20232 20233 20234 20235 20236 |
# File 'lib/aws-sdk-ec2/types.rb', line 20231 class DeleteNatGatewayRequest < Struct.new( :dry_run, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |
#nat_gateway_id ⇒ String
The ID of the NAT gateway.
20231 20232 20233 20234 20235 20236 |
# File 'lib/aws-sdk-ec2/types.rb', line 20231 class DeleteNatGatewayRequest < Struct.new( :dry_run, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |