Class: Aws::EC2::Types::DeleteNatGatewayRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteNatGatewayRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#nat_gateway_id ⇒ String
The ID of the NAT gateway.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
19348 19349 19350 19351 19352 19353 |
# File 'lib/aws-sdk-ec2/types.rb', line 19348 class DeleteNatGatewayRequest < Struct.new( :dry_run, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |
#nat_gateway_id ⇒ String
The ID of the NAT gateway.
19348 19349 19350 19351 19352 19353 |
# File 'lib/aws-sdk-ec2/types.rb', line 19348 class DeleteNatGatewayRequest < Struct.new( :dry_run, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |