Class: Aws::EC2::Types::DeleteNatGatewayRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


18653
18654
18655
18656
18657
18658
# File 'lib/aws-sdk-ec2/types.rb', line 18653

class DeleteNatGatewayRequest < Struct.new(
  :dry_run,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end

#nat_gateway_idString

The ID of the NAT gateway.

Returns:

  • (String)


18653
18654
18655
18656
18657
18658
# File 'lib/aws-sdk-ec2/types.rb', line 18653

class DeleteNatGatewayRequest < Struct.new(
  :dry_run,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end