Class: Aws::EC2::Types::DeleteNetworkAclEntryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


20271
20272
20273
20274
20275
20276
20277
20278
# File 'lib/aws-sdk-ec2/types.rb', line 20271

class DeleteNetworkAclEntryRequest < Struct.new(
  :dry_run,
  :network_acl_id,
  :rule_number,
  :egress)
  SENSITIVE = []
  include Aws::Structure
end

#egressBoolean

Indicates whether the rule is an egress rule.

Returns:

  • (Boolean)


20271
20272
20273
20274
20275
20276
20277
20278
# File 'lib/aws-sdk-ec2/types.rb', line 20271

class DeleteNetworkAclEntryRequest < Struct.new(
  :dry_run,
  :network_acl_id,
  :rule_number,
  :egress)
  SENSITIVE = []
  include Aws::Structure
end

#network_acl_idString

The ID of the network ACL.

Returns:

  • (String)


20271
20272
20273
20274
20275
20276
20277
20278
# File 'lib/aws-sdk-ec2/types.rb', line 20271

class DeleteNetworkAclEntryRequest < Struct.new(
  :dry_run,
  :network_acl_id,
  :rule_number,
  :egress)
  SENSITIVE = []
  include Aws::Structure
end

#rule_numberInteger

The rule number of the entry to delete.

Returns:

  • (Integer)


20271
20272
20273
20274
20275
20276
20277
20278
# File 'lib/aws-sdk-ec2/types.rb', line 20271

class DeleteNetworkAclEntryRequest < Struct.new(
  :dry_run,
  :network_acl_id,
  :rule_number,
  :egress)
  SENSITIVE = []
  include Aws::Structure
end