Class: Aws::EC2::Types::DeleteNetworkAclEntryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteNetworkAclEntryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#egress ⇒ Boolean
Indicates whether the rule is an egress rule.
-
#network_acl_id ⇒ String
The ID of the network ACL.
-
#rule_number ⇒ Integer
The rule number of the entry to delete.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
19339 19340 19341 19342 19343 19344 19345 19346 |
# File 'lib/aws-sdk-ec2/types.rb', line 19339 class DeleteNetworkAclEntryRequest < Struct.new( :dry_run, :network_acl_id, :rule_number, :egress) SENSITIVE = [] include Aws::Structure end |
#egress ⇒ Boolean
Indicates whether the rule is an egress rule.
19339 19340 19341 19342 19343 19344 19345 19346 |
# File 'lib/aws-sdk-ec2/types.rb', line 19339 class DeleteNetworkAclEntryRequest < Struct.new( :dry_run, :network_acl_id, :rule_number, :egress) SENSITIVE = [] include Aws::Structure end |
#network_acl_id ⇒ String
The ID of the network ACL.
19339 19340 19341 19342 19343 19344 19345 19346 |
# File 'lib/aws-sdk-ec2/types.rb', line 19339 class DeleteNetworkAclEntryRequest < Struct.new( :dry_run, :network_acl_id, :rule_number, :egress) SENSITIVE = [] include Aws::Structure end |
#rule_number ⇒ Integer
The rule number of the entry to delete.
19339 19340 19341 19342 19343 19344 19345 19346 |
# File 'lib/aws-sdk-ec2/types.rb', line 19339 class DeleteNetworkAclEntryRequest < Struct.new( :dry_run, :network_acl_id, :rule_number, :egress) SENSITIVE = [] include Aws::Structure end |