Class: Aws::EC2::Types::DeleteNetworkAclRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteNetworkAclRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#network_acl_id ⇒ String
The ID of the network ACL.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
20618 20619 20620 20621 20622 20623 |
# File 'lib/aws-sdk-ec2/types.rb', line 20618 class DeleteNetworkAclRequest < Struct.new( :dry_run, :network_acl_id) SENSITIVE = [] include Aws::Structure end |
#network_acl_id ⇒ String
The ID of the network ACL.
20618 20619 20620 20621 20622 20623 |
# File 'lib/aws-sdk-ec2/types.rb', line 20618 class DeleteNetworkAclRequest < Struct.new( :dry_run, :network_acl_id) SENSITIVE = [] include Aws::Structure end |