Class: Aws::EC2::Types::DeleteNetworkAclRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


19540
19541
19542
19543
19544
19545
# File 'lib/aws-sdk-ec2/types.rb', line 19540

class DeleteNetworkAclRequest < Struct.new(
  :dry_run,
  :network_acl_id)
  SENSITIVE = []
  include Aws::Structure
end

#network_acl_idString

The ID of the network ACL.

Returns:

  • (String)


19540
19541
19542
19543
19544
19545
# File 'lib/aws-sdk-ec2/types.rb', line 19540

class DeleteNetworkAclRequest < Struct.new(
  :dry_run,
  :network_acl_id)
  SENSITIVE = []
  include Aws::Structure
end