Class: Aws::EC2::Types::DeleteNetworkInsightsAccessScopeAnalysisRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteNetworkInsightsAccessScopeAnalysisRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#network_insights_access_scope_analysis_id ⇒ String
The ID of the Network Access Scope analysis.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
20313 20314 20315 20316 20317 20318 |
# File 'lib/aws-sdk-ec2/types.rb', line 20313 class DeleteNetworkInsightsAccessScopeAnalysisRequest < Struct.new( :network_insights_access_scope_analysis_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#network_insights_access_scope_analysis_id ⇒ String
The ID of the Network Access Scope analysis.
20313 20314 20315 20316 20317 20318 |
# File 'lib/aws-sdk-ec2/types.rb', line 20313 class DeleteNetworkInsightsAccessScopeAnalysisRequest < Struct.new( :network_insights_access_scope_analysis_id, :dry_run) SENSITIVE = [] include Aws::Structure end |