Class: Aws::EC2::Types::DeleteNetworkInsightsAccessScopeAnalysisRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


18729
18730
18731
18732
18733
18734
# File 'lib/aws-sdk-ec2/types.rb', line 18729

class DeleteNetworkInsightsAccessScopeAnalysisRequest < Struct.new(
  :network_insights_access_scope_analysis_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#network_insights_access_scope_analysis_idString

The ID of the Network Access Scope analysis.

Returns:

  • (String)


18729
18730
18731
18732
18733
18734
# File 'lib/aws-sdk-ec2/types.rb', line 18729

class DeleteNetworkInsightsAccessScopeAnalysisRequest < Struct.new(
  :network_insights_access_scope_analysis_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end