Class: Aws::EC2::Types::DeleteNetworkInsightsAccessScopeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


19209
19210
19211
19212
19213
19214
# File 'lib/aws-sdk-ec2/types.rb', line 19209

class DeleteNetworkInsightsAccessScopeRequest < Struct.new(
  :dry_run,
  :network_insights_access_scope_id)
  SENSITIVE = []
  include Aws::Structure
end

#network_insights_access_scope_idString

The ID of the Network Access Scope.

Returns:

  • (String)


19209
19210
19211
19212
19213
19214
# File 'lib/aws-sdk-ec2/types.rb', line 19209

class DeleteNetworkInsightsAccessScopeRequest < Struct.new(
  :dry_run,
  :network_insights_access_scope_id)
  SENSITIVE = []
  include Aws::Structure
end