Class: Aws::EC2::Types::DeleteNetworkInsightsAccessScopeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteNetworkInsightsAccessScopeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#network_insights_access_scope_id ⇒ String
The ID of the Network Access Scope.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
18761 18762 18763 18764 18765 18766 |
# File 'lib/aws-sdk-ec2/types.rb', line 18761 class DeleteNetworkInsightsAccessScopeRequest < Struct.new( :dry_run, :network_insights_access_scope_id) SENSITIVE = [] include Aws::Structure end |
#network_insights_access_scope_id ⇒ String
The ID of the Network Access Scope.
18761 18762 18763 18764 18765 18766 |
# File 'lib/aws-sdk-ec2/types.rb', line 18761 class DeleteNetworkInsightsAccessScopeRequest < Struct.new( :dry_run, :network_insights_access_scope_id) SENSITIVE = [] include Aws::Structure end |