Class: Aws::EC2::Types::DeleteNetworkInsightsAnalysisRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


19253
19254
19255
19256
19257
19258
# File 'lib/aws-sdk-ec2/types.rb', line 19253

class DeleteNetworkInsightsAnalysisRequest < Struct.new(
  :dry_run,
  :network_insights_analysis_id)
  SENSITIVE = []
  include Aws::Structure
end

#network_insights_analysis_idString

The ID of the network insights analysis.

Returns:

  • (String)


19253
19254
19255
19256
19257
19258
# File 'lib/aws-sdk-ec2/types.rb', line 19253

class DeleteNetworkInsightsAnalysisRequest < Struct.new(
  :dry_run,
  :network_insights_analysis_id)
  SENSITIVE = []
  include Aws::Structure
end