Class: Aws::EC2::Types::DeleteNetworkInsightsAnalysisRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


19241
19242
19243
19244
19245
19246
# File 'lib/aws-sdk-ec2/types.rb', line 19241

class DeleteNetworkInsightsAnalysisRequest < Struct.new(
  :dry_run,
  :network_insights_analysis_id)
  SENSITIVE = []
  include Aws::Structure
end

#network_insights_analysis_idString

The ID of the network insights analysis.

Returns:

  • (String)


19241
19242
19243
19244
19245
19246
# File 'lib/aws-sdk-ec2/types.rb', line 19241

class DeleteNetworkInsightsAnalysisRequest < Struct.new(
  :dry_run,
  :network_insights_analysis_id)
  SENSITIVE = []
  include Aws::Structure
end