Class: Aws::EC2::Types::DeleteNetworkInsightsAnalysisRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteNetworkInsightsAnalysisRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#network_insights_analysis_id ⇒ String
The ID of the network insights analysis.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
18793 18794 18795 18796 18797 18798 |
# File 'lib/aws-sdk-ec2/types.rb', line 18793 class DeleteNetworkInsightsAnalysisRequest < Struct.new( :dry_run, :network_insights_analysis_id) SENSITIVE = [] include Aws::Structure end |
#network_insights_analysis_id ⇒ String
The ID of the network insights analysis.
18793 18794 18795 18796 18797 18798 |
# File 'lib/aws-sdk-ec2/types.rb', line 18793 class DeleteNetworkInsightsAnalysisRequest < Struct.new( :dry_run, :network_insights_analysis_id) SENSITIVE = [] include Aws::Structure end |