Class: Aws::EC2::Types::DeleteNetworkInsightsPathRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteNetworkInsightsPathRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#network_insights_path_id ⇒ String
The ID of the path.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
19526 19527 19528 19529 19530 19531 |
# File 'lib/aws-sdk-ec2/types.rb', line 19526 class DeleteNetworkInsightsPathRequest < Struct.new( :dry_run, :network_insights_path_id) SENSITIVE = [] include Aws::Structure end |
#network_insights_path_id ⇒ String
The ID of the path.
19526 19527 19528 19529 19530 19531 |
# File 'lib/aws-sdk-ec2/types.rb', line 19526 class DeleteNetworkInsightsPathRequest < Struct.new( :dry_run, :network_insights_path_id) SENSITIVE = [] include Aws::Structure end |