Class: Aws::EC2::Types::DeleteNetworkInsightsPathRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


19285
19286
19287
19288
19289
19290
# File 'lib/aws-sdk-ec2/types.rb', line 19285

class DeleteNetworkInsightsPathRequest < Struct.new(
  :dry_run,
  :network_insights_path_id)
  SENSITIVE = []
  include Aws::Structure
end

#network_insights_path_idString

The ID of the path.

Returns:

  • (String)


19285
19286
19287
19288
19289
19290
# File 'lib/aws-sdk-ec2/types.rb', line 19285

class DeleteNetworkInsightsPathRequest < Struct.new(
  :dry_run,
  :network_insights_path_id)
  SENSITIVE = []
  include Aws::Structure
end