Class: Aws::EC2::Types::DeleteNetworkInterfacePermissionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for DeleteNetworkInterfacePermission.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


19522
19523
19524
19525
19526
19527
19528
# File 'lib/aws-sdk-ec2/types.rb', line 19522

class DeleteNetworkInterfacePermissionRequest < Struct.new(
  :network_interface_permission_id,
  :force,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#forceBoolean

Specify ‘true` to remove the permission even if the network interface is attached to an instance.

Returns:

  • (Boolean)


19522
19523
19524
19525
19526
19527
19528
# File 'lib/aws-sdk-ec2/types.rb', line 19522

class DeleteNetworkInterfacePermissionRequest < Struct.new(
  :network_interface_permission_id,
  :force,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#network_interface_permission_idString

The ID of the network interface permission.

Returns:

  • (String)


19522
19523
19524
19525
19526
19527
19528
# File 'lib/aws-sdk-ec2/types.rb', line 19522

class DeleteNetworkInterfacePermissionRequest < Struct.new(
  :network_interface_permission_id,
  :force,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end