Class: Aws::EC2::Types::DeleteNetworkInterfacePermissionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteNetworkInterfacePermissionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for DeleteNetworkInterfacePermission.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#force ⇒ Boolean
Specify ‘true` to remove the permission even if the network interface is attached to an instance.
-
#network_interface_permission_id ⇒ String
The ID of the network interface permission.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
18864 18865 18866 18867 18868 18869 18870 |
# File 'lib/aws-sdk-ec2/types.rb', line 18864 class DeleteNetworkInterfacePermissionRequest < Struct.new( :network_interface_permission_id, :force, :dry_run) SENSITIVE = [] include Aws::Structure end |
#force ⇒ Boolean
Specify ‘true` to remove the permission even if the network interface is attached to an instance.
18864 18865 18866 18867 18868 18869 18870 |
# File 'lib/aws-sdk-ec2/types.rb', line 18864 class DeleteNetworkInterfacePermissionRequest < Struct.new( :network_interface_permission_id, :force, :dry_run) SENSITIVE = [] include Aws::Structure end |
#network_interface_permission_id ⇒ String
The ID of the network interface permission.
18864 18865 18866 18867 18868 18869 18870 |
# File 'lib/aws-sdk-ec2/types.rb', line 18864 class DeleteNetworkInterfacePermissionRequest < Struct.new( :network_interface_permission_id, :force, :dry_run) SENSITIVE = [] include Aws::Structure end |