Class: Aws::EC2::Types::DeleteNetworkInterfaceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for DeleteNetworkInterface.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


19812
19813
19814
19815
19816
19817
# File 'lib/aws-sdk-ec2/types.rb', line 19812

class DeleteNetworkInterfaceRequest < Struct.new(
  :dry_run,
  :network_interface_id)
  SENSITIVE = []
  include Aws::Structure
end

#network_interface_idString

The ID of the network interface.

Returns:

  • (String)


19812
19813
19814
19815
19816
19817
# File 'lib/aws-sdk-ec2/types.rb', line 19812

class DeleteNetworkInterfaceRequest < Struct.new(
  :dry_run,
  :network_interface_id)
  SENSITIVE = []
  include Aws::Structure
end