Class: Aws::EC2::Types::DeleteNetworkInterfaceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteNetworkInterfaceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for DeleteNetworkInterface.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#network_interface_id ⇒ String
The ID of the network interface.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
19553 19554 19555 19556 19557 19558 |
# File 'lib/aws-sdk-ec2/types.rb', line 19553 class DeleteNetworkInterfaceRequest < Struct.new( :dry_run, :network_interface_id) SENSITIVE = [] include Aws::Structure end |
#network_interface_id ⇒ String
The ID of the network interface.
19553 19554 19555 19556 19557 19558 |
# File 'lib/aws-sdk-ec2/types.rb', line 19553 class DeleteNetworkInterfaceRequest < Struct.new( :dry_run, :network_interface_id) SENSITIVE = [] include Aws::Structure end |