Class: Aws::EC2::Types::DeletePlacementGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeletePlacementGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#group_name ⇒ String
The name of the placement group.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
20505 20506 20507 20508 20509 20510 |
# File 'lib/aws-sdk-ec2/types.rb', line 20505 class DeletePlacementGroupRequest < Struct.new( :dry_run, :group_name) SENSITIVE = [] include Aws::Structure end |
#group_name ⇒ String
The name of the placement group.
20505 20506 20507 20508 20509 20510 |
# File 'lib/aws-sdk-ec2/types.rb', line 20505 class DeletePlacementGroupRequest < Struct.new( :dry_run, :group_name) SENSITIVE = [] include Aws::Structure end |