Class: Aws::EC2::Types::DeletePlacementGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeletePlacementGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#group_name ⇒ String
The name of the placement group.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
19628 19629 19630 19631 19632 19633 |
# File 'lib/aws-sdk-ec2/types.rb', line 19628 class DeletePlacementGroupRequest < Struct.new( :dry_run, :group_name) SENSITIVE = [] include Aws::Structure end |
#group_name ⇒ String
The name of the placement group.
19628 19629 19630 19631 19632 19633 |
# File 'lib/aws-sdk-ec2/types.rb', line 19628 class DeletePlacementGroupRequest < Struct.new( :dry_run, :group_name) SENSITIVE = [] include Aws::Structure end |