Class: Aws::EC2::Types::DeletePublicIpv4PoolRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeletePublicIpv4PoolRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#network_border_group ⇒ String
The Availability Zone (AZ) or Local Zone (LZ) network border group that the resource that the IP address is assigned to is in.
-
#pool_id ⇒ String
The ID of the public IPv4 pool you want to delete.
Instance Attribute Details
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action
without actually making the request and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
20537 20538 20539 20540 20541 20542 20543 |
# File 'lib/aws-sdk-ec2/types.rb', line 20537 class DeletePublicIpv4PoolRequest < Struct.new( :dry_run, :pool_id, :network_border_group) SENSITIVE = [] include Aws::Structure end |
#network_border_group ⇒ String
The Availability Zone (AZ) or Local Zone (LZ) network border group that the resource that the IP address is assigned to is in. Defaults to an AZ network border group. For more information on available Local Zones, see Local Zone availability in the Amazon EC2 User Guide.
20537 20538 20539 20540 20541 20542 20543 |
# File 'lib/aws-sdk-ec2/types.rb', line 20537 class DeletePublicIpv4PoolRequest < Struct.new( :dry_run, :pool_id, :network_border_group) SENSITIVE = [] include Aws::Structure end |
#pool_id ⇒ String
The ID of the public IPv4 pool you want to delete.
20537 20538 20539 20540 20541 20542 20543 |
# File 'lib/aws-sdk-ec2/types.rb', line 20537 class DeletePublicIpv4PoolRequest < Struct.new( :dry_run, :pool_id, :network_border_group) SENSITIVE = [] include Aws::Structure end |