Class: Aws::EC2::Types::DeletePublicIpv4PoolRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


19864
19865
19866
19867
19868
19869
19870
# File 'lib/aws-sdk-ec2/types.rb', line 19864

class DeletePublicIpv4PoolRequest < Struct.new(
  :dry_run,
  :pool_id,
  :network_border_group)
  SENSITIVE = []
  include Aws::Structure
end

#network_border_groupString

The Availability Zone (AZ) or Local Zone (LZ) network border group that the resource that the IP address is assigned to is in. Defaults to an AZ network border group. For more information on available Local Zones, see Local Zone availability in the Amazon EC2 User Guide.

Returns:

  • (String)


19864
19865
19866
19867
19868
19869
19870
# File 'lib/aws-sdk-ec2/types.rb', line 19864

class DeletePublicIpv4PoolRequest < Struct.new(
  :dry_run,
  :pool_id,
  :network_border_group)
  SENSITIVE = []
  include Aws::Structure
end

#pool_idString

The ID of the public IPv4 pool you want to delete.

Returns:

  • (String)


19864
19865
19866
19867
19868
19869
19870
# File 'lib/aws-sdk-ec2/types.rb', line 19864

class DeletePublicIpv4PoolRequest < Struct.new(
  :dry_run,
  :pool_id,
  :network_border_group)
  SENSITIVE = []
  include Aws::Structure
end