Class: Aws::EC2::Types::DeleteQueuedReservedInstancesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteQueuedReservedInstancesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#reserved_instances_ids ⇒ Array<String>
The IDs of the Reserved Instances.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
20906 20907 20908 20909 20910 20911 |
# File 'lib/aws-sdk-ec2/types.rb', line 20906 class DeleteQueuedReservedInstancesRequest < Struct.new( :dry_run, :reserved_instances_ids) SENSITIVE = [] include Aws::Structure end |
#reserved_instances_ids ⇒ Array<String>
The IDs of the Reserved Instances.
20906 20907 20908 20909 20910 20911 |
# File 'lib/aws-sdk-ec2/types.rb', line 20906 class DeleteQueuedReservedInstancesRequest < Struct.new( :dry_run, :reserved_instances_ids) SENSITIVE = [] include Aws::Structure end |