Class: Aws::EC2::Types::DeleteQueuedReservedInstancesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteQueuedReservedInstancesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#reserved_instances_ids ⇒ Array<String>
The IDs of the Reserved Instances.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
19917 19918 19919 19920 19921 19922 |
# File 'lib/aws-sdk-ec2/types.rb', line 19917 class DeleteQueuedReservedInstancesRequest < Struct.new( :dry_run, :reserved_instances_ids) SENSITIVE = [] include Aws::Structure end |
#reserved_instances_ids ⇒ Array<String>
The IDs of the Reserved Instances.
19917 19918 19919 19920 19921 19922 |
# File 'lib/aws-sdk-ec2/types.rb', line 19917 class DeleteQueuedReservedInstancesRequest < Struct.new( :dry_run, :reserved_instances_ids) SENSITIVE = [] include Aws::Structure end |