Class: Aws::EC2::Types::DeleteQueuedReservedInstancesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


19713
19714
19715
19716
19717
19718
# File 'lib/aws-sdk-ec2/types.rb', line 19713

class DeleteQueuedReservedInstancesRequest < Struct.new(
  :dry_run,
  :reserved_instances_ids)
  SENSITIVE = []
  include Aws::Structure
end

#reserved_instances_idsArray<String>

The IDs of the Reserved Instances.

Returns:

  • (Array<String>)


19713
19714
19715
19716
19717
19718
# File 'lib/aws-sdk-ec2/types.rb', line 19713

class DeleteQueuedReservedInstancesRequest < Struct.new(
  :dry_run,
  :reserved_instances_ids)
  SENSITIVE = []
  include Aws::Structure
end