Class: Aws::EC2::Types::DeleteRouteRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#destination_cidr_blockString

The IPv4 CIDR range for the route. The value you specify must match the CIDR for the route exactly.

Returns:

  • (String)


20642
20643
20644
20645
20646
20647
20648
20649
20650
# File 'lib/aws-sdk-ec2/types.rb', line 20642

class DeleteRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :destination_ipv_6_cidr_block)
  SENSITIVE = []
  include Aws::Structure
end

#destination_ipv_6_cidr_blockString

The IPv6 CIDR range for the route. The value you specify must match the CIDR for the route exactly.

Returns:

  • (String)


20642
20643
20644
20645
20646
20647
20648
20649
20650
# File 'lib/aws-sdk-ec2/types.rb', line 20642

class DeleteRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :destination_ipv_6_cidr_block)
  SENSITIVE = []
  include Aws::Structure
end

#destination_prefix_list_idString

The ID of the prefix list for the route.

Returns:

  • (String)


20642
20643
20644
20645
20646
20647
20648
20649
20650
# File 'lib/aws-sdk-ec2/types.rb', line 20642

class DeleteRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :destination_ipv_6_cidr_block)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


20642
20643
20644
20645
20646
20647
20648
20649
20650
# File 'lib/aws-sdk-ec2/types.rb', line 20642

class DeleteRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :destination_ipv_6_cidr_block)
  SENSITIVE = []
  include Aws::Structure
end

#route_table_idString

The ID of the route table.

Returns:

  • (String)


20642
20643
20644
20645
20646
20647
20648
20649
20650
# File 'lib/aws-sdk-ec2/types.rb', line 20642

class DeleteRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :destination_ipv_6_cidr_block)
  SENSITIVE = []
  include Aws::Structure
end