Class: Aws::EC2::Types::DeleteRouteRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteRouteRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination_cidr_block ⇒ String
The IPv4 CIDR range for the route.
-
#destination_ipv_6_cidr_block ⇒ String
The IPv6 CIDR range for the route.
-
#destination_prefix_list_id ⇒ String
The ID of the prefix list for the route.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#route_table_id ⇒ String
The ID of the route table.
Instance Attribute Details
#destination_cidr_block ⇒ String
The IPv4 CIDR range for the route. The value you specify must match the CIDR for the route exactly.
19518 19519 19520 19521 19522 19523 19524 19525 19526 |
# File 'lib/aws-sdk-ec2/types.rb', line 19518 class DeleteRouteRequest < Struct.new( :destination_prefix_list_id, :dry_run, :route_table_id, :destination_cidr_block, :destination_ipv_6_cidr_block) SENSITIVE = [] include Aws::Structure end |
#destination_ipv_6_cidr_block ⇒ String
The IPv6 CIDR range for the route. The value you specify must match the CIDR for the route exactly.
19518 19519 19520 19521 19522 19523 19524 19525 19526 |
# File 'lib/aws-sdk-ec2/types.rb', line 19518 class DeleteRouteRequest < Struct.new( :destination_prefix_list_id, :dry_run, :route_table_id, :destination_cidr_block, :destination_ipv_6_cidr_block) SENSITIVE = [] include Aws::Structure end |
#destination_prefix_list_id ⇒ String
The ID of the prefix list for the route.
19518 19519 19520 19521 19522 19523 19524 19525 19526 |
# File 'lib/aws-sdk-ec2/types.rb', line 19518 class DeleteRouteRequest < Struct.new( :destination_prefix_list_id, :dry_run, :route_table_id, :destination_cidr_block, :destination_ipv_6_cidr_block) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
19518 19519 19520 19521 19522 19523 19524 19525 19526 |
# File 'lib/aws-sdk-ec2/types.rb', line 19518 class DeleteRouteRequest < Struct.new( :destination_prefix_list_id, :dry_run, :route_table_id, :destination_cidr_block, :destination_ipv_6_cidr_block) SENSITIVE = [] include Aws::Structure end |
#route_table_id ⇒ String
The ID of the route table.
19518 19519 19520 19521 19522 19523 19524 19525 19526 |
# File 'lib/aws-sdk-ec2/types.rb', line 19518 class DeleteRouteRequest < Struct.new( :destination_prefix_list_id, :dry_run, :route_table_id, :destination_cidr_block, :destination_ipv_6_cidr_block) SENSITIVE = [] include Aws::Structure end |