Class: Aws::EC2::Types::DeleteRouteRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#destination_cidr_blockString

The IPv4 CIDR range for the route. The value you specify must match the CIDR for the route exactly.

Returns:

  • (String)


19064
19065
19066
19067
19068
19069
19070
19071
19072
# File 'lib/aws-sdk-ec2/types.rb', line 19064

class DeleteRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :destination_ipv_6_cidr_block)
  SENSITIVE = []
  include Aws::Structure
end

#destination_ipv_6_cidr_blockString

The IPv6 CIDR range for the route. The value you specify must match the CIDR for the route exactly.

Returns:

  • (String)


19064
19065
19066
19067
19068
19069
19070
19071
19072
# File 'lib/aws-sdk-ec2/types.rb', line 19064

class DeleteRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :destination_ipv_6_cidr_block)
  SENSITIVE = []
  include Aws::Structure
end

#destination_prefix_list_idString

The ID of the prefix list for the route.

Returns:

  • (String)


19064
19065
19066
19067
19068
19069
19070
19071
19072
# File 'lib/aws-sdk-ec2/types.rb', line 19064

class DeleteRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :destination_ipv_6_cidr_block)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


19064
19065
19066
19067
19068
19069
19070
19071
19072
# File 'lib/aws-sdk-ec2/types.rb', line 19064

class DeleteRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :destination_ipv_6_cidr_block)
  SENSITIVE = []
  include Aws::Structure
end

#route_table_idString

The ID of the route table.

Returns:

  • (String)


19064
19065
19066
19067
19068
19069
19070
19071
19072
# File 'lib/aws-sdk-ec2/types.rb', line 19064

class DeleteRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :destination_ipv_6_cidr_block)
  SENSITIVE = []
  include Aws::Structure
end