Class: Aws::EC2::Types::DeleteRouteServerEndpointRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


19788
19789
19790
19791
19792
19793
# File 'lib/aws-sdk-ec2/types.rb', line 19788

class DeleteRouteServerEndpointRequest < Struct.new(
  :route_server_endpoint_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#route_server_endpoint_idString

The ID of the route server endpoint to delete.

Returns:

  • (String)


19788
19789
19790
19791
19792
19793
# File 'lib/aws-sdk-ec2/types.rb', line 19788

class DeleteRouteServerEndpointRequest < Struct.new(
  :route_server_endpoint_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end