Class: Aws::EC2::Types::DeleteRouteServerEndpointRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteRouteServerEndpointRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#route_server_endpoint_id ⇒ String
The ID of the route server endpoint to delete.
Instance Attribute Details
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
19739 19740 19741 19742 19743 19744 |
# File 'lib/aws-sdk-ec2/types.rb', line 19739 class DeleteRouteServerEndpointRequest < Struct.new( :route_server_endpoint_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#route_server_endpoint_id ⇒ String
The ID of the route server endpoint to delete.
19739 19740 19741 19742 19743 19744 |
# File 'lib/aws-sdk-ec2/types.rb', line 19739 class DeleteRouteServerEndpointRequest < Struct.new( :route_server_endpoint_id, :dry_run) SENSITIVE = [] include Aws::Structure end |