Class: Aws::EC2::Types::DeleteRouteServerPeerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteRouteServerPeerRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#route_server_peer_id ⇒ String
The ID of the route server peer to delete.
Instance Attribute Details
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
19119 19120 19121 19122 19123 19124 |
# File 'lib/aws-sdk-ec2/types.rb', line 19119 class DeleteRouteServerPeerRequest < Struct.new( :route_server_peer_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#route_server_peer_id ⇒ String
The ID of the route server peer to delete.
19119 19120 19121 19122 19123 19124 |
# File 'lib/aws-sdk-ec2/types.rb', line 19119 class DeleteRouteServerPeerRequest < Struct.new( :route_server_peer_id, :dry_run) SENSITIVE = [] include Aws::Structure end |