Class: Aws::EC2::Types::DeleteRouteServerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteRouteServerRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#route_server_id ⇒ String
The ID of the route server to delete.
Instance Attribute Details
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
19846 19847 19848 19849 19850 19851 |
# File 'lib/aws-sdk-ec2/types.rb', line 19846 class DeleteRouteServerRequest < Struct.new( :route_server_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#route_server_id ⇒ String
The ID of the route server to delete.
19846 19847 19848 19849 19850 19851 |
# File 'lib/aws-sdk-ec2/types.rb', line 19846 class DeleteRouteServerRequest < Struct.new( :route_server_id, :dry_run) SENSITIVE = [] include Aws::Structure end |