Class: Aws::EC2::Types::DeleteRouteServerRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


19797
19798
19799
19800
19801
19802
# File 'lib/aws-sdk-ec2/types.rb', line 19797

class DeleteRouteServerRequest < Struct.new(
  :route_server_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#route_server_idString

The ID of the route server to delete.

Returns:

  • (String)


19797
19798
19799
19800
19801
19802
# File 'lib/aws-sdk-ec2/types.rb', line 19797

class DeleteRouteServerRequest < Struct.new(
  :route_server_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end