Class: Aws::EC2::Types::DeleteRouteTableRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteRouteTableRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#route_table_id ⇒ String
The ID of the route table.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
21083 21084 21085 21086 21087 21088 |
# File 'lib/aws-sdk-ec2/types.rb', line 21083 class DeleteRouteTableRequest < Struct.new( :dry_run, :route_table_id) SENSITIVE = [] include Aws::Structure end |
#route_table_id ⇒ String
The ID of the route table.
21083 21084 21085 21086 21087 21088 |
# File 'lib/aws-sdk-ec2/types.rb', line 21083 class DeleteRouteTableRequest < Struct.new( :dry_run, :route_table_id) SENSITIVE = [] include Aws::Structure end |