Class: Aws::EC2::Types::DeleteRouteTableRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


21068
21069
21070
21071
21072
21073
# File 'lib/aws-sdk-ec2/types.rb', line 21068

class DeleteRouteTableRequest < Struct.new(
  :dry_run,
  :route_table_id)
  SENSITIVE = []
  include Aws::Structure
end

#route_table_idString

The ID of the route table.

Returns:

  • (String)


21068
21069
21070
21071
21072
21073
# File 'lib/aws-sdk-ec2/types.rb', line 21068

class DeleteRouteTableRequest < Struct.new(
  :dry_run,
  :route_table_id)
  SENSITIVE = []
  include Aws::Structure
end