Class: Aws::EC2::Types::DeleteRouteTableRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteRouteTableRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#route_table_id ⇒ String
The ID of the route table.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
19878 19879 19880 19881 19882 19883 |
# File 'lib/aws-sdk-ec2/types.rb', line 19878 class DeleteRouteTableRequest < Struct.new( :dry_run, :route_table_id) SENSITIVE = [] include Aws::Structure end |
#route_table_id ⇒ String
The ID of the route table.
19878 19879 19880 19881 19882 19883 |
# File 'lib/aws-sdk-ec2/types.rb', line 19878 class DeleteRouteTableRequest < Struct.new( :dry_run, :route_table_id) SENSITIVE = [] include Aws::Structure end |