Class: Aws::EC2::Types::DeleteSecondaryNetworkRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteSecondaryNetworkRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#secondary_network_id ⇒ String
The ID of the secondary network.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensure Idempotency.
A suitable default value is auto-generated. You should normally not need to pass this option.
21101 21102 21103 21104 21105 21106 21107 |
# File 'lib/aws-sdk-ec2/types.rb', line 21101 class DeleteSecondaryNetworkRequest < Struct.new( :client_token, :dry_run, :secondary_network_id) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
21101 21102 21103 21104 21105 21106 21107 |
# File 'lib/aws-sdk-ec2/types.rb', line 21101 class DeleteSecondaryNetworkRequest < Struct.new( :client_token, :dry_run, :secondary_network_id) SENSITIVE = [] include Aws::Structure end |
#secondary_network_id ⇒ String
The ID of the secondary network.
21101 21102 21103 21104 21105 21106 21107 |
# File 'lib/aws-sdk-ec2/types.rb', line 21101 class DeleteSecondaryNetworkRequest < Struct.new( :client_token, :dry_run, :secondary_network_id) SENSITIVE = [] include Aws::Structure end |