Class: Aws::EC2::Types::DeleteSecondaryNetworkRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensure Idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


20027
20028
20029
20030
20031
20032
20033
# File 'lib/aws-sdk-ec2/types.rb', line 20027

class DeleteSecondaryNetworkRequest < Struct.new(
  :client_token,
  :dry_run,
  :secondary_network_id)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


20027
20028
20029
20030
20031
20032
20033
# File 'lib/aws-sdk-ec2/types.rb', line 20027

class DeleteSecondaryNetworkRequest < Struct.new(
  :client_token,
  :dry_run,
  :secondary_network_id)
  SENSITIVE = []
  include Aws::Structure
end

#secondary_network_idString

The ID of the secondary network.

Returns:

  • (String)


20027
20028
20029
20030
20031
20032
20033
# File 'lib/aws-sdk-ec2/types.rb', line 20027

class DeleteSecondaryNetworkRequest < Struct.new(
  :client_token,
  :dry_run,
  :secondary_network_id)
  SENSITIVE = []
  include Aws::Structure
end