Class: Aws::EC2::Types::DeleteSecondaryNetworkResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier to ensure the idempotency of the request. Only returned if a client token was provided in the request.

Returns:

  • (String)


19678
19679
19680
19681
19682
19683
# File 'lib/aws-sdk-ec2/types.rb', line 19678

class DeleteSecondaryNetworkResult < Struct.new(
  :secondary_network,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#secondary_networkTypes::SecondaryNetwork

Information about the secondary network.



19678
19679
19680
19681
19682
19683
# File 'lib/aws-sdk-ec2/types.rb', line 19678

class DeleteSecondaryNetworkResult < Struct.new(
  :secondary_network,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end