Class: Aws::EC2::Types::DeleteSecondaryNetworkResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteSecondaryNetworkResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier to ensure the idempotency of the request.
-
#secondary_network ⇒ Types::SecondaryNetwork
Information about the secondary network.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier to ensure the idempotency of the request. Only returned if a client token was provided in the request.
19458 19459 19460 19461 19462 19463 |
# File 'lib/aws-sdk-ec2/types.rb', line 19458 class DeleteSecondaryNetworkResult < Struct.new( :secondary_network, :client_token) SENSITIVE = [] include Aws::Structure end |
#secondary_network ⇒ Types::SecondaryNetwork
Information about the secondary network.
19458 19459 19460 19461 19462 19463 |
# File 'lib/aws-sdk-ec2/types.rb', line 19458 class DeleteSecondaryNetworkResult < Struct.new( :secondary_network, :client_token) SENSITIVE = [] include Aws::Structure end |