Class: Aws::EC2::Types::DeleteSecondarySubnetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [Ensure Idempotency].

**A suitable default value is auto-generated.** You should normally not need to pass this option.

[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html

Returns:

  • (String)


19491
19492
19493
19494
19495
19496
19497
# File 'lib/aws-sdk-ec2/types.rb', line 19491

class DeleteSecondarySubnetRequest < Struct.new(
  :client_token,
  :dry_run,
  :secondary_subnet_id)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


19491
19492
19493
19494
19495
19496
19497
# File 'lib/aws-sdk-ec2/types.rb', line 19491

class DeleteSecondarySubnetRequest < Struct.new(
  :client_token,
  :dry_run,
  :secondary_subnet_id)
  SENSITIVE = []
  include Aws::Structure
end

#secondary_subnet_idString

The ID of the secondary subnet to delete.

Returns:

  • (String)


19491
19492
19493
19494
19495
19496
19497
# File 'lib/aws-sdk-ec2/types.rb', line 19491

class DeleteSecondarySubnetRequest < Struct.new(
  :client_token,
  :dry_run,
  :secondary_subnet_id)
  SENSITIVE = []
  include Aws::Structure
end