Class: Aws::EC2::Types::DeleteSecurityGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


19758
19759
19760
19761
19762
19763
19764
# File 'lib/aws-sdk-ec2/types.rb', line 19758

class DeleteSecurityGroupRequest < Struct.new(
  :group_id,
  :group_name,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#group_idString

The ID of the security group.

Returns:

  • (String)


19758
19759
19760
19761
19762
19763
19764
# File 'lib/aws-sdk-ec2/types.rb', line 19758

class DeleteSecurityGroupRequest < Struct.new(
  :group_id,
  :group_name,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#group_nameString

[Default VPC] The name of the security group. You can specify either the security group name or the security group ID. For security groups in a nondefault VPC, you must specify the security group ID.

Returns:

  • (String)


19758
19759
19760
19761
19762
19763
19764
# File 'lib/aws-sdk-ec2/types.rb', line 19758

class DeleteSecurityGroupRequest < Struct.new(
  :group_id,
  :group_name,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end