Class: Aws::EC2::Types::DeleteSnapshotRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteSnapshotRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#snapshot_id ⇒ String
The ID of the EBS snapshot.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
20055 20056 20057 20058 20059 20060 |
# File 'lib/aws-sdk-ec2/types.rb', line 20055 class DeleteSnapshotRequest < Struct.new( :snapshot_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#snapshot_id ⇒ String
The ID of the EBS snapshot.
20055 20056 20057 20058 20059 20060 |
# File 'lib/aws-sdk-ec2/types.rb', line 20055 class DeleteSnapshotRequest < Struct.new( :snapshot_id, :dry_run) SENSITIVE = [] include Aws::Structure end |