Class: Aws::EC2::Types::DeleteSpotDatafeedSubscriptionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for DeleteSpotDatafeedSubscription.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


20265
20266
20267
20268
20269
# File 'lib/aws-sdk-ec2/types.rb', line 20265

class DeleteSpotDatafeedSubscriptionRequest < Struct.new(
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end