Class: Aws::EC2::Types::DeleteSpotDatafeedSubscriptionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteSpotDatafeedSubscriptionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for DeleteSpotDatafeedSubscription.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
20061 20062 20063 20064 20065 |
# File 'lib/aws-sdk-ec2/types.rb', line 20061 class DeleteSpotDatafeedSubscriptionRequest < Struct.new( :dry_run) SENSITIVE = [] include Aws::Structure end |