Class: Aws::EC2::Types::DeleteSubnetCidrReservationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


21012
21013
21014
21015
21016
21017
# File 'lib/aws-sdk-ec2/types.rb', line 21012

class DeleteSubnetCidrReservationRequest < Struct.new(
  :subnet_cidr_reservation_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_cidr_reservation_idString

The ID of the subnet CIDR reservation.

Returns:

  • (String)


21012
21013
21014
21015
21016
21017
# File 'lib/aws-sdk-ec2/types.rb', line 21012

class DeleteSubnetCidrReservationRequest < Struct.new(
  :subnet_cidr_reservation_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end