Class: Aws::EC2::Types::DeleteSubnetCidrReservationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


20339
20340
20341
20342
20343
20344
# File 'lib/aws-sdk-ec2/types.rb', line 20339

class DeleteSubnetCidrReservationRequest < Struct.new(
  :subnet_cidr_reservation_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_cidr_reservation_idString

The ID of the subnet CIDR reservation.

Returns:

  • (String)


20339
20340
20341
20342
20343
20344
# File 'lib/aws-sdk-ec2/types.rb', line 20339

class DeleteSubnetCidrReservationRequest < Struct.new(
  :subnet_cidr_reservation_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end