Class: Aws::EC2::Types::DeleteSubnetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteSubnetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#subnet_id ⇒ String
The ID of the subnet.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
21369 21370 21371 21372 21373 21374 |
# File 'lib/aws-sdk-ec2/types.rb', line 21369 class DeleteSubnetRequest < Struct.new( :subnet_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#subnet_id ⇒ String
The ID of the subnet.
21369 21370 21371 21372 21373 21374 |
# File 'lib/aws-sdk-ec2/types.rb', line 21369 class DeleteSubnetRequest < Struct.new( :subnet_id, :dry_run) SENSITIVE = [] include Aws::Structure end |