Class: Aws::EC2::Types::DeleteSubnetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


19360
19361
19362
19363
19364
19365
# File 'lib/aws-sdk-ec2/types.rb', line 19360

class DeleteSubnetRequest < Struct.new(
  :subnet_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idString

The ID of the subnet.

Returns:

  • (String)


19360
19361
19362
19363
19364
19365
# File 'lib/aws-sdk-ec2/types.rb', line 19360

class DeleteSubnetRequest < Struct.new(
  :subnet_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end