Class: Aws::EC2::Types::DeleteTrafficMirrorSessionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


20493
20494
20495
20496
20497
20498
# File 'lib/aws-sdk-ec2/types.rb', line 20493

class DeleteTrafficMirrorSessionRequest < Struct.new(
  :traffic_mirror_session_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#traffic_mirror_session_idString

The ID of the Traffic Mirror session.

Returns:

  • (String)


20493
20494
20495
20496
20497
20498
# File 'lib/aws-sdk-ec2/types.rb', line 20493

class DeleteTrafficMirrorSessionRequest < Struct.new(
  :traffic_mirror_session_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end