Class: Aws::EC2::Types::DeleteTrafficMirrorSessionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteTrafficMirrorSessionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#traffic_mirror_session_id ⇒ String
The ID of the Traffic Mirror session.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
20438 20439 20440 20441 20442 20443 |
# File 'lib/aws-sdk-ec2/types.rb', line 20438 class DeleteTrafficMirrorSessionRequest < Struct.new( :traffic_mirror_session_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#traffic_mirror_session_id ⇒ String
The ID of the Traffic Mirror session.
20438 20439 20440 20441 20442 20443 |
# File 'lib/aws-sdk-ec2/types.rb', line 20438 class DeleteTrafficMirrorSessionRequest < Struct.new( :traffic_mirror_session_id, :dry_run) SENSITIVE = [] include Aws::Structure end |