Class: Aws::EC2::Types::DeleteTrafficMirrorSessionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


19476
19477
19478
19479
19480
19481
# File 'lib/aws-sdk-ec2/types.rb', line 19476

class DeleteTrafficMirrorSessionRequest < Struct.new(
  :traffic_mirror_session_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#traffic_mirror_session_idString

The ID of the Traffic Mirror session.

Returns:

  • (String)


19476
19477
19478
19479
19480
19481
# File 'lib/aws-sdk-ec2/types.rb', line 19476

class DeleteTrafficMirrorSessionRequest < Struct.new(
  :traffic_mirror_session_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end