Class: Aws::EC2::Types::DeleteTrafficMirrorTargetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteTrafficMirrorTargetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#traffic_mirror_target_id ⇒ String
The ID of the Traffic Mirror target.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
21198 21199 21200 21201 21202 21203 |
# File 'lib/aws-sdk-ec2/types.rb', line 21198 class DeleteTrafficMirrorTargetRequest < Struct.new( :traffic_mirror_target_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#traffic_mirror_target_id ⇒ String
The ID of the Traffic Mirror target.
21198 21199 21200 21201 21202 21203 |
# File 'lib/aws-sdk-ec2/types.rb', line 21198 class DeleteTrafficMirrorTargetRequest < Struct.new( :traffic_mirror_target_id, :dry_run) SENSITIVE = [] include Aws::Structure end |