Class: Aws::EC2::Types::DeleteTrafficMirrorTargetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


20431
20432
20433
20434
20435
20436
# File 'lib/aws-sdk-ec2/types.rb', line 20431

class DeleteTrafficMirrorTargetRequest < Struct.new(
  :traffic_mirror_target_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#traffic_mirror_target_idString

The ID of the Traffic Mirror target.

Returns:

  • (String)


20431
20432
20433
20434
20435
20436
# File 'lib/aws-sdk-ec2/types.rb', line 20431

class DeleteTrafficMirrorTargetRequest < Struct.new(
  :traffic_mirror_target_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end