Class: Aws::EC2::Types::DeleteTransitGatewayClientVpnAttachmentRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


20477
20478
20479
20480
20481
20482
# File 'lib/aws-sdk-ec2/types.rb', line 20477

class DeleteTransitGatewayClientVpnAttachmentRequest < Struct.new(
  :transit_gateway_attachment_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_attachment_idString

The ID of the Transit Gateway attachment.

Returns:

  • (String)


20477
20478
20479
20480
20481
20482
# File 'lib/aws-sdk-ec2/types.rb', line 20477

class DeleteTransitGatewayClientVpnAttachmentRequest < Struct.new(
  :transit_gateway_attachment_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end