Class: Aws::EC2::Types::DeleteTransitGatewayConnectPeerRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


20589
20590
20591
20592
20593
20594
# File 'lib/aws-sdk-ec2/types.rb', line 20589

class DeleteTransitGatewayConnectPeerRequest < Struct.new(
  :transit_gateway_connect_peer_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_connect_peer_idString

The ID of the Connect peer.

Returns:

  • (String)


20589
20590
20591
20592
20593
20594
# File 'lib/aws-sdk-ec2/types.rb', line 20589

class DeleteTransitGatewayConnectPeerRequest < Struct.new(
  :transit_gateway_connect_peer_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end