Class: Aws::EC2::Types::DeleteTransitGatewayConnectPeerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteTransitGatewayConnectPeerRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#transit_gateway_connect_peer_id ⇒ String
The ID of the Connect peer.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
19546 19547 19548 19549 19550 19551 |
# File 'lib/aws-sdk-ec2/types.rb', line 19546 class DeleteTransitGatewayConnectPeerRequest < Struct.new( :transit_gateway_connect_peer_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_connect_peer_id ⇒ String
The ID of the Connect peer.
19546 19547 19548 19549 19550 19551 |
# File 'lib/aws-sdk-ec2/types.rb', line 19546 class DeleteTransitGatewayConnectPeerRequest < Struct.new( :transit_gateway_connect_peer_id, :dry_run) SENSITIVE = [] include Aws::Structure end |