Class: Aws::EC2::Types::DeleteTransitGatewayConnectRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


20170
20171
20172
20173
20174
20175
# File 'lib/aws-sdk-ec2/types.rb', line 20170

class DeleteTransitGatewayConnectRequest < Struct.new(
  :transit_gateway_attachment_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_attachment_idString

The ID of the Connect attachment.

Returns:

  • (String)


20170
20171
20172
20173
20174
20175
# File 'lib/aws-sdk-ec2/types.rb', line 20170

class DeleteTransitGatewayConnectRequest < Struct.new(
  :transit_gateway_attachment_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end