Class: Aws::EC2::Types::DeleteTransitGatewayMeteringPolicyEntryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


20564
20565
20566
20567
20568
20569
20570
# File 'lib/aws-sdk-ec2/types.rb', line 20564

class DeleteTransitGatewayMeteringPolicyEntryRequest < Struct.new(
  :transit_gateway_metering_policy_id,
  :policy_rule_number,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#policy_rule_numberInteger

The rule number of the metering policy entry to delete.

Returns:

  • (Integer)


20564
20565
20566
20567
20568
20569
20570
# File 'lib/aws-sdk-ec2/types.rb', line 20564

class DeleteTransitGatewayMeteringPolicyEntryRequest < Struct.new(
  :transit_gateway_metering_policy_id,
  :policy_rule_number,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_metering_policy_idString

The ID of the transit gateway metering policy containing the entry to delete.

Returns:

  • (String)


20564
20565
20566
20567
20568
20569
20570
# File 'lib/aws-sdk-ec2/types.rb', line 20564

class DeleteTransitGatewayMeteringPolicyEntryRequest < Struct.new(
  :transit_gateway_metering_policy_id,
  :policy_rule_number,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end