Class: Aws::EC2::Types::DeleteTransitGatewayMeteringPolicyEntryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteTransitGatewayMeteringPolicyEntryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#policy_rule_number ⇒ Integer
The rule number of the metering policy entry to delete.
-
#transit_gateway_metering_policy_id ⇒ String
The ID of the transit gateway metering policy containing the entry to delete.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
20195 20196 20197 20198 20199 20200 20201 |
# File 'lib/aws-sdk-ec2/types.rb', line 20195 class DeleteTransitGatewayMeteringPolicyEntryRequest < Struct.new( :transit_gateway_metering_policy_id, :policy_rule_number, :dry_run) SENSITIVE = [] include Aws::Structure end |
#policy_rule_number ⇒ Integer
The rule number of the metering policy entry to delete.
20195 20196 20197 20198 20199 20200 20201 |
# File 'lib/aws-sdk-ec2/types.rb', line 20195 class DeleteTransitGatewayMeteringPolicyEntryRequest < Struct.new( :transit_gateway_metering_policy_id, :policy_rule_number, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_metering_policy_id ⇒ String
The ID of the transit gateway metering policy containing the entry to delete.
20195 20196 20197 20198 20199 20200 20201 |
# File 'lib/aws-sdk-ec2/types.rb', line 20195 class DeleteTransitGatewayMeteringPolicyEntryRequest < Struct.new( :transit_gateway_metering_policy_id, :policy_rule_number, :dry_run) SENSITIVE = [] include Aws::Structure end |