Class: Aws::EC2::Types::DeleteTransitGatewayMeteringPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteTransitGatewayMeteringPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#transit_gateway_metering_policy_id ⇒ String
The ID of the transit gateway metering policy to delete.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
21364 21365 21366 21367 21368 21369 |
# File 'lib/aws-sdk-ec2/types.rb', line 21364 class DeleteTransitGatewayMeteringPolicyRequest < Struct.new( :transit_gateway_metering_policy_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_metering_policy_id ⇒ String
The ID of the transit gateway metering policy to delete.
21364 21365 21366 21367 21368 21369 |
# File 'lib/aws-sdk-ec2/types.rb', line 21364 class DeleteTransitGatewayMeteringPolicyRequest < Struct.new( :transit_gateway_metering_policy_id, :dry_run) SENSITIVE = [] include Aws::Structure end |