Class: Aws::EC2::Types::DeleteTransitGatewayMeteringPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


20487
20488
20489
20490
20491
20492
# File 'lib/aws-sdk-ec2/types.rb', line 20487

class DeleteTransitGatewayMeteringPolicyRequest < Struct.new(
  :transit_gateway_metering_policy_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_metering_policy_idString

The ID of the transit gateway metering policy to delete.

Returns:

  • (String)


20487
20488
20489
20490
20491
20492
# File 'lib/aws-sdk-ec2/types.rb', line 20487

class DeleteTransitGatewayMeteringPolicyRequest < Struct.new(
  :transit_gateway_metering_policy_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end