Class: Aws::EC2::Types::DeleteTransitGatewayMulticastDomainRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


21712
21713
21714
21715
21716
21717
# File 'lib/aws-sdk-ec2/types.rb', line 21712

class DeleteTransitGatewayMulticastDomainRequest < Struct.new(
  :transit_gateway_multicast_domain_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_multicast_domain_idString

The ID of the transit gateway multicast domain.

Returns:

  • (String)


21712
21713
21714
21715
21716
21717
# File 'lib/aws-sdk-ec2/types.rb', line 21712

class DeleteTransitGatewayMulticastDomainRequest < Struct.new(
  :transit_gateway_multicast_domain_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end