Class: Aws::EC2::Types::DeleteTransitGatewayMulticastDomainRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteTransitGatewayMulticastDomainRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#transit_gateway_multicast_domain_id ⇒ String
The ID of the transit gateway multicast domain.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
20643 20644 20645 20646 20647 20648 |
# File 'lib/aws-sdk-ec2/types.rb', line 20643 class DeleteTransitGatewayMulticastDomainRequest < Struct.new( :transit_gateway_multicast_domain_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_multicast_domain_id ⇒ String
The ID of the transit gateway multicast domain.
20643 20644 20645 20646 20647 20648 |
# File 'lib/aws-sdk-ec2/types.rb', line 20643 class DeleteTransitGatewayMulticastDomainRequest < Struct.new( :transit_gateway_multicast_domain_id, :dry_run) SENSITIVE = [] include Aws::Structure end |