Class: Aws::EC2::Types::DeleteTransitGatewayPolicyTableEntryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


21771
21772
21773
21774
21775
21776
21777
# File 'lib/aws-sdk-ec2/types.rb', line 21771

class DeleteTransitGatewayPolicyTableEntryRequest < Struct.new(
  :transit_gateway_policy_table_id,
  :policy_rule_number,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#policy_rule_numberString

The rule number of the policy table entry to delete.

Returns:

  • (String)


21771
21772
21773
21774
21775
21776
21777
# File 'lib/aws-sdk-ec2/types.rb', line 21771

class DeleteTransitGatewayPolicyTableEntryRequest < Struct.new(
  :transit_gateway_policy_table_id,
  :policy_rule_number,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_policy_table_idString

The ID of the transit gateway policy table.

Returns:

  • (String)


21771
21772
21773
21774
21775
21776
21777
# File 'lib/aws-sdk-ec2/types.rb', line 21771

class DeleteTransitGatewayPolicyTableEntryRequest < Struct.new(
  :transit_gateway_policy_table_id,
  :policy_rule_number,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end