Class: Aws::EC2::Types::DeleteTransitGatewayPolicyTableRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


20534
20535
20536
20537
20538
20539
# File 'lib/aws-sdk-ec2/types.rb', line 20534

class DeleteTransitGatewayPolicyTableRequest < Struct.new(
  :transit_gateway_policy_table_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_policy_table_idString

The transit gateway policy table to delete.

Returns:

  • (String)


20534
20535
20536
20537
20538
20539
# File 'lib/aws-sdk-ec2/types.rb', line 20534

class DeleteTransitGatewayPolicyTableRequest < Struct.new(
  :transit_gateway_policy_table_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end