Class: Aws::EC2::Types::DeleteTransitGatewayRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


20801
20802
20803
20804
20805
20806
# File 'lib/aws-sdk-ec2/types.rb', line 20801

class DeleteTransitGatewayRequest < Struct.new(
  :transit_gateway_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_idString

The ID of the transit gateway.

Returns:

  • (String)


20801
20802
20803
20804
20805
20806
# File 'lib/aws-sdk-ec2/types.rb', line 20801

class DeleteTransitGatewayRequest < Struct.new(
  :transit_gateway_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end