Class: Aws::EC2::Types::DeleteTransitGatewayRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteTransitGatewayRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#transit_gateway_id ⇒ String
The ID of the transit gateway.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
20646 20647 20648 20649 20650 20651 |
# File 'lib/aws-sdk-ec2/types.rb', line 20646 class DeleteTransitGatewayRequest < Struct.new( :transit_gateway_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_id ⇒ String
The ID of the transit gateway.
20646 20647 20648 20649 20650 20651 |
# File 'lib/aws-sdk-ec2/types.rb', line 20646 class DeleteTransitGatewayRequest < Struct.new( :transit_gateway_id, :dry_run) SENSITIVE = [] include Aws::Structure end |