Class: Aws::EC2::Types::DeleteTransitGatewayRouteRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteTransitGatewayRouteRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination_cidr_block ⇒ String
The CIDR range for the route.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#transit_gateway_route_table_id ⇒ String
The ID of the transit gateway route table.
Instance Attribute Details
#destination_cidr_block ⇒ String
The CIDR range for the route. This must match the CIDR for the route exactly.
20178 20179 20180 20181 20182 20183 20184 |
# File 'lib/aws-sdk-ec2/types.rb', line 20178 class DeleteTransitGatewayRouteRequest < Struct.new( :transit_gateway_route_table_id, :destination_cidr_block, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
20178 20179 20180 20181 20182 20183 20184 |
# File 'lib/aws-sdk-ec2/types.rb', line 20178 class DeleteTransitGatewayRouteRequest < Struct.new( :transit_gateway_route_table_id, :destination_cidr_block, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_route_table_id ⇒ String
The ID of the transit gateway route table.
20178 20179 20180 20181 20182 20183 20184 |
# File 'lib/aws-sdk-ec2/types.rb', line 20178 class DeleteTransitGatewayRouteRequest < Struct.new( :transit_gateway_route_table_id, :destination_cidr_block, :dry_run) SENSITIVE = [] include Aws::Structure end |