Class: Aws::EC2::Types::DeleteTransitGatewayRouteRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteTransitGatewayRouteRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination_cidr_block ⇒ String
The CIDR range for the route.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#transit_gateway_route_table_id ⇒ String
The ID of the transit gateway route table.
Instance Attribute Details
#destination_cidr_block ⇒ String
The CIDR range for the route. This must match the CIDR for the route exactly.
19850 19851 19852 19853 19854 19855 19856 |
# File 'lib/aws-sdk-ec2/types.rb', line 19850 class DeleteTransitGatewayRouteRequest < Struct.new( :transit_gateway_route_table_id, :destination_cidr_block, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
19850 19851 19852 19853 19854 19855 19856 |
# File 'lib/aws-sdk-ec2/types.rb', line 19850 class DeleteTransitGatewayRouteRequest < Struct.new( :transit_gateway_route_table_id, :destination_cidr_block, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_route_table_id ⇒ String
The ID of the transit gateway route table.
19850 19851 19852 19853 19854 19855 19856 |
# File 'lib/aws-sdk-ec2/types.rb', line 19850 class DeleteTransitGatewayRouteRequest < Struct.new( :transit_gateway_route_table_id, :destination_cidr_block, :dry_run) SENSITIVE = [] include Aws::Structure end |