Class: Aws::EC2::Types::DeleteTransitGatewayRouteTableAnnouncementRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteTransitGatewayRouteTableAnnouncementRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#transit_gateway_route_table_announcement_id ⇒ String
The transit gateway route table ID that's being deleted.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
21943 21944 21945 21946 21947 21948 |
# File 'lib/aws-sdk-ec2/types.rb', line 21943 class DeleteTransitGatewayRouteTableAnnouncementRequest < Struct.new( :transit_gateway_route_table_announcement_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_route_table_announcement_id ⇒ String
The transit gateway route table ID that's being deleted.
21943 21944 21945 21946 21947 21948 |
# File 'lib/aws-sdk-ec2/types.rb', line 21943 class DeleteTransitGatewayRouteTableAnnouncementRequest < Struct.new( :transit_gateway_route_table_announcement_id, :dry_run) SENSITIVE = [] include Aws::Structure end |