Class: Aws::EC2::Types::DeleteTransitGatewayRouteTableAnnouncementRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteTransitGatewayRouteTableAnnouncementRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#transit_gateway_route_table_announcement_id ⇒ String
The transit gateway route table ID that's being deleted.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
20846 20847 20848 20849 20850 20851 |
# File 'lib/aws-sdk-ec2/types.rb', line 20846 class DeleteTransitGatewayRouteTableAnnouncementRequest < Struct.new( :transit_gateway_route_table_announcement_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_route_table_announcement_id ⇒ String
The transit gateway route table ID that's being deleted.
20846 20847 20848 20849 20850 20851 |
# File 'lib/aws-sdk-ec2/types.rb', line 20846 class DeleteTransitGatewayRouteTableAnnouncementRequest < Struct.new( :transit_gateway_route_table_announcement_id, :dry_run) SENSITIVE = [] include Aws::Structure end |