Class: Aws::EC2::Types::DeleteTransitGatewayRouteTableAnnouncementRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


20463
20464
20465
20466
20467
20468
# File 'lib/aws-sdk-ec2/types.rb', line 20463

class DeleteTransitGatewayRouteTableAnnouncementRequest < Struct.new(
  :transit_gateway_route_table_announcement_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_route_table_announcement_idString

The transit gateway route table ID that’s being deleted.

Returns:

  • (String)


20463
20464
20465
20466
20467
20468
# File 'lib/aws-sdk-ec2/types.rb', line 20463

class DeleteTransitGatewayRouteTableAnnouncementRequest < Struct.new(
  :transit_gateway_route_table_announcement_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end