Class: Aws::EC2::Types::DeleteTransitGatewayRouteTableRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


21668
21669
21670
21671
21672
21673
# File 'lib/aws-sdk-ec2/types.rb', line 21668

class DeleteTransitGatewayRouteTableRequest < Struct.new(
  :transit_gateway_route_table_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_route_table_idString

The ID of the transit gateway route table.

Returns:

  • (String)


21668
21669
21670
21671
21672
21673
# File 'lib/aws-sdk-ec2/types.rb', line 21668

class DeleteTransitGatewayRouteTableRequest < Struct.new(
  :transit_gateway_route_table_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end