Class: Aws::EC2::Types::DeleteTransitGatewayVpcAttachmentRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


21700
21701
21702
21703
21704
21705
# File 'lib/aws-sdk-ec2/types.rb', line 21700

class DeleteTransitGatewayVpcAttachmentRequest < Struct.new(
  :transit_gateway_attachment_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_attachment_idString

The ID of the attachment.

Returns:

  • (String)


21700
21701
21702
21703
21704
21705
# File 'lib/aws-sdk-ec2/types.rb', line 21700

class DeleteTransitGatewayVpcAttachmentRequest < Struct.new(
  :transit_gateway_attachment_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end