Class: Aws::EC2::Types::DeleteTransitGatewayVpcAttachmentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteTransitGatewayVpcAttachmentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#transit_gateway_attachment_id ⇒ String
The ID of the attachment.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
20275 20276 20277 20278 20279 20280 |
# File 'lib/aws-sdk-ec2/types.rb', line 20275 class DeleteTransitGatewayVpcAttachmentRequest < Struct.new( :transit_gateway_attachment_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_attachment_id ⇒ String
The ID of the attachment.
20275 20276 20277 20278 20279 20280 |
# File 'lib/aws-sdk-ec2/types.rb', line 20275 class DeleteTransitGatewayVpcAttachmentRequest < Struct.new( :transit_gateway_attachment_id, :dry_run) SENSITIVE = [] include Aws::Structure end |