Class: Aws::EC2::Types::DeleteVerifiedAccessEndpointRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see [Ensuring idempotency].

**A suitable default value is auto-generated.** You should normally not need to pass this option.

[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html

Returns:

  • (String)


20825
20826
20827
20828
20829
20830
20831
# File 'lib/aws-sdk-ec2/types.rb', line 20825

class DeleteVerifiedAccessEndpointRequest < Struct.new(
  :verified_access_endpoint_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


20825
20826
20827
20828
20829
20830
20831
# File 'lib/aws-sdk-ec2/types.rb', line 20825

class DeleteVerifiedAccessEndpointRequest < Struct.new(
  :verified_access_endpoint_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#verified_access_endpoint_idString

The ID of the Verified Access endpoint.

Returns:

  • (String)


20825
20826
20827
20828
20829
20830
20831
# File 'lib/aws-sdk-ec2/types.rb', line 20825

class DeleteVerifiedAccessEndpointRequest < Struct.new(
  :verified_access_endpoint_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end