Class: Aws::EC2::Types::DeleteVerifiedAccessGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteVerifiedAccessGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#verified_access_group_id ⇒ String
The ID of the Verified Access group.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring idempotency.
A suitable default value is auto-generated. You should normally not need to pass this option.
21791 21792 21793 21794 21795 21796 21797 |
# File 'lib/aws-sdk-ec2/types.rb', line 21791 class DeleteVerifiedAccessGroupRequest < Struct.new( :verified_access_group_id, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
21791 21792 21793 21794 21795 21796 21797 |
# File 'lib/aws-sdk-ec2/types.rb', line 21791 class DeleteVerifiedAccessGroupRequest < Struct.new( :verified_access_group_id, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#verified_access_group_id ⇒ String
The ID of the Verified Access group.
21791 21792 21793 21794 21795 21796 21797 |
# File 'lib/aws-sdk-ec2/types.rb', line 21791 class DeleteVerifiedAccessGroupRequest < Struct.new( :verified_access_group_id, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |