Class: Aws::EC2::Types::DeleteVerifiedAccessGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


21026
21027
21028
21029
21030
21031
21032
# File 'lib/aws-sdk-ec2/types.rb', line 21026

class DeleteVerifiedAccessGroupRequest < Struct.new(
  :verified_access_group_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


21026
21027
21028
21029
21030
21031
21032
# File 'lib/aws-sdk-ec2/types.rb', line 21026

class DeleteVerifiedAccessGroupRequest < Struct.new(
  :verified_access_group_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#verified_access_group_idString

The ID of the Verified Access group.

Returns:

  • (String)


21026
21027
21028
21029
21030
21031
21032
# File 'lib/aws-sdk-ec2/types.rb', line 21026

class DeleteVerifiedAccessGroupRequest < Struct.new(
  :verified_access_group_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end