Class: Aws::EC2::Types::DeleteVerifiedAccessGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see [Ensuring idempotency].

**A suitable default value is auto-generated.** You should normally not need to pass this option.

[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html

Returns:

  • (String)


20366
20367
20368
20369
20370
20371
20372
# File 'lib/aws-sdk-ec2/types.rb', line 20366

class DeleteVerifiedAccessGroupRequest < Struct.new(
  :verified_access_group_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


20366
20367
20368
20369
20370
20371
20372
# File 'lib/aws-sdk-ec2/types.rb', line 20366

class DeleteVerifiedAccessGroupRequest < Struct.new(
  :verified_access_group_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#verified_access_group_idString

The ID of the Verified Access group.

Returns:

  • (String)


20366
20367
20368
20369
20370
20371
20372
# File 'lib/aws-sdk-ec2/types.rb', line 20366

class DeleteVerifiedAccessGroupRequest < Struct.new(
  :verified_access_group_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end