Class: Aws::EC2::Types::DeleteVerifiedAccessTrustProviderRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteVerifiedAccessTrustProviderRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#verified_access_trust_provider_id ⇒ String
The ID of the Verified Access trust provider.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring idempotency.
A suitable default value is auto-generated. You should normally not need to pass this option.
22199 22200 22201 22202 22203 22204 22205 |
# File 'lib/aws-sdk-ec2/types.rb', line 22199 class DeleteVerifiedAccessTrustProviderRequest < Struct.new( :verified_access_trust_provider_id, :dry_run, :client_token) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
22199 22200 22201 22202 22203 22204 22205 |
# File 'lib/aws-sdk-ec2/types.rb', line 22199 class DeleteVerifiedAccessTrustProviderRequest < Struct.new( :verified_access_trust_provider_id, :dry_run, :client_token) SENSITIVE = [] include Aws::Structure end |
#verified_access_trust_provider_id ⇒ String
The ID of the Verified Access trust provider.
22199 22200 22201 22202 22203 22204 22205 |
# File 'lib/aws-sdk-ec2/types.rb', line 22199 class DeleteVerifiedAccessTrustProviderRequest < Struct.new( :verified_access_trust_provider_id, :dry_run, :client_token) SENSITIVE = [] include Aws::Structure end |