Class: Aws::EC2::Types::DeleteVerifiedAccessTrustProviderRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


22190
22191
22192
22193
22194
22195
22196
# File 'lib/aws-sdk-ec2/types.rb', line 22190

class DeleteVerifiedAccessTrustProviderRequest < Struct.new(
  :verified_access_trust_provider_id,
  :dry_run,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


22190
22191
22192
22193
22194
22195
22196
# File 'lib/aws-sdk-ec2/types.rb', line 22190

class DeleteVerifiedAccessTrustProviderRequest < Struct.new(
  :verified_access_trust_provider_id,
  :dry_run,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#verified_access_trust_provider_idString

The ID of the Verified Access trust provider.

Returns:

  • (String)


22190
22191
22192
22193
22194
22195
22196
# File 'lib/aws-sdk-ec2/types.rb', line 22190

class DeleteVerifiedAccessTrustProviderRequest < Struct.new(
  :verified_access_trust_provider_id,
  :dry_run,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end