Class: Aws::EC2::Types::DeleteVolumeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteVolumeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#volume_id ⇒ String
The ID of the volume.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
21243 21244 21245 21246 21247 21248 |
# File 'lib/aws-sdk-ec2/types.rb', line 21243 class DeleteVolumeRequest < Struct.new( :volume_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#volume_id ⇒ String
The ID of the volume.
21243 21244 21245 21246 21247 21248 |
# File 'lib/aws-sdk-ec2/types.rb', line 21243 class DeleteVolumeRequest < Struct.new( :volume_id, :dry_run) SENSITIVE = [] include Aws::Structure end |