Class: Aws::EC2::Types::DeleteVolumeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


20947
20948
20949
20950
20951
20952
# File 'lib/aws-sdk-ec2/types.rb', line 20947

class DeleteVolumeRequest < Struct.new(
  :volume_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#volume_idString

The ID of the volume.

Returns:

  • (String)


20947
20948
20949
20950
20951
20952
# File 'lib/aws-sdk-ec2/types.rb', line 20947

class DeleteVolumeRequest < Struct.new(
  :volume_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end