Class: Aws::EC2::Types::DeleteVolumeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteVolumeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#volume_id ⇒ String
The ID of the volume.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
20755 20756 20757 20758 20759 20760 |
# File 'lib/aws-sdk-ec2/types.rb', line 20755 class DeleteVolumeRequest < Struct.new( :volume_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#volume_id ⇒ String
The ID of the volume.
20755 20756 20757 20758 20759 20760 |
# File 'lib/aws-sdk-ec2/types.rb', line 20755 class DeleteVolumeRequest < Struct.new( :volume_id, :dry_run) SENSITIVE = [] include Aws::Structure end |