Class: Aws::EC2::Types::DeleteVpcBlockPublicAccessExclusionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


21171
21172
21173
21174
21175
21176
# File 'lib/aws-sdk-ec2/types.rb', line 21171

class DeleteVpcBlockPublicAccessExclusionRequest < Struct.new(
  :dry_run,
  :exclusion_id)
  SENSITIVE = []
  include Aws::Structure
end

#exclusion_idString

The ID of the exclusion.

Returns:

  • (String)


21171
21172
21173
21174
21175
21176
# File 'lib/aws-sdk-ec2/types.rb', line 21171

class DeleteVpcBlockPublicAccessExclusionRequest < Struct.new(
  :dry_run,
  :exclusion_id)
  SENSITIVE = []
  include Aws::Structure
end