Class: Aws::EC2::Types::DeleteVpcBlockPublicAccessExclusionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteVpcBlockPublicAccessExclusionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#exclusion_id ⇒ String
The ID of the exclusion.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
20511 20512 20513 20514 20515 20516 |
# File 'lib/aws-sdk-ec2/types.rb', line 20511 class DeleteVpcBlockPublicAccessExclusionRequest < Struct.new( :dry_run, :exclusion_id) SENSITIVE = [] include Aws::Structure end |
#exclusion_id ⇒ String
The ID of the exclusion.
20511 20512 20513 20514 20515 20516 |
# File 'lib/aws-sdk-ec2/types.rb', line 20511 class DeleteVpcBlockPublicAccessExclusionRequest < Struct.new( :dry_run, :exclusion_id) SENSITIVE = [] include Aws::Structure end |