Class: Aws::EC2::Types::DeleteVpcEncryptionControlRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteVpcEncryptionControlRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#vpc_encryption_control_id ⇒ String
The ID of the VPC Encryption Control resource to delete.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
22284 22285 22286 22287 22288 22289 |
# File 'lib/aws-sdk-ec2/types.rb', line 22284 class DeleteVpcEncryptionControlRequest < Struct.new( :dry_run, :vpc_encryption_control_id) SENSITIVE = [] include Aws::Structure end |
#vpc_encryption_control_id ⇒ String
The ID of the VPC Encryption Control resource to delete.
22284 22285 22286 22287 22288 22289 |
# File 'lib/aws-sdk-ec2/types.rb', line 22284 class DeleteVpcEncryptionControlRequest < Struct.new( :dry_run, :vpc_encryption_control_id) SENSITIVE = [] include Aws::Structure end |