Class: Aws::EC2::Types::DeleteVpcEncryptionControlRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


21005
21006
21007
21008
21009
21010
# File 'lib/aws-sdk-ec2/types.rb', line 21005

class DeleteVpcEncryptionControlRequest < Struct.new(
  :dry_run,
  :vpc_encryption_control_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_encryption_control_idString

The ID of the VPC Encryption Control resource to delete.

Returns:

  • (String)


21005
21006
21007
21008
21009
21010
# File 'lib/aws-sdk-ec2/types.rb', line 21005

class DeleteVpcEncryptionControlRequest < Struct.new(
  :dry_run,
  :vpc_encryption_control_id)
  SENSITIVE = []
  include Aws::Structure
end