Class: Aws::EC2::Types::DeleteVpcEndpointConnectionNotificationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteVpcEndpointConnectionNotificationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection_notification_ids ⇒ Array<String>
The IDs of the notifications.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#connection_notification_ids ⇒ Array<String>
The IDs of the notifications.
20827 20828 20829 20830 20831 20832 |
# File 'lib/aws-sdk-ec2/types.rb', line 20827 class DeleteVpcEndpointConnectionNotificationsRequest < Struct.new( :dry_run, :connection_notification_ids) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
20827 20828 20829 20830 20831 20832 |
# File 'lib/aws-sdk-ec2/types.rb', line 20827 class DeleteVpcEndpointConnectionNotificationsRequest < Struct.new( :dry_run, :connection_notification_ids) SENSITIVE = [] include Aws::Structure end |