Class: Aws::EC2::Types::DeleteVpcEndpointConnectionNotificationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteVpcEndpointConnectionNotificationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection_notification_ids ⇒ Array<String>
The IDs of the notifications.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#connection_notification_ids ⇒ Array<String>
The IDs of the notifications.
20247 20248 20249 20250 20251 20252 |
# File 'lib/aws-sdk-ec2/types.rb', line 20247 class DeleteVpcEndpointConnectionNotificationsRequest < Struct.new( :dry_run, :connection_notification_ids) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
20247 20248 20249 20250 20251 20252 |
# File 'lib/aws-sdk-ec2/types.rb', line 20247 class DeleteVpcEndpointConnectionNotificationsRequest < Struct.new( :dry_run, :connection_notification_ids) SENSITIVE = [] include Aws::Structure end |