Class: Aws::EC2::Types::DeleteVpcEndpointServiceConfigurationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


21243
21244
21245
21246
21247
21248
# File 'lib/aws-sdk-ec2/types.rb', line 21243

class DeleteVpcEndpointServiceConfigurationsRequest < Struct.new(
  :dry_run,
  :service_ids)
  SENSITIVE = []
  include Aws::Structure
end

#service_idsArray<String>

The IDs of the services.

Returns:

  • (Array<String>)


21243
21244
21245
21246
21247
21248
# File 'lib/aws-sdk-ec2/types.rb', line 21243

class DeleteVpcEndpointServiceConfigurationsRequest < Struct.new(
  :dry_run,
  :service_ids)
  SENSITIVE = []
  include Aws::Structure
end