Class: Aws::EC2::Types::DeleteVpcEndpointServiceConfigurationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteVpcEndpointServiceConfigurationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#service_ids ⇒ Array<String>
The IDs of the services.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
21113 21114 21115 21116 21117 21118 |
# File 'lib/aws-sdk-ec2/types.rb', line 21113 class DeleteVpcEndpointServiceConfigurationsRequest < Struct.new( :dry_run, :service_ids) SENSITIVE = [] include Aws::Structure end |
#service_ids ⇒ Array<String>
The IDs of the services.
21113 21114 21115 21116 21117 21118 |
# File 'lib/aws-sdk-ec2/types.rb', line 21113 class DeleteVpcEndpointServiceConfigurationsRequest < Struct.new( :dry_run, :service_ids) SENSITIVE = [] include Aws::Structure end |