Class: Aws::EC2::Types::DeleteVpcEndpointServiceConfigurationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


21064
21065
21066
21067
21068
21069
# File 'lib/aws-sdk-ec2/types.rb', line 21064

class DeleteVpcEndpointServiceConfigurationsRequest < Struct.new(
  :dry_run,
  :service_ids)
  SENSITIVE = []
  include Aws::Structure
end

#service_idsArray<String>

The IDs of the services.

Returns:

  • (Array<String>)


21064
21065
21066
21067
21068
21069
# File 'lib/aws-sdk-ec2/types.rb', line 21064

class DeleteVpcEndpointServiceConfigurationsRequest < Struct.new(
  :dry_run,
  :service_ids)
  SENSITIVE = []
  include Aws::Structure
end