Class: Aws::EC2::Types::DeleteVpcEndpointsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteVpcEndpointsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#vpc_endpoint_ids ⇒ Array<String>
The IDs of the VPC endpoints.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
21146 21147 21148 21149 21150 21151 |
# File 'lib/aws-sdk-ec2/types.rb', line 21146 class DeleteVpcEndpointsRequest < Struct.new( :dry_run, :vpc_endpoint_ids) SENSITIVE = [] include Aws::Structure end |
#vpc_endpoint_ids ⇒ Array<String>
The IDs of the VPC endpoints.
21146 21147 21148 21149 21150 21151 |
# File 'lib/aws-sdk-ec2/types.rb', line 21146 class DeleteVpcEndpointsRequest < Struct.new( :dry_run, :vpc_endpoint_ids) SENSITIVE = [] include Aws::Structure end |