Class: Aws::EC2::Types::DeleteVpcEndpointsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


21103
21104
21105
21106
21107
21108
# File 'lib/aws-sdk-ec2/types.rb', line 21103

class DeleteVpcEndpointsRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_ids)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_endpoint_idsArray<String>

The IDs of the VPC endpoints.

Returns:

  • (Array<String>)


21103
21104
21105
21106
21107
21108
# File 'lib/aws-sdk-ec2/types.rb', line 21103

class DeleteVpcEndpointsRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_ids)
  SENSITIVE = []
  include Aws::Structure
end