Class: Aws::EC2::Types::DeleteVpcPeeringConnectionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


21334
21335
21336
21337
21338
21339
# File 'lib/aws-sdk-ec2/types.rb', line 21334

class DeleteVpcPeeringConnectionRequest < Struct.new(
  :dry_run,
  :vpc_peering_connection_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_peering_connection_idString

The ID of the VPC peering connection.

Returns:

  • (String)


21334
21335
21336
21337
21338
21339
# File 'lib/aws-sdk-ec2/types.rb', line 21334

class DeleteVpcPeeringConnectionRequest < Struct.new(
  :dry_run,
  :vpc_peering_connection_id)
  SENSITIVE = []
  include Aws::Structure
end