Class: Aws::EC2::Types::DeleteVpcPeeringConnectionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


20926
20927
20928
20929
20930
20931
# File 'lib/aws-sdk-ec2/types.rb', line 20926

class DeleteVpcPeeringConnectionRequest < Struct.new(
  :dry_run,
  :vpc_peering_connection_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_peering_connection_idString

The ID of the VPC peering connection.

Returns:

  • (String)


20926
20927
20928
20929
20930
20931
# File 'lib/aws-sdk-ec2/types.rb', line 20926

class DeleteVpcPeeringConnectionRequest < Struct.new(
  :dry_run,
  :vpc_peering_connection_id)
  SENSITIVE = []
  include Aws::Structure
end