Class: Aws::EC2::Types::DeleteVpcRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


21163
21164
21165
21166
21167
21168
# File 'lib/aws-sdk-ec2/types.rb', line 21163

class DeleteVpcRequest < Struct.new(
  :vpc_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC.

Returns:

  • (String)


21163
21164
21165
21166
21167
21168
# File 'lib/aws-sdk-ec2/types.rb', line 21163

class DeleteVpcRequest < Struct.new(
  :vpc_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end