Class: Aws::EC2::Types::DeleteVpcRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteVpcRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#vpc_id ⇒ String
The ID of the VPC.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
20379 20380 20381 20382 20383 20384 |
# File 'lib/aws-sdk-ec2/types.rb', line 20379 class DeleteVpcRequest < Struct.new( :vpc_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC.
20379 20380 20381 20382 20383 20384 |
# File 'lib/aws-sdk-ec2/types.rb', line 20379 class DeleteVpcRequest < Struct.new( :vpc_id, :dry_run) SENSITIVE = [] include Aws::Structure end |