Class: Aws::EC2::Types::DeleteVpnConcentratorRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


22474
22475
22476
22477
22478
22479
# File 'lib/aws-sdk-ec2/types.rb', line 22474

class DeleteVpnConcentratorRequest < Struct.new(
  :vpn_concentrator_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpn_concentrator_idString

The ID of the VPN concentrator to delete.

Returns:

  • (String)


22474
22475
22476
22477
22478
22479
# File 'lib/aws-sdk-ec2/types.rb', line 22474

class DeleteVpnConcentratorRequest < Struct.new(
  :vpn_concentrator_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end