Class: Aws::EC2::Types::DeleteVpnConcentratorRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteVpnConcentratorRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#vpn_concentrator_id ⇒ String
The ID of the VPN concentrator to delete.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
22152 22153 22154 22155 22156 22157 |
# File 'lib/aws-sdk-ec2/types.rb', line 22152 class DeleteVpnConcentratorRequest < Struct.new( :vpn_concentrator_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#vpn_concentrator_id ⇒ String
The ID of the VPN concentrator to delete.
22152 22153 22154 22155 22156 22157 |
# File 'lib/aws-sdk-ec2/types.rb', line 22152 class DeleteVpnConcentratorRequest < Struct.new( :vpn_concentrator_id, :dry_run) SENSITIVE = [] include Aws::Structure end |