Class: Aws::EC2::Types::DeleteVpnConcentratorRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


21189
21190
21191
21192
21193
21194
# File 'lib/aws-sdk-ec2/types.rb', line 21189

class DeleteVpnConcentratorRequest < Struct.new(
  :vpn_concentrator_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpn_concentrator_idString

The ID of the VPN concentrator to delete.

Returns:

  • (String)


21189
21190
21191
21192
21193
21194
# File 'lib/aws-sdk-ec2/types.rb', line 21189

class DeleteVpnConcentratorRequest < Struct.new(
  :vpn_concentrator_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end