Class: Aws::EC2::Types::DeleteVpnConnectionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteVpnConnectionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for DeleteVpnConnection.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#vpn_connection_id ⇒ String
The ID of the VPN connection.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
22494 22495 22496 22497 22498 22499 |
# File 'lib/aws-sdk-ec2/types.rb', line 22494 class DeleteVpnConnectionRequest < Struct.new( :vpn_connection_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#vpn_connection_id ⇒ String
The ID of the VPN connection.
22494 22495 22496 22497 22498 22499 |
# File 'lib/aws-sdk-ec2/types.rb', line 22494 class DeleteVpnConnectionRequest < Struct.new( :vpn_connection_id, :dry_run) SENSITIVE = [] include Aws::Structure end |