Class: Aws::EC2::Types::DeleteVpnConnectionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for DeleteVpnConnection.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


21026
21027
21028
21029
21030
21031
# File 'lib/aws-sdk-ec2/types.rb', line 21026

class DeleteVpnConnectionRequest < Struct.new(
  :vpn_connection_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpn_connection_idString

The ID of the VPN connection.

Returns:

  • (String)


21026
21027
21028
21029
21030
21031
# File 'lib/aws-sdk-ec2/types.rb', line 21026

class DeleteVpnConnectionRequest < Struct.new(
  :vpn_connection_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end