Class: Aws::EC2::Types::DeleteVpnGatewayRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeleteVpnGatewayRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for DeleteVpnGateway.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#vpn_gateway_id ⇒ String
The ID of the virtual private gateway.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
21464 21465 21466 21467 21468 21469 |
# File 'lib/aws-sdk-ec2/types.rb', line 21464 class DeleteVpnGatewayRequest < Struct.new( :vpn_gateway_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#vpn_gateway_id ⇒ String
The ID of the virtual private gateway.
21464 21465 21466 21467 21468 21469 |
# File 'lib/aws-sdk-ec2/types.rb', line 21464 class DeleteVpnGatewayRequest < Struct.new( :vpn_gateway_id, :dry_run) SENSITIVE = [] include Aws::Structure end |