Class: Aws::EC2::Types::DeleteVpnGatewayRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for DeleteVpnGateway.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


21425
21426
21427
21428
21429
21430
# File 'lib/aws-sdk-ec2/types.rb', line 21425

class DeleteVpnGatewayRequest < Struct.new(
  :vpn_gateway_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpn_gateway_idString

The ID of the virtual private gateway.

Returns:

  • (String)


21425
21426
21427
21428
21429
21430
# File 'lib/aws-sdk-ec2/types.rb', line 21425

class DeleteVpnGatewayRequest < Struct.new(
  :vpn_gateway_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end