Class: Aws::EC2::Types::DeprovisionByoipCidrRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cidrString

The address range, in CIDR notation. The prefix must be the same prefix that you specified when you provisioned the address range.

Returns:

  • (String)


21360
21361
21362
21363
21364
21365
# File 'lib/aws-sdk-ec2/types.rb', line 21360

class DeprovisionByoipCidrRequest < Struct.new(
  :cidr,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


21360
21361
21362
21363
21364
21365
# File 'lib/aws-sdk-ec2/types.rb', line 21360

class DeprovisionByoipCidrRequest < Struct.new(
  :cidr,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end