Class: Aws::EC2::Types::DeprovisionByoipCidrRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeprovisionByoipCidrRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cidr ⇒ String
The address range, in CIDR notation.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#cidr ⇒ String
The address range, in CIDR notation. The prefix must be the same prefix that you specified when you provisioned the address range.
21119 21120 21121 21122 21123 21124 |
# File 'lib/aws-sdk-ec2/types.rb', line 21119 class DeprovisionByoipCidrRequest < Struct.new( :cidr, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
21119 21120 21121 21122 21123 21124 |
# File 'lib/aws-sdk-ec2/types.rb', line 21119 class DeprovisionByoipCidrRequest < Struct.new( :cidr, :dry_run) SENSITIVE = [] include Aws::Structure end |