Class: Aws::EC2::Types::DeprovisionIpamByoasnRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#asnString

An ASN.

Returns:

  • (String)


22316
22317
22318
22319
22320
22321
22322
# File 'lib/aws-sdk-ec2/types.rb', line 22316

class DeprovisionIpamByoasnRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :asn)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


22316
22317
22318
22319
22320
22321
22322
# File 'lib/aws-sdk-ec2/types.rb', line 22316

class DeprovisionIpamByoasnRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :asn)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_idString

The IPAM ID.

Returns:

  • (String)


22316
22317
22318
22319
22320
22321
22322
# File 'lib/aws-sdk-ec2/types.rb', line 22316

class DeprovisionIpamByoasnRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :asn)
  SENSITIVE = []
  include Aws::Structure
end