Class: Aws::EC2::Types::DeprovisionIpamByoasnRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#asnString

An ASN.

Returns:

  • (String)


21551
21552
21553
21554
21555
21556
21557
# File 'lib/aws-sdk-ec2/types.rb', line 21551

class DeprovisionIpamByoasnRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :asn)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


21551
21552
21553
21554
21555
21556
21557
# File 'lib/aws-sdk-ec2/types.rb', line 21551

class DeprovisionIpamByoasnRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :asn)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_idString

The IPAM ID.

Returns:

  • (String)


21551
21552
21553
21554
21555
21556
21557
# File 'lib/aws-sdk-ec2/types.rb', line 21551

class DeprovisionIpamByoasnRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :asn)
  SENSITIVE = []
  include Aws::Structure
end