Class: Aws::EC2::Types::DeprovisionIpamByoasnRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeprovisionIpamByoasnRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asn ⇒ String
An ASN.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#ipam_id ⇒ String
The IPAM ID.
Instance Attribute Details
#asn ⇒ String
An ASN.
21353 21354 21355 21356 21357 21358 21359 |
# File 'lib/aws-sdk-ec2/types.rb', line 21353 class DeprovisionIpamByoasnRequest < Struct.new( :dry_run, :ipam_id, :asn) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
21353 21354 21355 21356 21357 21358 21359 |
# File 'lib/aws-sdk-ec2/types.rb', line 21353 class DeprovisionIpamByoasnRequest < Struct.new( :dry_run, :ipam_id, :asn) SENSITIVE = [] include Aws::Structure end |
#ipam_id ⇒ String
The IPAM ID.
21353 21354 21355 21356 21357 21358 21359 |
# File 'lib/aws-sdk-ec2/types.rb', line 21353 class DeprovisionIpamByoasnRequest < Struct.new( :dry_run, :ipam_id, :asn) SENSITIVE = [] include Aws::Structure end |