Class: Aws::EC2::Types::DeprovisionIpamPoolCidrRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeprovisionIpamPoolCidrRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cidr ⇒ String
The CIDR which you want to deprovision from the pool.
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#ipam_pool_id ⇒ String
The ID of the pool that has the CIDR you want to deprovision.
Instance Attribute Details
#cidr ⇒ String
The CIDR which you want to deprovision from the pool.
21439 21440 21441 21442 21443 21444 21445 |
# File 'lib/aws-sdk-ec2/types.rb', line 21439 class DeprovisionIpamPoolCidrRequest < Struct.new( :dry_run, :ipam_pool_id, :cidr) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action
without actually making the request and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
21439 21440 21441 21442 21443 21444 21445 |
# File 'lib/aws-sdk-ec2/types.rb', line 21439 class DeprovisionIpamPoolCidrRequest < Struct.new( :dry_run, :ipam_pool_id, :cidr) SENSITIVE = [] include Aws::Structure end |
#ipam_pool_id ⇒ String
The ID of the pool that has the CIDR you want to deprovision.
21439 21440 21441 21442 21443 21444 21445 |
# File 'lib/aws-sdk-ec2/types.rb', line 21439 class DeprovisionIpamPoolCidrRequest < Struct.new( :dry_run, :ipam_pool_id, :cidr) SENSITIVE = [] include Aws::Structure end |