Class: Aws::EC2::Types::DeprovisionIpamPoolCidrRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cidrString

The CIDR which you want to deprovision from the pool.

Returns:

  • (String)


21180
21181
21182
21183
21184
21185
21186
# File 'lib/aws-sdk-ec2/types.rb', line 21180

class DeprovisionIpamPoolCidrRequest < Struct.new(
  :dry_run,
  :ipam_pool_id,
  :cidr)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


21180
21181
21182
21183
21184
21185
21186
# File 'lib/aws-sdk-ec2/types.rb', line 21180

class DeprovisionIpamPoolCidrRequest < Struct.new(
  :dry_run,
  :ipam_pool_id,
  :cidr)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_pool_idString

The ID of the pool that has the CIDR you want to deprovision.

Returns:

  • (String)


21180
21181
21182
21183
21184
21185
21186
# File 'lib/aws-sdk-ec2/types.rb', line 21180

class DeprovisionIpamPoolCidrRequest < Struct.new(
  :dry_run,
  :ipam_pool_id,
  :cidr)
  SENSITIVE = []
  include Aws::Structure
end