Class: Aws::EC2::Types::DeprovisionPublicIpv4PoolCidrRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DeprovisionPublicIpv4PoolCidrRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cidr ⇒ String
The CIDR you want to deprovision from the pool.
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#pool_id ⇒ String
The ID of the pool that you want to deprovision the CIDR from.
Instance Attribute Details
#cidr ⇒ String
The CIDR you want to deprovision from the pool.
21717 21718 21719 21720 21721 21722 21723 |
# File 'lib/aws-sdk-ec2/types.rb', line 21717 class DeprovisionPublicIpv4PoolCidrRequest < Struct.new( :dry_run, :pool_id, :cidr) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action
without actually making the request and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
21717 21718 21719 21720 21721 21722 21723 |
# File 'lib/aws-sdk-ec2/types.rb', line 21717 class DeprovisionPublicIpv4PoolCidrRequest < Struct.new( :dry_run, :pool_id, :cidr) SENSITIVE = [] include Aws::Structure end |
#pool_id ⇒ String
The ID of the pool that you want to deprovision the CIDR from.
21717 21718 21719 21720 21721 21722 21723 |
# File 'lib/aws-sdk-ec2/types.rb', line 21717 class DeprovisionPublicIpv4PoolCidrRequest < Struct.new( :dry_run, :pool_id, :cidr) SENSITIVE = [] include Aws::Structure end |