Class: Aws::EC2::Types::DeprovisionPublicIpv4PoolCidrRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cidrString

The CIDR you want to deprovision from the pool.

Returns:

  • (String)


21427
21428
21429
21430
21431
21432
21433
# File 'lib/aws-sdk-ec2/types.rb', line 21427

class DeprovisionPublicIpv4PoolCidrRequest < Struct.new(
  :dry_run,
  :pool_id,
  :cidr)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


21427
21428
21429
21430
21431
21432
21433
# File 'lib/aws-sdk-ec2/types.rb', line 21427

class DeprovisionPublicIpv4PoolCidrRequest < Struct.new(
  :dry_run,
  :pool_id,
  :cidr)
  SENSITIVE = []
  include Aws::Structure
end

#pool_idString

The ID of the pool that you want to deprovision the CIDR from.

Returns:

  • (String)


21427
21428
21429
21430
21431
21432
21433
# File 'lib/aws-sdk-ec2/types.rb', line 21427

class DeprovisionPublicIpv4PoolCidrRequest < Struct.new(
  :dry_run,
  :pool_id,
  :cidr)
  SENSITIVE = []
  include Aws::Structure
end