Class: Aws::EC2::Types::DescribeAccountAttributesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attribute_namesArray<String>

The account attribute names.

Returns:

  • (Array<String>)


22928
22929
22930
22931
22932
22933
# File 'lib/aws-sdk-ec2/types.rb', line 22928

class DescribeAccountAttributesRequest < Struct.new(
  :dry_run,
  :attribute_names)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


22928
22929
22930
22931
22932
22933
# File 'lib/aws-sdk-ec2/types.rb', line 22928

class DescribeAccountAttributesRequest < Struct.new(
  :dry_run,
  :attribute_names)
  SENSITIVE = []
  include Aws::Structure
end