Class: Aws::EC2::Types::DescribeAccountAttributesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeAccountAttributesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute_names ⇒ Array<String>
The account attribute names.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#attribute_names ⇒ Array<String>
The account attribute names.
21856 21857 21858 21859 21860 21861 |
# File 'lib/aws-sdk-ec2/types.rb', line 21856 class DescribeAccountAttributesRequest < Struct.new( :dry_run, :attribute_names) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
21856 21857 21858 21859 21860 21861 |
# File 'lib/aws-sdk-ec2/types.rb', line 21856 class DescribeAccountAttributesRequest < Struct.new( :dry_run, :attribute_names) SENSITIVE = [] include Aws::Structure end |