Class: Aws::EC2::Types::DescribeAccountAttributesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attribute_namesArray<String>

The account attribute names.

Returns:

  • (Array<String>)


21831
21832
21833
21834
21835
21836
# File 'lib/aws-sdk-ec2/types.rb', line 21831

class DescribeAccountAttributesRequest < Struct.new(
  :dry_run,
  :attribute_names)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


21831
21832
21833
21834
21835
21836
# File 'lib/aws-sdk-ec2/types.rb', line 21831

class DescribeAccountAttributesRequest < Struct.new(
  :dry_run,
  :attribute_names)
  SENSITIVE = []
  include Aws::Structure
end