Class: Aws::EC2::Types::DescribeAccountAttributesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeAccountAttributesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute_names ⇒ Array<String>
The account attribute names.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#attribute_names ⇒ Array<String>
The account attribute names.
21831 21832 21833 21834 21835 21836 |
# File 'lib/aws-sdk-ec2/types.rb', line 21831 class DescribeAccountAttributesRequest < Struct.new( :dry_run, :attribute_names) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
21831 21832 21833 21834 21835 21836 |
# File 'lib/aws-sdk-ec2/types.rb', line 21831 class DescribeAccountAttributesRequest < Struct.new( :dry_run, :attribute_names) SENSITIVE = [] include Aws::Structure end |