Class: Aws::EC2::Types::DescribeAccountAttributesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeAccountAttributesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute_names ⇒ Array<String>
The account attribute names.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#attribute_names ⇒ Array<String>
The account attribute names.
21448 21449 21450 21451 21452 21453 |
# File 'lib/aws-sdk-ec2/types.rb', line 21448 class DescribeAccountAttributesRequest < Struct.new( :dry_run, :attribute_names) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
21448 21449 21450 21451 21452 21453 |
# File 'lib/aws-sdk-ec2/types.rb', line 21448 class DescribeAccountAttributesRequest < Struct.new( :dry_run, :attribute_names) SENSITIVE = [] include Aws::Structure end |