Class: Aws::EC2::Types::DescribeAddressTransfersRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allocation_idsArray<String>

The allocation IDs of Elastic IP addresses.

Returns:

  • (Array<String>)


22018
22019
22020
22021
22022
22023
22024
22025
# File 'lib/aws-sdk-ec2/types.rb', line 22018

class DescribeAddressTransfersRequest < Struct.new(
  :allocation_ids,
  :next_token,
  :max_results,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


22018
22019
22020
22021
22022
22023
22024
22025
# File 'lib/aws-sdk-ec2/types.rb', line 22018

class DescribeAddressTransfersRequest < Struct.new(
  :allocation_ids,
  :next_token,
  :max_results,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of address transfers to return in one page of results.

Returns:

  • (Integer)


22018
22019
22020
22021
22022
22023
22024
22025
# File 'lib/aws-sdk-ec2/types.rb', line 22018

class DescribeAddressTransfersRequest < Struct.new(
  :allocation_ids,
  :next_token,
  :max_results,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Specify the pagination token from a previous request to retrieve the next page of results.

Returns:

  • (String)


22018
22019
22020
22021
22022
22023
22024
22025
# File 'lib/aws-sdk-ec2/types.rb', line 22018

class DescribeAddressTransfersRequest < Struct.new(
  :allocation_ids,
  :next_token,
  :max_results,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end