Class: Aws::EC2::Types::DescribeAddressTransfersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeAddressTransfersRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allocation_ids ⇒ Array<String>
The allocation IDs of Elastic IP addresses.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#max_results ⇒ Integer
The maximum number of address transfers to return in one page of results.
-
#next_token ⇒ String
Specify the pagination token from a previous request to retrieve the next page of results.
Instance Attribute Details
#allocation_ids ⇒ Array<String>
The allocation IDs of Elastic IP addresses.
21238 21239 21240 21241 21242 21243 21244 21245 |
# File 'lib/aws-sdk-ec2/types.rb', line 21238 class DescribeAddressTransfersRequest < Struct.new( :allocation_ids, :next_token, :max_results, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
21238 21239 21240 21241 21242 21243 21244 21245 |
# File 'lib/aws-sdk-ec2/types.rb', line 21238 class DescribeAddressTransfersRequest < Struct.new( :allocation_ids, :next_token, :max_results, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of address transfers to return in one page of results.
21238 21239 21240 21241 21242 21243 21244 21245 |
# File 'lib/aws-sdk-ec2/types.rb', line 21238 class DescribeAddressTransfersRequest < Struct.new( :allocation_ids, :next_token, :max_results, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Specify the pagination token from a previous request to retrieve the next page of results.
21238 21239 21240 21241 21242 21243 21244 21245 |
# File 'lib/aws-sdk-ec2/types.rb', line 21238 class DescribeAddressTransfersRequest < Struct.new( :allocation_ids, :next_token, :max_results, :dry_run) SENSITIVE = [] include Aws::Structure end |