Class: Aws::EC2::Types::DescribeAddressesAttributeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeAddressesAttributeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allocation_ids ⇒ Array<String>
[EC2-VPC] The allocation IDs.
-
#attribute ⇒ String
The attribute of the IP address.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
Instance Attribute Details
#allocation_ids ⇒ Array<String>
[EC2-VPC] The allocation IDs.
21748 21749 21750 21751 21752 21753 21754 21755 21756 |
# File 'lib/aws-sdk-ec2/types.rb', line 21748 class DescribeAddressesAttributeRequest < Struct.new( :allocation_ids, :attribute, :next_token, :max_results, :dry_run) SENSITIVE = [] include Aws::Structure end |
#attribute ⇒ String
The attribute of the IP address.
21748 21749 21750 21751 21752 21753 21754 21755 21756 |
# File 'lib/aws-sdk-ec2/types.rb', line 21748 class DescribeAddressesAttributeRequest < Struct.new( :allocation_ids, :attribute, :next_token, :max_results, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
21748 21749 21750 21751 21752 21753 21754 21755 21756 |
# File 'lib/aws-sdk-ec2/types.rb', line 21748 class DescribeAddressesAttributeRequest < Struct.new( :allocation_ids, :attribute, :next_token, :max_results, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.
21748 21749 21750 21751 21752 21753 21754 21755 21756 |
# File 'lib/aws-sdk-ec2/types.rb', line 21748 class DescribeAddressesAttributeRequest < Struct.new( :allocation_ids, :attribute, :next_token, :max_results, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
21748 21749 21750 21751 21752 21753 21754 21755 21756 |
# File 'lib/aws-sdk-ec2/types.rb', line 21748 class DescribeAddressesAttributeRequest < Struct.new( :allocation_ids, :attribute, :next_token, :max_results, :dry_run) SENSITIVE = [] include Aws::Structure end |