Class: Aws::EC2::Types::DescribeAddressesAttributeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allocation_idsArray<String>

[EC2-VPC] The allocation IDs.

Returns:

  • (Array<String>)


21544
21545
21546
21547
21548
21549
21550
21551
21552
# File 'lib/aws-sdk-ec2/types.rb', line 21544

class DescribeAddressesAttributeRequest < Struct.new(
  :allocation_ids,
  :attribute,
  :next_token,
  :max_results,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#attributeString

The attribute of the IP address.

Returns:

  • (String)


21544
21545
21546
21547
21548
21549
21550
21551
21552
# File 'lib/aws-sdk-ec2/types.rb', line 21544

class DescribeAddressesAttributeRequest < Struct.new(
  :allocation_ids,
  :attribute,
  :next_token,
  :max_results,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


21544
21545
21546
21547
21548
21549
21550
21551
21552
# File 'lib/aws-sdk-ec2/types.rb', line 21544

class DescribeAddressesAttributeRequest < Struct.new(
  :allocation_ids,
  :attribute,
  :next_token,
  :max_results,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.

Returns:

  • (Integer)


21544
21545
21546
21547
21548
21549
21550
21551
21552
# File 'lib/aws-sdk-ec2/types.rb', line 21544

class DescribeAddressesAttributeRequest < Struct.new(
  :allocation_ids,
  :attribute,
  :next_token,
  :max_results,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


21544
21545
21546
21547
21548
21549
21550
21551
21552
# File 'lib/aws-sdk-ec2/types.rb', line 21544

class DescribeAddressesAttributeRequest < Struct.new(
  :allocation_ids,
  :attribute,
  :next_token,
  :max_results,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end