Class: Aws::EC2::Types::DescribeAggregateIdFormatRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeAggregateIdFormatRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
23174 23175 23176 23177 23178 |
# File 'lib/aws-sdk-ec2/types.rb', line 23174 class DescribeAggregateIdFormatRequest < Struct.new( :dry_run) SENSITIVE = [] include Aws::Structure end |