Class: Aws::EC2::Types::DescribeAggregateIdFormatResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeAggregateIdFormatResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#statuses ⇒ Array<Types::IdFormat>
Information about each resource's ID format.
-
#use_long_ids_aggregated ⇒ Boolean
Indicates whether all resource types in the Region are configured to use longer IDs.
Instance Attribute Details
#statuses ⇒ Array<Types::IdFormat>
Information about each resource's ID format.
22876 22877 22878 22879 22880 22881 |
# File 'lib/aws-sdk-ec2/types.rb', line 22876 class DescribeAggregateIdFormatResult < Struct.new( :use_long_ids_aggregated, :statuses) SENSITIVE = [] include Aws::Structure end |
#use_long_ids_aggregated ⇒ Boolean
Indicates whether all resource types in the Region are configured to
use longer IDs. This value is only true if all users are
configured to use longer IDs for all resources types in the Region.
22876 22877 22878 22879 22880 22881 |
# File 'lib/aws-sdk-ec2/types.rb', line 22876 class DescribeAggregateIdFormatResult < Struct.new( :use_long_ids_aggregated, :statuses) SENSITIVE = [] include Aws::Structure end |