Class: Aws::EC2::Types::DescribeAggregateIdFormatResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#statusesArray<Types::IdFormat>

Information about each resource's ID format.

Returns:



21934
21935
21936
21937
21938
21939
# File 'lib/aws-sdk-ec2/types.rb', line 21934

class DescribeAggregateIdFormatResult < Struct.new(
  :use_long_ids_aggregated,
  :statuses)
  SENSITIVE = []
  include Aws::Structure
end

#use_long_ids_aggregatedBoolean

Indicates whether all resource types in the Region are configured to use longer IDs. This value is only true if all users are configured to use longer IDs for all resources types in the Region.

Returns:

  • (Boolean)


21934
21935
21936
21937
21938
21939
# File 'lib/aws-sdk-ec2/types.rb', line 21934

class DescribeAggregateIdFormatResult < Struct.new(
  :use_long_ids_aggregated,
  :statuses)
  SENSITIVE = []
  include Aws::Structure
end