Class: Aws::EC2::Types::DescribeApplicationStatusCheckAssociationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeApplicationStatusCheckAssociationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_status_check_ids ⇒ Array<String>
The IDs of the application status checks for which to describe associations.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The filters to use to limit the results.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token returned from a previous paginated request.
Instance Attribute Details
#application_status_check_ids ⇒ Array<String>
The IDs of the application status checks for which to describe associations.
23238 23239 23240 23241 23242 23243 23244 23245 23246 |
# File 'lib/aws-sdk-ec2/types.rb', line 23238 class DescribeApplicationStatusCheckAssociationsRequest < Struct.new( :application_status_check_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
23238 23239 23240 23241 23242 23243 23244 23245 23246 |
# File 'lib/aws-sdk-ec2/types.rb', line 23238 class DescribeApplicationStatusCheckAssociationsRequest < Struct.new( :application_status_check_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters to use to limit the results.
association-type– The type of association. Valid values:tagandinstance-id.
^
23238 23239 23240 23241 23242 23243 23244 23245 23246 |
# File 'lib/aws-sdk-ec2/types.rb', line 23238 class DescribeApplicationStatusCheckAssociationsRequest < Struct.new( :application_status_check_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
23238 23239 23240 23241 23242 23243 23244 23245 23246 |
# File 'lib/aws-sdk-ec2/types.rb', line 23238 class DescribeApplicationStatusCheckAssociationsRequest < Struct.new( :application_status_check_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
23238 23239 23240 23241 23242 23243 23244 23245 23246 |
# File 'lib/aws-sdk-ec2/types.rb', line 23238 class DescribeApplicationStatusCheckAssociationsRequest < Struct.new( :application_status_check_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |