Class: Aws::EC2::Types::DescribeApplicationStatusChecksRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_status_check_idsArray<String>

The IDs of the application status checks to describe.

Returns:

  • (Array<String>)


23001
23002
23003
23004
23005
23006
23007
23008
23009
23010
# File 'lib/aws-sdk-ec2/types.rb', line 23001

class DescribeApplicationStatusChecksRequest < Struct.new(
  :application_status_check_ids,
  :filters,
  :max_results,
  :next_token,
  :include_all,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


23001
23002
23003
23004
23005
23006
23007
23008
23009
23010
# File 'lib/aws-sdk-ec2/types.rb', line 23001

class DescribeApplicationStatusChecksRequest < Struct.new(
  :application_status_check_ids,
  :filters,
  :max_results,
  :next_token,
  :include_all,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters.

  • aggregation – The aggregation setting. Valid values: included and excluded.

^

Returns:



23001
23002
23003
23004
23005
23006
23007
23008
23009
23010
# File 'lib/aws-sdk-ec2/types.rb', line 23001

class DescribeApplicationStatusChecksRequest < Struct.new(
  :application_status_check_ids,
  :filters,
  :max_results,
  :next_token,
  :include_all,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#include_allBoolean

Specifies whether to include recently deleted application status checks that remain available during the deletion grace period. If you omit this parameter or set it to false, the response includes only active checks.

Returns:

  • (Boolean)


23001
23002
23003
23004
23005
23006
23007
23008
23009
23010
# File 'lib/aws-sdk-ec2/types.rb', line 23001

class DescribeApplicationStatusChecksRequest < Struct.new(
  :application_status_check_ids,
  :filters,
  :max_results,
  :next_token,
  :include_all,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.

Returns:

  • (Integer)


23001
23002
23003
23004
23005
23006
23007
23008
23009
23010
# File 'lib/aws-sdk-ec2/types.rb', line 23001

class DescribeApplicationStatusChecksRequest < Struct.new(
  :application_status_check_ids,
  :filters,
  :max_results,
  :next_token,
  :include_all,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Returns:

  • (String)


23001
23002
23003
23004
23005
23006
23007
23008
23009
23010
# File 'lib/aws-sdk-ec2/types.rb', line 23001

class DescribeApplicationStatusChecksRequest < Struct.new(
  :application_status_check_ids,
  :filters,
  :max_results,
  :next_token,
  :include_all,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end