Class: Aws::EC2::Types::DescribeApplicationStatusRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeApplicationStatusRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The filters.
-
#instance_ids ⇒ Array<String>
The IDs of the instances for which to describe application status.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token returned from a previous paginated request.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
23069 23070 23071 23072 23073 23074 23075 23076 23077 |
# File 'lib/aws-sdk-ec2/types.rb', line 23069 class DescribeApplicationStatusRequest < Struct.new( :instance_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters.
-
availability-zone-id– The ID of the Availability Zone. -
status– The instance-level application status. For valid values and their meanings, seeApplicationStatus.
23069 23070 23071 23072 23073 23074 23075 23076 23077 |
# File 'lib/aws-sdk-ec2/types.rb', line 23069 class DescribeApplicationStatusRequest < Struct.new( :instance_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#instance_ids ⇒ Array<String>
The IDs of the instances for which to describe application status.
23069 23070 23071 23072 23073 23074 23075 23076 23077 |
# File 'lib/aws-sdk-ec2/types.rb', line 23069 class DescribeApplicationStatusRequest < Struct.new( :instance_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
23069 23070 23071 23072 23073 23074 23075 23076 23077 |
# File 'lib/aws-sdk-ec2/types.rb', line 23069 class DescribeApplicationStatusRequest < Struct.new( :instance_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
23069 23070 23071 23072 23073 23074 23075 23076 23077 |
# File 'lib/aws-sdk-ec2/types.rb', line 23069 class DescribeApplicationStatusRequest < Struct.new( :instance_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |