Class: Aws::EC2::Types::DescribeByoipCidrsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


23633
23634
23635
23636
23637
23638
23639
# File 'lib/aws-sdk-ec2/types.rb', line 23633

class DescribeByoipCidrsRequest < Struct.new(
  :dry_run,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.

Returns:

  • (Integer)


23633
23634
23635
23636
23637
23638
23639
# File 'lib/aws-sdk-ec2/types.rb', line 23633

class DescribeByoipCidrsRequest < Struct.new(
  :dry_run,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


23633
23634
23635
23636
23637
23638
23639
# File 'lib/aws-sdk-ec2/types.rb', line 23633

class DescribeByoipCidrsRequest < Struct.new(
  :dry_run,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end