Class: Aws::EC2::Types::DescribeByoipCidrsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


22307
22308
22309
22310
22311
22312
22313
# File 'lib/aws-sdk-ec2/types.rb', line 22307

class DescribeByoipCidrsRequest < Struct.new(
  :dry_run,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.

Returns:

  • (Integer)


22307
22308
22309
22310
22311
22312
22313
# File 'lib/aws-sdk-ec2/types.rb', line 22307

class DescribeByoipCidrsRequest < Struct.new(
  :dry_run,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


22307
22308
22309
22310
22311
22312
22313
# File 'lib/aws-sdk-ec2/types.rb', line 22307

class DescribeByoipCidrsRequest < Struct.new(
  :dry_run,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end