Class: Aws::EC2::Types::DescribeByoipCidrsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


21910
21911
21912
21913
21914
21915
21916
# File 'lib/aws-sdk-ec2/types.rb', line 21910

class DescribeByoipCidrsRequest < Struct.new(
  :dry_run,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.

Returns:

  • (Integer)


21910
21911
21912
21913
21914
21915
21916
# File 'lib/aws-sdk-ec2/types.rb', line 21910

class DescribeByoipCidrsRequest < Struct.new(
  :dry_run,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


21910
21911
21912
21913
21914
21915
21916
# File 'lib/aws-sdk-ec2/types.rb', line 21910

class DescribeByoipCidrsRequest < Struct.new(
  :dry_run,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end