Class: Aws::EC2::Types::DescribeCapacityBlockExtensionHistoryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeCapacityBlockExtensionHistoryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_reservation_ids ⇒ Array<String>
The IDs of Capacity Block reservations that you want to display the history for.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token to use to retrieve the next page of results.
Instance Attribute Details
#capacity_reservation_ids ⇒ Array<String>
The IDs of Capacity Block reservations that you want to display the history for.
22242 22243 22244 22245 22246 22247 22248 22249 22250 |
# File 'lib/aws-sdk-ec2/types.rb', line 22242 class DescribeCapacityBlockExtensionHistoryRequest < Struct.new( :capacity_reservation_ids, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
22242 22243 22244 22245 22246 22247 22248 22249 22250 |
# File 'lib/aws-sdk-ec2/types.rb', line 22242 class DescribeCapacityBlockExtensionHistoryRequest < Struct.new( :capacity_reservation_ids, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters
-
availability-zone- The Availability Zone of the extension. -
availability-zone-id- The Availability Zone ID of the extension. -
capacity-block-extension-offering-id- The ID of the extension offering. -
capacity-block-extension-status- The status of the extension (payment-pending|payment-failed|payment-succeeded). -
capacity-reservation-id- The reservation ID of the extension. -
instance-type- The instance type of the extension.
22242 22243 22244 22245 22246 22247 22248 22249 22250 |
# File 'lib/aws-sdk-ec2/types.rb', line 22242 class DescribeCapacityBlockExtensionHistoryRequest < Struct.new( :capacity_reservation_ids, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
22242 22243 22244 22245 22246 22247 22248 22249 22250 |
# File 'lib/aws-sdk-ec2/types.rb', line 22242 class DescribeCapacityBlockExtensionHistoryRequest < Struct.new( :capacity_reservation_ids, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to retrieve the next page of results.
22242 22243 22244 22245 22246 22247 22248 22249 22250 |
# File 'lib/aws-sdk-ec2/types.rb', line 22242 class DescribeCapacityBlockExtensionHistoryRequest < Struct.new( :capacity_reservation_ids, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |