Class: Aws::EC2::Types::DescribeCapacityBlockExtensionHistoryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_reservation_idsArray<String>

The IDs of Capacity Block reservations that you want to display the history for.

Returns:

  • (Array<String>)


21403
21404
21405
21406
21407
21408
21409
21410
21411
# File 'lib/aws-sdk-ec2/types.rb', line 21403

class DescribeCapacityBlockExtensionHistoryRequest < Struct.new(
  :capacity_reservation_ids,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


21403
21404
21405
21406
21407
21408
21409
21410
21411
# File 'lib/aws-sdk-ec2/types.rb', line 21403

class DescribeCapacityBlockExtensionHistoryRequest < Struct.new(
  :capacity_reservation_ids,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters

  • ‘availability-zone` - The Availability Zone of the extension.

  • ‘availability-zone-id` - The Availability Zone ID of the extension.

  • ‘capacity-block-extension-offering-id` - The ID of the extension offering.

  • ‘capacity-block-extension-status` - The status of the extension (`payment-pending` | `payment-failed` | `payment-succeeded`).

  • ‘capacity-reservation-id` - The reservation ID of the extension.

  • ‘instance-type` - The instance type of the extension.

Returns:



21403
21404
21405
21406
21407
21408
21409
21410
21411
# File 'lib/aws-sdk-ec2/types.rb', line 21403

class DescribeCapacityBlockExtensionHistoryRequest < Struct.new(
  :capacity_reservation_ids,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination

Returns:

  • (Integer)


21403
21404
21405
21406
21407
21408
21409
21410
21411
# File 'lib/aws-sdk-ec2/types.rb', line 21403

class DescribeCapacityBlockExtensionHistoryRequest < Struct.new(
  :capacity_reservation_ids,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to use to retrieve the next page of results.

Returns:

  • (String)


21403
21404
21405
21406
21407
21408
21409
21410
21411
# File 'lib/aws-sdk-ec2/types.rb', line 21403

class DescribeCapacityBlockExtensionHistoryRequest < Struct.new(
  :capacity_reservation_ids,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end