Class: Aws::EC2::Types::DescribeCapacityBlockExtensionHistoryResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeCapacityBlockExtensionHistoryResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_block_extensions ⇒ Array<Types::CapacityBlockExtension>
Describes one or more of your Capacity Block extensions.
-
#next_token ⇒ String
The token to use to retrieve the next page of results.
Instance Attribute Details
#capacity_block_extensions ⇒ Array<Types::CapacityBlockExtension>
Describes one or more of your Capacity Block extensions. The results describe only the Capacity Block extensions in the Amazon Web Services Region that you’re currently using.
21426 21427 21428 21429 21430 21431 |
# File 'lib/aws-sdk-ec2/types.rb', line 21426 class DescribeCapacityBlockExtensionHistoryResult < Struct.new( :capacity_block_extensions, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to retrieve the next page of results. This value is ‘null` when there are no more results to return.
21426 21427 21428 21429 21430 21431 |
# File 'lib/aws-sdk-ec2/types.rb', line 21426 class DescribeCapacityBlockExtensionHistoryResult < Struct.new( :capacity_block_extensions, :next_token) SENSITIVE = [] include Aws::Structure end |