Class: Aws::EC2::Types::DescribeCapacityBlockExtensionOfferingsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeCapacityBlockExtensionOfferingsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_block_extension_duration_hours ⇒ Integer
The duration of the Capacity Block extension offering in hours.
-
#capacity_reservation_id ⇒ String
The ID of the Capacity reservation to be extended.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token to use to retrieve the next page of results.
Instance Attribute Details
#capacity_block_extension_duration_hours ⇒ Integer
The duration of the Capacity Block extension offering in hours.
22044 22045 22046 22047 22048 22049 22050 22051 22052 |
# File 'lib/aws-sdk-ec2/types.rb', line 22044 class DescribeCapacityBlockExtensionOfferingsRequest < Struct.new( :dry_run, :capacity_block_extension_duration_hours, :capacity_reservation_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#capacity_reservation_id ⇒ String
The ID of the Capacity reservation to be extended.
22044 22045 22046 22047 22048 22049 22050 22051 22052 |
# File 'lib/aws-sdk-ec2/types.rb', line 22044 class DescribeCapacityBlockExtensionOfferingsRequest < Struct.new( :dry_run, :capacity_block_extension_duration_hours, :capacity_reservation_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
22044 22045 22046 22047 22048 22049 22050 22051 22052 |
# File 'lib/aws-sdk-ec2/types.rb', line 22044 class DescribeCapacityBlockExtensionOfferingsRequest < Struct.new( :dry_run, :capacity_block_extension_duration_hours, :capacity_reservation_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination
22044 22045 22046 22047 22048 22049 22050 22051 22052 |
# File 'lib/aws-sdk-ec2/types.rb', line 22044 class DescribeCapacityBlockExtensionOfferingsRequest < Struct.new( :dry_run, :capacity_block_extension_duration_hours, :capacity_reservation_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to retrieve the next page of results.
22044 22045 22046 22047 22048 22049 22050 22051 22052 |
# File 'lib/aws-sdk-ec2/types.rb', line 22044 class DescribeCapacityBlockExtensionOfferingsRequest < Struct.new( :dry_run, :capacity_block_extension_duration_hours, :capacity_reservation_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |