Class: Aws::EC2::Types::DescribeCapacityBlockExtensionOfferingsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_block_extension_duration_hoursInteger

The duration of the Capacity Block extension offering in hours.

Returns:

  • (Integer)


21458
21459
21460
21461
21462
21463
21464
21465
21466
# File 'lib/aws-sdk-ec2/types.rb', line 21458

class DescribeCapacityBlockExtensionOfferingsRequest < Struct.new(
  :dry_run,
  :capacity_block_extension_duration_hours,
  :capacity_reservation_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#capacity_reservation_idString

The ID of the Capacity reservation to be extended.

Returns:

  • (String)


21458
21459
21460
21461
21462
21463
21464
21465
21466
# File 'lib/aws-sdk-ec2/types.rb', line 21458

class DescribeCapacityBlockExtensionOfferingsRequest < Struct.new(
  :dry_run,
  :capacity_block_extension_duration_hours,
  :capacity_reservation_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


21458
21459
21460
21461
21462
21463
21464
21465
21466
# File 'lib/aws-sdk-ec2/types.rb', line 21458

class DescribeCapacityBlockExtensionOfferingsRequest < Struct.new(
  :dry_run,
  :capacity_block_extension_duration_hours,
  :capacity_reservation_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination

Returns:

  • (Integer)


21458
21459
21460
21461
21462
21463
21464
21465
21466
# File 'lib/aws-sdk-ec2/types.rb', line 21458

class DescribeCapacityBlockExtensionOfferingsRequest < Struct.new(
  :dry_run,
  :capacity_block_extension_duration_hours,
  :capacity_reservation_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to use to retrieve the next page of results.

Returns:

  • (String)


21458
21459
21460
21461
21462
21463
21464
21465
21466
# File 'lib/aws-sdk-ec2/types.rb', line 21458

class DescribeCapacityBlockExtensionOfferingsRequest < Struct.new(
  :dry_run,
  :capacity_block_extension_duration_hours,
  :capacity_reservation_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end