Class: Aws::EC2::Types::DescribeCapacityBlockOfferingsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeCapacityBlockOfferingsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#all_availability_zones ⇒ Boolean
Include all Availability Zones and Local Zones, regardless of your opt-in status.
-
#capacity_duration_hours ⇒ Integer
The reservation duration for the Capacity Block, in hours.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#end_date_range ⇒ Time
The latest end date for the Capacity Block offering.
-
#instance_count ⇒ Integer
The number of instances for which to reserve capacity.
-
#instance_type ⇒ String
The type of instance for which the Capacity Block offering reserves capacity.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token to use to retrieve the next page of results.
-
#start_date_range ⇒ Time
The earliest start date for the Capacity Block offering.
-
#ultraserver_count ⇒ Integer
The number of EC2 UltraServers in the offerings.
-
#ultraserver_type ⇒ String
The EC2 UltraServer type of the Capacity Block offerings.
Instance Attribute Details
#all_availability_zones ⇒ Boolean
Include all Availability Zones and Local Zones, regardless of your opt-in status. If you do not use this parameter, the results include available offerings from all Availability Zones in the Amazon Web Services Region and Local Zones you are opted into.
22340 22341 22342 22343 22344 22345 22346 22347 22348 22349 22350 22351 22352 22353 22354 |
# File 'lib/aws-sdk-ec2/types.rb', line 22340 class DescribeCapacityBlockOfferingsRequest < Struct.new( :dry_run, :instance_type, :instance_count, :start_date_range, :end_date_range, :capacity_duration_hours, :next_token, :max_results, :ultraserver_type, :ultraserver_count, :all_availability_zones) SENSITIVE = [] include Aws::Structure end |
#capacity_duration_hours ⇒ Integer
The reservation duration for the Capacity Block, in hours. You must specify the duration in 1-day increments up 14 days, and in 7-day increments up to 182 days.
22340 22341 22342 22343 22344 22345 22346 22347 22348 22349 22350 22351 22352 22353 22354 |
# File 'lib/aws-sdk-ec2/types.rb', line 22340 class DescribeCapacityBlockOfferingsRequest < Struct.new( :dry_run, :instance_type, :instance_count, :start_date_range, :end_date_range, :capacity_duration_hours, :next_token, :max_results, :ultraserver_type, :ultraserver_count, :all_availability_zones) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
22340 22341 22342 22343 22344 22345 22346 22347 22348 22349 22350 22351 22352 22353 22354 |
# File 'lib/aws-sdk-ec2/types.rb', line 22340 class DescribeCapacityBlockOfferingsRequest < Struct.new( :dry_run, :instance_type, :instance_count, :start_date_range, :end_date_range, :capacity_duration_hours, :next_token, :max_results, :ultraserver_type, :ultraserver_count, :all_availability_zones) SENSITIVE = [] include Aws::Structure end |
#end_date_range ⇒ Time
The latest end date for the Capacity Block offering.
22340 22341 22342 22343 22344 22345 22346 22347 22348 22349 22350 22351 22352 22353 22354 |
# File 'lib/aws-sdk-ec2/types.rb', line 22340 class DescribeCapacityBlockOfferingsRequest < Struct.new( :dry_run, :instance_type, :instance_count, :start_date_range, :end_date_range, :capacity_duration_hours, :next_token, :max_results, :ultraserver_type, :ultraserver_count, :all_availability_zones) SENSITIVE = [] include Aws::Structure end |
#instance_count ⇒ Integer
The number of instances for which to reserve capacity. Each Capacity Block can have up to 64 instances, and you can have up to 256 instances across Capacity Blocks.
22340 22341 22342 22343 22344 22345 22346 22347 22348 22349 22350 22351 22352 22353 22354 |
# File 'lib/aws-sdk-ec2/types.rb', line 22340 class DescribeCapacityBlockOfferingsRequest < Struct.new( :dry_run, :instance_type, :instance_count, :start_date_range, :end_date_range, :capacity_duration_hours, :next_token, :max_results, :ultraserver_type, :ultraserver_count, :all_availability_zones) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The type of instance for which the Capacity Block offering reserves capacity.
22340 22341 22342 22343 22344 22345 22346 22347 22348 22349 22350 22351 22352 22353 22354 |
# File 'lib/aws-sdk-ec2/types.rb', line 22340 class DescribeCapacityBlockOfferingsRequest < Struct.new( :dry_run, :instance_type, :instance_count, :start_date_range, :end_date_range, :capacity_duration_hours, :next_token, :max_results, :ultraserver_type, :ultraserver_count, :all_availability_zones) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination
22340 22341 22342 22343 22344 22345 22346 22347 22348 22349 22350 22351 22352 22353 22354 |
# File 'lib/aws-sdk-ec2/types.rb', line 22340 class DescribeCapacityBlockOfferingsRequest < Struct.new( :dry_run, :instance_type, :instance_count, :start_date_range, :end_date_range, :capacity_duration_hours, :next_token, :max_results, :ultraserver_type, :ultraserver_count, :all_availability_zones) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to retrieve the next page of results.
22340 22341 22342 22343 22344 22345 22346 22347 22348 22349 22350 22351 22352 22353 22354 |
# File 'lib/aws-sdk-ec2/types.rb', line 22340 class DescribeCapacityBlockOfferingsRequest < Struct.new( :dry_run, :instance_type, :instance_count, :start_date_range, :end_date_range, :capacity_duration_hours, :next_token, :max_results, :ultraserver_type, :ultraserver_count, :all_availability_zones) SENSITIVE = [] include Aws::Structure end |
#start_date_range ⇒ Time
The earliest start date for the Capacity Block offering.
22340 22341 22342 22343 22344 22345 22346 22347 22348 22349 22350 22351 22352 22353 22354 |
# File 'lib/aws-sdk-ec2/types.rb', line 22340 class DescribeCapacityBlockOfferingsRequest < Struct.new( :dry_run, :instance_type, :instance_count, :start_date_range, :end_date_range, :capacity_duration_hours, :next_token, :max_results, :ultraserver_type, :ultraserver_count, :all_availability_zones) SENSITIVE = [] include Aws::Structure end |
#ultraserver_count ⇒ Integer
The number of EC2 UltraServers in the offerings.
22340 22341 22342 22343 22344 22345 22346 22347 22348 22349 22350 22351 22352 22353 22354 |
# File 'lib/aws-sdk-ec2/types.rb', line 22340 class DescribeCapacityBlockOfferingsRequest < Struct.new( :dry_run, :instance_type, :instance_count, :start_date_range, :end_date_range, :capacity_duration_hours, :next_token, :max_results, :ultraserver_type, :ultraserver_count, :all_availability_zones) SENSITIVE = [] include Aws::Structure end |
#ultraserver_type ⇒ String
The EC2 UltraServer type of the Capacity Block offerings.
22340 22341 22342 22343 22344 22345 22346 22347 22348 22349 22350 22351 22352 22353 22354 |
# File 'lib/aws-sdk-ec2/types.rb', line 22340 class DescribeCapacityBlockOfferingsRequest < Struct.new( :dry_run, :instance_type, :instance_count, :start_date_range, :end_date_range, :capacity_duration_hours, :next_token, :max_results, :ultraserver_type, :ultraserver_count, :all_availability_zones) SENSITIVE = [] include Aws::Structure end |