Class: Aws::EC2::Types::DescribeCapacityBlockStatusRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeCapacityBlockStatusRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_block_ids ⇒ Array<String>
The ID of the Capacity Block.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token to use to retrieve the next page of results.
Instance Attribute Details
#capacity_block_ids ⇒ Array<String>
The ID of the Capacity Block.
22459 22460 22461 22462 22463 22464 22465 22466 22467 |
# File 'lib/aws-sdk-ec2/types.rb', line 22459 class DescribeCapacityBlockStatusRequest < Struct.new( :capacity_block_ids, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
22459 22460 22461 22462 22463 22464 22465 22466 22467 |
# File 'lib/aws-sdk-ec2/types.rb', line 22459 class DescribeCapacityBlockStatusRequest < Struct.new( :capacity_block_ids, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters.
-
‘interconnect-status` - The status of the interconnect for the Capacity Block (`ok` | `impaired` | `insufficient-data`).
^
22459 22460 22461 22462 22463 22464 22465 22466 22467 |
# File 'lib/aws-sdk-ec2/types.rb', line 22459 class DescribeCapacityBlockStatusRequest < Struct.new( :capacity_block_ids, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination
22459 22460 22461 22462 22463 22464 22465 22466 22467 |
# File 'lib/aws-sdk-ec2/types.rb', line 22459 class DescribeCapacityBlockStatusRequest < Struct.new( :capacity_block_ids, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to retrieve the next page of results.
22459 22460 22461 22462 22463 22464 22465 22466 22467 |
# File 'lib/aws-sdk-ec2/types.rb', line 22459 class DescribeCapacityBlockStatusRequest < Struct.new( :capacity_block_ids, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |