Class: Aws::EC2::Types::DescribeCapacityBlockStatusRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_block_idsArray<String>

The ID of the Capacity Block.

Returns:

  • (Array<String>)


22206
22207
22208
22209
22210
22211
22212
22213
22214
# File 'lib/aws-sdk-ec2/types.rb', line 22206

class DescribeCapacityBlockStatusRequest < Struct.new(
  :capacity_block_ids,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


22206
22207
22208
22209
22210
22211
22212
22213
22214
# File 'lib/aws-sdk-ec2/types.rb', line 22206

class DescribeCapacityBlockStatusRequest < Struct.new(
  :capacity_block_ids,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters.

  • ‘interconnect-status` - The status of the interconnect for the Capacity Block (`ok` | `impaired` | `insufficient-data`).

^

Returns:



22206
22207
22208
22209
22210
22211
22212
22213
22214
# File 'lib/aws-sdk-ec2/types.rb', line 22206

class DescribeCapacityBlockStatusRequest < Struct.new(
  :capacity_block_ids,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination

Returns:

  • (Integer)


22206
22207
22208
22209
22210
22211
22212
22213
22214
# File 'lib/aws-sdk-ec2/types.rb', line 22206

class DescribeCapacityBlockStatusRequest < Struct.new(
  :capacity_block_ids,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to use to retrieve the next page of results.

Returns:

  • (String)


22206
22207
22208
22209
22210
22211
22212
22213
22214
# File 'lib/aws-sdk-ec2/types.rb', line 22206

class DescribeCapacityBlockStatusRequest < Struct.new(
  :capacity_block_ids,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end