Class: Aws::EC2::Types::DescribeCapacityBlocksRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_block_idsArray<String>

The IDs of the Capacity Blocks.

Returns:

  • (Array<String>)


21694
21695
21696
21697
21698
21699
21700
21701
21702
# File 'lib/aws-sdk-ec2/types.rb', line 21694

class DescribeCapacityBlocksRequest < Struct.new(
  :capacity_block_ids,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


21694
21695
21696
21697
21698
21699
21700
21701
21702
# File 'lib/aws-sdk-ec2/types.rb', line 21694

class DescribeCapacityBlocksRequest < Struct.new(
  :capacity_block_ids,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters.

  • ‘capacity-block-id` - The ID of the Capacity Block.

  • ‘ultraserver-type` - The Capacity Block type. The type can be `instances` or `ultraservers`.

  • ‘availability-zone` - The Availability Zone of the Capacity Block.

  • ‘start-date` - The date and time at which the Capacity Block was started.

  • ‘end-date` - The date and time at which the Capacity Block expires. When a Capacity Block expires, all instances in the Capacity Block are terminated.

  • ‘create-date` - The date and time at which the Capacity Block was created.

  • ‘state` - The state of the Capacity Block (`active` | `expired` | `unavailable` | `cancelled` | `failed` | `scheduled` | `payment-pending` | `payment-failed`).

  • ‘tags` - The tags assigned to the Capacity Block.

Returns:



21694
21695
21696
21697
21698
21699
21700
21701
21702
# File 'lib/aws-sdk-ec2/types.rb', line 21694

class DescribeCapacityBlocksRequest < Struct.new(
  :capacity_block_ids,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination

Returns:

  • (Integer)


21694
21695
21696
21697
21698
21699
21700
21701
21702
# File 'lib/aws-sdk-ec2/types.rb', line 21694

class DescribeCapacityBlocksRequest < Struct.new(
  :capacity_block_ids,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to use to retrieve the next page of results.

Returns:

  • (String)


21694
21695
21696
21697
21698
21699
21700
21701
21702
# File 'lib/aws-sdk-ec2/types.rb', line 21694

class DescribeCapacityBlocksRequest < Struct.new(
  :capacity_block_ids,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end