Class: Aws::EC2::Types::DescribeCapacityManagerDataExportsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeCapacityManagerDataExportsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_manager_data_export_ids ⇒ Array<String>
The IDs of the data export configurations to describe.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters to narrow the results.
-
#max_results ⇒ Integer
The maximum number of results to return in a single call.
-
#next_token ⇒ String
The token for the next page of results.
Instance Attribute Details
#capacity_manager_data_export_ids ⇒ Array<String>
The IDs of the data export configurations to describe. If not specified, all export configurations are returned.
21751 21752 21753 21754 21755 21756 21757 21758 21759 |
# File 'lib/aws-sdk-ec2/types.rb', line 21751 class DescribeCapacityManagerDataExportsRequest < Struct.new( :capacity_manager_data_export_ids, :max_results, :next_token, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
21751 21752 21753 21754 21755 21756 21757 21758 21759 |
# File 'lib/aws-sdk-ec2/types.rb', line 21751 class DescribeCapacityManagerDataExportsRequest < Struct.new( :capacity_manager_data_export_ids, :max_results, :next_token, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters to narrow the results. Supported filters include export status, creation date, and S3 bucket name.
21751 21752 21753 21754 21755 21756 21757 21758 21759 |
# File 'lib/aws-sdk-ec2/types.rb', line 21751 class DescribeCapacityManagerDataExportsRequest < Struct.new( :capacity_manager_data_export_ids, :max_results, :next_token, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in a single call. If not specified, up to 1000 results are returned.
21751 21752 21753 21754 21755 21756 21757 21758 21759 |
# File 'lib/aws-sdk-ec2/types.rb', line 21751 class DescribeCapacityManagerDataExportsRequest < Struct.new( :capacity_manager_data_export_ids, :max_results, :next_token, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results. Use this value in a subsequent call to retrieve additional results.
21751 21752 21753 21754 21755 21756 21757 21758 21759 |
# File 'lib/aws-sdk-ec2/types.rb', line 21751 class DescribeCapacityManagerDataExportsRequest < Struct.new( :capacity_manager_data_export_ids, :max_results, :next_token, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |