Class: Aws::EC2::Types::DescribeCapacityReservationBillingRequestsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_reservation_idsArray<String>

The ID of the Capacity Reservation.

Returns:

  • (Array<String>)


22177
22178
22179
22180
22181
22182
22183
22184
22185
22186
# File 'lib/aws-sdk-ec2/types.rb', line 22177

class DescribeCapacityReservationBillingRequestsRequest < Struct.new(
  :capacity_reservation_ids,
  :role,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


22177
22178
22179
22180
22181
22182
22183
22184
22185
22186
# File 'lib/aws-sdk-ec2/types.rb', line 22177

class DescribeCapacityReservationBillingRequestsRequest < Struct.new(
  :capacity_reservation_ids,
  :role,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters.

  • ‘status` - The state of the request (`pending` | `accepted` | `rejected` | `cancelled` | `revoked` | `expired`).

  • ‘requested-by` - The account ID of the Capacity Reservation owner that initiated the request. Not supported if you specify `requested-by` for Role.

  • ‘unused-reservation-billing-owner` - The ID of the consumer account to which the request was sent. Not supported if you specify `unused-reservation-billing-owner` for Role.

Returns:



22177
22178
22179
22180
22181
22182
22183
22184
22185
22186
# File 'lib/aws-sdk-ec2/types.rb', line 22177

class DescribeCapacityReservationBillingRequestsRequest < Struct.new(
  :capacity_reservation_ids,
  :role,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination

Returns:

  • (Integer)


22177
22178
22179
22180
22181
22182
22183
22184
22185
22186
# File 'lib/aws-sdk-ec2/types.rb', line 22177

class DescribeCapacityReservationBillingRequestsRequest < Struct.new(
  :capacity_reservation_ids,
  :role,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to use to retrieve the next page of results.

Returns:

  • (String)


22177
22178
22179
22180
22181
22182
22183
22184
22185
22186
# File 'lib/aws-sdk-ec2/types.rb', line 22177

class DescribeCapacityReservationBillingRequestsRequest < Struct.new(
  :capacity_reservation_ids,
  :role,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#roleString

Specify one of the following:

  • ‘odcr-owner` - If you are the Capacity Reservation owner, specify this value to view requests that you have initiated. Not supported with the `requested-by` filter.

  • ‘unused-reservation-billing-owner` - If you are the consumer account, specify this value to view requests that have been sent to you. Not supported with the `unused-reservation-billing-owner` filter.

Returns:

  • (String)


22177
22178
22179
22180
22181
22182
22183
22184
22185
22186
# File 'lib/aws-sdk-ec2/types.rb', line 22177

class DescribeCapacityReservationBillingRequestsRequest < Struct.new(
  :capacity_reservation_ids,
  :role,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end