Class: Aws::EC2::Types::DescribeCapacityReservationBillingRequestsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeCapacityReservationBillingRequestsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_reservation_ids ⇒ Array<String>
The ID of the Capacity Reservation.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token to use to retrieve the next page of results.
-
#role ⇒ String
Specify one of the following:.
Instance Attribute Details
#capacity_reservation_ids ⇒ Array<String>
The ID of the Capacity Reservation.
21841 21842 21843 21844 21845 21846 21847 21848 21849 21850 |
# File 'lib/aws-sdk-ec2/types.rb', line 21841 class DescribeCapacityReservationBillingRequestsRequest < Struct.new( :capacity_reservation_ids, :role, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
21841 21842 21843 21844 21845 21846 21847 21848 21849 21850 |
# File 'lib/aws-sdk-ec2/types.rb', line 21841 class DescribeCapacityReservationBillingRequestsRequest < Struct.new( :capacity_reservation_ids, :role, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters.
-
‘status` - The state of the request (`pending` | `accepted` | `rejected` | `cancelled` | `revoked` | `expired`).
-
‘requested-by` - The account ID of the Capacity Reservation owner that initiated the request. Not supported if you specify `requested-by` for Role.
-
‘unused-reservation-billing-owner` - The ID of the consumer account to which the request was sent. Not supported if you specify `unused-reservation-billing-owner` for Role.
21841 21842 21843 21844 21845 21846 21847 21848 21849 21850 |
# File 'lib/aws-sdk-ec2/types.rb', line 21841 class DescribeCapacityReservationBillingRequestsRequest < Struct.new( :capacity_reservation_ids, :role, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination
21841 21842 21843 21844 21845 21846 21847 21848 21849 21850 |
# File 'lib/aws-sdk-ec2/types.rb', line 21841 class DescribeCapacityReservationBillingRequestsRequest < Struct.new( :capacity_reservation_ids, :role, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to retrieve the next page of results.
21841 21842 21843 21844 21845 21846 21847 21848 21849 21850 |
# File 'lib/aws-sdk-ec2/types.rb', line 21841 class DescribeCapacityReservationBillingRequestsRequest < Struct.new( :capacity_reservation_ids, :role, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
Specify one of the following:
-
‘odcr-owner` - If you are the Capacity Reservation owner, specify this value to view requests that you have initiated. Not supported with the `requested-by` filter.
-
‘unused-reservation-billing-owner` - If you are the consumer account, specify this value to view requests that have been sent to you. Not supported with the `unused-reservation-billing-owner` filter.
21841 21842 21843 21844 21845 21846 21847 21848 21849 21850 |
# File 'lib/aws-sdk-ec2/types.rb', line 21841 class DescribeCapacityReservationBillingRequestsRequest < Struct.new( :capacity_reservation_ids, :role, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |