Class: Aws::EC2::Types::DescribeCapacityReservationCancellationQuotesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeCapacityReservationCancellationQuotesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_reservation_cancellation_quote_ids ⇒ Array<String>
The IDs of the cancellation quotes to describe.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token to use to retrieve the next page of results.
Instance Attribute Details
#capacity_reservation_cancellation_quote_ids ⇒ Array<String>
The IDs of the cancellation quotes to describe.
22900 22901 22902 22903 22904 22905 22906 22907 22908 |
# File 'lib/aws-sdk-ec2/types.rb', line 22900 class DescribeCapacityReservationCancellationQuotesRequest < Struct.new( :capacity_reservation_cancellation_quote_ids, :max_results, :next_token, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
22900 22901 22902 22903 22904 22905 22906 22907 22908 |
# File 'lib/aws-sdk-ec2/types.rb', line 22900 class DescribeCapacityReservationCancellationQuotesRequest < Struct.new( :capacity_reservation_cancellation_quote_ids, :max_results, :next_token, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters. Filter names and values are case-sensitive.
22900 22901 22902 22903 22904 22905 22906 22907 22908 |
# File 'lib/aws-sdk-ec2/types.rb', line 22900 class DescribeCapacityReservationCancellationQuotesRequest < Struct.new( :capacity_reservation_cancellation_quote_ids, :max_results, :next_token, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
22900 22901 22902 22903 22904 22905 22906 22907 22908 |
# File 'lib/aws-sdk-ec2/types.rb', line 22900 class DescribeCapacityReservationCancellationQuotesRequest < Struct.new( :capacity_reservation_cancellation_quote_ids, :max_results, :next_token, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to retrieve the next page of results.
22900 22901 22902 22903 22904 22905 22906 22907 22908 |
# File 'lib/aws-sdk-ec2/types.rb', line 22900 class DescribeCapacityReservationCancellationQuotesRequest < Struct.new( :capacity_reservation_cancellation_quote_ids, :max_results, :next_token, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |