Class: Aws::EC2::Types::DescribeCapacityReservationCancellationQuotesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_reservation_cancellation_quote_idsArray<String>

The IDs of the cancellation quotes to describe.

Returns:

  • (Array<String>)


22693
22694
22695
22696
22697
22698
22699
22700
22701
# File 'lib/aws-sdk-ec2/types.rb', line 22693

class DescribeCapacityReservationCancellationQuotesRequest < Struct.new(
  :capacity_reservation_cancellation_quote_ids,
  :max_results,
  :next_token,
  :dry_run,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


22693
22694
22695
22696
22697
22698
22699
22700
22701
# File 'lib/aws-sdk-ec2/types.rb', line 22693

class DescribeCapacityReservationCancellationQuotesRequest < Struct.new(
  :capacity_reservation_cancellation_quote_ids,
  :max_results,
  :next_token,
  :dry_run,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters. Filter names and values are case-sensitive.

Returns:



22693
22694
22695
22696
22697
22698
22699
22700
22701
# File 'lib/aws-sdk-ec2/types.rb', line 22693

class DescribeCapacityReservationCancellationQuotesRequest < Struct.new(
  :capacity_reservation_cancellation_quote_ids,
  :max_results,
  :next_token,
  :dry_run,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination

Returns:

  • (Integer)


22693
22694
22695
22696
22697
22698
22699
22700
22701
# File 'lib/aws-sdk-ec2/types.rb', line 22693

class DescribeCapacityReservationCancellationQuotesRequest < Struct.new(
  :capacity_reservation_cancellation_quote_ids,
  :max_results,
  :next_token,
  :dry_run,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to use to retrieve the next page of results.

Returns:

  • (String)


22693
22694
22695
22696
22697
22698
22699
22700
22701
# File 'lib/aws-sdk-ec2/types.rb', line 22693

class DescribeCapacityReservationCancellationQuotesRequest < Struct.new(
  :capacity_reservation_cancellation_quote_ids,
  :max_results,
  :next_token,
  :dry_run,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end