Class: Aws::EC2::Types::DescribeCapacityReservationFleetsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_reservation_fleet_idsArray<String>

The IDs of the Capacity Reservation Fleets to describe.

Returns:

  • (Array<String>)


24298
24299
24300
24301
24302
24303
24304
24305
24306
# File 'lib/aws-sdk-ec2/types.rb', line 24298

class DescribeCapacityReservationFleetsRequest < Struct.new(
  :capacity_reservation_fleet_ids,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


24298
24299
24300
24301
24302
24303
24304
24305
24306
# File 'lib/aws-sdk-ec2/types.rb', line 24298

class DescribeCapacityReservationFleetsRequest < Struct.new(
  :capacity_reservation_fleet_ids,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters.

  • state - The state of the Fleet (submitted | modifying | active | partially_fulfilled | expiring | expired | cancelling | cancelled | failed).

  • instance-match-criteria - The instance matching criteria for the Fleet. Only open is supported.

  • tenancy - The tenancy of the Fleet (default | dedicated).

  • allocation-strategy - The allocation strategy used by the Fleet. Only prioritized is supported.

Returns:



24298
24299
24300
24301
24302
24303
24304
24305
24306
# File 'lib/aws-sdk-ec2/types.rb', line 24298

class DescribeCapacityReservationFleetsRequest < Struct.new(
  :capacity_reservation_fleet_ids,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.

Returns:

  • (Integer)


24298
24299
24300
24301
24302
24303
24304
24305
24306
# File 'lib/aws-sdk-ec2/types.rb', line 24298

class DescribeCapacityReservationFleetsRequest < Struct.new(
  :capacity_reservation_fleet_ids,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to use to retrieve the next page of results.

Returns:

  • (String)


24298
24299
24300
24301
24302
24303
24304
24305
24306
# File 'lib/aws-sdk-ec2/types.rb', line 24298

class DescribeCapacityReservationFleetsRequest < Struct.new(
  :capacity_reservation_fleet_ids,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end