Class: Aws::EC2::Types::DescribeCapacityReservationFleetsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeCapacityReservationFleetsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_reservation_fleet_ids ⇒ Array<String>
The IDs of the Capacity Reservation Fleets to describe.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token to use to retrieve the next page of results.
Instance Attribute Details
#capacity_reservation_fleet_ids ⇒ Array<String>
The IDs of the Capacity Reservation Fleets to describe.
22764 22765 22766 22767 22768 22769 22770 22771 22772 |
# File 'lib/aws-sdk-ec2/types.rb', line 22764 class DescribeCapacityReservationFleetsRequest < Struct.new( :capacity_reservation_fleet_ids, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
22764 22765 22766 22767 22768 22769 22770 22771 22772 |
# File 'lib/aws-sdk-ec2/types.rb', line 22764 class DescribeCapacityReservationFleetsRequest < Struct.new( :capacity_reservation_fleet_ids, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters.
-
‘state` - The state of the Fleet (`submitted` | `modifying` | `active` | `partially_fulfilled` | `expiring` | `expired` | `cancelling` | `cancelled` | `failed`).
-
‘instance-match-criteria` - The instance matching criteria for the Fleet. Only `open` is supported.
-
‘tenancy` - The tenancy of the Fleet (`default` | `dedicated`).
-
‘allocation-strategy` - The allocation strategy used by the Fleet. Only `prioritized` is supported.
22764 22765 22766 22767 22768 22769 22770 22771 22772 |
# File 'lib/aws-sdk-ec2/types.rb', line 22764 class DescribeCapacityReservationFleetsRequest < Struct.new( :capacity_reservation_fleet_ids, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination
22764 22765 22766 22767 22768 22769 22770 22771 22772 |
# File 'lib/aws-sdk-ec2/types.rb', line 22764 class DescribeCapacityReservationFleetsRequest < Struct.new( :capacity_reservation_fleet_ids, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to retrieve the next page of results.
22764 22765 22766 22767 22768 22769 22770 22771 22772 |
# File 'lib/aws-sdk-ec2/types.rb', line 22764 class DescribeCapacityReservationFleetsRequest < Struct.new( :capacity_reservation_fleet_ids, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |