Class: Aws::EC2::Types::DescribeCapacityReservationTopologyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeCapacityReservationTopologyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_reservation_ids ⇒ Array<String>
The Capacity Reservation IDs.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The filters.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token returned from a previous paginated request.
Instance Attribute Details
#capacity_reservation_ids ⇒ Array<String>
The Capacity Reservation IDs.
Default: Describes all your Capacity Reservations.
Constraints: Maximum 100 explicitly specified Capacity Reservation IDs.
21987 21988 21989 21990 21991 21992 21993 21994 21995 |
# File 'lib/aws-sdk-ec2/types.rb', line 21987 class DescribeCapacityReservationTopologyRequest < Struct.new( :dry_run, :next_token, :max_results, :capacity_reservation_ids, :filters) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
21987 21988 21989 21990 21991 21992 21993 21994 21995 |
# File 'lib/aws-sdk-ec2/types.rb', line 21987 class DescribeCapacityReservationTopologyRequest < Struct.new( :dry_run, :next_token, :max_results, :capacity_reservation_ids, :filters) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters.
-
‘availability-zone` - The name of the Availability Zone (for example, `us-west-2a`) or Local Zone (for example, `us-west-2-lax-1b`) that the Capacity Reservation is in.
-
‘instance-type` - The instance type (for example, `p4d.24xlarge`) or instance family (for example, `p4d*`). You can use the `*` wildcard to match zero or more characters, or the `?` wildcard to match zero or one character.
21987 21988 21989 21990 21991 21992 21993 21994 21995 |
# File 'lib/aws-sdk-ec2/types.rb', line 21987 class DescribeCapacityReservationTopologyRequest < Struct.new( :dry_run, :next_token, :max_results, :capacity_reservation_ids, :filters) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].
You can’t specify this parameter and the Capacity Reservation IDs parameter in the same request.
Default: ‘10`
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination
21987 21988 21989 21990 21991 21992 21993 21994 21995 |
# File 'lib/aws-sdk-ec2/types.rb', line 21987 class DescribeCapacityReservationTopologyRequest < Struct.new( :dry_run, :next_token, :max_results, :capacity_reservation_ids, :filters) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
21987 21988 21989 21990 21991 21992 21993 21994 21995 |
# File 'lib/aws-sdk-ec2/types.rb', line 21987 class DescribeCapacityReservationTopologyRequest < Struct.new( :dry_run, :next_token, :max_results, :capacity_reservation_ids, :filters) SENSITIVE = [] include Aws::Structure end |