Class: Aws::EC2::Types::DescribeCapacityReservationTopologyResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeCapacityReservationTopologyResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_reservations ⇒ Array<Types::CapacityReservationTopology>
Information about the topology of each Capacity Reservation.
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
Instance Attribute Details
#capacity_reservations ⇒ Array<Types::CapacityReservationTopology>
Information about the topology of each Capacity Reservation.
24393 24394 24395 24396 24397 24398 |
# File 'lib/aws-sdk-ec2/types.rb', line 24393 class DescribeCapacityReservationTopologyResult < Struct.new( :next_token, :capacity_reservations) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
24393 24394 24395 24396 24397 24398 |
# File 'lib/aws-sdk-ec2/types.rb', line 24393 class DescribeCapacityReservationTopologyResult < Struct.new( :next_token, :capacity_reservations) SENSITIVE = [] include Aws::Structure end |