Class: Aws::EC2::Types::DescribeClassicLinkInstancesResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeClassicLinkInstancesResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instances ⇒ Array<Types::ClassicLinkInstance>
Information about one or more linked EC2-Classic instances.
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
Instance Attribute Details
#instances ⇒ Array<Types::ClassicLinkInstance>
Information about one or more linked EC2-Classic instances.
24696 24697 24698 24699 24700 24701 |
# File 'lib/aws-sdk-ec2/types.rb', line 24696 class DescribeClassicLinkInstancesResult < Struct.new( :instances, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
24696 24697 24698 24699 24700 24701 |
# File 'lib/aws-sdk-ec2/types.rb', line 24696 class DescribeClassicLinkInstancesResult < Struct.new( :instances, :next_token) SENSITIVE = [] include Aws::Structure end |