Class: Aws::EC2::Types::DescribeClassicLinkInstancesResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeClassicLinkInstancesResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instances ⇒ Array<Types::ClassicLinkInstance>
Information about one or more linked EC2-Classic instances.
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
Instance Attribute Details
#instances ⇒ Array<Types::ClassicLinkInstance>
Information about one or more linked EC2-Classic instances.
23394 23395 23396 23397 23398 23399 |
# File 'lib/aws-sdk-ec2/types.rb', line 23394 class DescribeClassicLinkInstancesResult < Struct.new( :instances, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
23394 23395 23396 23397 23398 23399 |
# File 'lib/aws-sdk-ec2/types.rb', line 23394 class DescribeClassicLinkInstancesResult < Struct.new( :instances, :next_token) SENSITIVE = [] include Aws::Structure end |