Class: Aws::EC2::Types::DescribeClientVpnConnectionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeClientVpnConnectionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_vpn_endpoint_id ⇒ String
The ID of the Client VPN endpoint.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters.
-
#max_results ⇒ Integer
The maximum number of results to return for the request in a single page.
-
#next_token ⇒ String
The token to retrieve the next page of results.
Instance Attribute Details
#client_vpn_endpoint_id ⇒ String
The ID of the Client VPN endpoint.
23013 23014 23015 23016 23017 23018 23019 23020 23021 |
# File 'lib/aws-sdk-ec2/types.rb', line 23013 class DescribeClientVpnConnectionsRequest < Struct.new( :client_vpn_endpoint_id, :filters, :next_token, :max_results, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
23013 23014 23015 23016 23017 23018 23019 23020 23021 |
# File 'lib/aws-sdk-ec2/types.rb', line 23013 class DescribeClientVpnConnectionsRequest < Struct.new( :client_vpn_endpoint_id, :filters, :next_token, :max_results, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters. Filter names and values are case-sensitive.
-
‘connection-id` - The ID of the connection.
-
‘username` - For Active Directory client authentication, the user name of the client who established the client connection.
23013 23014 23015 23016 23017 23018 23019 23020 23021 |
# File 'lib/aws-sdk-ec2/types.rb', line 23013 class DescribeClientVpnConnectionsRequest < Struct.new( :client_vpn_endpoint_id, :filters, :next_token, :max_results, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the nextToken value.
23013 23014 23015 23016 23017 23018 23019 23020 23021 |
# File 'lib/aws-sdk-ec2/types.rb', line 23013 class DescribeClientVpnConnectionsRequest < Struct.new( :client_vpn_endpoint_id, :filters, :next_token, :max_results, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to retrieve the next page of results.
23013 23014 23015 23016 23017 23018 23019 23020 23021 |
# File 'lib/aws-sdk-ec2/types.rb', line 23013 class DescribeClientVpnConnectionsRequest < Struct.new( :client_vpn_endpoint_id, :filters, :next_token, :max_results, :dry_run) SENSITIVE = [] include Aws::Structure end |