Class: Aws::EC2::Types::DescribeClientVpnConnectionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_vpn_endpoint_idString

The ID of the Client VPN endpoint.

Returns:

  • (String)


22749
22750
22751
22752
22753
22754
22755
22756
22757
# File 'lib/aws-sdk-ec2/types.rb', line 22749

class DescribeClientVpnConnectionsRequest < Struct.new(
  :client_vpn_endpoint_id,
  :filters,
  :next_token,
  :max_results,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


22749
22750
22751
22752
22753
22754
22755
22756
22757
# File 'lib/aws-sdk-ec2/types.rb', line 22749

class DescribeClientVpnConnectionsRequest < Struct.new(
  :client_vpn_endpoint_id,
  :filters,
  :next_token,
  :max_results,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters. Filter names and values are case-sensitive.

  • ‘connection-id` - The ID of the connection.

  • ‘username` - For Active Directory client authentication, the user name of the client who established the client connection.

Returns:



22749
22750
22751
22752
22753
22754
22755
22756
22757
# File 'lib/aws-sdk-ec2/types.rb', line 22749

class DescribeClientVpnConnectionsRequest < Struct.new(
  :client_vpn_endpoint_id,
  :filters,
  :next_token,
  :max_results,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the nextToken value.

Returns:

  • (Integer)


22749
22750
22751
22752
22753
22754
22755
22756
22757
# File 'lib/aws-sdk-ec2/types.rb', line 22749

class DescribeClientVpnConnectionsRequest < Struct.new(
  :client_vpn_endpoint_id,
  :filters,
  :next_token,
  :max_results,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to retrieve the next page of results.

Returns:

  • (String)


22749
22750
22751
22752
22753
22754
22755
22756
22757
# File 'lib/aws-sdk-ec2/types.rb', line 22749

class DescribeClientVpnConnectionsRequest < Struct.new(
  :client_vpn_endpoint_id,
  :filters,
  :next_token,
  :max_results,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end