Class: Aws::EC2::Types::DescribeClientVpnEndpointsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_vpn_endpoint_idsArray<String>

The ID of the Client VPN endpoint.

Returns:

  • (Array<String>)


24857
24858
24859
24860
24861
24862
24863
24864
24865
# File 'lib/aws-sdk-ec2/types.rb', line 24857

class DescribeClientVpnEndpointsRequest < Struct.new(
  :client_vpn_endpoint_ids,
  :max_results,
  :next_token,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


24857
24858
24859
24860
24861
24862
24863
24864
24865
# File 'lib/aws-sdk-ec2/types.rb', line 24857

class DescribeClientVpnEndpointsRequest < Struct.new(
  :client_vpn_endpoint_ids,
  :max_results,
  :next_token,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters. Filter names and values are case-sensitive.

  • endpoint-id - The ID of the Client VPN endpoint.

  • transport-protocol - The transport protocol (tcp | udp).

Returns:



24857
24858
24859
24860
24861
24862
24863
24864
24865
# File 'lib/aws-sdk-ec2/types.rb', line 24857

class DescribeClientVpnEndpointsRequest < Struct.new(
  :client_vpn_endpoint_ids,
  :max_results,
  :next_token,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the nextToken value.

Returns:

  • (Integer)


24857
24858
24859
24860
24861
24862
24863
24864
24865
# File 'lib/aws-sdk-ec2/types.rb', line 24857

class DescribeClientVpnEndpointsRequest < Struct.new(
  :client_vpn_endpoint_ids,
  :max_results,
  :next_token,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to retrieve the next page of results.

Returns:

  • (String)


24857
24858
24859
24860
24861
24862
24863
24864
24865
# File 'lib/aws-sdk-ec2/types.rb', line 24857

class DescribeClientVpnEndpointsRequest < Struct.new(
  :client_vpn_endpoint_ids,
  :max_results,
  :next_token,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end