Class: Aws::EC2::Types::DescribeClientVpnEndpointsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeClientVpnEndpointsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_vpn_endpoint_ids ⇒ Array<String>
The ID of the Client VPN endpoint.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters.
-
#max_results ⇒ Integer
The maximum number of results to return for the request in a single page.
-
#next_token ⇒ String
The token to retrieve the next page of results.
Instance Attribute Details
#client_vpn_endpoint_ids ⇒ Array<String>
The ID of the Client VPN endpoint.
23555 23556 23557 23558 23559 23560 23561 23562 23563 |
# File 'lib/aws-sdk-ec2/types.rb', line 23555 class DescribeClientVpnEndpointsRequest < Struct.new( :client_vpn_endpoint_ids, :max_results, :next_token, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
23555 23556 23557 23558 23559 23560 23561 23562 23563 |
# File 'lib/aws-sdk-ec2/types.rb', line 23555 class DescribeClientVpnEndpointsRequest < Struct.new( :client_vpn_endpoint_ids, :max_results, :next_token, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters. Filter names and values are case-sensitive.
-
endpoint-id- The ID of the Client VPN endpoint. -
transport-protocol- The transport protocol (tcp|udp).
23555 23556 23557 23558 23559 23560 23561 23562 23563 |
# File 'lib/aws-sdk-ec2/types.rb', line 23555 class DescribeClientVpnEndpointsRequest < Struct.new( :client_vpn_endpoint_ids, :max_results, :next_token, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the nextToken value.
23555 23556 23557 23558 23559 23560 23561 23562 23563 |
# File 'lib/aws-sdk-ec2/types.rb', line 23555 class DescribeClientVpnEndpointsRequest < Struct.new( :client_vpn_endpoint_ids, :max_results, :next_token, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to retrieve the next page of results.
23555 23556 23557 23558 23559 23560 23561 23562 23563 |
# File 'lib/aws-sdk-ec2/types.rb', line 23555 class DescribeClientVpnEndpointsRequest < Struct.new( :client_vpn_endpoint_ids, :max_results, :next_token, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |