Class: Aws::EC2::Types::DescribeClientVpnRoutesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeClientVpnRoutesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_vpn_endpoint_id ⇒ String
The ID of the Client VPN endpoint.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters.
-
#max_results ⇒ Integer
The maximum number of results to return for the request in a single page.
-
#next_token ⇒ String
The token to retrieve the next page of results.
Instance Attribute Details
#client_vpn_endpoint_id ⇒ String
The ID of the Client VPN endpoint.
22529 22530 22531 22532 22533 22534 22535 22536 22537 |
# File 'lib/aws-sdk-ec2/types.rb', line 22529 class DescribeClientVpnRoutesRequest < Struct.new( :client_vpn_endpoint_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
22529 22530 22531 22532 22533 22534 22535 22536 22537 |
# File 'lib/aws-sdk-ec2/types.rb', line 22529 class DescribeClientVpnRoutesRequest < Struct.new( :client_vpn_endpoint_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters. Filter names and values are case-sensitive.
-
‘destination-cidr` - The CIDR of the route destination.
-
‘origin` - How the route was associated with the Client VPN endpoint (`associate` | `add-route`).
-
‘target-subnet` - The ID of the subnet through which traffic is routed.
22529 22530 22531 22532 22533 22534 22535 22536 22537 |
# File 'lib/aws-sdk-ec2/types.rb', line 22529 class DescribeClientVpnRoutesRequest < Struct.new( :client_vpn_endpoint_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the nextToken value.
22529 22530 22531 22532 22533 22534 22535 22536 22537 |
# File 'lib/aws-sdk-ec2/types.rb', line 22529 class DescribeClientVpnRoutesRequest < Struct.new( :client_vpn_endpoint_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to retrieve the next page of results.
22529 22530 22531 22532 22533 22534 22535 22536 22537 |
# File 'lib/aws-sdk-ec2/types.rb', line 22529 class DescribeClientVpnRoutesRequest < Struct.new( :client_vpn_endpoint_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |