Class: Aws::EC2::Types::DescribeClientVpnTargetNetworksRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeClientVpnTargetNetworksRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#association_ids ⇒ Array<String>
The IDs of the target network associations.
-
#client_vpn_endpoint_id ⇒ String
The ID of the Client VPN endpoint.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters.
-
#max_results ⇒ Integer
The maximum number of results to return for the request in a single page.
-
#next_token ⇒ String
The token to retrieve the next page of results.
Instance Attribute Details
#association_ids ⇒ Array<String>
The IDs of the target network associations.
23502 23503 23504 23505 23506 23507 23508 23509 23510 23511 |
# File 'lib/aws-sdk-ec2/types.rb', line 23502 class DescribeClientVpnTargetNetworksRequest < Struct.new( :client_vpn_endpoint_id, :association_ids, :max_results, :next_token, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#client_vpn_endpoint_id ⇒ String
The ID of the Client VPN endpoint.
23502 23503 23504 23505 23506 23507 23508 23509 23510 23511 |
# File 'lib/aws-sdk-ec2/types.rb', line 23502 class DescribeClientVpnTargetNetworksRequest < Struct.new( :client_vpn_endpoint_id, :association_ids, :max_results, :next_token, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
23502 23503 23504 23505 23506 23507 23508 23509 23510 23511 |
# File 'lib/aws-sdk-ec2/types.rb', line 23502 class DescribeClientVpnTargetNetworksRequest < Struct.new( :client_vpn_endpoint_id, :association_ids, :max_results, :next_token, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters. Filter names and values are case-sensitive.
-
‘association-id` - The ID of the association.
-
‘target-network-id` - The ID of the subnet specified as the target network.
-
‘vpc-id` - The ID of the VPC in which the target network is located.
23502 23503 23504 23505 23506 23507 23508 23509 23510 23511 |
# File 'lib/aws-sdk-ec2/types.rb', line 23502 class DescribeClientVpnTargetNetworksRequest < Struct.new( :client_vpn_endpoint_id, :association_ids, :max_results, :next_token, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the nextToken value.
23502 23503 23504 23505 23506 23507 23508 23509 23510 23511 |
# File 'lib/aws-sdk-ec2/types.rb', line 23502 class DescribeClientVpnTargetNetworksRequest < Struct.new( :client_vpn_endpoint_id, :association_ids, :max_results, :next_token, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to retrieve the next page of results.
23502 23503 23504 23505 23506 23507 23508 23509 23510 23511 |
# File 'lib/aws-sdk-ec2/types.rb', line 23502 class DescribeClientVpnTargetNetworksRequest < Struct.new( :client_vpn_endpoint_id, :association_ids, :max_results, :next_token, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |