Class: Aws::EC2::Types::DescribeClientVpnTargetNetworksRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#association_idsArray<String>

The IDs of the target network associations.

Returns:

  • (Array<String>)


22602
22603
22604
22605
22606
22607
22608
22609
22610
22611
# File 'lib/aws-sdk-ec2/types.rb', line 22602

class DescribeClientVpnTargetNetworksRequest < Struct.new(
  :client_vpn_endpoint_id,
  :association_ids,
  :max_results,
  :next_token,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#client_vpn_endpoint_idString

The ID of the Client VPN endpoint.

Returns:

  • (String)


22602
22603
22604
22605
22606
22607
22608
22609
22610
22611
# File 'lib/aws-sdk-ec2/types.rb', line 22602

class DescribeClientVpnTargetNetworksRequest < Struct.new(
  :client_vpn_endpoint_id,
  :association_ids,
  :max_results,
  :next_token,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


22602
22603
22604
22605
22606
22607
22608
22609
22610
22611
# File 'lib/aws-sdk-ec2/types.rb', line 22602

class DescribeClientVpnTargetNetworksRequest < Struct.new(
  :client_vpn_endpoint_id,
  :association_ids,
  :max_results,
  :next_token,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters. Filter names and values are case-sensitive.

  • ‘association-id` - The ID of the association.

  • ‘target-network-id` - The ID of the subnet specified as the target network.

  • ‘vpc-id` - The ID of the VPC in which the target network is located.

Returns:



22602
22603
22604
22605
22606
22607
22608
22609
22610
22611
# File 'lib/aws-sdk-ec2/types.rb', line 22602

class DescribeClientVpnTargetNetworksRequest < Struct.new(
  :client_vpn_endpoint_id,
  :association_ids,
  :max_results,
  :next_token,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the nextToken value.

Returns:

  • (Integer)


22602
22603
22604
22605
22606
22607
22608
22609
22610
22611
# File 'lib/aws-sdk-ec2/types.rb', line 22602

class DescribeClientVpnTargetNetworksRequest < Struct.new(
  :client_vpn_endpoint_id,
  :association_ids,
  :max_results,
  :next_token,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to retrieve the next page of results.

Returns:

  • (String)


22602
22603
22604
22605
22606
22607
22608
22609
22610
22611
# File 'lib/aws-sdk-ec2/types.rb', line 22602

class DescribeClientVpnTargetNetworksRequest < Struct.new(
  :client_vpn_endpoint_id,
  :association_ids,
  :max_results,
  :next_token,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end