Class: Aws::EC2::Types::DescribeCoipPoolsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


22663
22664
22665
22666
22667
22668
22669
22670
22671
# File 'lib/aws-sdk-ec2/types.rb', line 22663

class DescribeCoipPoolsRequest < Struct.new(
  :pool_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters.

  • ‘coip-pool.local-gateway-route-table-id` - The ID of the local gateway route table.

  • ‘coip-pool.pool-id` - The ID of the address pool.

Returns:



22663
22664
22665
22666
22667
22668
22669
22670
22671
# File 'lib/aws-sdk-ec2/types.rb', line 22663

class DescribeCoipPoolsRequest < Struct.new(
  :pool_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.

Returns:

  • (Integer)


22663
22664
22665
22666
22667
22668
22669
22670
22671
# File 'lib/aws-sdk-ec2/types.rb', line 22663

class DescribeCoipPoolsRequest < Struct.new(
  :pool_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


22663
22664
22665
22666
22667
22668
22669
22670
22671
# File 'lib/aws-sdk-ec2/types.rb', line 22663

class DescribeCoipPoolsRequest < Struct.new(
  :pool_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#pool_idsArray<String>

The IDs of the address pools.

Returns:

  • (Array<String>)


22663
22664
22665
22666
22667
22668
22669
22670
22671
# File 'lib/aws-sdk-ec2/types.rb', line 22663

class DescribeCoipPoolsRequest < Struct.new(
  :pool_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end