Class: Aws::EC2::Types::DescribeConversionTasksRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#conversion_task_idsArray<String>

The conversion task IDs.

Returns:

  • (Array<String>)


24767
24768
24769
24770
24771
24772
# File 'lib/aws-sdk-ec2/types.rb', line 24767

class DescribeConversionTasksRequest < Struct.new(
  :dry_run,
  :conversion_task_ids)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


24767
24768
24769
24770
24771
24772
# File 'lib/aws-sdk-ec2/types.rb', line 24767

class DescribeConversionTasksRequest < Struct.new(
  :dry_run,
  :conversion_task_ids)
  SENSITIVE = []
  include Aws::Structure
end