Class: Aws::EC2::Types::DescribeConversionTasksRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeConversionTasksRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#conversion_task_ids ⇒ Array<String>
The conversion task IDs.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#conversion_task_ids ⇒ Array<String>
The conversion task IDs.
23292 23293 23294 23295 23296 23297 |
# File 'lib/aws-sdk-ec2/types.rb', line 23292 class DescribeConversionTasksRequest < Struct.new( :dry_run, :conversion_task_ids) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
23292 23293 23294 23295 23296 23297 |
# File 'lib/aws-sdk-ec2/types.rb', line 23292 class DescribeConversionTasksRequest < Struct.new( :dry_run, :conversion_task_ids) SENSITIVE = [] include Aws::Structure end |