Class: Aws::EC2::Types::DescribeDeclarativePoliciesReportsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


23155
23156
23157
23158
23159
23160
23161
23162
# File 'lib/aws-sdk-ec2/types.rb', line 23155

class DescribeDeclarativePoliciesReportsRequest < Struct.new(
  :dry_run,
  :next_token,
  :max_results,
  :report_ids)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination

Returns:

  • (Integer)


23155
23156
23157
23158
23159
23160
23161
23162
# File 'lib/aws-sdk-ec2/types.rb', line 23155

class DescribeDeclarativePoliciesReportsRequest < Struct.new(
  :dry_run,
  :next_token,
  :max_results,
  :report_ids)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Returns:

  • (String)


23155
23156
23157
23158
23159
23160
23161
23162
# File 'lib/aws-sdk-ec2/types.rb', line 23155

class DescribeDeclarativePoliciesReportsRequest < Struct.new(
  :dry_run,
  :next_token,
  :max_results,
  :report_ids)
  SENSITIVE = []
  include Aws::Structure
end

#report_idsArray<String>

One or more report IDs.

Returns:

  • (Array<String>)


23155
23156
23157
23158
23159
23160
23161
23162
# File 'lib/aws-sdk-ec2/types.rb', line 23155

class DescribeDeclarativePoliciesReportsRequest < Struct.new(
  :dry_run,
  :next_token,
  :max_results,
  :report_ids)
  SENSITIVE = []
  include Aws::Structure
end