Class: Aws::EC2::Types::DescribeDeclarativePoliciesReportsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeDeclarativePoliciesReportsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token returned from a previous paginated request.
-
#report_ids ⇒ Array<String>
One or more report IDs.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
22813 22814 22815 22816 22817 22818 22819 22820 |
# File 'lib/aws-sdk-ec2/types.rb', line 22813 class DescribeDeclarativePoliciesReportsRequest < Struct.new( :dry_run, :next_token, :max_results, :report_ids) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination
22813 22814 22815 22816 22817 22818 22819 22820 |
# File 'lib/aws-sdk-ec2/types.rb', line 22813 class DescribeDeclarativePoliciesReportsRequest < Struct.new( :dry_run, :next_token, :max_results, :report_ids) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
22813 22814 22815 22816 22817 22818 22819 22820 |
# File 'lib/aws-sdk-ec2/types.rb', line 22813 class DescribeDeclarativePoliciesReportsRequest < Struct.new( :dry_run, :next_token, :max_results, :report_ids) SENSITIVE = [] include Aws::Structure end |
#report_ids ⇒ Array<String>
One or more report IDs.
22813 22814 22815 22816 22817 22818 22819 22820 |
# File 'lib/aws-sdk-ec2/types.rb', line 22813 class DescribeDeclarativePoliciesReportsRequest < Struct.new( :dry_run, :next_token, :max_results, :report_ids) SENSITIVE = [] include Aws::Structure end |