Class: Aws::EC2::Types::DescribeDeclarativePoliciesReportsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeDeclarativePoliciesReportsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#reports ⇒ Array<Types::DeclarativePoliciesReport>
The report metadata.
Instance Attribute Details
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
24902 24903 24904 24905 24906 24907 |
# File 'lib/aws-sdk-ec2/types.rb', line 24902 class DescribeDeclarativePoliciesReportsResult < Struct.new( :next_token, :reports) SENSITIVE = [] include Aws::Structure end |
#reports ⇒ Array<Types::DeclarativePoliciesReport>
The report metadata.
24902 24903 24904 24905 24906 24907 |
# File 'lib/aws-sdk-ec2/types.rb', line 24902 class DescribeDeclarativePoliciesReportsResult < Struct.new( :next_token, :reports) SENSITIVE = [] include Aws::Structure end |