Class: Aws::EC2::Types::DescribeDeclarativePoliciesReportsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeDeclarativePoliciesReportsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#reports ⇒ Array<Types::DeclarativePoliciesReport>
The report metadata.
Instance Attribute Details
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
23745 23746 23747 23748 23749 23750 |
# File 'lib/aws-sdk-ec2/types.rb', line 23745 class DescribeDeclarativePoliciesReportsResult < Struct.new( :next_token, :reports) SENSITIVE = [] include Aws::Structure end |
#reports ⇒ Array<Types::DeclarativePoliciesReport>
The report metadata.
23745 23746 23747 23748 23749 23750 |
# File 'lib/aws-sdk-ec2/types.rb', line 23745 class DescribeDeclarativePoliciesReportsResult < Struct.new( :next_token, :reports) SENSITIVE = [] include Aws::Structure end |