Class: Aws::EC2::Types::DescribeDhcpOptionsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeDhcpOptionsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dhcp_options ⇒ Array<Types::DhcpOptions>
Information about the DHCP options sets.
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
Instance Attribute Details
#dhcp_options ⇒ Array<Types::DhcpOptions>
Information about the DHCP options sets.
25299 25300 25301 25302 25303 25304 |
# File 'lib/aws-sdk-ec2/types.rb', line 25299 class DescribeDhcpOptionsResult < Struct.new( :next_token, :dhcp_options) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
25299 25300 25301 25302 25303 25304 |
# File 'lib/aws-sdk-ec2/types.rb', line 25299 class DescribeDhcpOptionsResult < Struct.new( :next_token, :dhcp_options) SENSITIVE = [] include Aws::Structure end |