Class: Aws::EC2::Types::DescribeEgressOnlyInternetGatewaysResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeEgressOnlyInternetGatewaysResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#egress_only_internet_gateways ⇒ Array<Types::EgressOnlyInternetGateway>
Information about the egress-only internet gateways.
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
Instance Attribute Details
#egress_only_internet_gateways ⇒ Array<Types::EgressOnlyInternetGateway>
Information about the egress-only internet gateways.
25361 25362 25363 25364 25365 25366 |
# File 'lib/aws-sdk-ec2/types.rb', line 25361 class DescribeEgressOnlyInternetGatewaysResult < Struct.new( :egress_only_internet_gateways, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
25361 25362 25363 25364 25365 25366 |
# File 'lib/aws-sdk-ec2/types.rb', line 25361 class DescribeEgressOnlyInternetGatewaysResult < Struct.new( :egress_only_internet_gateways, :next_token) SENSITIVE = [] include Aws::Structure end |