Class: Aws::EC2::Types::DescribeElasticGpusRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeElasticGpusRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#elastic_gpu_ids ⇒ Array<String>
The Elastic Graphics accelerator IDs.
-
#filters ⇒ Array<Types::Filter>
The filters.
-
#max_results ⇒ Integer
The maximum number of results to return in a single call.
-
#next_token ⇒ String
The token to request the next page of results.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
23897 23898 23899 23900 23901 23902 23903 23904 23905 |
# File 'lib/aws-sdk-ec2/types.rb', line 23897 class DescribeElasticGpusRequest < Struct.new( :elastic_gpu_ids, :dry_run, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#elastic_gpu_ids ⇒ Array<String>
The Elastic Graphics accelerator IDs.
23897 23898 23899 23900 23901 23902 23903 23904 23905 |
# File 'lib/aws-sdk-ec2/types.rb', line 23897 class DescribeElasticGpusRequest < Struct.new( :elastic_gpu_ids, :dry_run, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters.
-
‘availability-zone` - The Availability Zone in which the Elastic Graphics accelerator resides.
-
‘elastic-gpu-health` - The status of the Elastic Graphics accelerator (`OK` | `IMPAIRED`).
-
‘elastic-gpu-state` - The state of the Elastic Graphics accelerator (`ATTACHED`).
-
‘elastic-gpu-type` - The type of Elastic Graphics accelerator; for example, `eg1.medium`.
-
‘instance-id` - The ID of the instance to which the Elastic Graphics accelerator is associated.
23897 23898 23899 23900 23901 23902 23903 23904 23905 |
# File 'lib/aws-sdk-ec2/types.rb', line 23897 class DescribeElasticGpusRequest < Struct.new( :elastic_gpu_ids, :dry_run, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned ‘NextToken` value. This value can be between 5 and 1000.
23897 23898 23899 23900 23901 23902 23903 23904 23905 |
# File 'lib/aws-sdk-ec2/types.rb', line 23897 class DescribeElasticGpusRequest < Struct.new( :elastic_gpu_ids, :dry_run, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to request the next page of results.
23897 23898 23899 23900 23901 23902 23903 23904 23905 |
# File 'lib/aws-sdk-ec2/types.rb', line 23897 class DescribeElasticGpusRequest < Struct.new( :elastic_gpu_ids, :dry_run, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |