Class: Aws::EC2::Types::DescribeElasticGpusResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeElasticGpusResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#elastic_gpu_set ⇒ Array<Types::ElasticGpus>
Information about the Elastic Graphics accelerators.
-
#max_results ⇒ Integer
The total number of items to return.
-
#next_token ⇒ String
The token to use to retrieve the next page of results.
Instance Attribute Details
#elastic_gpu_set ⇒ Array<Types::ElasticGpus>
Information about the Elastic Graphics accelerators.
24151 24152 24153 24154 24155 24156 24157 |
# File 'lib/aws-sdk-ec2/types.rb', line 24151 class DescribeElasticGpusResult < Struct.new( :elastic_gpu_set, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The total number of items to return. If the total number of items available is more than the value specified in max-items then a Next-Token will be provided in the output that you can use to resume pagination.
24151 24152 24153 24154 24155 24156 24157 |
# File 'lib/aws-sdk-ec2/types.rb', line 24151 class DescribeElasticGpusResult < Struct.new( :elastic_gpu_set, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to retrieve the next page of results. This value is
null when there are no more results to return.
24151 24152 24153 24154 24155 24156 24157 |
# File 'lib/aws-sdk-ec2/types.rb', line 24151 class DescribeElasticGpusResult < Struct.new( :elastic_gpu_set, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |