Class: Aws::EC2::Types::DescribeExportImageTasksRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeExportImageTasksRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#export_image_task_ids ⇒ Array<String>
The IDs of the export image tasks.
-
#filters ⇒ Array<Types::Filter>
Filter tasks using the ‘task-state` filter and one of the following values: `active`, `completed`, `deleting`, or `deleted`.
-
#max_results ⇒ Integer
The maximum number of results to return in a single call.
-
#next_token ⇒ String
A token that indicates the next page of results.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
23690 23691 23692 23693 23694 23695 23696 23697 23698 |
# File 'lib/aws-sdk-ec2/types.rb', line 23690 class DescribeExportImageTasksRequest < Struct.new( :dry_run, :filters, :export_image_task_ids, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#export_image_task_ids ⇒ Array<String>
The IDs of the export image tasks.
23690 23691 23692 23693 23694 23695 23696 23697 23698 |
# File 'lib/aws-sdk-ec2/types.rb', line 23690 class DescribeExportImageTasksRequest < Struct.new( :dry_run, :filters, :export_image_task_ids, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
Filter tasks using the ‘task-state` filter and one of the following values: `active`, `completed`, `deleting`, or `deleted`.
23690 23691 23692 23693 23694 23695 23696 23697 23698 |
# File 'lib/aws-sdk-ec2/types.rb', line 23690 class DescribeExportImageTasksRequest < Struct.new( :dry_run, :filters, :export_image_task_ids, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in a single call.
23690 23691 23692 23693 23694 23695 23696 23697 23698 |
# File 'lib/aws-sdk-ec2/types.rb', line 23690 class DescribeExportImageTasksRequest < Struct.new( :dry_run, :filters, :export_image_task_ids, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates the next page of results.
23690 23691 23692 23693 23694 23695 23696 23697 23698 |
# File 'lib/aws-sdk-ec2/types.rb', line 23690 class DescribeExportImageTasksRequest < Struct.new( :dry_run, :filters, :export_image_task_ids, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |