Class: Aws::EC2::Types::DescribeFastLaunchImagesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


23198
23199
23200
23201
23202
23203
23204
23205
23206
# File 'lib/aws-sdk-ec2/types.rb', line 23198

class DescribeFastLaunchImagesRequest < Struct.new(
  :image_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

Use the following filters to streamline results.

  • ‘resource-type` - The resource type for pre-provisioning.

  • ‘owner-id` - The owner ID for the pre-provisioning resource.

  • ‘state` - The current state of fast launching for the Windows AMI.

Returns:



23198
23199
23200
23201
23202
23203
23204
23205
23206
# File 'lib/aws-sdk-ec2/types.rb', line 23198

class DescribeFastLaunchImagesRequest < Struct.new(
  :image_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#image_idsArray<String>

Specify one or more Windows AMI image IDs for the request.

Returns:

  • (Array<String>)


23198
23199
23200
23201
23202
23203
23204
23205
23206
# File 'lib/aws-sdk-ec2/types.rb', line 23198

class DescribeFastLaunchImagesRequest < Struct.new(
  :image_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination

Returns:

  • (Integer)


23198
23199
23200
23201
23202
23203
23204
23205
23206
# File 'lib/aws-sdk-ec2/types.rb', line 23198

class DescribeFastLaunchImagesRequest < Struct.new(
  :image_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Returns:

  • (String)


23198
23199
23200
23201
23202
23203
23204
23205
23206
# File 'lib/aws-sdk-ec2/types.rb', line 23198

class DescribeFastLaunchImagesRequest < Struct.new(
  :image_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end