Class: Aws::EC2::Types::DescribeFastSnapshotRestoreSuccessItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeFastSnapshotRestoreSuccessItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes fast snapshot restores for a snapshot.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone ⇒ String
The Availability Zone.
-
#availability_zone_id ⇒ String
The ID of the Availability Zone.
-
#disabled_time ⇒ Time
The time at which fast snapshot restores entered the ‘disabled` state.
-
#disabling_time ⇒ Time
The time at which fast snapshot restores entered the ‘disabling` state.
-
#enabled_time ⇒ Time
The time at which fast snapshot restores entered the ‘enabled` state.
-
#enabling_time ⇒ Time
The time at which fast snapshot restores entered the ‘enabling` state.
-
#optimizing_time ⇒ Time
The time at which fast snapshot restores entered the ‘optimizing` state.
-
#owner_alias ⇒ String
The Amazon Web Services owner alias that enabled fast snapshot restores on the snapshot.
-
#owner_id ⇒ String
The ID of the Amazon Web Services account that enabled fast snapshot restores on the snapshot.
-
#snapshot_id ⇒ String
The ID of the snapshot.
-
#state ⇒ String
The state of fast snapshot restores.
-
#state_transition_reason ⇒ String
The reason for the state transition.
Instance Attribute Details
#availability_zone ⇒ String
The Availability Zone.
23352 23353 23354 23355 23356 23357 23358 23359 23360 23361 23362 23363 23364 23365 23366 23367 |
# File 'lib/aws-sdk-ec2/types.rb', line 23352 class DescribeFastSnapshotRestoreSuccessItem < Struct.new( :snapshot_id, :availability_zone, :availability_zone_id, :state, :state_transition_reason, :owner_id, :owner_alias, :enabling_time, :optimizing_time, :enabled_time, :disabling_time, :disabled_time) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
The ID of the Availability Zone.
23352 23353 23354 23355 23356 23357 23358 23359 23360 23361 23362 23363 23364 23365 23366 23367 |
# File 'lib/aws-sdk-ec2/types.rb', line 23352 class DescribeFastSnapshotRestoreSuccessItem < Struct.new( :snapshot_id, :availability_zone, :availability_zone_id, :state, :state_transition_reason, :owner_id, :owner_alias, :enabling_time, :optimizing_time, :enabled_time, :disabling_time, :disabled_time) SENSITIVE = [] include Aws::Structure end |
#disabled_time ⇒ Time
The time at which fast snapshot restores entered the ‘disabled` state.
23352 23353 23354 23355 23356 23357 23358 23359 23360 23361 23362 23363 23364 23365 23366 23367 |
# File 'lib/aws-sdk-ec2/types.rb', line 23352 class DescribeFastSnapshotRestoreSuccessItem < Struct.new( :snapshot_id, :availability_zone, :availability_zone_id, :state, :state_transition_reason, :owner_id, :owner_alias, :enabling_time, :optimizing_time, :enabled_time, :disabling_time, :disabled_time) SENSITIVE = [] include Aws::Structure end |
#disabling_time ⇒ Time
The time at which fast snapshot restores entered the ‘disabling` state.
23352 23353 23354 23355 23356 23357 23358 23359 23360 23361 23362 23363 23364 23365 23366 23367 |
# File 'lib/aws-sdk-ec2/types.rb', line 23352 class DescribeFastSnapshotRestoreSuccessItem < Struct.new( :snapshot_id, :availability_zone, :availability_zone_id, :state, :state_transition_reason, :owner_id, :owner_alias, :enabling_time, :optimizing_time, :enabled_time, :disabling_time, :disabled_time) SENSITIVE = [] include Aws::Structure end |
#enabled_time ⇒ Time
The time at which fast snapshot restores entered the ‘enabled` state.
23352 23353 23354 23355 23356 23357 23358 23359 23360 23361 23362 23363 23364 23365 23366 23367 |
# File 'lib/aws-sdk-ec2/types.rb', line 23352 class DescribeFastSnapshotRestoreSuccessItem < Struct.new( :snapshot_id, :availability_zone, :availability_zone_id, :state, :state_transition_reason, :owner_id, :owner_alias, :enabling_time, :optimizing_time, :enabled_time, :disabling_time, :disabled_time) SENSITIVE = [] include Aws::Structure end |
#enabling_time ⇒ Time
The time at which fast snapshot restores entered the ‘enabling` state.
23352 23353 23354 23355 23356 23357 23358 23359 23360 23361 23362 23363 23364 23365 23366 23367 |
# File 'lib/aws-sdk-ec2/types.rb', line 23352 class DescribeFastSnapshotRestoreSuccessItem < Struct.new( :snapshot_id, :availability_zone, :availability_zone_id, :state, :state_transition_reason, :owner_id, :owner_alias, :enabling_time, :optimizing_time, :enabled_time, :disabling_time, :disabled_time) SENSITIVE = [] include Aws::Structure end |
#optimizing_time ⇒ Time
The time at which fast snapshot restores entered the ‘optimizing` state.
23352 23353 23354 23355 23356 23357 23358 23359 23360 23361 23362 23363 23364 23365 23366 23367 |
# File 'lib/aws-sdk-ec2/types.rb', line 23352 class DescribeFastSnapshotRestoreSuccessItem < Struct.new( :snapshot_id, :availability_zone, :availability_zone_id, :state, :state_transition_reason, :owner_id, :owner_alias, :enabling_time, :optimizing_time, :enabled_time, :disabling_time, :disabled_time) SENSITIVE = [] include Aws::Structure end |
#owner_alias ⇒ String
The Amazon Web Services owner alias that enabled fast snapshot restores on the snapshot. This is intended for future use.
23352 23353 23354 23355 23356 23357 23358 23359 23360 23361 23362 23363 23364 23365 23366 23367 |
# File 'lib/aws-sdk-ec2/types.rb', line 23352 class DescribeFastSnapshotRestoreSuccessItem < Struct.new( :snapshot_id, :availability_zone, :availability_zone_id, :state, :state_transition_reason, :owner_id, :owner_alias, :enabling_time, :optimizing_time, :enabled_time, :disabling_time, :disabled_time) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
The ID of the Amazon Web Services account that enabled fast snapshot restores on the snapshot.
23352 23353 23354 23355 23356 23357 23358 23359 23360 23361 23362 23363 23364 23365 23366 23367 |
# File 'lib/aws-sdk-ec2/types.rb', line 23352 class DescribeFastSnapshotRestoreSuccessItem < Struct.new( :snapshot_id, :availability_zone, :availability_zone_id, :state, :state_transition_reason, :owner_id, :owner_alias, :enabling_time, :optimizing_time, :enabled_time, :disabling_time, :disabled_time) SENSITIVE = [] include Aws::Structure end |
#snapshot_id ⇒ String
The ID of the snapshot.
23352 23353 23354 23355 23356 23357 23358 23359 23360 23361 23362 23363 23364 23365 23366 23367 |
# File 'lib/aws-sdk-ec2/types.rb', line 23352 class DescribeFastSnapshotRestoreSuccessItem < Struct.new( :snapshot_id, :availability_zone, :availability_zone_id, :state, :state_transition_reason, :owner_id, :owner_alias, :enabling_time, :optimizing_time, :enabled_time, :disabling_time, :disabled_time) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of fast snapshot restores.
23352 23353 23354 23355 23356 23357 23358 23359 23360 23361 23362 23363 23364 23365 23366 23367 |
# File 'lib/aws-sdk-ec2/types.rb', line 23352 class DescribeFastSnapshotRestoreSuccessItem < Struct.new( :snapshot_id, :availability_zone, :availability_zone_id, :state, :state_transition_reason, :owner_id, :owner_alias, :enabling_time, :optimizing_time, :enabled_time, :disabling_time, :disabled_time) SENSITIVE = [] include Aws::Structure end |
#state_transition_reason ⇒ String
The reason for the state transition. The possible values are as follows:
-
‘Client.UserInitiated` - The state successfully transitioned to `enabling` or `disabling`.
-
‘Client.UserInitiated - Lifecycle state transition` - The state successfully transitioned to `optimizing`, `enabled`, or `disabled`.
23352 23353 23354 23355 23356 23357 23358 23359 23360 23361 23362 23363 23364 23365 23366 23367 |
# File 'lib/aws-sdk-ec2/types.rb', line 23352 class DescribeFastSnapshotRestoreSuccessItem < Struct.new( :snapshot_id, :availability_zone, :availability_zone_id, :state, :state_transition_reason, :owner_id, :owner_alias, :enabling_time, :optimizing_time, :enabled_time, :disabling_time, :disabled_time) SENSITIVE = [] include Aws::Structure end |