Class: Aws::EC2::Types::DescribeFastSnapshotRestoresResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeFastSnapshotRestoresResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#fast_snapshot_restores ⇒ Array<Types::DescribeFastSnapshotRestoreSuccessItem>
Information about the state of fast snapshot restores.
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
Instance Attribute Details
#fast_snapshot_restores ⇒ Array<Types::DescribeFastSnapshotRestoreSuccessItem>
Information about the state of fast snapshot restores.
25818 25819 25820 25821 25822 25823 |
# File 'lib/aws-sdk-ec2/types.rb', line 25818 class DescribeFastSnapshotRestoresResult < Struct.new( :fast_snapshot_restores, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
25818 25819 25820 25821 25822 25823 |
# File 'lib/aws-sdk-ec2/types.rb', line 25818 class DescribeFastSnapshotRestoresResult < Struct.new( :fast_snapshot_restores, :next_token) SENSITIVE = [] include Aws::Structure end |