Class: Aws::EC2::Types::DescribeFleetError

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes the instances that could not be launched by the fleet.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#error_codeString

The error code that indicates why the instance could not be launched. For more information about error codes, see Error codes.

Returns:

  • (String)


24540
24541
24542
24543
24544
24545
24546
24547
# File 'lib/aws-sdk-ec2/types.rb', line 24540

class DescribeFleetError < Struct.new(
  :launch_template_and_overrides,
  :lifecycle,
  :error_code,
  :error_message)
  SENSITIVE = []
  include Aws::Structure
end

#error_messageString

The error message that describes why the instance could not be launched. For more information about error messages, see Error codes.

Returns:

  • (String)


24540
24541
24542
24543
24544
24545
24546
24547
# File 'lib/aws-sdk-ec2/types.rb', line 24540

class DescribeFleetError < Struct.new(
  :launch_template_and_overrides,
  :lifecycle,
  :error_code,
  :error_message)
  SENSITIVE = []
  include Aws::Structure
end

#launch_template_and_overridesTypes::LaunchTemplateAndOverridesResponse

The launch templates and overrides that were used for launching the instances. The values that you specify in the Overrides replace the values in the launch template.



24540
24541
24542
24543
24544
24545
24546
24547
# File 'lib/aws-sdk-ec2/types.rb', line 24540

class DescribeFleetError < Struct.new(
  :launch_template_and_overrides,
  :lifecycle,
  :error_code,
  :error_message)
  SENSITIVE = []
  include Aws::Structure
end

#lifecycleString

Indicates if the instance that could not be launched was a Spot, On-Demand, Capacity Block, or Interruptible Capacity Reservation instance.

Returns:

  • (String)


24540
24541
24542
24543
24544
24545
24546
24547
# File 'lib/aws-sdk-ec2/types.rb', line 24540

class DescribeFleetError < Struct.new(
  :launch_template_and_overrides,
  :lifecycle,
  :error_code,
  :error_message)
  SENSITIVE = []
  include Aws::Structure
end