Class: Aws::EC2::Types::DescribeFleetError
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeFleetError
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the instances that could not be launched by the fleet.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#error_code ⇒ String
The error code that indicates why the instance could not be launched.
-
#error_message ⇒ String
The error message that describes why the instance could not be launched.
-
#launch_template_and_overrides ⇒ Types::LaunchTemplateAndOverridesResponse
The launch templates and overrides that were used for launching the instances.
-
#lifecycle ⇒ String
Indicates if the instance that could not be launched was a Spot, On-Demand, Capacity Block, or Interruptible Capacity Reservation instance.
Instance Attribute Details
#error_code ⇒ String
The error code that indicates why the instance could not be launched. For more information about error codes, see [Error codes].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/errors-overview.html.html
24070 24071 24072 24073 24074 24075 24076 24077 |
# File 'lib/aws-sdk-ec2/types.rb', line 24070 class DescribeFleetError < Struct.new( :launch_template_and_overrides, :lifecycle, :error_code, :error_message) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
The error message that describes why the instance could not be launched. For more information about error messages, see [Error codes].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/errors-overview.html.html
24070 24071 24072 24073 24074 24075 24076 24077 |
# File 'lib/aws-sdk-ec2/types.rb', line 24070 class DescribeFleetError < Struct.new( :launch_template_and_overrides, :lifecycle, :error_code, :error_message) SENSITIVE = [] include Aws::Structure end |
#launch_template_and_overrides ⇒ Types::LaunchTemplateAndOverridesResponse
The launch templates and overrides that were used for launching the instances. The values that you specify in the Overrides replace the values in the launch template.
24070 24071 24072 24073 24074 24075 24076 24077 |
# File 'lib/aws-sdk-ec2/types.rb', line 24070 class DescribeFleetError < Struct.new( :launch_template_and_overrides, :lifecycle, :error_code, :error_message) SENSITIVE = [] include Aws::Structure end |
#lifecycle ⇒ String
Indicates if the instance that could not be launched was a Spot, On-Demand, Capacity Block, or Interruptible Capacity Reservation instance.
24070 24071 24072 24073 24074 24075 24076 24077 |
# File 'lib/aws-sdk-ec2/types.rb', line 24070 class DescribeFleetError < Struct.new( :launch_template_and_overrides, :lifecycle, :error_code, :error_message) SENSITIVE = [] include Aws::Structure end |