Class: Aws::EC2::Types::DescribeFleetError

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes the instances that could not be launched by the fleet.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#error_codeString

The error code that indicates why the instance could not be launched. For more information about error codes, see [Error codes].

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/errors-overview.html.html

Returns:

  • (String)


23817
23818
23819
23820
23821
23822
23823
23824
# File 'lib/aws-sdk-ec2/types.rb', line 23817

class DescribeFleetError < Struct.new(
  :launch_template_and_overrides,
  :lifecycle,
  :error_code,
  :error_message)
  SENSITIVE = []
  include Aws::Structure
end

#error_messageString

The error message that describes why the instance could not be launched. For more information about error messages, see [Error codes].

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/errors-overview.html.html

Returns:

  • (String)


23817
23818
23819
23820
23821
23822
23823
23824
# File 'lib/aws-sdk-ec2/types.rb', line 23817

class DescribeFleetError < Struct.new(
  :launch_template_and_overrides,
  :lifecycle,
  :error_code,
  :error_message)
  SENSITIVE = []
  include Aws::Structure
end

#launch_template_and_overridesTypes::LaunchTemplateAndOverridesResponse

The launch templates and overrides that were used for launching the instances. The values that you specify in the Overrides replace the values in the launch template.



23817
23818
23819
23820
23821
23822
23823
23824
# File 'lib/aws-sdk-ec2/types.rb', line 23817

class DescribeFleetError < Struct.new(
  :launch_template_and_overrides,
  :lifecycle,
  :error_code,
  :error_message)
  SENSITIVE = []
  include Aws::Structure
end

#lifecycleString

Indicates if the instance that could not be launched was a Spot Instance or On-Demand Instance.

Returns:

  • (String)


23817
23818
23819
23820
23821
23822
23823
23824
# File 'lib/aws-sdk-ec2/types.rb', line 23817

class DescribeFleetError < Struct.new(
  :launch_template_and_overrides,
  :lifecycle,
  :error_code,
  :error_message)
  SENSITIVE = []
  include Aws::Structure
end