Class: Aws::EC2::Types::DescribeFleetHistoryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


24430
24431
24432
24433
24434
24435
24436
24437
24438
24439
# File 'lib/aws-sdk-ec2/types.rb', line 24430

class DescribeFleetHistoryRequest < Struct.new(
  :dry_run,
  :event_type,
  :max_results,
  :next_token,
  :fleet_id,
  :start_time)
  SENSITIVE = []
  include Aws::Structure
end

#event_typeString

The type of events to describe. By default, all events are described.

Returns:

  • (String)


24430
24431
24432
24433
24434
24435
24436
24437
24438
24439
# File 'lib/aws-sdk-ec2/types.rb', line 24430

class DescribeFleetHistoryRequest < Struct.new(
  :dry_run,
  :event_type,
  :max_results,
  :next_token,
  :fleet_id,
  :start_time)
  SENSITIVE = []
  include Aws::Structure
end

#fleet_idString

The ID of the EC2 Fleet.

Returns:

  • (String)


24430
24431
24432
24433
24434
24435
24436
24437
24438
24439
# File 'lib/aws-sdk-ec2/types.rb', line 24430

class DescribeFleetHistoryRequest < Struct.new(
  :dry_run,
  :event_type,
  :max_results,
  :next_token,
  :fleet_id,
  :start_time)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination

Returns:

  • (Integer)


24430
24431
24432
24433
24434
24435
24436
24437
24438
24439
# File 'lib/aws-sdk-ec2/types.rb', line 24430

class DescribeFleetHistoryRequest < Struct.new(
  :dry_run,
  :event_type,
  :max_results,
  :next_token,
  :fleet_id,
  :start_time)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Returns:

  • (String)


24430
24431
24432
24433
24434
24435
24436
24437
24438
24439
# File 'lib/aws-sdk-ec2/types.rb', line 24430

class DescribeFleetHistoryRequest < Struct.new(
  :dry_run,
  :event_type,
  :max_results,
  :next_token,
  :fleet_id,
  :start_time)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The start date and time for the events, in UTC format (for example, YYYY-MM-*DD*T*HH*:MM:*SS*Z).

Returns:

  • (Time)


24430
24431
24432
24433
24434
24435
24436
24437
24438
24439
# File 'lib/aws-sdk-ec2/types.rb', line 24430

class DescribeFleetHistoryRequest < Struct.new(
  :dry_run,
  :event_type,
  :max_results,
  :next_token,
  :fleet_id,
  :start_time)
  SENSITIVE = []
  include Aws::Structure
end