Class: Aws::EC2::Types::DescribeFleetHistoryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeFleetHistoryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#event_type ⇒ String
The type of events to describe.
-
#fleet_id ⇒ String
The ID of the EC2 Fleet.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token returned from a previous paginated request.
-
#start_time ⇒ Time
The start date and time for the events, in UTC format (for example, YYYY-MM-*DD*T*HH*:MM:*SS*Z).
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
24387 24388 24389 24390 24391 24392 24393 24394 24395 24396 |
# File 'lib/aws-sdk-ec2/types.rb', line 24387 class DescribeFleetHistoryRequest < Struct.new( :dry_run, :event_type, :max_results, :next_token, :fleet_id, :start_time) SENSITIVE = [] include Aws::Structure end |
#event_type ⇒ String
The type of events to describe. By default, all events are described.
24387 24388 24389 24390 24391 24392 24393 24394 24395 24396 |
# File 'lib/aws-sdk-ec2/types.rb', line 24387 class DescribeFleetHistoryRequest < Struct.new( :dry_run, :event_type, :max_results, :next_token, :fleet_id, :start_time) SENSITIVE = [] include Aws::Structure end |
#fleet_id ⇒ String
The ID of the EC2 Fleet.
24387 24388 24389 24390 24391 24392 24393 24394 24395 24396 |
# File 'lib/aws-sdk-ec2/types.rb', line 24387 class DescribeFleetHistoryRequest < Struct.new( :dry_run, :event_type, :max_results, :next_token, :fleet_id, :start_time) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination
24387 24388 24389 24390 24391 24392 24393 24394 24395 24396 |
# File 'lib/aws-sdk-ec2/types.rb', line 24387 class DescribeFleetHistoryRequest < Struct.new( :dry_run, :event_type, :max_results, :next_token, :fleet_id, :start_time) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
24387 24388 24389 24390 24391 24392 24393 24394 24395 24396 |
# File 'lib/aws-sdk-ec2/types.rb', line 24387 class DescribeFleetHistoryRequest < Struct.new( :dry_run, :event_type, :max_results, :next_token, :fleet_id, :start_time) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The start date and time for the events, in UTC format (for example, YYYY-MM-*DD*T*HH*:MM:*SS*Z).
24387 24388 24389 24390 24391 24392 24393 24394 24395 24396 |
# File 'lib/aws-sdk-ec2/types.rb', line 24387 class DescribeFleetHistoryRequest < Struct.new( :dry_run, :event_type, :max_results, :next_token, :fleet_id, :start_time) SENSITIVE = [] include Aws::Structure end |