Class: Aws::EC2::Types::DescribeFleetHistoryResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeFleetHistoryResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#fleet_id ⇒ String
The ID of the EC Fleet.
-
#history_records ⇒ Array<Types::HistoryRecordEntry>
Information about the events in the history of the EC2 Fleet.
-
#last_evaluated_time ⇒ Time
The last date and time for the events, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ).
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#start_time ⇒ Time
The start date and time for the events, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ).
Instance Attribute Details
#fleet_id ⇒ String
The ID of the EC Fleet.
24628 24629 24630 24631 24632 24633 24634 24635 24636 |
# File 'lib/aws-sdk-ec2/types.rb', line 24628 class DescribeFleetHistoryResult < Struct.new( :history_records, :last_evaluated_time, :next_token, :fleet_id, :start_time) SENSITIVE = [] include Aws::Structure end |
#history_records ⇒ Array<Types::HistoryRecordEntry>
Information about the events in the history of the EC2 Fleet.
24628 24629 24630 24631 24632 24633 24634 24635 24636 |
# File 'lib/aws-sdk-ec2/types.rb', line 24628 class DescribeFleetHistoryResult < Struct.new( :history_records, :last_evaluated_time, :next_token, :fleet_id, :start_time) SENSITIVE = [] include Aws::Structure end |
#last_evaluated_time ⇒ Time
The last date and time for the events, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ). All records up to this time were retrieved.
If nextToken indicates that there are more items, this value is
not present.
24628 24629 24630 24631 24632 24633 24634 24635 24636 |
# File 'lib/aws-sdk-ec2/types.rb', line 24628 class DescribeFleetHistoryResult < Struct.new( :history_records, :last_evaluated_time, :next_token, :fleet_id, :start_time) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
24628 24629 24630 24631 24632 24633 24634 24635 24636 |
# File 'lib/aws-sdk-ec2/types.rb', line 24628 class DescribeFleetHistoryResult < Struct.new( :history_records, :last_evaluated_time, :next_token, :fleet_id, :start_time) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The start date and time for the events, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ).
24628 24629 24630 24631 24632 24633 24634 24635 24636 |
# File 'lib/aws-sdk-ec2/types.rb', line 24628 class DescribeFleetHistoryResult < Struct.new( :history_records, :last_evaluated_time, :next_token, :fleet_id, :start_time) SENSITIVE = [] include Aws::Structure end |