Class: Aws::EC2::Types::DescribeFleetInstancesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


23616
23617
23618
23619
23620
23621
23622
23623
23624
# File 'lib/aws-sdk-ec2/types.rb', line 23616

class DescribeFleetInstancesRequest < Struct.new(
  :dry_run,
  :max_results,
  :next_token,
  :fleet_id,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters.

  • ‘instance-type` - The instance type.

^

Returns:



23616
23617
23618
23619
23620
23621
23622
23623
23624
# File 'lib/aws-sdk-ec2/types.rb', line 23616

class DescribeFleetInstancesRequest < Struct.new(
  :dry_run,
  :max_results,
  :next_token,
  :fleet_id,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#fleet_idString

The ID of the EC2 Fleet.

Returns:

  • (String)


23616
23617
23618
23619
23620
23621
23622
23623
23624
# File 'lib/aws-sdk-ec2/types.rb', line 23616

class DescribeFleetInstancesRequest < Struct.new(
  :dry_run,
  :max_results,
  :next_token,
  :fleet_id,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination

Returns:

  • (Integer)


23616
23617
23618
23619
23620
23621
23622
23623
23624
# File 'lib/aws-sdk-ec2/types.rb', line 23616

class DescribeFleetInstancesRequest < Struct.new(
  :dry_run,
  :max_results,
  :next_token,
  :fleet_id,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Returns:

  • (String)


23616
23617
23618
23619
23620
23621
23622
23623
23624
# File 'lib/aws-sdk-ec2/types.rb', line 23616

class DescribeFleetInstancesRequest < Struct.new(
  :dry_run,
  :max_results,
  :next_token,
  :fleet_id,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end