Class: Aws::EC2::Types::DescribeFleetInstancesResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeFleetInstancesResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#active_instances ⇒ Array<Types::ActiveInstance>
The running instances.
-
#fleet_id ⇒ String
The ID of the EC2 Fleet.
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
Instance Attribute Details
#active_instances ⇒ Array<Types::ActiveInstance>
The running instances. This list is refreshed periodically and might be out of date.
24549 24550 24551 24552 24553 24554 24555 |
# File 'lib/aws-sdk-ec2/types.rb', line 24549 class DescribeFleetInstancesResult < Struct.new( :active_instances, :next_token, :fleet_id) SENSITIVE = [] include Aws::Structure end |
#fleet_id ⇒ String
The ID of the EC2 Fleet.
24549 24550 24551 24552 24553 24554 24555 |
# File 'lib/aws-sdk-ec2/types.rb', line 24549 class DescribeFleetInstancesResult < Struct.new( :active_instances, :next_token, :fleet_id) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
24549 24550 24551 24552 24553 24554 24555 |
# File 'lib/aws-sdk-ec2/types.rb', line 24549 class DescribeFleetInstancesResult < Struct.new( :active_instances, :next_token, :fleet_id) SENSITIVE = [] include Aws::Structure end |