Class: Aws::EC2::Types::DescribeFleetsInstances

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes the instances that were launched by the fleet.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_idsArray<String>

The IDs of the instances.

Returns:

  • (Array<String>)


24723
24724
24725
24726
24727
24728
24729
24730
24731
# File 'lib/aws-sdk-ec2/types.rb', line 24723

class DescribeFleetsInstances < Struct.new(
  :launch_template_and_overrides,
  :lifecycle,
  :instance_ids,
  :instance_type,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

The instance type.

Returns:

  • (String)


24723
24724
24725
24726
24727
24728
24729
24730
24731
# File 'lib/aws-sdk-ec2/types.rb', line 24723

class DescribeFleetsInstances < Struct.new(
  :launch_template_and_overrides,
  :lifecycle,
  :instance_ids,
  :instance_type,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#launch_template_and_overridesTypes::LaunchTemplateAndOverridesResponse

The launch templates and overrides that were used for launching the instances. The values that you specify in the Overrides replace the values in the launch template.



24723
24724
24725
24726
24727
24728
24729
24730
24731
# File 'lib/aws-sdk-ec2/types.rb', line 24723

class DescribeFleetsInstances < Struct.new(
  :launch_template_and_overrides,
  :lifecycle,
  :instance_ids,
  :instance_type,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#lifecycleString

Indicates if the instance that was launched is a Spot, On-Demand, Capacity Block, or Interruptible Capacity Reservation instance.

Returns:

  • (String)


24723
24724
24725
24726
24727
24728
24729
24730
24731
# File 'lib/aws-sdk-ec2/types.rb', line 24723

class DescribeFleetsInstances < Struct.new(
  :launch_template_and_overrides,
  :lifecycle,
  :instance_ids,
  :instance_type,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#platformString

The value is windows for Windows instances in an EC2 Fleet. Otherwise, the value is blank.

Returns:

  • (String)


24723
24724
24725
24726
24727
24728
24729
24730
24731
# File 'lib/aws-sdk-ec2/types.rb', line 24723

class DescribeFleetsInstances < Struct.new(
  :launch_template_and_overrides,
  :lifecycle,
  :instance_ids,
  :instance_type,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end