Class: Aws::EC2::Types::DescribeFpgaImageAttributeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeFpgaImageAttributeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute ⇒ String
The AFI attribute.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#fpga_image_id ⇒ String
The ID of the AFI.
Instance Attribute Details
#attribute ⇒ String
The AFI attribute.
26255 26256 26257 26258 26259 26260 26261 |
# File 'lib/aws-sdk-ec2/types.rb', line 26255 class DescribeFpgaImageAttributeRequest < Struct.new( :dry_run, :fpga_image_id, :attribute) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
26255 26256 26257 26258 26259 26260 26261 |
# File 'lib/aws-sdk-ec2/types.rb', line 26255 class DescribeFpgaImageAttributeRequest < Struct.new( :dry_run, :fpga_image_id, :attribute) SENSITIVE = [] include Aws::Structure end |
#fpga_image_id ⇒ String
The ID of the AFI.
26255 26256 26257 26258 26259 26260 26261 |
# File 'lib/aws-sdk-ec2/types.rb', line 26255 class DescribeFpgaImageAttributeRequest < Struct.new( :dry_run, :fpga_image_id, :attribute) SENSITIVE = [] include Aws::Structure end |