Class: Aws::EC2::Types::DescribeFpgaImageAttributeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributeString

The AFI attribute.

Returns:

  • (String)


25051
25052
25053
25054
25055
25056
25057
# File 'lib/aws-sdk-ec2/types.rb', line 25051

class DescribeFpgaImageAttributeRequest < Struct.new(
  :dry_run,
  :fpga_image_id,
  :attribute)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


25051
25052
25053
25054
25055
25056
25057
# File 'lib/aws-sdk-ec2/types.rb', line 25051

class DescribeFpgaImageAttributeRequest < Struct.new(
  :dry_run,
  :fpga_image_id,
  :attribute)
  SENSITIVE = []
  include Aws::Structure
end

#fpga_image_idString

The ID of the AFI.

Returns:

  • (String)


25051
25052
25053
25054
25055
25056
25057
# File 'lib/aws-sdk-ec2/types.rb', line 25051

class DescribeFpgaImageAttributeRequest < Struct.new(
  :dry_run,
  :fpga_image_id,
  :attribute)
  SENSITIVE = []
  include Aws::Structure
end