Class: Aws::EC2::Types::DescribeFpgaImageAttributeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeFpgaImageAttributeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute ⇒ String
The AFI attribute.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#fpga_image_id ⇒ String
The ID of the AFI.
Instance Attribute Details
#attribute ⇒ String
The AFI attribute.
24727 24728 24729 24730 24731 24732 24733 |
# File 'lib/aws-sdk-ec2/types.rb', line 24727 class DescribeFpgaImageAttributeRequest < Struct.new( :dry_run, :fpga_image_id, :attribute) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
24727 24728 24729 24730 24731 24732 24733 |
# File 'lib/aws-sdk-ec2/types.rb', line 24727 class DescribeFpgaImageAttributeRequest < Struct.new( :dry_run, :fpga_image_id, :attribute) SENSITIVE = [] include Aws::Structure end |
#fpga_image_id ⇒ String
The ID of the AFI.
24727 24728 24729 24730 24731 24732 24733 |
# File 'lib/aws-sdk-ec2/types.rb', line 24727 class DescribeFpgaImageAttributeRequest < Struct.new( :dry_run, :fpga_image_id, :attribute) SENSITIVE = [] include Aws::Structure end |