Class: Aws::EC2::Types::DescribeIamInstanceProfileAssociationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#association_idsArray<String>

The IAM instance profile associations.

Returns:

  • (Array<String>)


26605
26606
26607
26608
26609
26610
26611
26612
# File 'lib/aws-sdk-ec2/types.rb', line 26605

class DescribeIamInstanceProfileAssociationsRequest < Struct.new(
  :association_ids,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters.

  • instance-id - The ID of the instance.

  • state - The state of the association (associating | associated | disassociating).

Returns:



26605
26606
26607
26608
26609
26610
26611
26612
# File 'lib/aws-sdk-ec2/types.rb', line 26605

class DescribeIamInstanceProfileAssociationsRequest < Struct.new(
  :association_ids,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.

Returns:

  • (Integer)


26605
26606
26607
26608
26609
26610
26611
26612
# File 'lib/aws-sdk-ec2/types.rb', line 26605

class DescribeIamInstanceProfileAssociationsRequest < Struct.new(
  :association_ids,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Returns:

  • (String)


26605
26606
26607
26608
26609
26610
26611
26612
# File 'lib/aws-sdk-ec2/types.rb', line 26605

class DescribeIamInstanceProfileAssociationsRequest < Struct.new(
  :association_ids,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end