Class: Aws::EC2::Types::DescribeIamInstanceProfileAssociationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeIamInstanceProfileAssociationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#association_ids ⇒ Array<String>
The IAM instance profile associations.
-
#filters ⇒ Array<Types::Filter>
The filters.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token returned from a previous paginated request.
Instance Attribute Details
#association_ids ⇒ Array<String>
The IAM instance profile associations.
24234 24235 24236 24237 24238 24239 24240 24241 |
# File 'lib/aws-sdk-ec2/types.rb', line 24234 class DescribeIamInstanceProfileAssociationsRequest < Struct.new( :association_ids, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters.
-
‘instance-id` - The ID of the instance.
-
‘state` - The state of the association (`associating` | `associated` | `disassociating`).
24234 24235 24236 24237 24238 24239 24240 24241 |
# File 'lib/aws-sdk-ec2/types.rb', line 24234 class DescribeIamInstanceProfileAssociationsRequest < Struct.new( :association_ids, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination
24234 24235 24236 24237 24238 24239 24240 24241 |
# File 'lib/aws-sdk-ec2/types.rb', line 24234 class DescribeIamInstanceProfileAssociationsRequest < Struct.new( :association_ids, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
24234 24235 24236 24237 24238 24239 24240 24241 |
# File 'lib/aws-sdk-ec2/types.rb', line 24234 class DescribeIamInstanceProfileAssociationsRequest < Struct.new( :association_ids, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |