Class: Aws::EC2::Types::DescribeIamInstanceProfileAssociationsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeIamInstanceProfileAssociationsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#iam_instance_profile_associations ⇒ Array<Types::IamInstanceProfileAssociation>
Information about the IAM instance profile associations.
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
Instance Attribute Details
#iam_instance_profile_associations ⇒ Array<Types::IamInstanceProfileAssociation>
Information about the IAM instance profile associations.
25161 25162 25163 25164 25165 25166 |
# File 'lib/aws-sdk-ec2/types.rb', line 25161 class DescribeIamInstanceProfileAssociationsResult < Struct.new( :iam_instance_profile_associations, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
25161 25162 25163 25164 25165 25166 |
# File 'lib/aws-sdk-ec2/types.rb', line 25161 class DescribeIamInstanceProfileAssociationsResult < Struct.new( :iam_instance_profile_associations, :next_token) SENSITIVE = [] include Aws::Structure end |