Class: Aws::EC2::Types::DescribeImageAttributeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeImageAttributeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for DescribeImageAttribute.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute ⇒ String
The AMI attribute.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#image_id ⇒ String
The ID of the AMI.
Instance Attribute Details
#attribute ⇒ String
The AMI attribute.
Note: The blockDeviceMapping attribute is deprecated. Using
this attribute returns the Client.AuthFailure error. To get
information about the block device mappings for an AMI, describe the
image instead.
25416 25417 25418 25419 25420 25421 25422 |
# File 'lib/aws-sdk-ec2/types.rb', line 25416 class DescribeImageAttributeRequest < Struct.new( :attribute, :image_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
25416 25417 25418 25419 25420 25421 25422 |
# File 'lib/aws-sdk-ec2/types.rb', line 25416 class DescribeImageAttributeRequest < Struct.new( :attribute, :image_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#image_id ⇒ String
The ID of the AMI.
25416 25417 25418 25419 25420 25421 25422 |
# File 'lib/aws-sdk-ec2/types.rb', line 25416 class DescribeImageAttributeRequest < Struct.new( :attribute, :image_id, :dry_run) SENSITIVE = [] include Aws::Structure end |