Class: Aws::EC2::Types::DescribeImageAttributeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for DescribeImageAttribute.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributeString

The AMI attribute.

Note: The ‘blockDeviceMapping` attribute is deprecated. Using this attribute returns the `Client.AuthFailure` error. To get information about the block device mappings for an AMI, describe the image instead.

Returns:

  • (String)


25215
25216
25217
25218
25219
25220
25221
# File 'lib/aws-sdk-ec2/types.rb', line 25215

class DescribeImageAttributeRequest < Struct.new(
  :attribute,
  :image_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


25215
25216
25217
25218
25219
25220
25221
# File 'lib/aws-sdk-ec2/types.rb', line 25215

class DescribeImageAttributeRequest < Struct.new(
  :attribute,
  :image_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#image_idString

The ID of the AMI.

Returns:

  • (String)


25215
25216
25217
25218
25219
25220
25221
# File 'lib/aws-sdk-ec2/types.rb', line 25215

class DescribeImageAttributeRequest < Struct.new(
  :attribute,
  :image_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end