Class: Aws::EC2::Types::DescribeImageAttributeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for DescribeImageAttribute.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributeString

The AMI attribute.

Note: The ‘blockDeviceMapping` attribute is deprecated. Using this attribute returns the `Client.AuthFailure` error. To get information about the block device mappings for an AMI, describe the image instead.

Returns:

  • (String)


24693
24694
24695
24696
24697
24698
24699
# File 'lib/aws-sdk-ec2/types.rb', line 24693

class DescribeImageAttributeRequest < Struct.new(
  :attribute,
  :image_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


24693
24694
24695
24696
24697
24698
24699
# File 'lib/aws-sdk-ec2/types.rb', line 24693

class DescribeImageAttributeRequest < Struct.new(
  :attribute,
  :image_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#image_idString

The ID of the AMI.

Returns:

  • (String)


24693
24694
24695
24696
24697
24698
24699
# File 'lib/aws-sdk-ec2/types.rb', line 24693

class DescribeImageAttributeRequest < Struct.new(
  :attribute,
  :image_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end