Class: Aws::EC2::Types::DescribeImageReferencesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeImageReferencesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#image_ids ⇒ Array<String>
The IDs of the images to check for resource references.
-
#include_all_resource_types ⇒ Boolean
Specifies whether to check all supported Amazon Web Services resource types for image references.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token returned from a previous paginated request.
-
#resource_types ⇒ Array<Types::ResourceTypeRequest>
The Amazon Web Services resource types to check for image references.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
24416 24417 24418 24419 24420 24421 24422 24423 24424 24425 |
# File 'lib/aws-sdk-ec2/types.rb', line 24416 class DescribeImageReferencesRequest < Struct.new( :image_ids, :include_all_resource_types, :resource_types, :next_token, :dry_run, :max_results) SENSITIVE = [] include Aws::Structure end |
#image_ids ⇒ Array<String>
The IDs of the images to check for resource references.
24416 24417 24418 24419 24420 24421 24422 24423 24424 24425 |
# File 'lib/aws-sdk-ec2/types.rb', line 24416 class DescribeImageReferencesRequest < Struct.new( :image_ids, :include_all_resource_types, :resource_types, :next_token, :dry_run, :max_results) SENSITIVE = [] include Aws::Structure end |
#include_all_resource_types ⇒ Boolean
Specifies whether to check all supported Amazon Web Services resource types for image references. When specified, default values are applied for ‘ResourceTypeOptions`. For the default values, see
- How AMI reference checks work][1
-
in the *Amazon EC2 User Guide*.
If you also specify ‘ResourceTypes` with `ResourceTypeOptions`, your specified values override the default values.
Supported resource types: ‘ec2:Instance` | `ec2:LaunchTemplate` | `ssm:Parameter` | `imagebuilder:ImageRecipe` | `imagebuilder:ContainerRecipe`
Either ‘IncludeAllResourceTypes` or `ResourceTypes` must be specified.
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-ami-references.html#how-ami-references-works
24416 24417 24418 24419 24420 24421 24422 24423 24424 24425 |
# File 'lib/aws-sdk-ec2/types.rb', line 24416 class DescribeImageReferencesRequest < Struct.new( :image_ids, :include_all_resource_types, :resource_types, :next_token, :dry_run, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination
24416 24417 24418 24419 24420 24421 24422 24423 24424 24425 |
# File 'lib/aws-sdk-ec2/types.rb', line 24416 class DescribeImageReferencesRequest < Struct.new( :image_ids, :include_all_resource_types, :resource_types, :next_token, :dry_run, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
24416 24417 24418 24419 24420 24421 24422 24423 24424 24425 |
# File 'lib/aws-sdk-ec2/types.rb', line 24416 class DescribeImageReferencesRequest < Struct.new( :image_ids, :include_all_resource_types, :resource_types, :next_token, :dry_run, :max_results) SENSITIVE = [] include Aws::Structure end |
#resource_types ⇒ Array<Types::ResourceTypeRequest>
The Amazon Web Services resource types to check for image references.
Either ‘IncludeAllResourceTypes` or `ResourceTypes` must be specified.
24416 24417 24418 24419 24420 24421 24422 24423 24424 24425 |
# File 'lib/aws-sdk-ec2/types.rb', line 24416 class DescribeImageReferencesRequest < Struct.new( :image_ids, :include_all_resource_types, :resource_types, :next_token, :dry_run, :max_results) SENSITIVE = [] include Aws::Structure end |