Class: Aws::EC2::Types::DescribeImageReferencesResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#image_referencesArray<Types::ImageReference>

The resources that are referencing the specified images.

Returns:



26815
26816
26817
26818
26819
26820
# File 'lib/aws-sdk-ec2/types.rb', line 26815

class DescribeImageReferencesResult < Struct.new(
  :next_token,
  :image_references)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to include in another request to get the next page of items. This value is null when there are no more items to return.

Returns:

  • (String)


26815
26816
26817
26818
26819
26820
# File 'lib/aws-sdk-ec2/types.rb', line 26815

class DescribeImageReferencesResult < Struct.new(
  :next_token,
  :image_references)
  SENSITIVE = []
  include Aws::Structure
end