Class: Aws::EC2::Types::DescribeImageReferencesResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeImageReferencesResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#image_references ⇒ Array<Types::ImageReference>
The resources that are referencing the specified images.
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
Instance Attribute Details
#image_references ⇒ Array<Types::ImageReference>
The resources that are referencing the specified images.
26815 26816 26817 26818 26819 26820 |
# File 'lib/aws-sdk-ec2/types.rb', line 26815 class DescribeImageReferencesResult < Struct.new( :next_token, :image_references) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
26815 26816 26817 26818 26819 26820 |
# File 'lib/aws-sdk-ec2/types.rb', line 26815 class DescribeImageReferencesResult < Struct.new( :next_token, :image_references) SENSITIVE = [] include Aws::Structure end |