Class: Aws::EC2::Types::DescribeImageUsageReportEntriesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeImageUsageReportEntriesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The filters.
-
#image_ids ⇒ Array<String>
The IDs of the images for filtering the report entries.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token returned from a previous paginated request.
-
#report_ids ⇒ Array<String>
The IDs of the usage reports.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
25088 25089 25090 25091 25092 25093 25094 25095 25096 25097 |
# File 'lib/aws-sdk-ec2/types.rb', line 25088 class DescribeImageUsageReportEntriesRequest < Struct.new( :image_ids, :report_ids, :next_token, :filters, :dry_run, :max_results) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters.
-
‘account-id` - A 12-digit Amazon Web Services account ID.
-
‘creation-time` - The time when the report was created, in the ISO 8601 format in the UTC time zone (YYYY-MM-DDThh:mm:ss.sssZ), for example, `2025-11-29T11:04:43.305Z`. You can use a wildcard (`*`), for example, `2025-11-29T*`, which matches an entire day.
-
‘resource-type` - The resource type (`ec2:Instance` | `ec2:LaunchTemplate`).
25088 25089 25090 25091 25092 25093 25094 25095 25096 25097 |
# File 'lib/aws-sdk-ec2/types.rb', line 25088 class DescribeImageUsageReportEntriesRequest < Struct.new( :image_ids, :report_ids, :next_token, :filters, :dry_run, :max_results) SENSITIVE = [] include Aws::Structure end |
#image_ids ⇒ Array<String>
The IDs of the images for filtering the report entries. If specified, only report entries containing these images are returned.
25088 25089 25090 25091 25092 25093 25094 25095 25096 25097 |
# File 'lib/aws-sdk-ec2/types.rb', line 25088 class DescribeImageUsageReportEntriesRequest < Struct.new( :image_ids, :report_ids, :next_token, :filters, :dry_run, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination
25088 25089 25090 25091 25092 25093 25094 25095 25096 25097 |
# File 'lib/aws-sdk-ec2/types.rb', line 25088 class DescribeImageUsageReportEntriesRequest < Struct.new( :image_ids, :report_ids, :next_token, :filters, :dry_run, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
25088 25089 25090 25091 25092 25093 25094 25095 25096 25097 |
# File 'lib/aws-sdk-ec2/types.rb', line 25088 class DescribeImageUsageReportEntriesRequest < Struct.new( :image_ids, :report_ids, :next_token, :filters, :dry_run, :max_results) SENSITIVE = [] include Aws::Structure end |
#report_ids ⇒ Array<String>
The IDs of the usage reports.
25088 25089 25090 25091 25092 25093 25094 25095 25096 25097 |
# File 'lib/aws-sdk-ec2/types.rb', line 25088 class DescribeImageUsageReportEntriesRequest < Struct.new( :image_ids, :report_ids, :next_token, :filters, :dry_run, :max_results) SENSITIVE = [] include Aws::Structure end |