Class: Aws::EC2::Types::DescribeImageUsageReportEntriesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


24493
24494
24495
24496
24497
24498
24499
24500
24501
24502
# File 'lib/aws-sdk-ec2/types.rb', line 24493

class DescribeImageUsageReportEntriesRequest < Struct.new(
  :image_ids,
  :report_ids,
  :next_token,
  :filters,
  :dry_run,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters.

  • ‘account-id` - A 12-digit Amazon Web Services account ID.

  • ‘creation-time` - The time when the report was created, in the ISO 8601 format in the UTC time zone (YYYY-MM-DDThh:mm:ss.sssZ), for example, `2025-11-29T11:04:43.305Z`. You can use a wildcard (`*`), for example, `2025-11-29T*`, which matches an entire day.

  • ‘resource-type` - The resource type (`ec2:Instance` | `ec2:LaunchTemplate`).

Returns:



24493
24494
24495
24496
24497
24498
24499
24500
24501
24502
# File 'lib/aws-sdk-ec2/types.rb', line 24493

class DescribeImageUsageReportEntriesRequest < Struct.new(
  :image_ids,
  :report_ids,
  :next_token,
  :filters,
  :dry_run,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#image_idsArray<String>

The IDs of the images for filtering the report entries. If specified, only report entries containing these images are returned.

Returns:

  • (Array<String>)


24493
24494
24495
24496
24497
24498
24499
24500
24501
24502
# File 'lib/aws-sdk-ec2/types.rb', line 24493

class DescribeImageUsageReportEntriesRequest < Struct.new(
  :image_ids,
  :report_ids,
  :next_token,
  :filters,
  :dry_run,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination

Returns:

  • (Integer)


24493
24494
24495
24496
24497
24498
24499
24500
24501
24502
# File 'lib/aws-sdk-ec2/types.rb', line 24493

class DescribeImageUsageReportEntriesRequest < Struct.new(
  :image_ids,
  :report_ids,
  :next_token,
  :filters,
  :dry_run,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Returns:

  • (String)


24493
24494
24495
24496
24497
24498
24499
24500
24501
24502
# File 'lib/aws-sdk-ec2/types.rb', line 24493

class DescribeImageUsageReportEntriesRequest < Struct.new(
  :image_ids,
  :report_ids,
  :next_token,
  :filters,
  :dry_run,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#report_idsArray<String>

The IDs of the usage reports.

Returns:

  • (Array<String>)


24493
24494
24495
24496
24497
24498
24499
24500
24501
24502
# File 'lib/aws-sdk-ec2/types.rb', line 24493

class DescribeImageUsageReportEntriesRequest < Struct.new(
  :image_ids,
  :report_ids,
  :next_token,
  :filters,
  :dry_run,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end