Class: Aws::EC2::Types::DescribeImageUsageReportEntriesResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeImageUsageReportEntriesResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#image_usage_report_entries ⇒ Array<Types::ImageUsageReportEntry>
The content of the usage reports.
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
Instance Attribute Details
#image_usage_report_entries ⇒ Array<Types::ImageUsageReportEntry>
The content of the usage reports.
26892 26893 26894 26895 26896 26897 |
# File 'lib/aws-sdk-ec2/types.rb', line 26892 class DescribeImageUsageReportEntriesResult < Struct.new( :next_token, :image_usage_report_entries) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
26892 26893 26894 26895 26896 26897 |
# File 'lib/aws-sdk-ec2/types.rb', line 26892 class DescribeImageUsageReportEntriesResult < Struct.new( :next_token, :image_usage_report_entries) SENSITIVE = [] include Aws::Structure end |