Class: Aws::EC2::Types::DescribeImageUsageReportsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeImageUsageReportsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The filters.
-
#image_ids ⇒ Array<String>
The IDs of the images for filtering the reports.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token returned from a previous paginated request.
-
#report_ids ⇒ Array<String>
The IDs of the image usage reports.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
25173 25174 25175 25176 25177 25178 25179 25180 25181 25182 |
# File 'lib/aws-sdk-ec2/types.rb', line 25173 class DescribeImageUsageReportsRequest < Struct.new( :image_ids, :report_ids, :next_token, :filters, :dry_run, :max_results) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters.
-
‘creation-time` - The time when the report was created, in the ISO 8601 format in the UTC time zone (YYYY-MM-DDThh:mm:ss.sssZ), for example, `2025-11-29T11:04:43.305Z`. You can use a wildcard (`*`), for example, `2025-11-29T*`, which matches an entire day.
-
‘state` - The state of the report (`available` | `pending` | `error`).
-
‘tag:<key>` - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key `Owner` and the value `TeamA`, specify `tag:Owner` for the filter name and `TeamA` for the filter value.
-
‘tag-key` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.
25173 25174 25175 25176 25177 25178 25179 25180 25181 25182 |
# File 'lib/aws-sdk-ec2/types.rb', line 25173 class DescribeImageUsageReportsRequest < Struct.new( :image_ids, :report_ids, :next_token, :filters, :dry_run, :max_results) SENSITIVE = [] include Aws::Structure end |
#image_ids ⇒ Array<String>
The IDs of the images for filtering the reports. If specified, only reports containing these images are returned.
25173 25174 25175 25176 25177 25178 25179 25180 25181 25182 |
# File 'lib/aws-sdk-ec2/types.rb', line 25173 class DescribeImageUsageReportsRequest < Struct.new( :image_ids, :report_ids, :next_token, :filters, :dry_run, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination
25173 25174 25175 25176 25177 25178 25179 25180 25181 25182 |
# File 'lib/aws-sdk-ec2/types.rb', line 25173 class DescribeImageUsageReportsRequest < Struct.new( :image_ids, :report_ids, :next_token, :filters, :dry_run, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
25173 25174 25175 25176 25177 25178 25179 25180 25181 25182 |
# File 'lib/aws-sdk-ec2/types.rb', line 25173 class DescribeImageUsageReportsRequest < Struct.new( :image_ids, :report_ids, :next_token, :filters, :dry_run, :max_results) SENSITIVE = [] include Aws::Structure end |
#report_ids ⇒ Array<String>
The IDs of the image usage reports.
25173 25174 25175 25176 25177 25178 25179 25180 25181 25182 |
# File 'lib/aws-sdk-ec2/types.rb', line 25173 class DescribeImageUsageReportsRequest < Struct.new( :image_ids, :report_ids, :next_token, :filters, :dry_run, :max_results) SENSITIVE = [] include Aws::Structure end |