Class: Aws::EC2::Types::DescribeImageUsageReportsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


24578
24579
24580
24581
24582
24583
24584
24585
24586
24587
# File 'lib/aws-sdk-ec2/types.rb', line 24578

class DescribeImageUsageReportsRequest < Struct.new(
  :image_ids,
  :report_ids,
  :next_token,
  :filters,
  :dry_run,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters.

  • ‘creation-time` - The time when the report was created, in the ISO 8601 format in the UTC time zone (YYYY-MM-DDThh:mm:ss.sssZ), for example, `2025-11-29T11:04:43.305Z`. You can use a wildcard (`*`), for example, `2025-11-29T*`, which matches an entire day.

  • ‘state` - The state of the report (`available` | `pending` | `error`).

  • ‘tag:<key>` - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key `Owner` and the value `TeamA`, specify `tag:Owner` for the filter name and `TeamA` for the filter value.

  • ‘tag-key` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.

Returns:



24578
24579
24580
24581
24582
24583
24584
24585
24586
24587
# File 'lib/aws-sdk-ec2/types.rb', line 24578

class DescribeImageUsageReportsRequest < Struct.new(
  :image_ids,
  :report_ids,
  :next_token,
  :filters,
  :dry_run,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#image_idsArray<String>

The IDs of the images for filtering the reports. If specified, only reports containing these images are returned.

Returns:

  • (Array<String>)


24578
24579
24580
24581
24582
24583
24584
24585
24586
24587
# File 'lib/aws-sdk-ec2/types.rb', line 24578

class DescribeImageUsageReportsRequest < Struct.new(
  :image_ids,
  :report_ids,
  :next_token,
  :filters,
  :dry_run,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination

Returns:

  • (Integer)


24578
24579
24580
24581
24582
24583
24584
24585
24586
24587
# File 'lib/aws-sdk-ec2/types.rb', line 24578

class DescribeImageUsageReportsRequest < Struct.new(
  :image_ids,
  :report_ids,
  :next_token,
  :filters,
  :dry_run,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Returns:

  • (String)


24578
24579
24580
24581
24582
24583
24584
24585
24586
24587
# File 'lib/aws-sdk-ec2/types.rb', line 24578

class DescribeImageUsageReportsRequest < Struct.new(
  :image_ids,
  :report_ids,
  :next_token,
  :filters,
  :dry_run,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#report_idsArray<String>

The IDs of the image usage reports.

Returns:

  • (Array<String>)


24578
24579
24580
24581
24582
24583
24584
24585
24586
24587
# File 'lib/aws-sdk-ec2/types.rb', line 24578

class DescribeImageUsageReportsRequest < Struct.new(
  :image_ids,
  :report_ids,
  :next_token,
  :filters,
  :dry_run,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end