Class: Aws::EC2::Types::DescribeImagesResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeImagesResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#images ⇒ Array<Types::Image>
Information about the images.
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
Instance Attribute Details
#images ⇒ Array<Types::Image>
Information about the images.
26927 26928 26929 26930 26931 26932 |
# File 'lib/aws-sdk-ec2/types.rb', line 26927 class DescribeImagesResult < Struct.new( :next_token, :images) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
26927 26928 26929 26930 26931 26932 |
# File 'lib/aws-sdk-ec2/types.rb', line 26927 class DescribeImagesResult < Struct.new( :next_token, :images) SENSITIVE = [] include Aws::Structure end |