Class: Aws::EC2::Types::DescribeImportImageTasksRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeImportImageTasksRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
Filter tasks using the
task-statefilter and one of the following values:active,completed,deleting, ordeleted. -
#import_task_ids ⇒ Array<String>
The IDs of the import image tasks.
-
#max_results ⇒ Integer
The maximum number of results to return in a single call.
-
#next_token ⇒ String
A token that indicates the next page of results.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
26072 26073 26074 26075 26076 26077 26078 26079 26080 |
# File 'lib/aws-sdk-ec2/types.rb', line 26072 class DescribeImportImageTasksRequest < Struct.new( :dry_run, :filters, :import_task_ids, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
Filter tasks using the task-state filter and one of the following
values: active, completed, deleting, or deleted.
26072 26073 26074 26075 26076 26077 26078 26079 26080 |
# File 'lib/aws-sdk-ec2/types.rb', line 26072 class DescribeImportImageTasksRequest < Struct.new( :dry_run, :filters, :import_task_ids, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#import_task_ids ⇒ Array<String>
The IDs of the import image tasks.
26072 26073 26074 26075 26076 26077 26078 26079 26080 |
# File 'lib/aws-sdk-ec2/types.rb', line 26072 class DescribeImportImageTasksRequest < Struct.new( :dry_run, :filters, :import_task_ids, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in a single call.
26072 26073 26074 26075 26076 26077 26078 26079 26080 |
# File 'lib/aws-sdk-ec2/types.rb', line 26072 class DescribeImportImageTasksRequest < Struct.new( :dry_run, :filters, :import_task_ids, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates the next page of results.
26072 26073 26074 26075 26076 26077 26078 26079 26080 |
# File 'lib/aws-sdk-ec2/types.rb', line 26072 class DescribeImportImageTasksRequest < Struct.new( :dry_run, :filters, :import_task_ids, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |