Class: Aws::EC2::Types::DescribeImportImageTasksRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


25914
25915
25916
25917
25918
25919
25920
25921
25922
# File 'lib/aws-sdk-ec2/types.rb', line 25914

class DescribeImportImageTasksRequest < Struct.new(
  :dry_run,
  :filters,
  :import_task_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

Filter tasks using the task-state filter and one of the following values: active, completed, deleting, or deleted.

Returns:



25914
25915
25916
25917
25918
25919
25920
25921
25922
# File 'lib/aws-sdk-ec2/types.rb', line 25914

class DescribeImportImageTasksRequest < Struct.new(
  :dry_run,
  :filters,
  :import_task_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#import_task_idsArray<String>

The IDs of the import image tasks.

Returns:

  • (Array<String>)


25914
25915
25916
25917
25918
25919
25920
25921
25922
# File 'lib/aws-sdk-ec2/types.rb', line 25914

class DescribeImportImageTasksRequest < Struct.new(
  :dry_run,
  :filters,
  :import_task_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in a single call.

Returns:

  • (Integer)


25914
25915
25916
25917
25918
25919
25920
25921
25922
# File 'lib/aws-sdk-ec2/types.rb', line 25914

class DescribeImportImageTasksRequest < Struct.new(
  :dry_run,
  :filters,
  :import_task_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token that indicates the next page of results.

Returns:

  • (String)


25914
25915
25916
25917
25918
25919
25920
25921
25922
# File 'lib/aws-sdk-ec2/types.rb', line 25914

class DescribeImportImageTasksRequest < Struct.new(
  :dry_run,
  :filters,
  :import_task_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end