Class: Aws::EC2::Types::DescribeImportSnapshotTasksRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


25970
25971
25972
25973
25974
25975
25976
25977
25978
# File 'lib/aws-sdk-ec2/types.rb', line 25970

class DescribeImportSnapshotTasksRequest < Struct.new(
  :dry_run,
  :filters,
  :import_task_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters.

Returns:



25970
25971
25972
25973
25974
25975
25976
25977
25978
# File 'lib/aws-sdk-ec2/types.rb', line 25970

class DescribeImportSnapshotTasksRequest < Struct.new(
  :dry_run,
  :filters,
  :import_task_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#import_task_idsArray<String>

A list of import snapshot task IDs.

Returns:

  • (Array<String>)


25970
25971
25972
25973
25974
25975
25976
25977
25978
# File 'lib/aws-sdk-ec2/types.rb', line 25970

class DescribeImportSnapshotTasksRequest < Struct.new(
  :dry_run,
  :filters,
  :import_task_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned NextToken value.

Returns:

  • (Integer)


25970
25971
25972
25973
25974
25975
25976
25977
25978
# File 'lib/aws-sdk-ec2/types.rb', line 25970

class DescribeImportSnapshotTasksRequest < Struct.new(
  :dry_run,
  :filters,
  :import_task_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token that indicates the next page of results.

Returns:

  • (String)


25970
25971
25972
25973
25974
25975
25976
25977
25978
# File 'lib/aws-sdk-ec2/types.rb', line 25970

class DescribeImportSnapshotTasksRequest < Struct.new(
  :dry_run,
  :filters,
  :import_task_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end