Class: Aws::EC2::Types::DescribeImportSnapshotTasksRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeImportSnapshotTasksRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The filters.
-
#import_task_ids ⇒ Array<String>
A list of import snapshot task IDs.
-
#max_results ⇒ Integer
The maximum number of results to return in a single call.
-
#next_token ⇒ String
A token that indicates the next page of results.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
25970 25971 25972 25973 25974 25975 25976 25977 25978 |
# File 'lib/aws-sdk-ec2/types.rb', line 25970 class DescribeImportSnapshotTasksRequest < Struct.new( :dry_run, :filters, :import_task_ids, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters.
25970 25971 25972 25973 25974 25975 25976 25977 25978 |
# File 'lib/aws-sdk-ec2/types.rb', line 25970 class DescribeImportSnapshotTasksRequest < Struct.new( :dry_run, :filters, :import_task_ids, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#import_task_ids ⇒ Array<String>
A list of import snapshot task IDs.
25970 25971 25972 25973 25974 25975 25976 25977 25978 |
# File 'lib/aws-sdk-ec2/types.rb', line 25970 class DescribeImportSnapshotTasksRequest < Struct.new( :dry_run, :filters, :import_task_ids, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in a single call. To
retrieve the remaining results, make another call with the returned
NextToken value.
25970 25971 25972 25973 25974 25975 25976 25977 25978 |
# File 'lib/aws-sdk-ec2/types.rb', line 25970 class DescribeImportSnapshotTasksRequest < Struct.new( :dry_run, :filters, :import_task_ids, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates the next page of results.
25970 25971 25972 25973 25974 25975 25976 25977 25978 |
# File 'lib/aws-sdk-ec2/types.rb', line 25970 class DescribeImportSnapshotTasksRequest < Struct.new( :dry_run, :filters, :import_task_ids, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |