Class: Aws::EC2::Types::DescribeImportSnapshotTasksRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


25826
25827
25828
25829
25830
25831
25832
25833
25834
# File 'lib/aws-sdk-ec2/types.rb', line 25826

class DescribeImportSnapshotTasksRequest < Struct.new(
  :dry_run,
  :filters,
  :import_task_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters.

Returns:



25826
25827
25828
25829
25830
25831
25832
25833
25834
# File 'lib/aws-sdk-ec2/types.rb', line 25826

class DescribeImportSnapshotTasksRequest < Struct.new(
  :dry_run,
  :filters,
  :import_task_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#import_task_idsArray<String>

A list of import snapshot task IDs.

Returns:

  • (Array<String>)


25826
25827
25828
25829
25830
25831
25832
25833
25834
# File 'lib/aws-sdk-ec2/types.rb', line 25826

class DescribeImportSnapshotTasksRequest < Struct.new(
  :dry_run,
  :filters,
  :import_task_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned ‘NextToken` value.

Returns:

  • (Integer)


25826
25827
25828
25829
25830
25831
25832
25833
25834
# File 'lib/aws-sdk-ec2/types.rb', line 25826

class DescribeImportSnapshotTasksRequest < Struct.new(
  :dry_run,
  :filters,
  :import_task_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token that indicates the next page of results.

Returns:

  • (String)


25826
25827
25828
25829
25830
25831
25832
25833
25834
# File 'lib/aws-sdk-ec2/types.rb', line 25826

class DescribeImportSnapshotTasksRequest < Struct.new(
  :dry_run,
  :filters,
  :import_task_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end