Class: Aws::EC2::Types::DescribeImportSnapshotTasksRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


24925
24926
24927
24928
24929
24930
24931
24932
24933
# File 'lib/aws-sdk-ec2/types.rb', line 24925

class DescribeImportSnapshotTasksRequest < Struct.new(
  :dry_run,
  :filters,
  :import_task_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters.

Returns:



24925
24926
24927
24928
24929
24930
24931
24932
24933
# File 'lib/aws-sdk-ec2/types.rb', line 24925

class DescribeImportSnapshotTasksRequest < Struct.new(
  :dry_run,
  :filters,
  :import_task_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#import_task_idsArray<String>

A list of import snapshot task IDs.

Returns:

  • (Array<String>)


24925
24926
24927
24928
24929
24930
24931
24932
24933
# File 'lib/aws-sdk-ec2/types.rb', line 24925

class DescribeImportSnapshotTasksRequest < Struct.new(
  :dry_run,
  :filters,
  :import_task_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned ‘NextToken` value.

Returns:

  • (Integer)


24925
24926
24927
24928
24929
24930
24931
24932
24933
# File 'lib/aws-sdk-ec2/types.rb', line 24925

class DescribeImportSnapshotTasksRequest < Struct.new(
  :dry_run,
  :filters,
  :import_task_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token that indicates the next page of results.

Returns:

  • (String)


24925
24926
24927
24928
24929
24930
24931
24932
24933
# File 'lib/aws-sdk-ec2/types.rb', line 24925

class DescribeImportSnapshotTasksRequest < Struct.new(
  :dry_run,
  :filters,
  :import_task_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end