Class: Aws::EC2::Types::DescribeInstanceAttributeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributeString

The instance attribute.

Note that the enaSupport attribute is not supported.

Returns:

  • (String)


26045
26046
26047
26048
26049
26050
26051
# File 'lib/aws-sdk-ec2/types.rb', line 26045

class DescribeInstanceAttributeRequest < Struct.new(
  :dry_run,
  :instance_id,
  :attribute)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


26045
26046
26047
26048
26049
26050
26051
# File 'lib/aws-sdk-ec2/types.rb', line 26045

class DescribeInstanceAttributeRequest < Struct.new(
  :dry_run,
  :instance_id,
  :attribute)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The ID of the instance.

Returns:

  • (String)


26045
26046
26047
26048
26049
26050
26051
# File 'lib/aws-sdk-ec2/types.rb', line 26045

class DescribeInstanceAttributeRequest < Struct.new(
  :dry_run,
  :instance_id,
  :attribute)
  SENSITIVE = []
  include Aws::Structure
end