Class: Aws::EC2::Types::DescribeInstanceAttributeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeInstanceAttributeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute ⇒ String
The instance attribute.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#instance_id ⇒ String
The ID of the instance.
Instance Attribute Details
#attribute ⇒ String
The instance attribute.
Note that the ‘enaSupport` attribute is not supported.
25825 25826 25827 25828 25829 25830 25831 |
# File 'lib/aws-sdk-ec2/types.rb', line 25825 class DescribeInstanceAttributeRequest < Struct.new( :dry_run, :instance_id, :attribute) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
25825 25826 25827 25828 25829 25830 25831 |
# File 'lib/aws-sdk-ec2/types.rb', line 25825 class DescribeInstanceAttributeRequest < Struct.new( :dry_run, :instance_id, :attribute) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the instance.
25825 25826 25827 25828 25829 25830 25831 |
# File 'lib/aws-sdk-ec2/types.rb', line 25825 class DescribeInstanceAttributeRequest < Struct.new( :dry_run, :instance_id, :attribute) SENSITIVE = [] include Aws::Structure end |