Class: Aws::EC2::Types::DescribeInstanceCreditSpecificationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


26020
26021
26022
26023
26024
26025
26026
26027
26028
# File 'lib/aws-sdk-ec2/types.rb', line 26020

class DescribeInstanceCreditSpecificationsRequest < Struct.new(
  :dry_run,
  :filters,
  :instance_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters.

  • instance-id - The ID of the instance.

^

Returns:



26020
26021
26022
26023
26024
26025
26026
26027
26028
# File 'lib/aws-sdk-ec2/types.rb', line 26020

class DescribeInstanceCreditSpecificationsRequest < Struct.new(
  :dry_run,
  :filters,
  :instance_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idsArray<String>

The instance IDs.

Default: Describes all your instances.

Constraints: Maximum 1000 explicitly specified instance IDs.

Returns:

  • (Array<String>)


26020
26021
26022
26023
26024
26025
26026
26027
26028
# File 'lib/aws-sdk-ec2/types.rb', line 26020

class DescribeInstanceCreditSpecificationsRequest < Struct.new(
  :dry_run,
  :filters,
  :instance_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.

You cannot specify this parameter and the instance IDs parameter in the same call.

Returns:

  • (Integer)


26020
26021
26022
26023
26024
26025
26026
26027
26028
# File 'lib/aws-sdk-ec2/types.rb', line 26020

class DescribeInstanceCreditSpecificationsRequest < Struct.new(
  :dry_run,
  :filters,
  :instance_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Returns:

  • (String)


26020
26021
26022
26023
26024
26025
26026
26027
26028
# File 'lib/aws-sdk-ec2/types.rb', line 26020

class DescribeInstanceCreditSpecificationsRequest < Struct.new(
  :dry_run,
  :filters,
  :instance_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end