Class: Aws::EC2::Types::DescribeInstanceCreditSpecificationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


25971
25972
25973
25974
25975
25976
25977
25978
25979
# File 'lib/aws-sdk-ec2/types.rb', line 25971

class DescribeInstanceCreditSpecificationsRequest < Struct.new(
  :dry_run,
  :filters,
  :instance_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters.

  • ‘instance-id` - The ID of the instance.

^

Returns:



25971
25972
25973
25974
25975
25976
25977
25978
25979
# File 'lib/aws-sdk-ec2/types.rb', line 25971

class DescribeInstanceCreditSpecificationsRequest < Struct.new(
  :dry_run,
  :filters,
  :instance_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idsArray<String>

The instance IDs.

Default: Describes all your instances.

Constraints: Maximum 1000 explicitly specified instance IDs.

Returns:

  • (Array<String>)


25971
25972
25973
25974
25975
25976
25977
25978
25979
# File 'lib/aws-sdk-ec2/types.rb', line 25971

class DescribeInstanceCreditSpecificationsRequest < Struct.new(
  :dry_run,
  :filters,
  :instance_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].

You cannot specify this parameter and the instance IDs parameter in the same call.

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination

Returns:

  • (Integer)


25971
25972
25973
25974
25975
25976
25977
25978
25979
# File 'lib/aws-sdk-ec2/types.rb', line 25971

class DescribeInstanceCreditSpecificationsRequest < Struct.new(
  :dry_run,
  :filters,
  :instance_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Returns:

  • (String)


25971
25972
25973
25974
25975
25976
25977
25978
25979
# File 'lib/aws-sdk-ec2/types.rb', line 25971

class DescribeInstanceCreditSpecificationsRequest < Struct.new(
  :dry_run,
  :filters,
  :instance_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end