Class: Aws::EC2::Types::DescribeInstanceCreditSpecificationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeInstanceCreditSpecificationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The filters.
-
#instance_ids ⇒ Array<String>
The instance IDs.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token returned from a previous paginated request.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
25702 25703 25704 25705 25706 25707 25708 25709 25710 |
# File 'lib/aws-sdk-ec2/types.rb', line 25702 class DescribeInstanceCreditSpecificationsRequest < Struct.new( :dry_run, :filters, :instance_ids, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters.
-
‘instance-id` - The ID of the instance.
^
25702 25703 25704 25705 25706 25707 25708 25709 25710 |
# File 'lib/aws-sdk-ec2/types.rb', line 25702 class DescribeInstanceCreditSpecificationsRequest < Struct.new( :dry_run, :filters, :instance_ids, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#instance_ids ⇒ Array<String>
The instance IDs.
Default: Describes all your instances.
Constraints: Maximum 1000 explicitly specified instance IDs.
25702 25703 25704 25705 25706 25707 25708 25709 25710 |
# File 'lib/aws-sdk-ec2/types.rb', line 25702 class DescribeInstanceCreditSpecificationsRequest < Struct.new( :dry_run, :filters, :instance_ids, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].
You cannot specify this parameter and the instance IDs parameter in the same call.
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination
25702 25703 25704 25705 25706 25707 25708 25709 25710 |
# File 'lib/aws-sdk-ec2/types.rb', line 25702 class DescribeInstanceCreditSpecificationsRequest < Struct.new( :dry_run, :filters, :instance_ids, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
25702 25703 25704 25705 25706 25707 25708 25709 25710 |
# File 'lib/aws-sdk-ec2/types.rb', line 25702 class DescribeInstanceCreditSpecificationsRequest < Struct.new( :dry_run, :filters, :instance_ids, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |