Class: Aws::EC2::Types::DescribeInstanceCreditSpecificationsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeInstanceCreditSpecificationsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_credit_specifications ⇒ Array<Types::InstanceCreditSpecification>
Information about the credit option for CPU usage of an instance.
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
Instance Attribute Details
#instance_credit_specifications ⇒ Array<Types::InstanceCreditSpecification>
Information about the credit option for CPU usage of an instance.
27541 27542 27543 27544 27545 27546 |
# File 'lib/aws-sdk-ec2/types.rb', line 27541 class DescribeInstanceCreditSpecificationsResult < Struct.new( :instance_credit_specifications, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
27541 27542 27543 27544 27545 27546 |
# File 'lib/aws-sdk-ec2/types.rb', line 27541 class DescribeInstanceCreditSpecificationsResult < Struct.new( :instance_credit_specifications, :next_token) SENSITIVE = [] include Aws::Structure end |