Class: Aws::EC2::Types::DescribeInstanceEventNotificationAttributesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


25144
25145
25146
25147
25148
# File 'lib/aws-sdk-ec2/types.rb', line 25144

class DescribeInstanceEventNotificationAttributesRequest < Struct.new(
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end