Class: Aws::EC2::Types::DescribeInstanceImageMetadataResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeInstanceImageMetadataResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_image_metadata ⇒ Array<Types::InstanceImageMetadata>
Information about the instance and the AMI used to launch the instance.
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
Instance Attribute Details
#instance_image_metadata ⇒ Array<Types::InstanceImageMetadata>
Information about the instance and the AMI used to launch the instance.
26270 26271 26272 26273 26274 26275 |
# File 'lib/aws-sdk-ec2/types.rb', line 26270 class DescribeInstanceImageMetadataResult < Struct.new( :instance_image_metadata, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
26270 26271 26272 26273 26274 26275 |
# File 'lib/aws-sdk-ec2/types.rb', line 26270 class DescribeInstanceImageMetadataResult < Struct.new( :instance_image_metadata, :next_token) SENSITIVE = [] include Aws::Structure end |