Class: Aws::EC2::Types::DescribeInstanceSqlHaHistoryStatesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


25770
25771
25772
25773
25774
25775
25776
25777
25778
25779
25780
# File 'lib/aws-sdk-ec2/types.rb', line 25770

class DescribeInstanceSqlHaHistoryStatesRequest < Struct.new(
  :instance_ids,
  :start_time,
  :end_time,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

The end data and time of the period for which to get historical SQL Server High Availability states. If omitted, the API returns historical states up to the current date and time.

Timezone: UTC

Format: ‘YYYY-MM-DDThh:mm:ss.sssZ`

Returns:

  • (Time)


25770
25771
25772
25773
25774
25775
25776
25777
25778
25779
25780
# File 'lib/aws-sdk-ec2/types.rb', line 25770

class DescribeInstanceSqlHaHistoryStatesRequest < Struct.new(
  :instance_ids,
  :start_time,
  :end_time,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters to apply to the results. Supported filters include:

  • ‘tag:<key>` - The tag key and value pair assigned to the instance. For example, to find all instances tagged with `Owner:TeamA`, specify `tag:Owner` for the filter name and `TeamA` for the filter value.

  • ‘tag-key` - The tag key assigned to the instance.

  • ‘haStatus` - The SQL Server High Availability status of the SQL Server High Availability instance (`processing` | `active` | `standby` | `invalid`).

  • ‘sqlServerLicenseUsage` - The license type for the SQL Server license (`full` | `waived`).

Returns:



25770
25771
25772
25773
25774
25775
25776
25777
25778
25779
25780
# File 'lib/aws-sdk-ec2/types.rb', line 25770

class DescribeInstanceSqlHaHistoryStatesRequest < Struct.new(
  :instance_ids,
  :start_time,
  :end_time,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idsArray<String>

The IDs of the SQL Server High Availability instances to describe. If omitted, the API returns historical states for all SQL Server High Availability instances.

Returns:

  • (Array<String>)


25770
25771
25772
25773
25774
25775
25776
25777
25778
25779
25780
# File 'lib/aws-sdk-ec2/types.rb', line 25770

class DescribeInstanceSqlHaHistoryStatesRequest < Struct.new(
  :instance_ids,
  :start_time,
  :end_time,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the returned ‘nextToken` value.

Returns:

  • (Integer)


25770
25771
25772
25773
25774
25775
25776
25777
25778
25779
25780
# File 'lib/aws-sdk-ec2/types.rb', line 25770

class DescribeInstanceSqlHaHistoryStatesRequest < Struct.new(
  :instance_ids,
  :start_time,
  :end_time,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to use to retrieve the next page of results.

Returns:

  • (String)


25770
25771
25772
25773
25774
25775
25776
25777
25778
25779
25780
# File 'lib/aws-sdk-ec2/types.rb', line 25770

class DescribeInstanceSqlHaHistoryStatesRequest < Struct.new(
  :instance_ids,
  :start_time,
  :end_time,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The start data and time of the period for which to get the historical SQL Server High Availability states. If omitted, the API returns all available historical states.

Timezone: UTC

Format: ‘YYYY-MM-DDThh:mm:ss.sssZ`

Returns:

  • (Time)


25770
25771
25772
25773
25774
25775
25776
25777
25778
25779
25780
# File 'lib/aws-sdk-ec2/types.rb', line 25770

class DescribeInstanceSqlHaHistoryStatesRequest < Struct.new(
  :instance_ids,
  :start_time,
  :end_time,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end