Class: Aws::EC2::Types::DescribeInstanceStatusResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeInstanceStatusResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_statuses ⇒ Array<Types::InstanceStatus>
Information about the status of the instances.
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
Instance Attribute Details
#instance_statuses ⇒ Array<Types::InstanceStatus>
Information about the status of the instances.
26877 26878 26879 26880 26881 26882 |
# File 'lib/aws-sdk-ec2/types.rb', line 26877 class DescribeInstanceStatusResult < Struct.new( :instance_statuses, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
26877 26878 26879 26880 26881 26882 |
# File 'lib/aws-sdk-ec2/types.rb', line 26877 class DescribeInstanceStatusResult < Struct.new( :instance_statuses, :next_token) SENSITIVE = [] include Aws::Structure end |