Class: Aws::EC2::Types::DescribeInstanceTopologyResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeInstanceTopologyResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instances ⇒ Array<Types::InstanceTopology>
Information about the topology of each instance.
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
Instance Attribute Details
#instances ⇒ Array<Types::InstanceTopology>
Information about the topology of each instance.
27859 27860 27861 27862 27863 27864 |
# File 'lib/aws-sdk-ec2/types.rb', line 27859 class DescribeInstanceTopologyResult < Struct.new( :instances, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
27859 27860 27861 27862 27863 27864 |
# File 'lib/aws-sdk-ec2/types.rb', line 27859 class DescribeInstanceTopologyResult < Struct.new( :instances, :next_token) SENSITIVE = [] include Aws::Structure end |