Class: Aws::EC2::Types::DescribeInstanceTopologyResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeInstanceTopologyResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instances ⇒ Array<Types::InstanceTopology>
Information about the topology of each instance.
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
Instance Attribute Details
#instances ⇒ Array<Types::InstanceTopology>
Information about the topology of each instance.
26875 26876 26877 26878 26879 26880 |
# File 'lib/aws-sdk-ec2/types.rb', line 26875 class DescribeInstanceTopologyResult < Struct.new( :instances, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
26875 26876 26877 26878 26879 26880 |
# File 'lib/aws-sdk-ec2/types.rb', line 26875 class DescribeInstanceTopologyResult < Struct.new( :instances, :next_token) SENSITIVE = [] include Aws::Structure end |