Class: Aws::EC2::Types::DescribeInstanceTypeOfferingsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeInstanceTypeOfferingsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_type_offerings ⇒ Array<Types::InstanceTypeOffering>
The instance types offered in the location.
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
Instance Attribute Details
#instance_type_offerings ⇒ Array<Types::InstanceTypeOffering>
The instance types offered in the location.
26756 26757 26758 26759 26760 26761 |
# File 'lib/aws-sdk-ec2/types.rb', line 26756 class DescribeInstanceTypeOfferingsResult < Struct.new( :instance_type_offerings, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
26756 26757 26758 26759 26760 26761 |
# File 'lib/aws-sdk-ec2/types.rb', line 26756 class DescribeInstanceTypeOfferingsResult < Struct.new( :instance_type_offerings, :next_token) SENSITIVE = [] include Aws::Structure end |