Class: Aws::EC2::Types::DescribeInstanceTypesResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeInstanceTypesResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_types ⇒ Array<Types::InstanceTypeInfo>
The instance type.
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
Instance Attribute Details
#instance_types ⇒ Array<Types::InstanceTypeInfo>
The instance type.
28515 28516 28517 28518 28519 28520 |
# File 'lib/aws-sdk-ec2/types.rb', line 28515 class DescribeInstanceTypesResult < Struct.new( :instance_types, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
28515 28516 28517 28518 28519 28520 |
# File 'lib/aws-sdk-ec2/types.rb', line 28515 class DescribeInstanceTypesResult < Struct.new( :instance_types, :next_token) SENSITIVE = [] include Aws::Structure end |