Class: Aws::EC2::Types::DescribeInstanceTypesResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_typesArray<Types::InstanceTypeInfo>

The instance type.

Returns:



27301
27302
27303
27304
27305
27306
# File 'lib/aws-sdk-ec2/types.rb', line 27301

class DescribeInstanceTypesResult < Struct.new(
  :instance_types,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to include in another request to get the next page of items. This value is null when there are no more items to return.

Returns:

  • (String)


27301
27302
27303
27304
27305
27306
# File 'lib/aws-sdk-ec2/types.rb', line 27301

class DescribeInstanceTypesResult < Struct.new(
  :instance_types,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end