Class: Aws::EC2::Types::DescribeInstancesResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeInstancesResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#reservations ⇒ Array<Types::Reservation>
Information about the reservations.
Instance Attribute Details
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
27698 27699 27700 27701 27702 27703 |
# File 'lib/aws-sdk-ec2/types.rb', line 27698 class DescribeInstancesResult < Struct.new( :next_token, :reservations) SENSITIVE = [] include Aws::Structure end |
#reservations ⇒ Array<Types::Reservation>
Information about the reservations.
27698 27699 27700 27701 27702 27703 |
# File 'lib/aws-sdk-ec2/types.rb', line 27698 class DescribeInstancesResult < Struct.new( :next_token, :reservations) SENSITIVE = [] include Aws::Structure end |