Class: Aws::EC2::Types::DescribeInternetGatewaysResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeInternetGatewaysResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#internet_gateways ⇒ Array<Types::InternetGateway>
Information about the internet gateways.
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
Instance Attribute Details
#internet_gateways ⇒ Array<Types::InternetGateway>
Information about the internet gateways.
29112 29113 29114 29115 29116 29117 |
# File 'lib/aws-sdk-ec2/types.rb', line 29112 class DescribeInternetGatewaysResult < Struct.new( :internet_gateways, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
29112 29113 29114 29115 29116 29117 |
# File 'lib/aws-sdk-ec2/types.rb', line 29112 class DescribeInternetGatewaysResult < Struct.new( :internet_gateways, :next_token) SENSITIVE = [] include Aws::Structure end |