Class: Aws::EC2::Types::DescribeIpamByoasnRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


27049
27050
27051
27052
27053
27054
27055
# File 'lib/aws-sdk-ec2/types.rb', line 27049

class DescribeIpamByoasnRequest < Struct.new(
  :dry_run,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.

Returns:

  • (Integer)


27049
27050
27051
27052
27053
27054
27055
# File 'lib/aws-sdk-ec2/types.rb', line 27049

class DescribeIpamByoasnRequest < Struct.new(
  :dry_run,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


27049
27050
27051
27052
27053
27054
27055
# File 'lib/aws-sdk-ec2/types.rb', line 27049

class DescribeIpamByoasnRequest < Struct.new(
  :dry_run,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end