Class: Aws::EC2::Types::DescribeIpamExternalResourceVerificationTokensRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeIpamExternalResourceVerificationTokensRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters for the request.
-
#ipam_external_resource_verification_token_ids ⇒ Array<String>
Verification token IDs.
-
#max_results ⇒ Integer
The maximum number of tokens to return in one page of results.
-
#next_token ⇒ String
The token for the next page of results.
Instance Attribute Details
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action
without actually making the request and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
29214 29215 29216 29217 29218 29219 29220 29221 29222 |
# File 'lib/aws-sdk-ec2/types.rb', line 29214 class DescribeIpamExternalResourceVerificationTokensRequest < Struct.new( :dry_run, :filters, :next_token, :max_results, :ipam_external_resource_verification_token_ids) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters for the request. For more information about filtering, see Filtering CLI output.
Available filters:
-
ipam-arn -
ipam-external-resource-verification-token-arn -
ipam-external-resource-verification-token-id -
ipam-id -
ipam-region -
state -
status -
token-name -
token-value
29214 29215 29216 29217 29218 29219 29220 29221 29222 |
# File 'lib/aws-sdk-ec2/types.rb', line 29214 class DescribeIpamExternalResourceVerificationTokensRequest < Struct.new( :dry_run, :filters, :next_token, :max_results, :ipam_external_resource_verification_token_ids) SENSITIVE = [] include Aws::Structure end |
#ipam_external_resource_verification_token_ids ⇒ Array<String>
Verification token IDs.
29214 29215 29216 29217 29218 29219 29220 29221 29222 |
# File 'lib/aws-sdk-ec2/types.rb', line 29214 class DescribeIpamExternalResourceVerificationTokensRequest < Struct.new( :dry_run, :filters, :next_token, :max_results, :ipam_external_resource_verification_token_ids) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of tokens to return in one page of results.
29214 29215 29216 29217 29218 29219 29220 29221 29222 |
# File 'lib/aws-sdk-ec2/types.rb', line 29214 class DescribeIpamExternalResourceVerificationTokensRequest < Struct.new( :dry_run, :filters, :next_token, :max_results, :ipam_external_resource_verification_token_ids) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
29214 29215 29216 29217 29218 29219 29220 29221 29222 |
# File 'lib/aws-sdk-ec2/types.rb', line 29214 class DescribeIpamExternalResourceVerificationTokensRequest < Struct.new( :dry_run, :filters, :next_token, :max_results, :ipam_external_resource_verification_token_ids) SENSITIVE = [] include Aws::Structure end |