Class: Aws::EC2::Types::DescribeIpamExternalResourceVerificationTokensRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


27394
27395
27396
27397
27398
27399
27400
27401
27402
# File 'lib/aws-sdk-ec2/types.rb', line 27394

class DescribeIpamExternalResourceVerificationTokensRequest < Struct.new(
  :dry_run,
  :filters,
  :next_token,
  :max_results,
  :ipam_external_resource_verification_token_ids)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters for the request. For more information about filtering, see [Filtering CLI output].

Available filters:

  • ‘ipam-arn`

  • ‘ipam-external-resource-verification-token-arn`

  • ‘ipam-external-resource-verification-token-id`

  • ‘ipam-id`

  • ‘ipam-region`

  • ‘state`

  • ‘status`

  • ‘token-name`

  • ‘token-value`

[1]: docs.aws.amazon.com/cli/latest/userguide/cli-usage-filter.html

Returns:



27394
27395
27396
27397
27398
27399
27400
27401
27402
# File 'lib/aws-sdk-ec2/types.rb', line 27394

class DescribeIpamExternalResourceVerificationTokensRequest < Struct.new(
  :dry_run,
  :filters,
  :next_token,
  :max_results,
  :ipam_external_resource_verification_token_ids)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_external_resource_verification_token_idsArray<String>

Verification token IDs.

Returns:

  • (Array<String>)


27394
27395
27396
27397
27398
27399
27400
27401
27402
# File 'lib/aws-sdk-ec2/types.rb', line 27394

class DescribeIpamExternalResourceVerificationTokensRequest < Struct.new(
  :dry_run,
  :filters,
  :next_token,
  :max_results,
  :ipam_external_resource_verification_token_ids)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of tokens to return in one page of results.

Returns:

  • (Integer)


27394
27395
27396
27397
27398
27399
27400
27401
27402
# File 'lib/aws-sdk-ec2/types.rb', line 27394

class DescribeIpamExternalResourceVerificationTokensRequest < Struct.new(
  :dry_run,
  :filters,
  :next_token,
  :max_results,
  :ipam_external_resource_verification_token_ids)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


27394
27395
27396
27397
27398
27399
27400
27401
27402
# File 'lib/aws-sdk-ec2/types.rb', line 27394

class DescribeIpamExternalResourceVerificationTokensRequest < Struct.new(
  :dry_run,
  :filters,
  :next_token,
  :max_results,
  :ipam_external_resource_verification_token_ids)
  SENSITIVE = []
  include Aws::Structure
end