Class: Aws::EC2::Types::DescribeIpamExternalResourceVerificationTokensRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeIpamExternalResourceVerificationTokensRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters for the request.
-
#ipam_external_resource_verification_token_ids ⇒ Array<String>
Verification token IDs.
-
#max_results ⇒ Integer
The maximum number of tokens to return in one page of results.
-
#next_token ⇒ String
The token for the next page of results.
Instance Attribute Details
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
27394 27395 27396 27397 27398 27399 27400 27401 27402 |
# File 'lib/aws-sdk-ec2/types.rb', line 27394 class DescribeIpamExternalResourceVerificationTokensRequest < Struct.new( :dry_run, :filters, :next_token, :max_results, :ipam_external_resource_verification_token_ids) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters for the request. For more information about filtering, see [Filtering CLI output].
Available filters:
-
‘ipam-arn`
-
‘ipam-external-resource-verification-token-arn`
-
‘ipam-external-resource-verification-token-id`
-
‘ipam-id`
-
‘ipam-region`
-
‘state`
-
‘status`
-
‘token-name`
-
‘token-value`
[1]: docs.aws.amazon.com/cli/latest/userguide/cli-usage-filter.html
27394 27395 27396 27397 27398 27399 27400 27401 27402 |
# File 'lib/aws-sdk-ec2/types.rb', line 27394 class DescribeIpamExternalResourceVerificationTokensRequest < Struct.new( :dry_run, :filters, :next_token, :max_results, :ipam_external_resource_verification_token_ids) SENSITIVE = [] include Aws::Structure end |
#ipam_external_resource_verification_token_ids ⇒ Array<String>
Verification token IDs.
27394 27395 27396 27397 27398 27399 27400 27401 27402 |
# File 'lib/aws-sdk-ec2/types.rb', line 27394 class DescribeIpamExternalResourceVerificationTokensRequest < Struct.new( :dry_run, :filters, :next_token, :max_results, :ipam_external_resource_verification_token_ids) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of tokens to return in one page of results.
27394 27395 27396 27397 27398 27399 27400 27401 27402 |
# File 'lib/aws-sdk-ec2/types.rb', line 27394 class DescribeIpamExternalResourceVerificationTokensRequest < Struct.new( :dry_run, :filters, :next_token, :max_results, :ipam_external_resource_verification_token_ids) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
27394 27395 27396 27397 27398 27399 27400 27401 27402 |
# File 'lib/aws-sdk-ec2/types.rb', line 27394 class DescribeIpamExternalResourceVerificationTokensRequest < Struct.new( :dry_run, :filters, :next_token, :max_results, :ipam_external_resource_verification_token_ids) SENSITIVE = [] include Aws::Structure end |