Class: Aws::EC2::Types::DescribeIpamInternetRegistryAssociationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeIpamInternetRegistryAssociationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters to apply to the results.
-
#ipam_internet_registry_association_ids ⇒ Array<String>
The IDs of the internet registry associations to describe.
-
#max_results ⇒ Integer
The maximum number of results to return in a single call.
-
#next_token ⇒ String
The token for the next page of results.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
29279 29280 29281 29282 29283 29284 29285 29286 29287 |
# File 'lib/aws-sdk-ec2/types.rb', line 29279 class DescribeIpamInternetRegistryAssociationsRequest < Struct.new( :dry_run, :ipam_internet_registry_association_ids, :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters to apply to the results.
29279 29280 29281 29282 29283 29284 29285 29286 29287 |
# File 'lib/aws-sdk-ec2/types.rb', line 29279 class DescribeIpamInternetRegistryAssociationsRequest < Struct.new( :dry_run, :ipam_internet_registry_association_ids, :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#ipam_internet_registry_association_ids ⇒ Array<String>
The IDs of the internet registry associations to describe.
29279 29280 29281 29282 29283 29284 29285 29286 29287 |
# File 'lib/aws-sdk-ec2/types.rb', line 29279 class DescribeIpamInternetRegistryAssociationsRequest < Struct.new( :dry_run, :ipam_internet_registry_association_ids, :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in a single call. If not
specified, all available results are returned. To retrieve the
remaining results, make another call with the returned nextToken
value.
29279 29280 29281 29282 29283 29284 29285 29286 29287 |
# File 'lib/aws-sdk-ec2/types.rb', line 29279 class DescribeIpamInternetRegistryAssociationsRequest < Struct.new( :dry_run, :ipam_internet_registry_association_ids, :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
29279 29280 29281 29282 29283 29284 29285 29286 29287 |
# File 'lib/aws-sdk-ec2/types.rb', line 29279 class DescribeIpamInternetRegistryAssociationsRequest < Struct.new( :dry_run, :ipam_internet_registry_association_ids, :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |