Class: Aws::EC2::Types::DescribeIpamInternetRegistryAssociationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


29270
29271
29272
29273
29274
29275
29276
29277
29278
# File 'lib/aws-sdk-ec2/types.rb', line 29270

class DescribeIpamInternetRegistryAssociationsRequest < Struct.new(
  :dry_run,
  :ipam_internet_registry_association_ids,
  :max_results,
  :next_token,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters to apply to the results.

Returns:



29270
29271
29272
29273
29274
29275
29276
29277
29278
# File 'lib/aws-sdk-ec2/types.rb', line 29270

class DescribeIpamInternetRegistryAssociationsRequest < Struct.new(
  :dry_run,
  :ipam_internet_registry_association_ids,
  :max_results,
  :next_token,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_internet_registry_association_idsArray<String>

The IDs of the internet registry associations to describe.

Returns:

  • (Array<String>)


29270
29271
29272
29273
29274
29275
29276
29277
29278
# File 'lib/aws-sdk-ec2/types.rb', line 29270

class DescribeIpamInternetRegistryAssociationsRequest < Struct.new(
  :dry_run,
  :ipam_internet_registry_association_ids,
  :max_results,
  :next_token,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in a single call. If not specified, all available results are returned. To retrieve the remaining results, make another call with the returned nextToken value.

Returns:

  • (Integer)


29270
29271
29272
29273
29274
29275
29276
29277
29278
# File 'lib/aws-sdk-ec2/types.rb', line 29270

class DescribeIpamInternetRegistryAssociationsRequest < Struct.new(
  :dry_run,
  :ipam_internet_registry_association_ids,
  :max_results,
  :next_token,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


29270
29271
29272
29273
29274
29275
29276
29277
29278
# File 'lib/aws-sdk-ec2/types.rb', line 29270

class DescribeIpamInternetRegistryAssociationsRequest < Struct.new(
  :dry_run,
  :ipam_internet_registry_association_ids,
  :max_results,
  :next_token,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end