Class: Aws::EC2::Types::DescribeIpamPoliciesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


28960
28961
28962
28963
28964
28965
28966
28967
28968
# File 'lib/aws-sdk-ec2/types.rb', line 28960

class DescribeIpamPoliciesRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :ipam_policy_ids)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters for the IPAM policy description.

Returns:



28960
28961
28962
28963
28964
28965
28966
28967
28968
# File 'lib/aws-sdk-ec2/types.rb', line 28960

class DescribeIpamPoliciesRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :ipam_policy_ids)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_policy_idsArray<String>

The IDs of the IPAM policies to describe.

Returns:

  • (Array<String>)


28960
28961
28962
28963
28964
28965
28966
28967
28968
# File 'lib/aws-sdk-ec2/types.rb', line 28960

class DescribeIpamPoliciesRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :ipam_policy_ids)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in a single call.

Returns:

  • (Integer)


28960
28961
28962
28963
28964
28965
28966
28967
28968
# File 'lib/aws-sdk-ec2/types.rb', line 28960

class DescribeIpamPoliciesRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :ipam_policy_ids)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


28960
28961
28962
28963
28964
28965
28966
28967
28968
# File 'lib/aws-sdk-ec2/types.rb', line 28960

class DescribeIpamPoliciesRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :ipam_policy_ids)
  SENSITIVE = []
  include Aws::Structure
end