Class: Aws::EC2::Types::DescribeIpamPoliciesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeIpamPoliciesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters for the IPAM policy description.
-
#ipam_policy_ids ⇒ Array<String>
The IDs of the IPAM policies to describe.
-
#max_results ⇒ Integer
The maximum number of results to return in a single call.
-
#next_token ⇒ String
The token for the next page of results.
Instance Attribute Details
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
27178 27179 27180 27181 27182 27183 27184 27185 27186 |
# File 'lib/aws-sdk-ec2/types.rb', line 27178 class DescribeIpamPoliciesRequest < Struct.new( :dry_run, :filters, :max_results, :next_token, :ipam_policy_ids) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters for the IPAM policy description.
27178 27179 27180 27181 27182 27183 27184 27185 27186 |
# File 'lib/aws-sdk-ec2/types.rb', line 27178 class DescribeIpamPoliciesRequest < Struct.new( :dry_run, :filters, :max_results, :next_token, :ipam_policy_ids) SENSITIVE = [] include Aws::Structure end |
#ipam_policy_ids ⇒ Array<String>
The IDs of the IPAM policies to describe.
27178 27179 27180 27181 27182 27183 27184 27185 27186 |
# File 'lib/aws-sdk-ec2/types.rb', line 27178 class DescribeIpamPoliciesRequest < Struct.new( :dry_run, :filters, :max_results, :next_token, :ipam_policy_ids) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in a single call.
27178 27179 27180 27181 27182 27183 27184 27185 27186 |
# File 'lib/aws-sdk-ec2/types.rb', line 27178 class DescribeIpamPoliciesRequest < Struct.new( :dry_run, :filters, :max_results, :next_token, :ipam_policy_ids) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
27178 27179 27180 27181 27182 27183 27184 27185 27186 |
# File 'lib/aws-sdk-ec2/types.rb', line 27178 class DescribeIpamPoliciesRequest < Struct.new( :dry_run, :filters, :max_results, :next_token, :ipam_policy_ids) SENSITIVE = [] include Aws::Structure end |