Class: Aws::EC2::Types::DescribeIpamPoolAllocationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


28011
28012
28013
28014
28015
28016
28017
28018
28019
# File 'lib/aws-sdk-ec2/types.rb', line 28011

class DescribeIpamPoolAllocationsRequest < Struct.new(
  :dry_run,
  :ipam_pool_allocation_ids,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters for the request. For more information about filtering, see Filtering CLI output.

Returns:



28011
28012
28013
28014
28015
28016
28017
28018
28019
# File 'lib/aws-sdk-ec2/types.rb', line 28011

class DescribeIpamPoolAllocationsRequest < Struct.new(
  :dry_run,
  :ipam_pool_allocation_ids,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_pool_allocation_idsArray<String>

The IDs of the IPAM pool allocations you want to describe.

Returns:

  • (Array<String>)


28011
28012
28013
28014
28015
28016
28017
28018
28019
# File 'lib/aws-sdk-ec2/types.rb', line 28011

class DescribeIpamPoolAllocationsRequest < Struct.new(
  :dry_run,
  :ipam_pool_allocation_ids,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.

Returns:

  • (Integer)


28011
28012
28013
28014
28015
28016
28017
28018
28019
# File 'lib/aws-sdk-ec2/types.rb', line 28011

class DescribeIpamPoolAllocationsRequest < Struct.new(
  :dry_run,
  :ipam_pool_allocation_ids,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


28011
28012
28013
28014
28015
28016
28017
28018
28019
# File 'lib/aws-sdk-ec2/types.rb', line 28011

class DescribeIpamPoolAllocationsRequest < Struct.new(
  :dry_run,
  :ipam_pool_allocation_ids,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end