Class: Aws::EC2::Types::DescribeIpamPoolsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


28089
28090
28091
28092
28093
28094
28095
28096
28097
# File 'lib/aws-sdk-ec2/types.rb', line 28089

class DescribeIpamPoolsRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :ipam_pool_ids)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters for the request. For more information about filtering, see Filtering CLI output.

Returns:



28089
28090
28091
28092
28093
28094
28095
28096
28097
# File 'lib/aws-sdk-ec2/types.rb', line 28089

class DescribeIpamPoolsRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :ipam_pool_ids)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_pool_idsArray<String>

The IDs of the IPAM pools you would like information on.

Returns:

  • (Array<String>)


28089
28090
28091
28092
28093
28094
28095
28096
28097
# File 'lib/aws-sdk-ec2/types.rb', line 28089

class DescribeIpamPoolsRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :ipam_pool_ids)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.

Returns:

  • (Integer)


28089
28090
28091
28092
28093
28094
28095
28096
28097
# File 'lib/aws-sdk-ec2/types.rb', line 28089

class DescribeIpamPoolsRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :ipam_pool_ids)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


28089
28090
28091
28092
28093
28094
28095
28096
28097
# File 'lib/aws-sdk-ec2/types.rb', line 28089

class DescribeIpamPoolsRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :ipam_pool_ids)
  SENSITIVE = []
  include Aws::Structure
end