Class: Aws::EC2::Types::DescribeIpamPoolsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeIpamPoolsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters for the request.
-
#ipam_pool_ids ⇒ Array<String>
The IDs of the IPAM pools you would like information on.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token for the next page of results.
Instance Attribute Details
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
27904 27905 27906 27907 27908 27909 27910 27911 27912 |
# File 'lib/aws-sdk-ec2/types.rb', line 27904 class DescribeIpamPoolsRequest < Struct.new( :dry_run, :filters, :max_results, :next_token, :ipam_pool_ids) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters for the request. For more information about filtering, see [Filtering CLI output].
[1]: docs.aws.amazon.com/cli/latest/userguide/cli-usage-filter.html
27904 27905 27906 27907 27908 27909 27910 27911 27912 |
# File 'lib/aws-sdk-ec2/types.rb', line 27904 class DescribeIpamPoolsRequest < Struct.new( :dry_run, :filters, :max_results, :next_token, :ipam_pool_ids) SENSITIVE = [] include Aws::Structure end |
#ipam_pool_ids ⇒ Array<String>
The IDs of the IPAM pools you would like information on.
27904 27905 27906 27907 27908 27909 27910 27911 27912 |
# File 'lib/aws-sdk-ec2/types.rb', line 27904 class DescribeIpamPoolsRequest < Struct.new( :dry_run, :filters, :max_results, :next_token, :ipam_pool_ids) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination
27904 27905 27906 27907 27908 27909 27910 27911 27912 |
# File 'lib/aws-sdk-ec2/types.rb', line 27904 class DescribeIpamPoolsRequest < Struct.new( :dry_run, :filters, :max_results, :next_token, :ipam_pool_ids) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
27904 27905 27906 27907 27908 27909 27910 27911 27912 |
# File 'lib/aws-sdk-ec2/types.rb', line 27904 class DescribeIpamPoolsRequest < Struct.new( :dry_run, :filters, :max_results, :next_token, :ipam_pool_ids) SENSITIVE = [] include Aws::Structure end |