Class: Aws::EC2::Types::DescribeIpamResourceDiscoveriesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeIpamResourceDiscoveriesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The resource discovery filters.
-
#ipam_resource_discovery_ids ⇒ Array<String>
The IPAM resource discovery IDs.
-
#max_results ⇒ Integer
The maximum number of resource discoveries to return in one page of results.
-
#next_token ⇒ String
The token for the next page of results.
Instance Attribute Details
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action
without actually making the request and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
28269 28270 28271 28272 28273 28274 28275 28276 28277 |
# File 'lib/aws-sdk-ec2/types.rb', line 28269 class DescribeIpamResourceDiscoveriesRequest < Struct.new( :dry_run, :ipam_resource_discovery_ids, :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The resource discovery filters.
28269 28270 28271 28272 28273 28274 28275 28276 28277 |
# File 'lib/aws-sdk-ec2/types.rb', line 28269 class DescribeIpamResourceDiscoveriesRequest < Struct.new( :dry_run, :ipam_resource_discovery_ids, :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |
#ipam_resource_discovery_ids ⇒ Array<String>
The IPAM resource discovery IDs.
28269 28270 28271 28272 28273 28274 28275 28276 28277 |
# File 'lib/aws-sdk-ec2/types.rb', line 28269 class DescribeIpamResourceDiscoveriesRequest < Struct.new( :dry_run, :ipam_resource_discovery_ids, :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of resource discoveries to return in one page of results.
28269 28270 28271 28272 28273 28274 28275 28276 28277 |
# File 'lib/aws-sdk-ec2/types.rb', line 28269 class DescribeIpamResourceDiscoveriesRequest < Struct.new( :dry_run, :ipam_resource_discovery_ids, :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
28269 28270 28271 28272 28273 28274 28275 28276 28277 |
# File 'lib/aws-sdk-ec2/types.rb', line 28269 class DescribeIpamResourceDiscoveriesRequest < Struct.new( :dry_run, :ipam_resource_discovery_ids, :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |