Class: Aws::EC2::Types::DescribeIpamResourceDiscoveryAssociationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeIpamResourceDiscoveryAssociationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The resource discovery association filters.
-
#ipam_resource_discovery_association_ids ⇒ Array<String>
The resource discovery association IDs.
-
#max_results ⇒ Integer
The maximum number of resource discovery associations to return in one page of results.
-
#next_token ⇒ String
Specify the pagination token from a previous request to retrieve the next page of results.
Instance Attribute Details
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action
without actually making the request and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
28145 28146 28147 28148 28149 28150 28151 28152 28153 |
# File 'lib/aws-sdk-ec2/types.rb', line 28145 class DescribeIpamResourceDiscoveryAssociationsRequest < Struct.new( :dry_run, :ipam_resource_discovery_association_ids, :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The resource discovery association filters.
28145 28146 28147 28148 28149 28150 28151 28152 28153 |
# File 'lib/aws-sdk-ec2/types.rb', line 28145 class DescribeIpamResourceDiscoveryAssociationsRequest < Struct.new( :dry_run, :ipam_resource_discovery_association_ids, :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |
#ipam_resource_discovery_association_ids ⇒ Array<String>
The resource discovery association IDs.
28145 28146 28147 28148 28149 28150 28151 28152 28153 |
# File 'lib/aws-sdk-ec2/types.rb', line 28145 class DescribeIpamResourceDiscoveryAssociationsRequest < Struct.new( :dry_run, :ipam_resource_discovery_association_ids, :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of resource discovery associations to return in one page of results.
28145 28146 28147 28148 28149 28150 28151 28152 28153 |
# File 'lib/aws-sdk-ec2/types.rb', line 28145 class DescribeIpamResourceDiscoveryAssociationsRequest < Struct.new( :dry_run, :ipam_resource_discovery_association_ids, :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Specify the pagination token from a previous request to retrieve the next page of results.
28145 28146 28147 28148 28149 28150 28151 28152 28153 |
# File 'lib/aws-sdk-ec2/types.rb', line 28145 class DescribeIpamResourceDiscoveryAssociationsRequest < Struct.new( :dry_run, :ipam_resource_discovery_association_ids, :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |