Class: Aws::EC2::Types::DescribeIpamResourceDiscoveryAssociationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


27734
27735
27736
27737
27738
27739
27740
27741
27742
# File 'lib/aws-sdk-ec2/types.rb', line 27734

class DescribeIpamResourceDiscoveryAssociationsRequest < Struct.new(
  :dry_run,
  :ipam_resource_discovery_association_ids,
  :next_token,
  :max_results,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The resource discovery association filters.

Returns:



27734
27735
27736
27737
27738
27739
27740
27741
27742
# File 'lib/aws-sdk-ec2/types.rb', line 27734

class DescribeIpamResourceDiscoveryAssociationsRequest < Struct.new(
  :dry_run,
  :ipam_resource_discovery_association_ids,
  :next_token,
  :max_results,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_resource_discovery_association_idsArray<String>

The resource discovery association IDs.

Returns:

  • (Array<String>)


27734
27735
27736
27737
27738
27739
27740
27741
27742
# File 'lib/aws-sdk-ec2/types.rb', line 27734

class DescribeIpamResourceDiscoveryAssociationsRequest < Struct.new(
  :dry_run,
  :ipam_resource_discovery_association_ids,
  :next_token,
  :max_results,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of resource discovery associations to return in one page of results.

Returns:

  • (Integer)


27734
27735
27736
27737
27738
27739
27740
27741
27742
# File 'lib/aws-sdk-ec2/types.rb', line 27734

class DescribeIpamResourceDiscoveryAssociationsRequest < Struct.new(
  :dry_run,
  :ipam_resource_discovery_association_ids,
  :next_token,
  :max_results,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Specify the pagination token from a previous request to retrieve the next page of results.

Returns:

  • (String)


27734
27735
27736
27737
27738
27739
27740
27741
27742
# File 'lib/aws-sdk-ec2/types.rb', line 27734

class DescribeIpamResourceDiscoveryAssociationsRequest < Struct.new(
  :dry_run,
  :ipam_resource_discovery_association_ids,
  :next_token,
  :max_results,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end