Class: Aws::EC2::Types::DescribeIpamScopesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeIpamScopesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters for the request.
-
#ipam_scope_ids ⇒ Array<String>
The IDs of the scopes you want information on.
-
#max_results ⇒ Integer
The maximum number of results to return in the request.
-
#next_token ⇒ String
The token for the next page of results.
Instance Attribute Details
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
27808 27809 27810 27811 27812 27813 27814 27815 27816 |
# File 'lib/aws-sdk-ec2/types.rb', line 27808 class DescribeIpamScopesRequest < Struct.new( :dry_run, :filters, :max_results, :next_token, :ipam_scope_ids) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters for the request. For more information about filtering, see [Filtering CLI output].
[1]: docs.aws.amazon.com/cli/latest/userguide/cli-usage-filter.html
27808 27809 27810 27811 27812 27813 27814 27815 27816 |
# File 'lib/aws-sdk-ec2/types.rb', line 27808 class DescribeIpamScopesRequest < Struct.new( :dry_run, :filters, :max_results, :next_token, :ipam_scope_ids) SENSITIVE = [] include Aws::Structure end |
#ipam_scope_ids ⇒ Array<String>
The IDs of the scopes you want information on.
27808 27809 27810 27811 27812 27813 27814 27815 27816 |
# File 'lib/aws-sdk-ec2/types.rb', line 27808 class DescribeIpamScopesRequest < Struct.new( :dry_run, :filters, :max_results, :next_token, :ipam_scope_ids) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in the request.
27808 27809 27810 27811 27812 27813 27814 27815 27816 |
# File 'lib/aws-sdk-ec2/types.rb', line 27808 class DescribeIpamScopesRequest < Struct.new( :dry_run, :filters, :max_results, :next_token, :ipam_scope_ids) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
27808 27809 27810 27811 27812 27813 27814 27815 27816 |
# File 'lib/aws-sdk-ec2/types.rb', line 27808 class DescribeIpamScopesRequest < Struct.new( :dry_run, :filters, :max_results, :next_token, :ipam_scope_ids) SENSITIVE = [] include Aws::Structure end |