Class: Aws::EC2::Types::DescribeIpamsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


29823
29824
29825
29826
29827
29828
29829
29830
29831
# File 'lib/aws-sdk-ec2/types.rb', line 29823

class DescribeIpamsRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :ipam_ids)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters for the request. For more information about filtering, see Filtering CLI output.

Returns:



29823
29824
29825
29826
29827
29828
29829
29830
29831
# File 'lib/aws-sdk-ec2/types.rb', line 29823

class DescribeIpamsRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :ipam_ids)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_idsArray<String>

The IDs of the IPAMs you want information on.

Returns:

  • (Array<String>)


29823
29824
29825
29826
29827
29828
29829
29830
29831
# File 'lib/aws-sdk-ec2/types.rb', line 29823

class DescribeIpamsRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :ipam_ids)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.

Returns:

  • (Integer)


29823
29824
29825
29826
29827
29828
29829
29830
29831
# File 'lib/aws-sdk-ec2/types.rb', line 29823

class DescribeIpamsRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :ipam_ids)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


29823
29824
29825
29826
29827
29828
29829
29830
29831
# File 'lib/aws-sdk-ec2/types.rb', line 29823

class DescribeIpamsRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :ipam_ids)
  SENSITIVE = []
  include Aws::Structure
end