Class: Aws::EC2::Types::DescribeIpamsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


28218
28219
28220
28221
28222
28223
28224
28225
28226
# File 'lib/aws-sdk-ec2/types.rb', line 28218

class DescribeIpamsRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :ipam_ids)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters for the request. For more information about filtering, see [Filtering CLI output].

[1]: docs.aws.amazon.com/cli/latest/userguide/cli-usage-filter.html

Returns:



28218
28219
28220
28221
28222
28223
28224
28225
28226
# File 'lib/aws-sdk-ec2/types.rb', line 28218

class DescribeIpamsRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :ipam_ids)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_idsArray<String>

The IDs of the IPAMs you want information on.

Returns:

  • (Array<String>)


28218
28219
28220
28221
28222
28223
28224
28225
28226
# File 'lib/aws-sdk-ec2/types.rb', line 28218

class DescribeIpamsRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :ipam_ids)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination

Returns:

  • (Integer)


28218
28219
28220
28221
28222
28223
28224
28225
28226
# File 'lib/aws-sdk-ec2/types.rb', line 28218

class DescribeIpamsRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :ipam_ids)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


28218
28219
28220
28221
28222
28223
28224
28225
28226
# File 'lib/aws-sdk-ec2/types.rb', line 28218

class DescribeIpamsRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :ipam_ids)
  SENSITIVE = []
  include Aws::Structure
end