Class: Aws::EC2::Types::DescribeIpamsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeIpamsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters for the request.
-
#ipam_ids ⇒ Array<String>
The IDs of the IPAMs you want information on.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token for the next page of results.
Instance Attribute Details
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
27967 27968 27969 27970 27971 27972 27973 27974 27975 |
# File 'lib/aws-sdk-ec2/types.rb', line 27967 class DescribeIpamsRequest < Struct.new( :dry_run, :filters, :max_results, :next_token, :ipam_ids) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters for the request. For more information about filtering, see [Filtering CLI output].
[1]: docs.aws.amazon.com/cli/latest/userguide/cli-usage-filter.html
27967 27968 27969 27970 27971 27972 27973 27974 27975 |
# File 'lib/aws-sdk-ec2/types.rb', line 27967 class DescribeIpamsRequest < Struct.new( :dry_run, :filters, :max_results, :next_token, :ipam_ids) SENSITIVE = [] include Aws::Structure end |
#ipam_ids ⇒ Array<String>
The IDs of the IPAMs you want information on.
27967 27968 27969 27970 27971 27972 27973 27974 27975 |
# File 'lib/aws-sdk-ec2/types.rb', line 27967 class DescribeIpamsRequest < Struct.new( :dry_run, :filters, :max_results, :next_token, :ipam_ids) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination
27967 27968 27969 27970 27971 27972 27973 27974 27975 |
# File 'lib/aws-sdk-ec2/types.rb', line 27967 class DescribeIpamsRequest < Struct.new( :dry_run, :filters, :max_results, :next_token, :ipam_ids) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
27967 27968 27969 27970 27971 27972 27973 27974 27975 |
# File 'lib/aws-sdk-ec2/types.rb', line 27967 class DescribeIpamsRequest < Struct.new( :dry_run, :filters, :max_results, :next_token, :ipam_ids) SENSITIVE = [] include Aws::Structure end |