Class: Aws::EC2::Types::DescribeIpamsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


27261
27262
27263
27264
27265
27266
27267
27268
27269
# File 'lib/aws-sdk-ec2/types.rb', line 27261

class DescribeIpamsRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :ipam_ids)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters for the request. For more information about filtering, see [Filtering CLI output].

[1]: docs.aws.amazon.com/cli/latest/userguide/cli-usage-filter.html

Returns:



27261
27262
27263
27264
27265
27266
27267
27268
27269
# File 'lib/aws-sdk-ec2/types.rb', line 27261

class DescribeIpamsRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :ipam_ids)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_idsArray<String>

The IDs of the IPAMs you want information on.

Returns:

  • (Array<String>)


27261
27262
27263
27264
27265
27266
27267
27268
27269
# File 'lib/aws-sdk-ec2/types.rb', line 27261

class DescribeIpamsRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :ipam_ids)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in the request.

Returns:

  • (Integer)


27261
27262
27263
27264
27265
27266
27267
27268
27269
# File 'lib/aws-sdk-ec2/types.rb', line 27261

class DescribeIpamsRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :ipam_ids)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


27261
27262
27263
27264
27265
27266
27267
27268
27269
# File 'lib/aws-sdk-ec2/types.rb', line 27261

class DescribeIpamsRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :ipam_ids)
  SENSITIVE = []
  include Aws::Structure
end