Class: Aws::EC2::Types::DescribeLaunchTemplatesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


28239
28240
28241
28242
28243
28244
28245
28246
28247
28248
28249
# File 'lib/aws-sdk-ec2/types.rb', line 28239

class DescribeLaunchTemplatesRequest < Struct.new(
  :dry_run,
  :launch_template_ids,
  :launch_template_names,
  :filters,
  :next_token,
  :max_results,
  :include_managed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters.

  • ‘create-time` - The time the launch template was created.

  • ‘launch-template-name` - The name of the launch template.

  • ‘tag`:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key `Owner` and the value `TeamA`, specify `tag:Owner` for the filter name and `TeamA` for the filter value.

  • ‘tag-key` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.

Returns:



28239
28240
28241
28242
28243
28244
28245
28246
28247
28248
28249
# File 'lib/aws-sdk-ec2/types.rb', line 28239

class DescribeLaunchTemplatesRequest < Struct.new(
  :dry_run,
  :launch_template_ids,
  :launch_template_names,
  :filters,
  :next_token,
  :max_results,
  :include_managed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#include_managed_resourcesBoolean

Indicates whether to include managed resources in the output. If this parameter is set to ‘true`, the output includes resources that are managed by Amazon Web Services services, even if managed resource visibility is set to hidden.

Returns:

  • (Boolean)


28239
28240
28241
28242
28243
28244
28245
28246
28247
28248
28249
# File 'lib/aws-sdk-ec2/types.rb', line 28239

class DescribeLaunchTemplatesRequest < Struct.new(
  :dry_run,
  :launch_template_ids,
  :launch_template_names,
  :filters,
  :next_token,
  :max_results,
  :include_managed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#launch_template_idsArray<String>

One or more launch template IDs.

Returns:

  • (Array<String>)


28239
28240
28241
28242
28243
28244
28245
28246
28247
28248
28249
# File 'lib/aws-sdk-ec2/types.rb', line 28239

class DescribeLaunchTemplatesRequest < Struct.new(
  :dry_run,
  :launch_template_ids,
  :launch_template_names,
  :filters,
  :next_token,
  :max_results,
  :include_managed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#launch_template_namesArray<String>

One or more launch template names.

Returns:

  • (Array<String>)


28239
28240
28241
28242
28243
28244
28245
28246
28247
28248
28249
# File 'lib/aws-sdk-ec2/types.rb', line 28239

class DescribeLaunchTemplatesRequest < Struct.new(
  :dry_run,
  :launch_template_ids,
  :launch_template_names,
  :filters,
  :next_token,
  :max_results,
  :include_managed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned ‘NextToken` value. This value can be between 1 and 200.

Returns:

  • (Integer)


28239
28240
28241
28242
28243
28244
28245
28246
28247
28248
28249
# File 'lib/aws-sdk-ec2/types.rb', line 28239

class DescribeLaunchTemplatesRequest < Struct.new(
  :dry_run,
  :launch_template_ids,
  :launch_template_names,
  :filters,
  :next_token,
  :max_results,
  :include_managed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to request the next page of results.

Returns:

  • (String)


28239
28240
28241
28242
28243
28244
28245
28246
28247
28248
28249
# File 'lib/aws-sdk-ec2/types.rb', line 28239

class DescribeLaunchTemplatesRequest < Struct.new(
  :dry_run,
  :launch_template_ids,
  :launch_template_names,
  :filters,
  :next_token,
  :max_results,
  :include_managed_resources)
  SENSITIVE = []
  include Aws::Structure
end