Class: Aws::EC2::Types::DescribeLocalGatewayRouteTableVpcAssociationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


27767
27768
27769
27770
27771
27772
27773
27774
27775
# File 'lib/aws-sdk-ec2/types.rb', line 27767

class DescribeLocalGatewayRouteTableVpcAssociationsRequest < Struct.new(
  :local_gateway_route_table_vpc_association_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters.

  • ‘local-gateway-id` - The ID of a local gateway.

  • ‘local-gateway-route-table-arn` - The Amazon Resource Name (ARN) of the local gateway route table for the association.

  • ‘local-gateway-route-table-id` - The ID of the local gateway route table.

  • ‘local-gateway-route-table-vpc-association-id` - The ID of the association.

  • ‘owner-id` - The ID of the Amazon Web Services account that owns the local gateway route table for the association.

  • ‘state` - The state of the association.

  • ‘vpc-id` - The ID of the VPC.

Returns:



27767
27768
27769
27770
27771
27772
27773
27774
27775
# File 'lib/aws-sdk-ec2/types.rb', line 27767

class DescribeLocalGatewayRouteTableVpcAssociationsRequest < Struct.new(
  :local_gateway_route_table_vpc_association_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#local_gateway_route_table_vpc_association_idsArray<String>

The IDs of the associations.

Returns:

  • (Array<String>)


27767
27768
27769
27770
27771
27772
27773
27774
27775
# File 'lib/aws-sdk-ec2/types.rb', line 27767

class DescribeLocalGatewayRouteTableVpcAssociationsRequest < Struct.new(
  :local_gateway_route_table_vpc_association_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.

Returns:

  • (Integer)


27767
27768
27769
27770
27771
27772
27773
27774
27775
# File 'lib/aws-sdk-ec2/types.rb', line 27767

class DescribeLocalGatewayRouteTableVpcAssociationsRequest < Struct.new(
  :local_gateway_route_table_vpc_association_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


27767
27768
27769
27770
27771
27772
27773
27774
27775
# File 'lib/aws-sdk-ec2/types.rb', line 27767

class DescribeLocalGatewayRouteTableVpcAssociationsRequest < Struct.new(
  :local_gateway_route_table_vpc_association_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end