Class: Aws::EC2::Types::DescribeLocalGatewayRouteTablesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeLocalGatewayRouteTablesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters.
-
#local_gateway_route_table_ids ⇒ Array<String>
The IDs of the local gateway route tables.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
30053 30054 30055 30056 30057 30058 30059 30060 30061 |
# File 'lib/aws-sdk-ec2/types.rb', line 30053 class DescribeLocalGatewayRouteTablesRequest < Struct.new( :local_gateway_route_table_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters.
-
local-gateway-id- The ID of a local gateway. -
local-gateway-route-table-arn- The Amazon Resource Name (ARN) of the local gateway route table. -
local-gateway-route-table-id- The ID of a local gateway route table. -
outpost-arn- The Amazon Resource Name (ARN) of the Outpost. -
owner-id- The ID of the Amazon Web Services account that owns the local gateway route table. -
state- The state of the local gateway route table.
30053 30054 30055 30056 30057 30058 30059 30060 30061 |
# File 'lib/aws-sdk-ec2/types.rb', line 30053 class DescribeLocalGatewayRouteTablesRequest < Struct.new( :local_gateway_route_table_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#local_gateway_route_table_ids ⇒ Array<String>
The IDs of the local gateway route tables.
30053 30054 30055 30056 30057 30058 30059 30060 30061 |
# File 'lib/aws-sdk-ec2/types.rb', line 30053 class DescribeLocalGatewayRouteTablesRequest < Struct.new( :local_gateway_route_table_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To
retrieve the remaining results, make another call with the returned
nextToken value.
30053 30054 30055 30056 30057 30058 30059 30060 30061 |
# File 'lib/aws-sdk-ec2/types.rb', line 30053 class DescribeLocalGatewayRouteTablesRequest < Struct.new( :local_gateway_route_table_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
30053 30054 30055 30056 30057 30058 30059 30060 30061 |
# File 'lib/aws-sdk-ec2/types.rb', line 30053 class DescribeLocalGatewayRouteTablesRequest < Struct.new( :local_gateway_route_table_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |