Class: Aws::EC2::Types::DescribeLocalGatewayVirtualInterfaceGroupsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeLocalGatewayVirtualInterfaceGroupsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters.
-
#local_gateway_virtual_interface_group_ids ⇒ Array<String>
The IDs of the virtual interface groups.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
27897 27898 27899 27900 27901 27902 27903 27904 27905 |
# File 'lib/aws-sdk-ec2/types.rb', line 27897 class DescribeLocalGatewayVirtualInterfaceGroupsRequest < Struct.new( :local_gateway_virtual_interface_group_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters.
-
‘local-gateway-id` - The ID of a local gateway.
-
‘local-gateway-virtual-interface-group-id` - The ID of the virtual interface group.
-
‘local-gateway-virtual-interface-id` - The ID of the virtual interface.
-
‘owner-id` - The ID of the Amazon Web Services account that owns the local gateway virtual interface group.
27897 27898 27899 27900 27901 27902 27903 27904 27905 |
# File 'lib/aws-sdk-ec2/types.rb', line 27897 class DescribeLocalGatewayVirtualInterfaceGroupsRequest < Struct.new( :local_gateway_virtual_interface_group_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#local_gateway_virtual_interface_group_ids ⇒ Array<String>
The IDs of the virtual interface groups.
27897 27898 27899 27900 27901 27902 27903 27904 27905 |
# File 'lib/aws-sdk-ec2/types.rb', line 27897 class DescribeLocalGatewayVirtualInterfaceGroupsRequest < Struct.new( :local_gateway_virtual_interface_group_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.
27897 27898 27899 27900 27901 27902 27903 27904 27905 |
# File 'lib/aws-sdk-ec2/types.rb', line 27897 class DescribeLocalGatewayVirtualInterfaceGroupsRequest < Struct.new( :local_gateway_virtual_interface_group_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
27897 27898 27899 27900 27901 27902 27903 27904 27905 |
# File 'lib/aws-sdk-ec2/types.rb', line 27897 class DescribeLocalGatewayVirtualInterfaceGroupsRequest < Struct.new( :local_gateway_virtual_interface_group_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |