Class: Aws::EC2::Types::DescribeLocalGatewayVirtualInterfacesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


28598
28599
28600
28601
28602
28603
28604
28605
28606
# File 'lib/aws-sdk-ec2/types.rb', line 28598

class DescribeLocalGatewayVirtualInterfacesRequest < Struct.new(
  :local_gateway_virtual_interface_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters.

  • ‘local-address` - The local address.

  • ‘local-bgp-asn` - The Border Gateway Protocol (BGP) Autonomous System Number (ASN) of the local gateway.

  • ‘local-gateway-id` - The ID of the local gateway.

  • ‘local-gateway-virtual-interface-id` - The ID of the virtual interface.

  • ‘owner-id` - The ID of the Amazon Web Services account that owns the local gateway virtual interface.

  • ‘peer-address` - The peer address.

  • ‘peer-bgp-asn` - The peer BGP ASN.

  • ‘vlan` - The ID of the VLAN.

Returns:



28598
28599
28600
28601
28602
28603
28604
28605
28606
# File 'lib/aws-sdk-ec2/types.rb', line 28598

class DescribeLocalGatewayVirtualInterfacesRequest < Struct.new(
  :local_gateway_virtual_interface_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#local_gateway_virtual_interface_idsArray<String>

The IDs of the virtual interfaces.

Returns:

  • (Array<String>)


28598
28599
28600
28601
28602
28603
28604
28605
28606
# File 'lib/aws-sdk-ec2/types.rb', line 28598

class DescribeLocalGatewayVirtualInterfacesRequest < Struct.new(
  :local_gateway_virtual_interface_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.

Returns:

  • (Integer)


28598
28599
28600
28601
28602
28603
28604
28605
28606
# File 'lib/aws-sdk-ec2/types.rb', line 28598

class DescribeLocalGatewayVirtualInterfacesRequest < Struct.new(
  :local_gateway_virtual_interface_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


28598
28599
28600
28601
28602
28603
28604
28605
28606
# File 'lib/aws-sdk-ec2/types.rb', line 28598

class DescribeLocalGatewayVirtualInterfacesRequest < Struct.new(
  :local_gateway_virtual_interface_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end