Class: Aws::EC2::Types::DescribeLocalGatewaysRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeLocalGatewaysRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters.
-
#local_gateway_ids ⇒ Array<String>
The IDs of the local gateways.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
30619 30620 30621 30622 30623 30624 30625 30626 30627 |
# File 'lib/aws-sdk-ec2/types.rb', line 30619 class DescribeLocalGatewaysRequest < Struct.new( :local_gateway_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters.
-
local-gateway-id- The ID of a local gateway. -
outpost-arn- The Amazon Resource Name (ARN) of the Outpost. -
owner-id- The ID of the Amazon Web Services account that owns the local gateway. -
state- The state of the association.
30619 30620 30621 30622 30623 30624 30625 30626 30627 |
# File 'lib/aws-sdk-ec2/types.rb', line 30619 class DescribeLocalGatewaysRequest < Struct.new( :local_gateway_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#local_gateway_ids ⇒ Array<String>
The IDs of the local gateways.
30619 30620 30621 30622 30623 30624 30625 30626 30627 |
# File 'lib/aws-sdk-ec2/types.rb', line 30619 class DescribeLocalGatewaysRequest < Struct.new( :local_gateway_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To
retrieve the remaining results, make another call with the returned
nextToken value.
30619 30620 30621 30622 30623 30624 30625 30626 30627 |
# File 'lib/aws-sdk-ec2/types.rb', line 30619 class DescribeLocalGatewaysRequest < Struct.new( :local_gateway_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
30619 30620 30621 30622 30623 30624 30625 30626 30627 |
# File 'lib/aws-sdk-ec2/types.rb', line 30619 class DescribeLocalGatewaysRequest < Struct.new( :local_gateway_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |