Class: Aws::EC2::Types::DescribeLocalGatewaysRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


28763
28764
28765
28766
28767
28768
28769
28770
28771
# File 'lib/aws-sdk-ec2/types.rb', line 28763

class DescribeLocalGatewaysRequest < Struct.new(
  :local_gateway_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters.

  • ‘local-gateway-id` - The ID of a local gateway.

  • ‘outpost-arn` - The Amazon Resource Name (ARN) of the Outpost.

  • ‘owner-id` - The ID of the Amazon Web Services account that owns the local gateway.

  • ‘state` - The state of the association.

Returns:



28763
28764
28765
28766
28767
28768
28769
28770
28771
# File 'lib/aws-sdk-ec2/types.rb', line 28763

class DescribeLocalGatewaysRequest < Struct.new(
  :local_gateway_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#local_gateway_idsArray<String>

The IDs of the local gateways.

Returns:

  • (Array<String>)


28763
28764
28765
28766
28767
28768
28769
28770
28771
# File 'lib/aws-sdk-ec2/types.rb', line 28763

class DescribeLocalGatewaysRequest < Struct.new(
  :local_gateway_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.

Returns:

  • (Integer)


28763
28764
28765
28766
28767
28768
28769
28770
28771
# File 'lib/aws-sdk-ec2/types.rb', line 28763

class DescribeLocalGatewaysRequest < Struct.new(
  :local_gateway_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


28763
28764
28765
28766
28767
28768
28769
28770
28771
# File 'lib/aws-sdk-ec2/types.rb', line 28763

class DescribeLocalGatewaysRequest < Struct.new(
  :local_gateway_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end