Class: Aws::EC2::Types::DescribeLockedSnapshotsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


30324
30325
30326
30327
30328
30329
30330
30331
30332
# File 'lib/aws-sdk-ec2/types.rb', line 30324

class DescribeLockedSnapshotsRequest < Struct.new(
  :filters,
  :max_results,
  :next_token,
  :snapshot_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters.

  • lock-state - The state of the snapshot lock (compliance-cooloff | governance | compliance | expired).

^

Returns:



30324
30325
30326
30327
30328
30329
30330
30331
30332
# File 'lib/aws-sdk-ec2/types.rb', line 30324

class DescribeLockedSnapshotsRequest < Struct.new(
  :filters,
  :max_results,
  :next_token,
  :snapshot_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.

Returns:

  • (Integer)


30324
30325
30326
30327
30328
30329
30330
30331
30332
# File 'lib/aws-sdk-ec2/types.rb', line 30324

class DescribeLockedSnapshotsRequest < Struct.new(
  :filters,
  :max_results,
  :next_token,
  :snapshot_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Returns:

  • (String)


30324
30325
30326
30327
30328
30329
30330
30331
30332
# File 'lib/aws-sdk-ec2/types.rb', line 30324

class DescribeLockedSnapshotsRequest < Struct.new(
  :filters,
  :max_results,
  :next_token,
  :snapshot_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_idsArray<String>

The IDs of the snapshots for which to view the lock status.

Returns:

  • (Array<String>)


30324
30325
30326
30327
30328
30329
30330
30331
30332
# File 'lib/aws-sdk-ec2/types.rb', line 30324

class DescribeLockedSnapshotsRequest < Struct.new(
  :filters,
  :max_results,
  :next_token,
  :snapshot_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end