Class: Aws::EC2::Types::DescribeLockedSnapshotsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeLockedSnapshotsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The filters.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token returned from a previous paginated request.
-
#snapshot_ids ⇒ Array<String>
The IDs of the snapshots for which to view the lock status.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
28736 28737 28738 28739 28740 28741 28742 28743 28744 |
# File 'lib/aws-sdk-ec2/types.rb', line 28736 class DescribeLockedSnapshotsRequest < Struct.new( :filters, :max_results, :next_token, :snapshot_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters.
-
‘lock-state` - The state of the snapshot lock (`compliance-cooloff` | `governance` | `compliance` | `expired`).
^
28736 28737 28738 28739 28740 28741 28742 28743 28744 |
# File 'lib/aws-sdk-ec2/types.rb', line 28736 class DescribeLockedSnapshotsRequest < Struct.new( :filters, :max_results, :next_token, :snapshot_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination
28736 28737 28738 28739 28740 28741 28742 28743 28744 |
# File 'lib/aws-sdk-ec2/types.rb', line 28736 class DescribeLockedSnapshotsRequest < Struct.new( :filters, :max_results, :next_token, :snapshot_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
28736 28737 28738 28739 28740 28741 28742 28743 28744 |
# File 'lib/aws-sdk-ec2/types.rb', line 28736 class DescribeLockedSnapshotsRequest < Struct.new( :filters, :max_results, :next_token, :snapshot_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#snapshot_ids ⇒ Array<String>
The IDs of the snapshots for which to view the lock status.
28736 28737 28738 28739 28740 28741 28742 28743 28744 |
# File 'lib/aws-sdk-ec2/types.rb', line 28736 class DescribeLockedSnapshotsRequest < Struct.new( :filters, :max_results, :next_token, :snapshot_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |