Class: Aws::EC2::Types::DescribeLockedSnapshotsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeLockedSnapshotsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#snapshots ⇒ Array<Types::LockedSnapshotsInfo>
Information about the snapshots.
Instance Attribute Details
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
29361 29362 29363 29364 29365 29366 |
# File 'lib/aws-sdk-ec2/types.rb', line 29361 class DescribeLockedSnapshotsResult < Struct.new( :snapshots, :next_token) SENSITIVE = [] include Aws::Structure end |
#snapshots ⇒ Array<Types::LockedSnapshotsInfo>
Information about the snapshots.
29361 29362 29363 29364 29365 29366 |
# File 'lib/aws-sdk-ec2/types.rb', line 29361 class DescribeLockedSnapshotsResult < Struct.new( :snapshots, :next_token) SENSITIVE = [] include Aws::Structure end |