Class: Aws::EC2::Types::DescribeMacModificationTasksRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


29440
29441
29442
29443
29444
29445
29446
29447
29448
# File 'lib/aws-sdk-ec2/types.rb', line 29440

class DescribeMacModificationTasksRequest < Struct.new(
  :dry_run,
  :filters,
  :mac_modification_task_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

Specifies one or more filters for the request:

  • instance-id - The ID of the instance for which the task was created.

  • task-state - The state of the task (successful | failed | in-progress | pending).

  • mac-system-integrity-protection-configuration.sip-status - The overall SIP state requested in the task (enabled | disabled).

  • start-time - The date and time the task was created.

  • task-type - The type of task (sip-modification | volume-ownership-delegation).

Returns:



29440
29441
29442
29443
29444
29445
29446
29447
29448
# File 'lib/aws-sdk-ec2/types.rb', line 29440

class DescribeMacModificationTasksRequest < Struct.new(
  :dry_run,
  :filters,
  :mac_modification_task_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#mac_modification_task_idsArray<String>

The ID of task.

Returns:

  • (Array<String>)


29440
29441
29442
29443
29444
29445
29446
29447
29448
# File 'lib/aws-sdk-ec2/types.rb', line 29440

class DescribeMacModificationTasksRequest < Struct.new(
  :dry_run,
  :filters,
  :mac_modification_task_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the returned nextToken value. This value can be between 5 and 500. If maxResults is given a larger value than 500, you receive an error.

Returns:

  • (Integer)


29440
29441
29442
29443
29444
29445
29446
29447
29448
# File 'lib/aws-sdk-ec2/types.rb', line 29440

class DescribeMacModificationTasksRequest < Struct.new(
  :dry_run,
  :filters,
  :mac_modification_task_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to use to retrieve the next page of results.

Returns:

  • (String)


29440
29441
29442
29443
29444
29445
29446
29447
29448
# File 'lib/aws-sdk-ec2/types.rb', line 29440

class DescribeMacModificationTasksRequest < Struct.new(
  :dry_run,
  :filters,
  :mac_modification_task_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end