Class: Aws::EC2::Types::DescribeMacModificationTasksRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeMacModificationTasksRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
Specifies one or more filters for the request:.
-
#mac_modification_task_ids ⇒ Array<String>
The ID of task.
-
#max_results ⇒ Integer
The maximum number of results to return for the request in a single page.
-
#next_token ⇒ String
The token to use to retrieve the next page of results.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
29255 29256 29257 29258 29259 29260 29261 29262 29263 |
# File 'lib/aws-sdk-ec2/types.rb', line 29255 class DescribeMacModificationTasksRequest < Struct.new( :dry_run, :filters, :mac_modification_task_ids, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
Specifies one or more filters for the request:
-
‘instance-id` - The ID of the instance for which the task was created.
-
‘task-state` - The state of the task (`successful` | `failed` | `in-progress` | `pending`).
-
‘mac-system-integrity-protection-configuration.sip-status` - The overall SIP state requested in the task (`enabled` | `disabled`).
-
‘start-time` - The date and time the task was created.
-
‘task-type` - The type of task (`sip-modification` | `volume-ownership-delegation`).
29255 29256 29257 29258 29259 29260 29261 29262 29263 |
# File 'lib/aws-sdk-ec2/types.rb', line 29255 class DescribeMacModificationTasksRequest < Struct.new( :dry_run, :filters, :mac_modification_task_ids, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#mac_modification_task_ids ⇒ Array<String>
The ID of task.
29255 29256 29257 29258 29259 29260 29261 29262 29263 |
# File 'lib/aws-sdk-ec2/types.rb', line 29255 class DescribeMacModificationTasksRequest < Struct.new( :dry_run, :filters, :mac_modification_task_ids, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the returned ‘nextToken` value. This value can be between 5 and
-
If ‘maxResults` is given a larger value than 500, you receive
an error.
29255 29256 29257 29258 29259 29260 29261 29262 29263 |
# File 'lib/aws-sdk-ec2/types.rb', line 29255 class DescribeMacModificationTasksRequest < Struct.new( :dry_run, :filters, :mac_modification_task_ids, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to retrieve the next page of results.
29255 29256 29257 29258 29259 29260 29261 29262 29263 |
# File 'lib/aws-sdk-ec2/types.rb', line 29255 class DescribeMacModificationTasksRequest < Struct.new( :dry_run, :filters, :mac_modification_task_ids, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |