Class: Aws::EC2::Types::DescribeMovingAddressesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


29331
29332
29333
29334
29335
29336
29337
29338
29339
# File 'lib/aws-sdk-ec2/types.rb', line 29331

class DescribeMovingAddressesRequest < Struct.new(
  :dry_run,
  :public_ips,
  :next_token,
  :filters,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters.

  • ‘moving-status` - The status of the Elastic IP address (`MovingToVpc` | `RestoringToClassic`).

^

Returns:



29331
29332
29333
29334
29335
29336
29337
29338
29339
# File 'lib/aws-sdk-ec2/types.rb', line 29331

class DescribeMovingAddressesRequest < Struct.new(
  :dry_run,
  :public_ips,
  :next_token,
  :filters,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return for the request in a single page. The remaining results of the initial request can be seen by sending another request with the returned ‘NextToken` value. This value can be between 5 and 1000; if `MaxResults` is given a value outside of this range, an error is returned.

Default: If no value is provided, the default is 1000.

Returns:

  • (Integer)


29331
29332
29333
29334
29335
29336
29337
29338
29339
# File 'lib/aws-sdk-ec2/types.rb', line 29331

class DescribeMovingAddressesRequest < Struct.new(
  :dry_run,
  :public_ips,
  :next_token,
  :filters,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


29331
29332
29333
29334
29335
29336
29337
29338
29339
# File 'lib/aws-sdk-ec2/types.rb', line 29331

class DescribeMovingAddressesRequest < Struct.new(
  :dry_run,
  :public_ips,
  :next_token,
  :filters,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#public_ipsArray<String>

One or more Elastic IP addresses.

Returns:

  • (Array<String>)


29331
29332
29333
29334
29335
29336
29337
29338
29339
# File 'lib/aws-sdk-ec2/types.rb', line 29331

class DescribeMovingAddressesRequest < Struct.new(
  :dry_run,
  :public_ips,
  :next_token,
  :filters,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end