Class: Aws::EC2::Types::DescribeMovingAddressesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeMovingAddressesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters.
-
#max_results ⇒ Integer
The maximum number of results to return for the request in a single page.
-
#next_token ⇒ String
The token for the next page of results.
-
#public_ips ⇒ Array<String>
One or more Elastic IP addresses.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
29331 29332 29333 29334 29335 29336 29337 29338 29339 |
# File 'lib/aws-sdk-ec2/types.rb', line 29331 class DescribeMovingAddressesRequest < Struct.new( :dry_run, :public_ips, :next_token, :filters, :max_results) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters.
-
‘moving-status` - The status of the Elastic IP address (`MovingToVpc` | `RestoringToClassic`).
^
29331 29332 29333 29334 29335 29336 29337 29338 29339 |
# File 'lib/aws-sdk-ec2/types.rb', line 29331 class DescribeMovingAddressesRequest < Struct.new( :dry_run, :public_ips, :next_token, :filters, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return for the request in a single page. The remaining results of the initial request can be seen by sending another request with the returned ‘NextToken` value. This value can be between 5 and 1000; if `MaxResults` is given a value outside of this range, an error is returned.
Default: If no value is provided, the default is 1000.
29331 29332 29333 29334 29335 29336 29337 29338 29339 |
# File 'lib/aws-sdk-ec2/types.rb', line 29331 class DescribeMovingAddressesRequest < Struct.new( :dry_run, :public_ips, :next_token, :filters, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
29331 29332 29333 29334 29335 29336 29337 29338 29339 |
# File 'lib/aws-sdk-ec2/types.rb', line 29331 class DescribeMovingAddressesRequest < Struct.new( :dry_run, :public_ips, :next_token, :filters, :max_results) SENSITIVE = [] include Aws::Structure end |
#public_ips ⇒ Array<String>
One or more Elastic IP addresses.
29331 29332 29333 29334 29335 29336 29337 29338 29339 |
# File 'lib/aws-sdk-ec2/types.rb', line 29331 class DescribeMovingAddressesRequest < Struct.new( :dry_run, :public_ips, :next_token, :filters, :max_results) SENSITIVE = [] include Aws::Structure end |