Class: Aws::EC2::Types::DescribeNatGatewaysResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeNatGatewaysResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#nat_gateways ⇒ Array<Types::NatGateway>
Information about the NAT gateways.
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
Instance Attribute Details
#nat_gateways ⇒ Array<Types::NatGateway>
Information about the NAT gateways.
31038 31039 31040 31041 31042 31043 |
# File 'lib/aws-sdk-ec2/types.rb', line 31038 class DescribeNatGatewaysResult < Struct.new( :nat_gateways, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
31038 31039 31040 31041 31042 31043 |
# File 'lib/aws-sdk-ec2/types.rb', line 31038 class DescribeNatGatewaysResult < Struct.new( :nat_gateways, :next_token) SENSITIVE = [] include Aws::Structure end |