Class: Aws::EC2::Types::DescribeNetworkAclsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeNetworkAclsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#network_acls ⇒ Array<Types::NetworkAcl>
Information about the network ACLs.
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
Instance Attribute Details
#network_acls ⇒ Array<Types::NetworkAcl>
Information about the network ACLs.
29742 29743 29744 29745 29746 29747 |
# File 'lib/aws-sdk-ec2/types.rb', line 29742 class DescribeNetworkAclsResult < Struct.new( :network_acls, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
29742 29743 29744 29745 29746 29747 |
# File 'lib/aws-sdk-ec2/types.rb', line 29742 class DescribeNetworkAclsResult < Struct.new( :network_acls, :next_token) SENSITIVE = [] include Aws::Structure end |