Class: Aws::EC2::Types::DescribeNetworkInsightsAccessScopeAnalysesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#analysis_start_time_beginTime

Filters the results based on the start time. The analysis must have started on or after this time.

Returns:

  • (Time)


31202
31203
31204
31205
31206
31207
31208
31209
31210
31211
31212
31213
# File 'lib/aws-sdk-ec2/types.rb', line 31202

class DescribeNetworkInsightsAccessScopeAnalysesRequest < Struct.new(
  :network_insights_access_scope_analysis_ids,
  :network_insights_access_scope_id,
  :analysis_start_time_begin,
  :analysis_start_time_end,
  :filters,
  :max_results,
  :dry_run,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#analysis_start_time_endTime

Filters the results based on the start time. The analysis must have started on or before this time.

Returns:

  • (Time)


31202
31203
31204
31205
31206
31207
31208
31209
31210
31211
31212
31213
# File 'lib/aws-sdk-ec2/types.rb', line 31202

class DescribeNetworkInsightsAccessScopeAnalysesRequest < Struct.new(
  :network_insights_access_scope_analysis_ids,
  :network_insights_access_scope_id,
  :analysis_start_time_begin,
  :analysis_start_time_end,
  :filters,
  :max_results,
  :dry_run,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


31202
31203
31204
31205
31206
31207
31208
31209
31210
31211
31212
31213
# File 'lib/aws-sdk-ec2/types.rb', line 31202

class DescribeNetworkInsightsAccessScopeAnalysesRequest < Struct.new(
  :network_insights_access_scope_analysis_ids,
  :network_insights_access_scope_id,
  :analysis_start_time_begin,
  :analysis_start_time_end,
  :filters,
  :max_results,
  :dry_run,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

There are no supported filters.

Returns:



31202
31203
31204
31205
31206
31207
31208
31209
31210
31211
31212
31213
# File 'lib/aws-sdk-ec2/types.rb', line 31202

class DescribeNetworkInsightsAccessScopeAnalysesRequest < Struct.new(
  :network_insights_access_scope_analysis_ids,
  :network_insights_access_scope_id,
  :analysis_start_time_begin,
  :analysis_start_time_end,
  :filters,
  :max_results,
  :dry_run,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.

Returns:

  • (Integer)


31202
31203
31204
31205
31206
31207
31208
31209
31210
31211
31212
31213
# File 'lib/aws-sdk-ec2/types.rb', line 31202

class DescribeNetworkInsightsAccessScopeAnalysesRequest < Struct.new(
  :network_insights_access_scope_analysis_ids,
  :network_insights_access_scope_id,
  :analysis_start_time_begin,
  :analysis_start_time_end,
  :filters,
  :max_results,
  :dry_run,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#network_insights_access_scope_analysis_idsArray<String>

The IDs of the Network Access Scope analyses.

Returns:

  • (Array<String>)


31202
31203
31204
31205
31206
31207
31208
31209
31210
31211
31212
31213
# File 'lib/aws-sdk-ec2/types.rb', line 31202

class DescribeNetworkInsightsAccessScopeAnalysesRequest < Struct.new(
  :network_insights_access_scope_analysis_ids,
  :network_insights_access_scope_id,
  :analysis_start_time_begin,
  :analysis_start_time_end,
  :filters,
  :max_results,
  :dry_run,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#network_insights_access_scope_idString

The ID of the Network Access Scope.

Returns:

  • (String)


31202
31203
31204
31205
31206
31207
31208
31209
31210
31211
31212
31213
# File 'lib/aws-sdk-ec2/types.rb', line 31202

class DescribeNetworkInsightsAccessScopeAnalysesRequest < Struct.new(
  :network_insights_access_scope_analysis_ids,
  :network_insights_access_scope_id,
  :analysis_start_time_begin,
  :analysis_start_time_end,
  :filters,
  :max_results,
  :dry_run,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


31202
31203
31204
31205
31206
31207
31208
31209
31210
31211
31212
31213
# File 'lib/aws-sdk-ec2/types.rb', line 31202

class DescribeNetworkInsightsAccessScopeAnalysesRequest < Struct.new(
  :network_insights_access_scope_analysis_ids,
  :network_insights_access_scope_id,
  :analysis_start_time_begin,
  :analysis_start_time_end,
  :filters,
  :max_results,
  :dry_run,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end