Class: Aws::EC2::Types::DescribeNetworkInsightsAccessScopeAnalysesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeNetworkInsightsAccessScopeAnalysesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analysis_start_time_begin ⇒ Time
Filters the results based on the start time.
-
#analysis_start_time_end ⇒ Time
Filters the results based on the start time.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
There are no supported filters.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#network_insights_access_scope_analysis_ids ⇒ Array<String>
The IDs of the Network Access Scope analyses.
-
#network_insights_access_scope_id ⇒ String
The ID of the Network Access Scope.
-
#next_token ⇒ String
The token for the next page of results.
Instance Attribute Details
#analysis_start_time_begin ⇒ Time
Filters the results based on the start time. The analysis must have started on or after this time.
28618 28619 28620 28621 28622 28623 28624 28625 28626 28627 28628 28629 |
# File 'lib/aws-sdk-ec2/types.rb', line 28618 class DescribeNetworkInsightsAccessScopeAnalysesRequest < Struct.new( :network_insights_access_scope_analysis_ids, :network_insights_access_scope_id, :analysis_start_time_begin, :analysis_start_time_end, :filters, :max_results, :dry_run, :next_token) SENSITIVE = [] include Aws::Structure end |
#analysis_start_time_end ⇒ Time
Filters the results based on the start time. The analysis must have started on or before this time.
28618 28619 28620 28621 28622 28623 28624 28625 28626 28627 28628 28629 |
# File 'lib/aws-sdk-ec2/types.rb', line 28618 class DescribeNetworkInsightsAccessScopeAnalysesRequest < Struct.new( :network_insights_access_scope_analysis_ids, :network_insights_access_scope_id, :analysis_start_time_begin, :analysis_start_time_end, :filters, :max_results, :dry_run, :next_token) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
28618 28619 28620 28621 28622 28623 28624 28625 28626 28627 28628 28629 |
# File 'lib/aws-sdk-ec2/types.rb', line 28618 class DescribeNetworkInsightsAccessScopeAnalysesRequest < Struct.new( :network_insights_access_scope_analysis_ids, :network_insights_access_scope_id, :analysis_start_time_begin, :analysis_start_time_end, :filters, :max_results, :dry_run, :next_token) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
There are no supported filters.
28618 28619 28620 28621 28622 28623 28624 28625 28626 28627 28628 28629 |
# File 'lib/aws-sdk-ec2/types.rb', line 28618 class DescribeNetworkInsightsAccessScopeAnalysesRequest < Struct.new( :network_insights_access_scope_analysis_ids, :network_insights_access_scope_id, :analysis_start_time_begin, :analysis_start_time_end, :filters, :max_results, :dry_run, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.
28618 28619 28620 28621 28622 28623 28624 28625 28626 28627 28628 28629 |
# File 'lib/aws-sdk-ec2/types.rb', line 28618 class DescribeNetworkInsightsAccessScopeAnalysesRequest < Struct.new( :network_insights_access_scope_analysis_ids, :network_insights_access_scope_id, :analysis_start_time_begin, :analysis_start_time_end, :filters, :max_results, :dry_run, :next_token) SENSITIVE = [] include Aws::Structure end |
#network_insights_access_scope_analysis_ids ⇒ Array<String>
The IDs of the Network Access Scope analyses.
28618 28619 28620 28621 28622 28623 28624 28625 28626 28627 28628 28629 |
# File 'lib/aws-sdk-ec2/types.rb', line 28618 class DescribeNetworkInsightsAccessScopeAnalysesRequest < Struct.new( :network_insights_access_scope_analysis_ids, :network_insights_access_scope_id, :analysis_start_time_begin, :analysis_start_time_end, :filters, :max_results, :dry_run, :next_token) SENSITIVE = [] include Aws::Structure end |
#network_insights_access_scope_id ⇒ String
The ID of the Network Access Scope.
28618 28619 28620 28621 28622 28623 28624 28625 28626 28627 28628 28629 |
# File 'lib/aws-sdk-ec2/types.rb', line 28618 class DescribeNetworkInsightsAccessScopeAnalysesRequest < Struct.new( :network_insights_access_scope_analysis_ids, :network_insights_access_scope_id, :analysis_start_time_begin, :analysis_start_time_end, :filters, :max_results, :dry_run, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
28618 28619 28620 28621 28622 28623 28624 28625 28626 28627 28628 28629 |
# File 'lib/aws-sdk-ec2/types.rb', line 28618 class DescribeNetworkInsightsAccessScopeAnalysesRequest < Struct.new( :network_insights_access_scope_analysis_ids, :network_insights_access_scope_id, :analysis_start_time_begin, :analysis_start_time_end, :filters, :max_results, :dry_run, :next_token) SENSITIVE = [] include Aws::Structure end |