Class: Aws::EC2::Types::DescribeNetworkInsightsAccessScopesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


29848
29849
29850
29851
29852
29853
29854
29855
29856
# File 'lib/aws-sdk-ec2/types.rb', line 29848

class DescribeNetworkInsightsAccessScopesRequest < Struct.new(
  :network_insights_access_scope_ids,
  :filters,
  :max_results,
  :dry_run,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

There are no supported filters.

Returns:



29848
29849
29850
29851
29852
29853
29854
29855
29856
# File 'lib/aws-sdk-ec2/types.rb', line 29848

class DescribeNetworkInsightsAccessScopesRequest < Struct.new(
  :network_insights_access_scope_ids,
  :filters,
  :max_results,
  :dry_run,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.

Returns:

  • (Integer)


29848
29849
29850
29851
29852
29853
29854
29855
29856
# File 'lib/aws-sdk-ec2/types.rb', line 29848

class DescribeNetworkInsightsAccessScopesRequest < Struct.new(
  :network_insights_access_scope_ids,
  :filters,
  :max_results,
  :dry_run,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#network_insights_access_scope_idsArray<String>

The IDs of the Network Access Scopes.

Returns:

  • (Array<String>)


29848
29849
29850
29851
29852
29853
29854
29855
29856
# File 'lib/aws-sdk-ec2/types.rb', line 29848

class DescribeNetworkInsightsAccessScopesRequest < Struct.new(
  :network_insights_access_scope_ids,
  :filters,
  :max_results,
  :dry_run,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


29848
29849
29850
29851
29852
29853
29854
29855
29856
# File 'lib/aws-sdk-ec2/types.rb', line 29848

class DescribeNetworkInsightsAccessScopesRequest < Struct.new(
  :network_insights_access_scope_ids,
  :filters,
  :max_results,
  :dry_run,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end