Class: Aws::EC2::Types::DescribeNetworkInsightsAccessScopesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeNetworkInsightsAccessScopesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
There are no supported filters.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#network_insights_access_scope_ids ⇒ Array<String>
The IDs of the Network Access Scopes.
-
#next_token ⇒ String
The token for the next page of results.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
28682 28683 28684 28685 28686 28687 28688 28689 28690 |
# File 'lib/aws-sdk-ec2/types.rb', line 28682 class DescribeNetworkInsightsAccessScopesRequest < Struct.new( :network_insights_access_scope_ids, :filters, :max_results, :dry_run, :next_token) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
There are no supported filters.
28682 28683 28684 28685 28686 28687 28688 28689 28690 |
# File 'lib/aws-sdk-ec2/types.rb', line 28682 class DescribeNetworkInsightsAccessScopesRequest < Struct.new( :network_insights_access_scope_ids, :filters, :max_results, :dry_run, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.
28682 28683 28684 28685 28686 28687 28688 28689 28690 |
# File 'lib/aws-sdk-ec2/types.rb', line 28682 class DescribeNetworkInsightsAccessScopesRequest < Struct.new( :network_insights_access_scope_ids, :filters, :max_results, :dry_run, :next_token) SENSITIVE = [] include Aws::Structure end |
#network_insights_access_scope_ids ⇒ Array<String>
The IDs of the Network Access Scopes.
28682 28683 28684 28685 28686 28687 28688 28689 28690 |
# File 'lib/aws-sdk-ec2/types.rb', line 28682 class DescribeNetworkInsightsAccessScopesRequest < Struct.new( :network_insights_access_scope_ids, :filters, :max_results, :dry_run, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
28682 28683 28684 28685 28686 28687 28688 28689 28690 |
# File 'lib/aws-sdk-ec2/types.rb', line 28682 class DescribeNetworkInsightsAccessScopesRequest < Struct.new( :network_insights_access_scope_ids, :filters, :max_results, :dry_run, :next_token) SENSITIVE = [] include Aws::Structure end |