Class: Aws::EC2::Types::DescribeNetworkInsightsAnalysesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#analysis_end_timeTime

The time when the network insights analyses ended.

Returns:

  • (Time)


29346
29347
29348
29349
29350
29351
29352
29353
29354
29355
29356
29357
# File 'lib/aws-sdk-ec2/types.rb', line 29346

class DescribeNetworkInsightsAnalysesRequest < Struct.new(
  :network_insights_analysis_ids,
  :network_insights_path_id,
  :analysis_start_time,
  :analysis_end_time,
  :filters,
  :max_results,
  :dry_run,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#analysis_start_timeTime

The time when the network insights analyses started.

Returns:

  • (Time)


29346
29347
29348
29349
29350
29351
29352
29353
29354
29355
29356
29357
# File 'lib/aws-sdk-ec2/types.rb', line 29346

class DescribeNetworkInsightsAnalysesRequest < Struct.new(
  :network_insights_analysis_ids,
  :network_insights_path_id,
  :analysis_start_time,
  :analysis_end_time,
  :filters,
  :max_results,
  :dry_run,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


29346
29347
29348
29349
29350
29351
29352
29353
29354
29355
29356
29357
# File 'lib/aws-sdk-ec2/types.rb', line 29346

class DescribeNetworkInsightsAnalysesRequest < Struct.new(
  :network_insights_analysis_ids,
  :network_insights_path_id,
  :analysis_start_time,
  :analysis_end_time,
  :filters,
  :max_results,
  :dry_run,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters. The following are the possible values:

  • path-found - A Boolean value that indicates whether a feasible path is found.

  • status - The status of the analysis (running | succeeded | failed).

Returns:



29346
29347
29348
29349
29350
29351
29352
29353
29354
29355
29356
29357
# File 'lib/aws-sdk-ec2/types.rb', line 29346

class DescribeNetworkInsightsAnalysesRequest < Struct.new(
  :network_insights_analysis_ids,
  :network_insights_path_id,
  :analysis_start_time,
  :analysis_end_time,
  :filters,
  :max_results,
  :dry_run,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.

Returns:

  • (Integer)


29346
29347
29348
29349
29350
29351
29352
29353
29354
29355
29356
29357
# File 'lib/aws-sdk-ec2/types.rb', line 29346

class DescribeNetworkInsightsAnalysesRequest < Struct.new(
  :network_insights_analysis_ids,
  :network_insights_path_id,
  :analysis_start_time,
  :analysis_end_time,
  :filters,
  :max_results,
  :dry_run,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#network_insights_analysis_idsArray<String>

The ID of the network insights analyses. You must specify either analysis IDs or a path ID.

Returns:

  • (Array<String>)


29346
29347
29348
29349
29350
29351
29352
29353
29354
29355
29356
29357
# File 'lib/aws-sdk-ec2/types.rb', line 29346

class DescribeNetworkInsightsAnalysesRequest < Struct.new(
  :network_insights_analysis_ids,
  :network_insights_path_id,
  :analysis_start_time,
  :analysis_end_time,
  :filters,
  :max_results,
  :dry_run,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#network_insights_path_idString

The ID of the path. You must specify either a path ID or analysis IDs.

Returns:

  • (String)


29346
29347
29348
29349
29350
29351
29352
29353
29354
29355
29356
29357
# File 'lib/aws-sdk-ec2/types.rb', line 29346

class DescribeNetworkInsightsAnalysesRequest < Struct.new(
  :network_insights_analysis_ids,
  :network_insights_path_id,
  :analysis_start_time,
  :analysis_end_time,
  :filters,
  :max_results,
  :dry_run,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


29346
29347
29348
29349
29350
29351
29352
29353
29354
29355
29356
29357
# File 'lib/aws-sdk-ec2/types.rb', line 29346

class DescribeNetworkInsightsAnalysesRequest < Struct.new(
  :network_insights_analysis_ids,
  :network_insights_path_id,
  :analysis_start_time,
  :analysis_end_time,
  :filters,
  :max_results,
  :dry_run,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end