Class: Aws::EC2::Types::DescribeNetworkInsightsAnalysesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeNetworkInsightsAnalysesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analysis_end_time ⇒ Time
The time when the network insights analyses ended.
-
#analysis_start_time ⇒ Time
The time when the network insights analyses started.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The filters.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#network_insights_analysis_ids ⇒ Array<String>
The ID of the network insights analyses.
-
#network_insights_path_id ⇒ String
The ID of the path.
-
#next_token ⇒ String
The token for the next page of results.
Instance Attribute Details
#analysis_end_time ⇒ Time
The time when the network insights analyses ended.
28751 28752 28753 28754 28755 28756 28757 28758 28759 28760 28761 28762 |
# File 'lib/aws-sdk-ec2/types.rb', line 28751 class DescribeNetworkInsightsAnalysesRequest < Struct.new( :network_insights_analysis_ids, :network_insights_path_id, :analysis_start_time, :analysis_end_time, :filters, :max_results, :dry_run, :next_token) SENSITIVE = [] include Aws::Structure end |
#analysis_start_time ⇒ Time
The time when the network insights analyses started.
28751 28752 28753 28754 28755 28756 28757 28758 28759 28760 28761 28762 |
# File 'lib/aws-sdk-ec2/types.rb', line 28751 class DescribeNetworkInsightsAnalysesRequest < Struct.new( :network_insights_analysis_ids, :network_insights_path_id, :analysis_start_time, :analysis_end_time, :filters, :max_results, :dry_run, :next_token) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
28751 28752 28753 28754 28755 28756 28757 28758 28759 28760 28761 28762 |
# File 'lib/aws-sdk-ec2/types.rb', line 28751 class DescribeNetworkInsightsAnalysesRequest < Struct.new( :network_insights_analysis_ids, :network_insights_path_id, :analysis_start_time, :analysis_end_time, :filters, :max_results, :dry_run, :next_token) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters. The following are the possible values:
-
path-found - A Boolean value that indicates whether a feasible path is found.
-
status - The status of the analysis (running | succeeded | failed).
28751 28752 28753 28754 28755 28756 28757 28758 28759 28760 28761 28762 |
# File 'lib/aws-sdk-ec2/types.rb', line 28751 class DescribeNetworkInsightsAnalysesRequest < Struct.new( :network_insights_analysis_ids, :network_insights_path_id, :analysis_start_time, :analysis_end_time, :filters, :max_results, :dry_run, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.
28751 28752 28753 28754 28755 28756 28757 28758 28759 28760 28761 28762 |
# File 'lib/aws-sdk-ec2/types.rb', line 28751 class DescribeNetworkInsightsAnalysesRequest < Struct.new( :network_insights_analysis_ids, :network_insights_path_id, :analysis_start_time, :analysis_end_time, :filters, :max_results, :dry_run, :next_token) SENSITIVE = [] include Aws::Structure end |
#network_insights_analysis_ids ⇒ Array<String>
The ID of the network insights analyses. You must specify either analysis IDs or a path ID.
28751 28752 28753 28754 28755 28756 28757 28758 28759 28760 28761 28762 |
# File 'lib/aws-sdk-ec2/types.rb', line 28751 class DescribeNetworkInsightsAnalysesRequest < Struct.new( :network_insights_analysis_ids, :network_insights_path_id, :analysis_start_time, :analysis_end_time, :filters, :max_results, :dry_run, :next_token) SENSITIVE = [] include Aws::Structure end |
#network_insights_path_id ⇒ String
The ID of the path. You must specify either a path ID or analysis IDs.
28751 28752 28753 28754 28755 28756 28757 28758 28759 28760 28761 28762 |
# File 'lib/aws-sdk-ec2/types.rb', line 28751 class DescribeNetworkInsightsAnalysesRequest < Struct.new( :network_insights_analysis_ids, :network_insights_path_id, :analysis_start_time, :analysis_end_time, :filters, :max_results, :dry_run, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
28751 28752 28753 28754 28755 28756 28757 28758 28759 28760 28761 28762 |
# File 'lib/aws-sdk-ec2/types.rb', line 28751 class DescribeNetworkInsightsAnalysesRequest < Struct.new( :network_insights_analysis_ids, :network_insights_path_id, :analysis_start_time, :analysis_end_time, :filters, :max_results, :dry_run, :next_token) SENSITIVE = [] include Aws::Structure end |