Class: Aws::EC2::Types::DescribeNetworkInsightsPathsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeNetworkInsightsPathsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The filters.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#network_insights_path_ids ⇒ Array<String>
The IDs of the paths.
-
#next_token ⇒ String
The token for the next page of results.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
29181 29182 29183 29184 29185 29186 29187 29188 29189 |
# File 'lib/aws-sdk-ec2/types.rb', line 29181 class DescribeNetworkInsightsPathsRequest < Struct.new( :network_insights_path_ids, :filters, :max_results, :dry_run, :next_token) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters. The following are the possible values:
-
destination - The ID of the resource.
-
filter-at-source.source-address - The source IPv4 address at the source.
-
filter-at-source.source-port-range - The source port range at the source.
-
filter-at-source.destination-address - The destination IPv4 address at the source.
-
filter-at-source.destination-port-range - The destination port range at the source.
-
filter-at-destination.source-address - The source IPv4 address at the destination.
-
filter-at-destination.source-port-range - The source port range at the destination.
-
filter-at-destination.destination-address - The destination IPv4 address at the destination.
-
filter-at-destination.destination-port-range - The destination port range at the destination.
-
protocol - The protocol.
-
source - The ID of the resource.
29181 29182 29183 29184 29185 29186 29187 29188 29189 |
# File 'lib/aws-sdk-ec2/types.rb', line 29181 class DescribeNetworkInsightsPathsRequest < Struct.new( :network_insights_path_ids, :filters, :max_results, :dry_run, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.
29181 29182 29183 29184 29185 29186 29187 29188 29189 |
# File 'lib/aws-sdk-ec2/types.rb', line 29181 class DescribeNetworkInsightsPathsRequest < Struct.new( :network_insights_path_ids, :filters, :max_results, :dry_run, :next_token) SENSITIVE = [] include Aws::Structure end |
#network_insights_path_ids ⇒ Array<String>
The IDs of the paths.
29181 29182 29183 29184 29185 29186 29187 29188 29189 |
# File 'lib/aws-sdk-ec2/types.rb', line 29181 class DescribeNetworkInsightsPathsRequest < Struct.new( :network_insights_path_ids, :filters, :max_results, :dry_run, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
29181 29182 29183 29184 29185 29186 29187 29188 29189 |
# File 'lib/aws-sdk-ec2/types.rb', line 29181 class DescribeNetworkInsightsPathsRequest < Struct.new( :network_insights_path_ids, :filters, :max_results, :dry_run, :next_token) SENSITIVE = [] include Aws::Structure end |