Class: Aws::EC2::Types::DescribeNetworkInsightsPathsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


28845
28846
28847
28848
28849
28850
28851
28852
28853
# File 'lib/aws-sdk-ec2/types.rb', line 28845

class DescribeNetworkInsightsPathsRequest < Struct.new(
  :network_insights_path_ids,
  :filters,
  :max_results,
  :dry_run,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters. The following are the possible values:

  • destination - The ID of the resource.

  • filter-at-source.source-address - The source IPv4 address at the source.

  • filter-at-source.source-port-range - The source port range at the source.

  • filter-at-source.destination-address - The destination IPv4 address at the source.

  • filter-at-source.destination-port-range - The destination port range at the source.

  • filter-at-destination.source-address - The source IPv4 address at the destination.

  • filter-at-destination.source-port-range - The source port range at the destination.

  • filter-at-destination.destination-address - The destination IPv4 address at the destination.

  • filter-at-destination.destination-port-range - The destination port range at the destination.

  • protocol - The protocol.

  • source - The ID of the resource.

Returns:



28845
28846
28847
28848
28849
28850
28851
28852
28853
# File 'lib/aws-sdk-ec2/types.rb', line 28845

class DescribeNetworkInsightsPathsRequest < Struct.new(
  :network_insights_path_ids,
  :filters,
  :max_results,
  :dry_run,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.

Returns:

  • (Integer)


28845
28846
28847
28848
28849
28850
28851
28852
28853
# File 'lib/aws-sdk-ec2/types.rb', line 28845

class DescribeNetworkInsightsPathsRequest < Struct.new(
  :network_insights_path_ids,
  :filters,
  :max_results,
  :dry_run,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#network_insights_path_idsArray<String>

The IDs of the paths.

Returns:

  • (Array<String>)


28845
28846
28847
28848
28849
28850
28851
28852
28853
# File 'lib/aws-sdk-ec2/types.rb', line 28845

class DescribeNetworkInsightsPathsRequest < Struct.new(
  :network_insights_path_ids,
  :filters,
  :max_results,
  :dry_run,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


28845
28846
28847
28848
28849
28850
28851
28852
28853
# File 'lib/aws-sdk-ec2/types.rb', line 28845

class DescribeNetworkInsightsPathsRequest < Struct.new(
  :network_insights_path_ids,
  :filters,
  :max_results,
  :dry_run,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end