Class: Aws::EC2::Types::DescribeNetworkInterfaceAttributeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for DescribeNetworkInterfaceAttribute.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributeString

The attribute of the network interface. This parameter is required.

Returns:

  • (String)


31479
31480
31481
31482
31483
31484
31485
# File 'lib/aws-sdk-ec2/types.rb', line 31479

class DescribeNetworkInterfaceAttributeRequest < Struct.new(
  :dry_run,
  :network_interface_id,
  :attribute)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


31479
31480
31481
31482
31483
31484
31485
# File 'lib/aws-sdk-ec2/types.rb', line 31479

class DescribeNetworkInterfaceAttributeRequest < Struct.new(
  :dry_run,
  :network_interface_id,
  :attribute)
  SENSITIVE = []
  include Aws::Structure
end

#network_interface_idString

The ID of the network interface.

Returns:

  • (String)


31479
31480
31481
31482
31483
31484
31485
# File 'lib/aws-sdk-ec2/types.rb', line 31479

class DescribeNetworkInterfaceAttributeRequest < Struct.new(
  :dry_run,
  :network_interface_id,
  :attribute)
  SENSITIVE = []
  include Aws::Structure
end