Class: Aws::EC2::Types::DescribeNetworkInterfaceAttributeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeNetworkInterfaceAttributeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for DescribeNetworkInterfaceAttribute.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute ⇒ String
The attribute of the network interface.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#network_interface_id ⇒ String
The ID of the network interface.
Instance Attribute Details
#attribute ⇒ String
The attribute of the network interface. This parameter is required.
28886 28887 28888 28889 28890 28891 28892 |
# File 'lib/aws-sdk-ec2/types.rb', line 28886 class DescribeNetworkInterfaceAttributeRequest < Struct.new( :dry_run, :network_interface_id, :attribute) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
28886 28887 28888 28889 28890 28891 28892 |
# File 'lib/aws-sdk-ec2/types.rb', line 28886 class DescribeNetworkInterfaceAttributeRequest < Struct.new( :dry_run, :network_interface_id, :attribute) SENSITIVE = [] include Aws::Structure end |
#network_interface_id ⇒ String
The ID of the network interface.
28886 28887 28888 28889 28890 28891 28892 |
# File 'lib/aws-sdk-ec2/types.rb', line 28886 class DescribeNetworkInterfaceAttributeRequest < Struct.new( :dry_run, :network_interface_id, :attribute) SENSITIVE = [] include Aws::Structure end |