Class: Aws::EC2::Types::DescribeNetworkInterfacePermissionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeNetworkInterfacePermissionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for DescribeNetworkInterfacePermissions.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::Filter>
One or more filters.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#network_interface_permission_ids ⇒ Array<String>
The network interface permission IDs.
-
#next_token ⇒ String
The token returned from a previous paginated request.
Instance Attribute Details
#filters ⇒ Array<Types::Filter>
One or more filters.
-
‘network-interface-permission.network-interface-permission-id` - The ID of the permission.
-
‘network-interface-permission.network-interface-id` - The ID of the network interface.
-
‘network-interface-permission.aws-account-id` - The Amazon Web Services account ID.
-
‘network-interface-permission.aws-service` - The Amazon Web Services service.
-
‘network-interface-permission.permission` - The type of permission (`INSTANCE-ATTACH` | `EIP-ASSOCIATE`).
30007 30008 30009 30010 30011 30012 30013 30014 |
# File 'lib/aws-sdk-ec2/types.rb', line 30007 class DescribeNetworkInterfacePermissionsRequest < Struct.new( :network_interface_permission_ids, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. If this parameter is not specified, up to 50 results are returned by default. For more information, see [Pagination].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination
30007 30008 30009 30010 30011 30012 30013 30014 |
# File 'lib/aws-sdk-ec2/types.rb', line 30007 class DescribeNetworkInterfacePermissionsRequest < Struct.new( :network_interface_permission_ids, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#network_interface_permission_ids ⇒ Array<String>
The network interface permission IDs.
30007 30008 30009 30010 30011 30012 30013 30014 |
# File 'lib/aws-sdk-ec2/types.rb', line 30007 class DescribeNetworkInterfacePermissionsRequest < Struct.new( :network_interface_permission_ids, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
30007 30008 30009 30010 30011 30012 30013 30014 |
# File 'lib/aws-sdk-ec2/types.rb', line 30007 class DescribeNetworkInterfacePermissionsRequest < Struct.new( :network_interface_permission_ids, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |