Class: Aws::EC2::Types::DescribeNetworkInterfacePermissionsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeNetworkInterfacePermissionsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the output for DescribeNetworkInterfacePermissions.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#network_interface_permissions ⇒ Array<Types::NetworkInterfacePermission>
The network interface permissions.
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
Instance Attribute Details
#network_interface_permissions ⇒ Array<Types::NetworkInterfacePermission>
The network interface permissions.
30173 30174 30175 30176 30177 30178 |
# File 'lib/aws-sdk-ec2/types.rb', line 30173 class DescribeNetworkInterfacePermissionsResult < Struct.new( :network_interface_permissions, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
30173 30174 30175 30176 30177 30178 |
# File 'lib/aws-sdk-ec2/types.rb', line 30173 class DescribeNetworkInterfacePermissionsResult < Struct.new( :network_interface_permissions, :next_token) SENSITIVE = [] include Aws::Structure end |