Class: Aws::EC2::Types::DescribeNetworkInterfacesResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeNetworkInterfacesResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#network_interfaces ⇒ Array<Types::NetworkInterface>
Information about the network interfaces.
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
Instance Attribute Details
#network_interfaces ⇒ Array<Types::NetworkInterface>
Information about the network interfaces.
31793 31794 31795 31796 31797 31798 |
# File 'lib/aws-sdk-ec2/types.rb', line 31793 class DescribeNetworkInterfacesResult < Struct.new( :network_interfaces, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
31793 31794 31795 31796 31797 31798 |
# File 'lib/aws-sdk-ec2/types.rb', line 31793 class DescribeNetworkInterfacesResult < Struct.new( :network_interfaces, :next_token) SENSITIVE = [] include Aws::Structure end |