Class: Aws::EC2::Types::DescribeOutpostLagsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


29848
29849
29850
29851
29852
29853
29854
29855
29856
# File 'lib/aws-sdk-ec2/types.rb', line 29848

class DescribeOutpostLagsRequest < Struct.new(
  :outpost_lag_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters to use for narrowing down the request. The following filters are supported:

  • ‘service-link-virtual-interface-id` - The ID of the service link virtual interface.

  • ‘service-link-virtual-interface-arn` - The ARN of the service link virtual interface.

  • ‘outpost-id` - The Outpost ID.

  • ‘outpost-arn` - The Outpost ARN.

  • ‘owner-id` - The ID of the Amazon Web Services account that owns the service link virtual interface.

  • ‘vlan` - The ID of the address pool.

  • ‘local-address` - The local address.

  • ‘peer-address` - The peer address.

  • ‘peer-bgp-asn` - The peer BGP ASN.

  • ‘outpost-lag-id` - The Outpost LAG ID.

  • ‘configuration-state` - The configuration state of the service link virtual interface.

Returns:



29848
29849
29850
29851
29852
29853
29854
29855
29856
# File 'lib/aws-sdk-ec2/types.rb', line 29848

class DescribeOutpostLagsRequest < Struct.new(
  :outpost_lag_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.

Returns:

  • (Integer)


29848
29849
29850
29851
29852
29853
29854
29855
29856
# File 'lib/aws-sdk-ec2/types.rb', line 29848

class DescribeOutpostLagsRequest < Struct.new(
  :outpost_lag_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


29848
29849
29850
29851
29852
29853
29854
29855
29856
# File 'lib/aws-sdk-ec2/types.rb', line 29848

class DescribeOutpostLagsRequest < Struct.new(
  :outpost_lag_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#outpost_lag_idsArray<String>

The IDs of the Outpost LAGs.

Returns:

  • (Array<String>)


29848
29849
29850
29851
29852
29853
29854
29855
29856
# File 'lib/aws-sdk-ec2/types.rb', line 29848

class DescribeOutpostLagsRequest < Struct.new(
  :outpost_lag_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end