Class: Aws::EC2::Types::DescribePrincipalIdFormatRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


30627
30628
30629
30630
30631
30632
30633
30634
# File 'lib/aws-sdk-ec2/types.rb', line 30627

class DescribePrincipalIdFormatRequest < Struct.new(
  :dry_run,
  :resources,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned NextToken value.

Returns:

  • (Integer)


30627
30628
30629
30630
30631
30632
30633
30634
# File 'lib/aws-sdk-ec2/types.rb', line 30627

class DescribePrincipalIdFormatRequest < Struct.new(
  :dry_run,
  :resources,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to request the next page of results.

Returns:

  • (String)


30627
30628
30629
30630
30631
30632
30633
30634
# File 'lib/aws-sdk-ec2/types.rb', line 30627

class DescribePrincipalIdFormatRequest < Struct.new(
  :dry_run,
  :resources,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#resourcesArray<String>

The type of resource: bundle | conversion-task | customer-gateway | dhcp-options | elastic-ip-allocation | elastic-ip-association | export-task | flow-log | image | import-task | instance | internet-gateway | network-acl | network-acl-association | network-interface | network-interface-attachment | prefix-list | reservation | route-table | route-table-association | security-group | snapshot | subnet | subnet-cidr-block-association | volume | vpc | vpc-cidr-block-association | vpc-endpoint | vpc-peering-connection | vpn-connection | vpn-gateway

Returns:

  • (Array<String>)


30627
30628
30629
30630
30631
30632
30633
30634
# File 'lib/aws-sdk-ec2/types.rb', line 30627

class DescribePrincipalIdFormatRequest < Struct.new(
  :dry_run,
  :resources,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end