Class: Aws::EC2::Types::DescribePrincipalIdFormatRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribePrincipalIdFormatRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#max_results ⇒ Integer
The maximum number of results to return in a single call.
-
#next_token ⇒ String
The token to request the next page of results.
-
#resources ⇒ Array<String>
The type of resource:
bundle|conversion-task|customer-gateway|dhcp-options|elastic-ip-allocation|elastic-ip-association|export-task|flow-log|image|import-task|instance|internet-gateway|network-acl|network-acl-association|network-interface|network-interface-attachment|prefix-list|reservation|route-table|route-table-association|security-group|snapshot|subnet|subnet-cidr-block-association|volume|vpc|vpc-cidr-block-association|vpc-endpoint|vpc-peering-connection|vpn-connection|vpn-gateway.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
30489 30490 30491 30492 30493 30494 30495 30496 |
# File 'lib/aws-sdk-ec2/types.rb', line 30489 class DescribePrincipalIdFormatRequest < Struct.new( :dry_run, :resources, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned NextToken value.
30489 30490 30491 30492 30493 30494 30495 30496 |
# File 'lib/aws-sdk-ec2/types.rb', line 30489 class DescribePrincipalIdFormatRequest < Struct.new( :dry_run, :resources, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to request the next page of results.
30489 30490 30491 30492 30493 30494 30495 30496 |
# File 'lib/aws-sdk-ec2/types.rb', line 30489 class DescribePrincipalIdFormatRequest < Struct.new( :dry_run, :resources, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#resources ⇒ Array<String>
The type of resource: bundle | conversion-task |
customer-gateway | dhcp-options | elastic-ip-allocation |
elastic-ip-association | export-task | flow-log | image
| import-task | instance | internet-gateway |
network-acl | network-acl-association | network-interface |
network-interface-attachment | prefix-list | reservation |
route-table | route-table-association | security-group |
snapshot | subnet | subnet-cidr-block-association |
volume | vpc | vpc-cidr-block-association | vpc-endpoint
| vpc-peering-connection | vpn-connection | vpn-gateway
30489 30490 30491 30492 30493 30494 30495 30496 |
# File 'lib/aws-sdk-ec2/types.rb', line 30489 class DescribePrincipalIdFormatRequest < Struct.new( :dry_run, :resources, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |