Class: Aws::EC2::Types::DescribeRegionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#all_regionsBoolean

Indicates whether to display all Regions, including Regions that are disabled for your account.

Returns:

  • (Boolean)


32154
32155
32156
32157
32158
32159
32160
32161
# File 'lib/aws-sdk-ec2/types.rb', line 32154

class DescribeRegionsRequest < Struct.new(
  :region_names,
  :all_regions,
  :dry_run,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


32154
32155
32156
32157
32158
32159
32160
32161
# File 'lib/aws-sdk-ec2/types.rb', line 32154

class DescribeRegionsRequest < Struct.new(
  :region_names,
  :all_regions,
  :dry_run,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters.

  • endpoint - The endpoint of the Region (for example, ec2.us-east-1.amazonaws.com).

  • opt-in-status - The opt-in status of the Region (opt-in-not-required | opted-in | not-opted-in).

  • region-name - The name of the Region (for example, us-east-1).

Returns:



32154
32155
32156
32157
32158
32159
32160
32161
# File 'lib/aws-sdk-ec2/types.rb', line 32154

class DescribeRegionsRequest < Struct.new(
  :region_names,
  :all_regions,
  :dry_run,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#region_namesArray<String>

The names of the Regions. You can specify any Regions, whether they are enabled and disabled for your account.

Returns:

  • (Array<String>)


32154
32155
32156
32157
32158
32159
32160
32161
# File 'lib/aws-sdk-ec2/types.rb', line 32154

class DescribeRegionsRequest < Struct.new(
  :region_names,
  :all_regions,
  :dry_run,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end