Class: Aws::EC2::Types::DescribeReplaceRootVolumeTasksRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeReplaceRootVolumeTasksRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
Filter to use:.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token returned from a previous paginated request.
-
#replace_root_volume_task_ids ⇒ Array<String>
The ID of the root volume replacement task to view.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
32213 32214 32215 32216 32217 32218 32219 32220 32221 |
# File 'lib/aws-sdk-ec2/types.rb', line 32213 class DescribeReplaceRootVolumeTasksRequest < Struct.new( :replace_root_volume_task_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
Filter to use:
instance-id- The ID of the instance for which the root volume replacement task was created.
^
32213 32214 32215 32216 32217 32218 32219 32220 32221 |
# File 'lib/aws-sdk-ec2/types.rb', line 32213 class DescribeReplaceRootVolumeTasksRequest < Struct.new( :replace_root_volume_task_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
32213 32214 32215 32216 32217 32218 32219 32220 32221 |
# File 'lib/aws-sdk-ec2/types.rb', line 32213 class DescribeReplaceRootVolumeTasksRequest < Struct.new( :replace_root_volume_task_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
32213 32214 32215 32216 32217 32218 32219 32220 32221 |
# File 'lib/aws-sdk-ec2/types.rb', line 32213 class DescribeReplaceRootVolumeTasksRequest < Struct.new( :replace_root_volume_task_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#replace_root_volume_task_ids ⇒ Array<String>
The ID of the root volume replacement task to view.
32213 32214 32215 32216 32217 32218 32219 32220 32221 |
# File 'lib/aws-sdk-ec2/types.rb', line 32213 class DescribeReplaceRootVolumeTasksRequest < Struct.new( :replace_root_volume_task_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |