Class: Aws::EC2::Types::DescribeReplaceRootVolumeTasksRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


31851
31852
31853
31854
31855
31856
31857
31858
31859
# File 'lib/aws-sdk-ec2/types.rb', line 31851

class DescribeReplaceRootVolumeTasksRequest < Struct.new(
  :replace_root_volume_task_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

Filter to use:

  • instance-id - The ID of the instance for which the root volume replacement task was created.

^

Returns:



31851
31852
31853
31854
31855
31856
31857
31858
31859
# File 'lib/aws-sdk-ec2/types.rb', line 31851

class DescribeReplaceRootVolumeTasksRequest < Struct.new(
  :replace_root_volume_task_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.

Returns:

  • (Integer)


31851
31852
31853
31854
31855
31856
31857
31858
31859
# File 'lib/aws-sdk-ec2/types.rb', line 31851

class DescribeReplaceRootVolumeTasksRequest < Struct.new(
  :replace_root_volume_task_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Returns:

  • (String)


31851
31852
31853
31854
31855
31856
31857
31858
31859
# File 'lib/aws-sdk-ec2/types.rb', line 31851

class DescribeReplaceRootVolumeTasksRequest < Struct.new(
  :replace_root_volume_task_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#replace_root_volume_task_idsArray<String>

The ID of the root volume replacement task to view.

Returns:

  • (Array<String>)


31851
31852
31853
31854
31855
31856
31857
31858
31859
# File 'lib/aws-sdk-ec2/types.rb', line 31851

class DescribeReplaceRootVolumeTasksRequest < Struct.new(
  :replace_root_volume_task_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end