Class: Aws::EC2::Types::DescribeRouteServerPeersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeRouteServerPeersRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters to apply to the describe request.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
-
#route_server_peer_ids ⇒ Array<String>
The IDs of the route server peers to describe.
Instance Attribute Details
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
31145 31146 31147 31148 31149 31150 31151 31152 31153 |
# File 'lib/aws-sdk-ec2/types.rb', line 31145 class DescribeRouteServerPeersRequest < Struct.new( :route_server_peer_ids, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters to apply to the describe request.
31145 31146 31147 31148 31149 31150 31151 31152 31153 |
# File 'lib/aws-sdk-ec2/types.rb', line 31145 class DescribeRouteServerPeersRequest < Struct.new( :route_server_peer_ids, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call.
31145 31146 31147 31148 31149 31150 31151 31152 31153 |
# File 'lib/aws-sdk-ec2/types.rb', line 31145 class DescribeRouteServerPeersRequest < Struct.new( :route_server_peer_ids, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
31145 31146 31147 31148 31149 31150 31151 31152 31153 |
# File 'lib/aws-sdk-ec2/types.rb', line 31145 class DescribeRouteServerPeersRequest < Struct.new( :route_server_peer_ids, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#route_server_peer_ids ⇒ Array<String>
The IDs of the route server peers to describe.
31145 31146 31147 31148 31149 31150 31151 31152 31153 |
# File 'lib/aws-sdk-ec2/types.rb', line 31145 class DescribeRouteServerPeersRequest < Struct.new( :route_server_peer_ids, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |