Class: Aws::EC2::Types::DescribeRouteServerPeersRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


31139
31140
31141
31142
31143
31144
31145
31146
31147
# File 'lib/aws-sdk-ec2/types.rb', line 31139

class DescribeRouteServerPeersRequest < Struct.new(
  :route_server_peer_ids,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters to apply to the describe request.

Returns:



31139
31140
31141
31142
31143
31144
31145
31146
31147
# File 'lib/aws-sdk-ec2/types.rb', line 31139

class DescribeRouteServerPeersRequest < Struct.new(
  :route_server_peer_ids,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call.

Returns:

  • (Integer)


31139
31140
31141
31142
31143
31144
31145
31146
31147
# File 'lib/aws-sdk-ec2/types.rb', line 31139

class DescribeRouteServerPeersRequest < Struct.new(
  :route_server_peer_ids,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


31139
31140
31141
31142
31143
31144
31145
31146
31147
# File 'lib/aws-sdk-ec2/types.rb', line 31139

class DescribeRouteServerPeersRequest < Struct.new(
  :route_server_peer_ids,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#route_server_peer_idsArray<String>

The IDs of the route server peers to describe.

Returns:

  • (Array<String>)


31139
31140
31141
31142
31143
31144
31145
31146
31147
# File 'lib/aws-sdk-ec2/types.rb', line 31139

class DescribeRouteServerPeersRequest < Struct.new(
  :route_server_peer_ids,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end