Class: Aws::EC2::Types::DescribeRouteServersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeRouteServersRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters to apply to the describe request.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
-
#route_server_ids ⇒ Array<String>
The IDs of the route servers to describe.
Instance Attribute Details
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action
without actually making the request and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
32435 32436 32437 32438 32439 32440 32441 32442 32443 |
# File 'lib/aws-sdk-ec2/types.rb', line 32435 class DescribeRouteServersRequest < Struct.new( :route_server_ids, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters to apply to the describe request.
32435 32436 32437 32438 32439 32440 32441 32442 32443 |
# File 'lib/aws-sdk-ec2/types.rb', line 32435 class DescribeRouteServersRequest < Struct.new( :route_server_ids, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call.
32435 32436 32437 32438 32439 32440 32441 32442 32443 |
# File 'lib/aws-sdk-ec2/types.rb', line 32435 class DescribeRouteServersRequest < Struct.new( :route_server_ids, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
32435 32436 32437 32438 32439 32440 32441 32442 32443 |
# File 'lib/aws-sdk-ec2/types.rb', line 32435 class DescribeRouteServersRequest < Struct.new( :route_server_ids, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#route_server_ids ⇒ Array<String>
The IDs of the route servers to describe.
32435 32436 32437 32438 32439 32440 32441 32442 32443 |
# File 'lib/aws-sdk-ec2/types.rb', line 32435 class DescribeRouteServersRequest < Struct.new( :route_server_ids, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |