Class: Aws::EC2::Types::DescribeRouteTablesResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeRouteTablesResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the output of DescribeRouteTables.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#route_tables ⇒ Array<Types::RouteTable>
Information about the route tables.
Instance Attribute Details
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
31567 31568 31569 31570 31571 31572 |
# File 'lib/aws-sdk-ec2/types.rb', line 31567 class DescribeRouteTablesResult < Struct.new( :route_tables, :next_token) SENSITIVE = [] include Aws::Structure end |
#route_tables ⇒ Array<Types::RouteTable>
Information about the route tables.
31567 31568 31569 31570 31571 31572 |
# File 'lib/aws-sdk-ec2/types.rb', line 31567 class DescribeRouteTablesResult < Struct.new( :route_tables, :next_token) SENSITIVE = [] include Aws::Structure end |