Class: Aws::EC2::Types::DescribeScheduledInstanceAvailabilityRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for DescribeScheduledInstanceAvailability.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


31758
31759
31760
31761
31762
31763
31764
31765
31766
31767
31768
31769
# File 'lib/aws-sdk-ec2/types.rb', line 31758

class DescribeScheduledInstanceAvailabilityRequest < Struct.new(
  :dry_run,
  :filters,
  :first_slot_start_time_range,
  :max_results,
  :max_slot_duration_in_hours,
  :min_slot_duration_in_hours,
  :next_token,
  :recurrence)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters.

  • availability-zone - The Availability Zone (for example, us-west-2a).

  • instance-type - The instance type (for example, c4.large).

  • platform - The platform (Linux/UNIX or Windows).

Returns:



31758
31759
31760
31761
31762
31763
31764
31765
31766
31767
31768
31769
# File 'lib/aws-sdk-ec2/types.rb', line 31758

class DescribeScheduledInstanceAvailabilityRequest < Struct.new(
  :dry_run,
  :filters,
  :first_slot_start_time_range,
  :max_results,
  :max_slot_duration_in_hours,
  :min_slot_duration_in_hours,
  :next_token,
  :recurrence)
  SENSITIVE = []
  include Aws::Structure
end

#first_slot_start_time_rangeTypes::SlotDateTimeRangeRequest

The time period for the first schedule to start.



31758
31759
31760
31761
31762
31763
31764
31765
31766
31767
31768
31769
# File 'lib/aws-sdk-ec2/types.rb', line 31758

class DescribeScheduledInstanceAvailabilityRequest < Struct.new(
  :dry_run,
  :filters,
  :first_slot_start_time_range,
  :max_results,
  :max_slot_duration_in_hours,
  :min_slot_duration_in_hours,
  :next_token,
  :recurrence)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in a single call. This value can be between 5 and 300. The default value is 300. To retrieve the remaining results, make another call with the returned NextToken value.

Returns:

  • (Integer)


31758
31759
31760
31761
31762
31763
31764
31765
31766
31767
31768
31769
# File 'lib/aws-sdk-ec2/types.rb', line 31758

class DescribeScheduledInstanceAvailabilityRequest < Struct.new(
  :dry_run,
  :filters,
  :first_slot_start_time_range,
  :max_results,
  :max_slot_duration_in_hours,
  :min_slot_duration_in_hours,
  :next_token,
  :recurrence)
  SENSITIVE = []
  include Aws::Structure
end

#max_slot_duration_in_hoursInteger

The maximum available duration, in hours. This value must be greater than MinSlotDurationInHours and less than 1,720.

Returns:

  • (Integer)


31758
31759
31760
31761
31762
31763
31764
31765
31766
31767
31768
31769
# File 'lib/aws-sdk-ec2/types.rb', line 31758

class DescribeScheduledInstanceAvailabilityRequest < Struct.new(
  :dry_run,
  :filters,
  :first_slot_start_time_range,
  :max_results,
  :max_slot_duration_in_hours,
  :min_slot_duration_in_hours,
  :next_token,
  :recurrence)
  SENSITIVE = []
  include Aws::Structure
end

#min_slot_duration_in_hoursInteger

The minimum available duration, in hours. The minimum required duration is 1,200 hours per year. For example, the minimum daily schedule is 4 hours, the minimum weekly schedule is 24 hours, and the minimum monthly schedule is 100 hours.

Returns:

  • (Integer)


31758
31759
31760
31761
31762
31763
31764
31765
31766
31767
31768
31769
# File 'lib/aws-sdk-ec2/types.rb', line 31758

class DescribeScheduledInstanceAvailabilityRequest < Struct.new(
  :dry_run,
  :filters,
  :first_slot_start_time_range,
  :max_results,
  :max_slot_duration_in_hours,
  :min_slot_duration_in_hours,
  :next_token,
  :recurrence)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results.

Returns:

  • (String)


31758
31759
31760
31761
31762
31763
31764
31765
31766
31767
31768
31769
# File 'lib/aws-sdk-ec2/types.rb', line 31758

class DescribeScheduledInstanceAvailabilityRequest < Struct.new(
  :dry_run,
  :filters,
  :first_slot_start_time_range,
  :max_results,
  :max_slot_duration_in_hours,
  :min_slot_duration_in_hours,
  :next_token,
  :recurrence)
  SENSITIVE = []
  include Aws::Structure
end

#recurrenceTypes::ScheduledInstanceRecurrenceRequest

The schedule recurrence.



31758
31759
31760
31761
31762
31763
31764
31765
31766
31767
31768
31769
# File 'lib/aws-sdk-ec2/types.rb', line 31758

class DescribeScheduledInstanceAvailabilityRequest < Struct.new(
  :dry_run,
  :filters,
  :first_slot_start_time_range,
  :max_results,
  :max_slot_duration_in_hours,
  :min_slot_duration_in_hours,
  :next_token,
  :recurrence)
  SENSITIVE = []
  include Aws::Structure
end