Class: Aws::EC2::Types::DescribeScheduledInstanceAvailabilityRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeScheduledInstanceAvailabilityRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for DescribeScheduledInstanceAvailability.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The filters.
-
#first_slot_start_time_range ⇒ Types::SlotDateTimeRangeRequest
The time period for the first schedule to start.
-
#max_results ⇒ Integer
The maximum number of results to return in a single call.
-
#max_slot_duration_in_hours ⇒ Integer
The maximum available duration, in hours.
-
#min_slot_duration_in_hours ⇒ Integer
The minimum available duration, in hours.
-
#next_token ⇒ String
The token for the next set of results.
-
#recurrence ⇒ Types::ScheduledInstanceRecurrenceRequest
The schedule recurrence.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
31015 31016 31017 31018 31019 31020 31021 31022 31023 31024 31025 31026 |
# File 'lib/aws-sdk-ec2/types.rb', line 31015 class DescribeScheduledInstanceAvailabilityRequest < Struct.new( :dry_run, :filters, :first_slot_start_time_range, :max_results, :max_slot_duration_in_hours, :min_slot_duration_in_hours, :next_token, :recurrence) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters.
-
‘availability-zone` - The Availability Zone (for example, `us-west-2a`).
-
‘instance-type` - The instance type (for example, `c4.large`).
-
‘platform` - The platform (`Linux/UNIX` or `Windows`).
31015 31016 31017 31018 31019 31020 31021 31022 31023 31024 31025 31026 |
# File 'lib/aws-sdk-ec2/types.rb', line 31015 class DescribeScheduledInstanceAvailabilityRequest < Struct.new( :dry_run, :filters, :first_slot_start_time_range, :max_results, :max_slot_duration_in_hours, :min_slot_duration_in_hours, :next_token, :recurrence) SENSITIVE = [] include Aws::Structure end |
#first_slot_start_time_range ⇒ Types::SlotDateTimeRangeRequest
The time period for the first schedule to start.
31015 31016 31017 31018 31019 31020 31021 31022 31023 31024 31025 31026 |
# File 'lib/aws-sdk-ec2/types.rb', line 31015 class DescribeScheduledInstanceAvailabilityRequest < Struct.new( :dry_run, :filters, :first_slot_start_time_range, :max_results, :max_slot_duration_in_hours, :min_slot_duration_in_hours, :next_token, :recurrence) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in a single call. This value can be between 5 and 300. The default value is 300. To retrieve the remaining results, make another call with the returned ‘NextToken` value.
31015 31016 31017 31018 31019 31020 31021 31022 31023 31024 31025 31026 |
# File 'lib/aws-sdk-ec2/types.rb', line 31015 class DescribeScheduledInstanceAvailabilityRequest < Struct.new( :dry_run, :filters, :first_slot_start_time_range, :max_results, :max_slot_duration_in_hours, :min_slot_duration_in_hours, :next_token, :recurrence) SENSITIVE = [] include Aws::Structure end |
#max_slot_duration_in_hours ⇒ Integer
The maximum available duration, in hours. This value must be greater than ‘MinSlotDurationInHours` and less than 1,720.
31015 31016 31017 31018 31019 31020 31021 31022 31023 31024 31025 31026 |
# File 'lib/aws-sdk-ec2/types.rb', line 31015 class DescribeScheduledInstanceAvailabilityRequest < Struct.new( :dry_run, :filters, :first_slot_start_time_range, :max_results, :max_slot_duration_in_hours, :min_slot_duration_in_hours, :next_token, :recurrence) SENSITIVE = [] include Aws::Structure end |
#min_slot_duration_in_hours ⇒ Integer
The minimum available duration, in hours. The minimum required duration is 1,200 hours per year. For example, the minimum daily schedule is 4 hours, the minimum weekly schedule is 24 hours, and the minimum monthly schedule is 100 hours.
31015 31016 31017 31018 31019 31020 31021 31022 31023 31024 31025 31026 |
# File 'lib/aws-sdk-ec2/types.rb', line 31015 class DescribeScheduledInstanceAvailabilityRequest < Struct.new( :dry_run, :filters, :first_slot_start_time_range, :max_results, :max_slot_duration_in_hours, :min_slot_duration_in_hours, :next_token, :recurrence) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results.
31015 31016 31017 31018 31019 31020 31021 31022 31023 31024 31025 31026 |
# File 'lib/aws-sdk-ec2/types.rb', line 31015 class DescribeScheduledInstanceAvailabilityRequest < Struct.new( :dry_run, :filters, :first_slot_start_time_range, :max_results, :max_slot_duration_in_hours, :min_slot_duration_in_hours, :next_token, :recurrence) SENSITIVE = [] include Aws::Structure end |
#recurrence ⇒ Types::ScheduledInstanceRecurrenceRequest
The schedule recurrence.
31015 31016 31017 31018 31019 31020 31021 31022 31023 31024 31025 31026 |
# File 'lib/aws-sdk-ec2/types.rb', line 31015 class DescribeScheduledInstanceAvailabilityRequest < Struct.new( :dry_run, :filters, :first_slot_start_time_range, :max_results, :max_slot_duration_in_hours, :min_slot_duration_in_hours, :next_token, :recurrence) SENSITIVE = [] include Aws::Structure end |