Class: Aws::EC2::Types::DescribeScheduledInstancesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for DescribeScheduledInstances.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


32724
32725
32726
32727
32728
32729
32730
32731
32732
32733
# File 'lib/aws-sdk-ec2/types.rb', line 32724

class DescribeScheduledInstancesRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :scheduled_instance_ids,
  :slot_start_time_range)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters.

  • availability-zone - The Availability Zone (for example, us-west-2a).

  • instance-type - The instance type (for example, c4.large).

  • platform - The platform (Linux/UNIX or Windows).

Returns:



32724
32725
32726
32727
32728
32729
32730
32731
32732
32733
# File 'lib/aws-sdk-ec2/types.rb', line 32724

class DescribeScheduledInstancesRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :scheduled_instance_ids,
  :slot_start_time_range)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in a single call. This value can be between 5 and 300. The default value is 100. To retrieve the remaining results, make another call with the returned NextToken value.

Returns:

  • (Integer)


32724
32725
32726
32727
32728
32729
32730
32731
32732
32733
# File 'lib/aws-sdk-ec2/types.rb', line 32724

class DescribeScheduledInstancesRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :scheduled_instance_ids,
  :slot_start_time_range)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results.

Returns:

  • (String)


32724
32725
32726
32727
32728
32729
32730
32731
32732
32733
# File 'lib/aws-sdk-ec2/types.rb', line 32724

class DescribeScheduledInstancesRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :scheduled_instance_ids,
  :slot_start_time_range)
  SENSITIVE = []
  include Aws::Structure
end

#scheduled_instance_idsArray<String>

The Scheduled Instance IDs.

Returns:

  • (Array<String>)


32724
32725
32726
32727
32728
32729
32730
32731
32732
32733
# File 'lib/aws-sdk-ec2/types.rb', line 32724

class DescribeScheduledInstancesRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :scheduled_instance_ids,
  :slot_start_time_range)
  SENSITIVE = []
  include Aws::Structure
end

#slot_start_time_rangeTypes::SlotStartTimeRangeRequest

The time period for the first schedule to start.



32724
32725
32726
32727
32728
32729
32730
32731
32732
32733
# File 'lib/aws-sdk-ec2/types.rb', line 32724

class DescribeScheduledInstancesRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :scheduled_instance_ids,
  :slot_start_time_range)
  SENSITIVE = []
  include Aws::Structure
end