Class: Aws::EC2::Types::DescribeScheduledInstancesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeScheduledInstancesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for DescribeScheduledInstances.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The filters.
-
#max_results ⇒ Integer
The maximum number of results to return in a single call.
-
#next_token ⇒ String
The token for the next set of results.
-
#scheduled_instance_ids ⇒ Array<String>
The Scheduled Instance IDs.
-
#slot_start_time_range ⇒ Types::SlotStartTimeRangeRequest
The time period for the first schedule to start.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
31701 31702 31703 31704 31705 31706 31707 31708 31709 31710 |
# File 'lib/aws-sdk-ec2/types.rb', line 31701 class DescribeScheduledInstancesRequest < Struct.new( :dry_run, :filters, :max_results, :next_token, :scheduled_instance_ids, :slot_start_time_range) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters.
-
availability-zone- The Availability Zone (for example,us-west-2a). -
instance-type- The instance type (for example,c4.large). -
platform- The platform (Linux/UNIXorWindows).
31701 31702 31703 31704 31705 31706 31707 31708 31709 31710 |
# File 'lib/aws-sdk-ec2/types.rb', line 31701 class DescribeScheduledInstancesRequest < Struct.new( :dry_run, :filters, :max_results, :next_token, :scheduled_instance_ids, :slot_start_time_range) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in a single call. This value
can be between 5 and 300. The default value is 100. To retrieve the
remaining results, make another call with the returned NextToken
value.
31701 31702 31703 31704 31705 31706 31707 31708 31709 31710 |
# File 'lib/aws-sdk-ec2/types.rb', line 31701 class DescribeScheduledInstancesRequest < Struct.new( :dry_run, :filters, :max_results, :next_token, :scheduled_instance_ids, :slot_start_time_range) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results.
31701 31702 31703 31704 31705 31706 31707 31708 31709 31710 |
# File 'lib/aws-sdk-ec2/types.rb', line 31701 class DescribeScheduledInstancesRequest < Struct.new( :dry_run, :filters, :max_results, :next_token, :scheduled_instance_ids, :slot_start_time_range) SENSITIVE = [] include Aws::Structure end |
#scheduled_instance_ids ⇒ Array<String>
The Scheduled Instance IDs.
31701 31702 31703 31704 31705 31706 31707 31708 31709 31710 |
# File 'lib/aws-sdk-ec2/types.rb', line 31701 class DescribeScheduledInstancesRequest < Struct.new( :dry_run, :filters, :max_results, :next_token, :scheduled_instance_ids, :slot_start_time_range) SENSITIVE = [] include Aws::Structure end |
#slot_start_time_range ⇒ Types::SlotStartTimeRangeRequest
The time period for the first schedule to start.
31701 31702 31703 31704 31705 31706 31707 31708 31709 31710 |
# File 'lib/aws-sdk-ec2/types.rb', line 31701 class DescribeScheduledInstancesRequest < Struct.new( :dry_run, :filters, :max_results, :next_token, :scheduled_instance_ids, :slot_start_time_range) SENSITIVE = [] include Aws::Structure end |