Class: Aws::EC2::Types::DescribeScheduledInstancesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for DescribeScheduledInstances.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


31129
31130
31131
31132
31133
31134
31135
31136
31137
31138
# File 'lib/aws-sdk-ec2/types.rb', line 31129

class DescribeScheduledInstancesRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :scheduled_instance_ids,
  :slot_start_time_range)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters.

  • ‘availability-zone` - The Availability Zone (for example, `us-west-2a`).

  • ‘instance-type` - The instance type (for example, `c4.large`).

  • ‘platform` - The platform (`Linux/UNIX` or `Windows`).

Returns:



31129
31130
31131
31132
31133
31134
31135
31136
31137
31138
# File 'lib/aws-sdk-ec2/types.rb', line 31129

class DescribeScheduledInstancesRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :scheduled_instance_ids,
  :slot_start_time_range)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in a single call. This value can be between 5 and 300. The default value is 100. To retrieve the remaining results, make another call with the returned ‘NextToken` value.

Returns:

  • (Integer)


31129
31130
31131
31132
31133
31134
31135
31136
31137
31138
# File 'lib/aws-sdk-ec2/types.rb', line 31129

class DescribeScheduledInstancesRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :scheduled_instance_ids,
  :slot_start_time_range)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results.

Returns:

  • (String)


31129
31130
31131
31132
31133
31134
31135
31136
31137
31138
# File 'lib/aws-sdk-ec2/types.rb', line 31129

class DescribeScheduledInstancesRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :scheduled_instance_ids,
  :slot_start_time_range)
  SENSITIVE = []
  include Aws::Structure
end

#scheduled_instance_idsArray<String>

The Scheduled Instance IDs.

Returns:

  • (Array<String>)


31129
31130
31131
31132
31133
31134
31135
31136
31137
31138
# File 'lib/aws-sdk-ec2/types.rb', line 31129

class DescribeScheduledInstancesRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :scheduled_instance_ids,
  :slot_start_time_range)
  SENSITIVE = []
  include Aws::Structure
end

#slot_start_time_rangeTypes::SlotStartTimeRangeRequest

The time period for the first schedule to start.



31129
31130
31131
31132
31133
31134
31135
31136
31137
31138
# File 'lib/aws-sdk-ec2/types.rb', line 31129

class DescribeScheduledInstancesRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token,
  :scheduled_instance_ids,
  :slot_start_time_range)
  SENSITIVE = []
  include Aws::Structure
end