Class: Aws::EC2::Types::DescribeSecondaryNetworksRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeSecondaryNetworksRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The filters.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
-
#secondary_network_ids ⇒ Array<String>
The IDs of the secondary networks.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
31027 31028 31029 31030 31031 31032 31033 31034 31035 |
# File 'lib/aws-sdk-ec2/types.rb', line 31027 class DescribeSecondaryNetworksRequest < Struct.new( :dry_run, :filters, :max_results, :next_token, :secondary_network_ids) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters. The following are the possible values:
-
‘ipv4-cidr-block-association.association-id` - The association ID for an IPv4 CIDR block associated with the secondary network.
-
‘ipv4-cidr-block-association.cidr-block` - An IPv4 CIDR block associated with the secondary network.
-
‘ipv4-cidr-block-association.state` - The state of an IPv4 CIDR block associated with the secondary network.
-
‘owner-id` - The ID of the Amazon Web Services account that owns the secondary network.
-
‘secondary-network-id` - The ID of the secondary network.
-
‘secondary-network-arn` - The ARN of the secondary network.
-
‘state` - The state of the secondary network (`create-in-progress` | `create-complete` | `create-failed` | `delete-in-progress` | `delete-complete` | `delete-failed`).
-
‘tag`:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key `Owner` and the value `TeamA`, specify `tag:Owner` for the filter name and `TeamA` for the filter value.
-
‘tag-key` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.
-
‘type` - The type of the secondary network (`rdma`).
31027 31028 31029 31030 31031 31032 31033 31034 31035 |
# File 'lib/aws-sdk-ec2/types.rb', line 31027 class DescribeSecondaryNetworksRequest < Struct.new( :dry_run, :filters, :max_results, :next_token, :secondary_network_ids) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.
31027 31028 31029 31030 31031 31032 31033 31034 31035 |
# File 'lib/aws-sdk-ec2/types.rb', line 31027 class DescribeSecondaryNetworksRequest < Struct.new( :dry_run, :filters, :max_results, :next_token, :secondary_network_ids) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
31027 31028 31029 31030 31031 31032 31033 31034 31035 |
# File 'lib/aws-sdk-ec2/types.rb', line 31027 class DescribeSecondaryNetworksRequest < Struct.new( :dry_run, :filters, :max_results, :next_token, :secondary_network_ids) SENSITIVE = [] include Aws::Structure end |
#secondary_network_ids ⇒ Array<String>
The IDs of the secondary networks.
31027 31028 31029 31030 31031 31032 31033 31034 31035 |
# File 'lib/aws-sdk-ec2/types.rb', line 31027 class DescribeSecondaryNetworksRequest < Struct.new( :dry_run, :filters, :max_results, :next_token, :secondary_network_ids) SENSITIVE = [] include Aws::Structure end |