Class: Aws::EC2::Types::DescribeSecurityGroupReferencesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeSecurityGroupReferencesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#group_id ⇒ Array<String>
The IDs of the security groups in your account.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
32062 32063 32064 32065 32066 32067 |
# File 'lib/aws-sdk-ec2/types.rb', line 32062 class DescribeSecurityGroupReferencesRequest < Struct.new( :dry_run, :group_id) SENSITIVE = [] include Aws::Structure end |
#group_id ⇒ Array<String>
The IDs of the security groups in your account.
32062 32063 32064 32065 32066 32067 |
# File 'lib/aws-sdk-ec2/types.rb', line 32062 class DescribeSecurityGroupReferencesRequest < Struct.new( :dry_run, :group_id) SENSITIVE = [] include Aws::Structure end |