Class: Aws::EC2::Types::DescribeSecurityGroupReferencesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


31458
31459
31460
31461
31462
31463
# File 'lib/aws-sdk-ec2/types.rb', line 31458

class DescribeSecurityGroupReferencesRequest < Struct.new(
  :dry_run,
  :group_id)
  SENSITIVE = []
  include Aws::Structure
end

#group_idArray<String>

The IDs of the security groups in your account.

Returns:

  • (Array<String>)


31458
31459
31460
31461
31462
31463
# File 'lib/aws-sdk-ec2/types.rb', line 31458

class DescribeSecurityGroupReferencesRequest < Struct.new(
  :dry_run,
  :group_id)
  SENSITIVE = []
  include Aws::Structure
end