Class: Aws::EC2::Types::DescribeSecurityGroupRulesResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeSecurityGroupRulesResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#security_group_rules ⇒ Array<Types::SecurityGroupRule>
Information about security group rules.
Instance Attribute Details
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
33131 33132 33133 33134 33135 33136 |
# File 'lib/aws-sdk-ec2/types.rb', line 33131 class DescribeSecurityGroupRulesResult < Struct.new( :security_group_rules, :next_token) SENSITIVE = [] include Aws::Structure end |
#security_group_rules ⇒ Array<Types::SecurityGroupRule>
Information about security group rules.
33131 33132 33133 33134 33135 33136 |
# File 'lib/aws-sdk-ec2/types.rb', line 33131 class DescribeSecurityGroupRulesResult < Struct.new( :security_group_rules, :next_token) SENSITIVE = [] include Aws::Structure end |