Class: Aws::EC2::Types::DescribeSecurityGroupVpcAssociationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeSecurityGroupVpcAssociationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
Security group VPC association filters.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token returned from a previous paginated request.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
30675 30676 30677 30678 30679 30680 30681 30682 |
# File 'lib/aws-sdk-ec2/types.rb', line 30675 class DescribeSecurityGroupVpcAssociationsRequest < Struct.new( :filters, :next_token, :max_results, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
Security group VPC association filters.
-
‘group-id`: The security group ID.
-
‘group-owner-id`: The group owner ID.
-
‘state`: The state of the association.
-
‘vpc-id`: The ID of the associated VPC.
-
‘vpc-owner-id`: The account ID of the VPC owner.
30675 30676 30677 30678 30679 30680 30681 30682 |
# File 'lib/aws-sdk-ec2/types.rb', line 30675 class DescribeSecurityGroupVpcAssociationsRequest < Struct.new( :filters, :next_token, :max_results, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination
30675 30676 30677 30678 30679 30680 30681 30682 |
# File 'lib/aws-sdk-ec2/types.rb', line 30675 class DescribeSecurityGroupVpcAssociationsRequest < Struct.new( :filters, :next_token, :max_results, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
30675 30676 30677 30678 30679 30680 30681 30682 |
# File 'lib/aws-sdk-ec2/types.rb', line 30675 class DescribeSecurityGroupVpcAssociationsRequest < Struct.new( :filters, :next_token, :max_results, :dry_run) SENSITIVE = [] include Aws::Structure end |