Class: Aws::EC2::Types::DescribeSecurityGroupVpcAssociationsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeSecurityGroupVpcAssociationsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#security_group_vpc_associations ⇒ Array<Types::SecurityGroupVpcAssociation>
The security group VPC associations.
Instance Attribute Details
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
32213 32214 32215 32216 32217 32218 |
# File 'lib/aws-sdk-ec2/types.rb', line 32213 class DescribeSecurityGroupVpcAssociationsResult < Struct.new( :security_group_vpc_associations, :next_token) SENSITIVE = [] include Aws::Structure end |
#security_group_vpc_associations ⇒ Array<Types::SecurityGroupVpcAssociation>
The security group VPC associations.
32213 32214 32215 32216 32217 32218 |
# File 'lib/aws-sdk-ec2/types.rb', line 32213 class DescribeSecurityGroupVpcAssociationsResult < Struct.new( :security_group_vpc_associations, :next_token) SENSITIVE = [] include Aws::Structure end |