Class: Aws::EC2::Types::DescribeSecurityGroupVpcAssociationsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeSecurityGroupVpcAssociationsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#security_group_vpc_associations ⇒ Array<Types::SecurityGroupVpcAssociation>
The security group VPC associations.
Instance Attribute Details
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
32188 32189 32190 32191 32192 32193 |
# File 'lib/aws-sdk-ec2/types.rb', line 32188 class DescribeSecurityGroupVpcAssociationsResult < Struct.new( :security_group_vpc_associations, :next_token) SENSITIVE = [] include Aws::Structure end |
#security_group_vpc_associations ⇒ Array<Types::SecurityGroupVpcAssociation>
The security group VPC associations.
32188 32189 32190 32191 32192 32193 |
# File 'lib/aws-sdk-ec2/types.rb', line 32188 class DescribeSecurityGroupVpcAssociationsResult < Struct.new( :security_group_vpc_associations, :next_token) SENSITIVE = [] include Aws::Structure end |