Class: Aws::EC2::Types::DescribeSecurityGroupsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeSecurityGroupsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#security_groups ⇒ Array<Types::SecurityGroup>
Information about the security groups.
Instance Attribute Details
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
32344 32345 32346 32347 32348 32349 |
# File 'lib/aws-sdk-ec2/types.rb', line 32344 class DescribeSecurityGroupsResult < Struct.new( :next_token, :security_groups) SENSITIVE = [] include Aws::Structure end |
#security_groups ⇒ Array<Types::SecurityGroup>
Information about the security groups.
32344 32345 32346 32347 32348 32349 |
# File 'lib/aws-sdk-ec2/types.rb', line 32344 class DescribeSecurityGroupsResult < Struct.new( :next_token, :security_groups) SENSITIVE = [] include Aws::Structure end |