Class: Aws::EC2::Types::DescribeServiceLinkVirtualInterfacesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeServiceLinkVirtualInterfacesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The filters to use for narrowing down the request.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
-
#service_link_virtual_interface_ids ⇒ Array<String>
The IDs of the service link virtual interfaces.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
32396 32397 32398 32399 32400 32401 32402 32403 32404 |
# File 'lib/aws-sdk-ec2/types.rb', line 32396 class DescribeServiceLinkVirtualInterfacesRequest < Struct.new( :service_link_virtual_interface_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters to use for narrowing down the request. The following filters are supported:
-
outpost-lag-id- The ID of the Outpost LAG. -
outpost-arn- The Outpost ARN. -
owner-id- The ID of the Amazon Web Services account that owns the service link virtual interface. -
state- The state of the Outpost LAG. -
vlan- The ID of the address pool. -
service-link-virtual-interface-id- The ID of the service link virtual interface. -
local-gateway-virtual-interface-id- The ID of the local gateway virtual interface.
32396 32397 32398 32399 32400 32401 32402 32403 32404 |
# File 'lib/aws-sdk-ec2/types.rb', line 32396 class DescribeServiceLinkVirtualInterfacesRequest < Struct.new( :service_link_virtual_interface_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To
retrieve the remaining results, make another call with the returned
nextToken value.
32396 32397 32398 32399 32400 32401 32402 32403 32404 |
# File 'lib/aws-sdk-ec2/types.rb', line 32396 class DescribeServiceLinkVirtualInterfacesRequest < Struct.new( :service_link_virtual_interface_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
32396 32397 32398 32399 32400 32401 32402 32403 32404 |
# File 'lib/aws-sdk-ec2/types.rb', line 32396 class DescribeServiceLinkVirtualInterfacesRequest < Struct.new( :service_link_virtual_interface_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#service_link_virtual_interface_ids ⇒ Array<String>
The IDs of the service link virtual interfaces.
32396 32397 32398 32399 32400 32401 32402 32403 32404 |
# File 'lib/aws-sdk-ec2/types.rb', line 32396 class DescribeServiceLinkVirtualInterfacesRequest < Struct.new( :service_link_virtual_interface_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |