Class: Aws::EC2::Types::DescribeServiceLinkVirtualInterfacesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


31810
31811
31812
31813
31814
31815
31816
31817
31818
# File 'lib/aws-sdk-ec2/types.rb', line 31810

class DescribeServiceLinkVirtualInterfacesRequest < Struct.new(
  :service_link_virtual_interface_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters to use for narrowing down the request. The following filters are supported:

  • ‘outpost-lag-id` - The ID of the Outpost LAG.

  • ‘outpost-arn` - The Outpost ARN.

  • ‘owner-id` - The ID of the Amazon Web Services account that owns the service link virtual interface.

  • ‘state` - The state of the Outpost LAG.

  • ‘vlan` - The ID of the address pool.

  • ‘service-link-virtual-interface-id` - The ID of the service link virtual interface.

  • ‘local-gateway-virtual-interface-id` - The ID of the local gateway virtual interface.

Returns:



31810
31811
31812
31813
31814
31815
31816
31817
31818
# File 'lib/aws-sdk-ec2/types.rb', line 31810

class DescribeServiceLinkVirtualInterfacesRequest < Struct.new(
  :service_link_virtual_interface_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.

Returns:

  • (Integer)


31810
31811
31812
31813
31814
31815
31816
31817
31818
# File 'lib/aws-sdk-ec2/types.rb', line 31810

class DescribeServiceLinkVirtualInterfacesRequest < Struct.new(
  :service_link_virtual_interface_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


31810
31811
31812
31813
31814
31815
31816
31817
31818
# File 'lib/aws-sdk-ec2/types.rb', line 31810

class DescribeServiceLinkVirtualInterfacesRequest < Struct.new(
  :service_link_virtual_interface_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

The IDs of the service link virtual interfaces.

Returns:

  • (Array<String>)


31810
31811
31812
31813
31814
31815
31816
31817
31818
# File 'lib/aws-sdk-ec2/types.rb', line 31810

class DescribeServiceLinkVirtualInterfacesRequest < Struct.new(
  :service_link_virtual_interface_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end