Class: Aws::EC2::Types::DescribeSnapshotAttributeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributeString

The snapshot attribute you would like to view.

Returns:

  • (String)


32441
32442
32443
32444
32445
32446
32447
# File 'lib/aws-sdk-ec2/types.rb', line 32441

class DescribeSnapshotAttributeRequest < Struct.new(
  :attribute,
  :snapshot_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


32441
32442
32443
32444
32445
32446
32447
# File 'lib/aws-sdk-ec2/types.rb', line 32441

class DescribeSnapshotAttributeRequest < Struct.new(
  :attribute,
  :snapshot_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_idString

The ID of the EBS snapshot.

Returns:

  • (String)


32441
32442
32443
32444
32445
32446
32447
# File 'lib/aws-sdk-ec2/types.rb', line 32441

class DescribeSnapshotAttributeRequest < Struct.new(
  :attribute,
  :snapshot_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end