Class: Aws::EC2::Types::DescribeSnapshotAttributeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeSnapshotAttributeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute ⇒ String
The snapshot attribute you would like to view.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#snapshot_id ⇒ String
The ID of the EBS snapshot.
Instance Attribute Details
#attribute ⇒ String
The snapshot attribute you would like to view.
31855 31856 31857 31858 31859 31860 31861 |
# File 'lib/aws-sdk-ec2/types.rb', line 31855 class DescribeSnapshotAttributeRequest < Struct.new( :attribute, :snapshot_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
31855 31856 31857 31858 31859 31860 31861 |
# File 'lib/aws-sdk-ec2/types.rb', line 31855 class DescribeSnapshotAttributeRequest < Struct.new( :attribute, :snapshot_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#snapshot_id ⇒ String
The ID of the EBS snapshot.
31855 31856 31857 31858 31859 31860 31861 |
# File 'lib/aws-sdk-ec2/types.rb', line 31855 class DescribeSnapshotAttributeRequest < Struct.new( :attribute, :snapshot_id, :dry_run) SENSITIVE = [] include Aws::Structure end |