Class: Aws::EC2::Types::DescribeSnapshotTierStatusRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


32512
32513
32514
32515
32516
32517
32518
32519
# File 'lib/aws-sdk-ec2/types.rb', line 32512

class DescribeSnapshotTierStatusRequest < Struct.new(
  :filters,
  :dry_run,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters.

  • snapshot-id - The snapshot ID.

  • volume-id - The ID of the volume the snapshot is for.

  • last-tiering-operation - The state of the last archive or restore action. (archival-in-progress | archival-completed | archival-failed | permanent-restore-in-progress | permanent-restore-completed | permanent-restore-failed | temporary-restore-in-progress | temporary-restore-completed | temporary-restore-failed)

Returns:



32512
32513
32514
32515
32516
32517
32518
32519
# File 'lib/aws-sdk-ec2/types.rb', line 32512

class DescribeSnapshotTierStatusRequest < Struct.new(
  :filters,
  :dry_run,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.

Returns:

  • (Integer)


32512
32513
32514
32515
32516
32517
32518
32519
# File 'lib/aws-sdk-ec2/types.rb', line 32512

class DescribeSnapshotTierStatusRequest < Struct.new(
  :filters,
  :dry_run,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Returns:

  • (String)


32512
32513
32514
32515
32516
32517
32518
32519
# File 'lib/aws-sdk-ec2/types.rb', line 32512

class DescribeSnapshotTierStatusRequest < Struct.new(
  :filters,
  :dry_run,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end