Class: Aws::EC2::Types::DescribeSnapshotTierStatusResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeSnapshotTierStatusResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#snapshot_tier_statuses ⇒ Array<Types::SnapshotTierStatus>
Information about the snapshot's storage tier.
Instance Attribute Details
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
32649 32650 32651 32652 32653 32654 |
# File 'lib/aws-sdk-ec2/types.rb', line 32649 class DescribeSnapshotTierStatusResult < Struct.new( :snapshot_tier_statuses, :next_token) SENSITIVE = [] include Aws::Structure end |
#snapshot_tier_statuses ⇒ Array<Types::SnapshotTierStatus>
Information about the snapshot's storage tier.
32649 32650 32651 32652 32653 32654 |
# File 'lib/aws-sdk-ec2/types.rb', line 32649 class DescribeSnapshotTierStatusResult < Struct.new( :snapshot_tier_statuses, :next_token) SENSITIVE = [] include Aws::Structure end |