Class: Aws::EC2::Types::DescribeSnapshotsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeSnapshotsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#snapshots ⇒ Array<Types::Snapshot>
Information about the snapshots.
Instance Attribute Details
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
34033 34034 34035 34036 34037 34038 |
# File 'lib/aws-sdk-ec2/types.rb', line 34033 class DescribeSnapshotsResult < Struct.new( :next_token, :snapshots) SENSITIVE = [] include Aws::Structure end |
#snapshots ⇒ Array<Types::Snapshot>
Information about the snapshots.
34033 34034 34035 34036 34037 34038 |
# File 'lib/aws-sdk-ec2/types.rb', line 34033 class DescribeSnapshotsResult < Struct.new( :next_token, :snapshots) SENSITIVE = [] include Aws::Structure end |