Class: Aws::EC2::Types::DescribeSnapshotsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeSnapshotsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#snapshots ⇒ Array<Types::Snapshot>
Information about the snapshots.
Instance Attribute Details
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
32639 32640 32641 32642 32643 32644 |
# File 'lib/aws-sdk-ec2/types.rb', line 32639 class DescribeSnapshotsResult < Struct.new( :next_token, :snapshots) SENSITIVE = [] include Aws::Structure end |
#snapshots ⇒ Array<Types::Snapshot>
Information about the snapshots.
32639 32640 32641 32642 32643 32644 |
# File 'lib/aws-sdk-ec2/types.rb', line 32639 class DescribeSnapshotsResult < Struct.new( :next_token, :snapshots) SENSITIVE = [] include Aws::Structure end |