Class: Aws::EC2::Types::DescribeSpotDatafeedSubscriptionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for DescribeSpotDatafeedSubscription.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


32696
32697
32698
32699
32700
# File 'lib/aws-sdk-ec2/types.rb', line 32696

class DescribeSpotDatafeedSubscriptionRequest < Struct.new(
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end