Class: Aws::EC2::Types::DescribeSpotFleetInstancesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeSpotFleetInstancesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for DescribeSpotFleetInstances.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#spot_fleet_request_id ⇒ String
The ID of the Spot Fleet request.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
34107 34108 34109 34110 34111 34112 34113 34114 |
# File 'lib/aws-sdk-ec2/types.rb', line 34107 class DescribeSpotFleetInstancesRequest < Struct.new( :dry_run, :spot_fleet_request_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
34107 34108 34109 34110 34111 34112 34113 34114 |
# File 'lib/aws-sdk-ec2/types.rb', line 34107 class DescribeSpotFleetInstancesRequest < Struct.new( :dry_run, :spot_fleet_request_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
34107 34108 34109 34110 34111 34112 34113 34114 |
# File 'lib/aws-sdk-ec2/types.rb', line 34107 class DescribeSpotFleetInstancesRequest < Struct.new( :dry_run, :spot_fleet_request_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#spot_fleet_request_id ⇒ String
The ID of the Spot Fleet request.
34107 34108 34109 34110 34111 34112 34113 34114 |
# File 'lib/aws-sdk-ec2/types.rb', line 34107 class DescribeSpotFleetInstancesRequest < Struct.new( :dry_run, :spot_fleet_request_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |