Class: Aws::EC2::Types::DescribeSpotFleetInstancesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeSpotFleetInstancesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for DescribeSpotFleetInstances.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#spot_fleet_request_id ⇒ String
The ID of the Spot Fleet request.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
32236 32237 32238 32239 32240 32241 32242 32243 |
# File 'lib/aws-sdk-ec2/types.rb', line 32236 class DescribeSpotFleetInstancesRequest < Struct.new( :dry_run, :spot_fleet_request_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination
32236 32237 32238 32239 32240 32241 32242 32243 |
# File 'lib/aws-sdk-ec2/types.rb', line 32236 class DescribeSpotFleetInstancesRequest < Struct.new( :dry_run, :spot_fleet_request_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of items. This value is ‘null` when there are no more items to return.
32236 32237 32238 32239 32240 32241 32242 32243 |
# File 'lib/aws-sdk-ec2/types.rb', line 32236 class DescribeSpotFleetInstancesRequest < Struct.new( :dry_run, :spot_fleet_request_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#spot_fleet_request_id ⇒ String
The ID of the Spot Fleet request.
32236 32237 32238 32239 32240 32241 32242 32243 |
# File 'lib/aws-sdk-ec2/types.rb', line 32236 class DescribeSpotFleetInstancesRequest < Struct.new( :dry_run, :spot_fleet_request_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |