Class: Aws::EC2::Types::DescribeSpotFleetInstancesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for DescribeSpotFleetInstances.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


32135
32136
32137
32138
32139
32140
32141
32142
# File 'lib/aws-sdk-ec2/types.rb', line 32135

class DescribeSpotFleetInstancesRequest < Struct.new(
  :dry_run,
  :spot_fleet_request_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination

Returns:

  • (Integer)


32135
32136
32137
32138
32139
32140
32141
32142
# File 'lib/aws-sdk-ec2/types.rb', line 32135

class DescribeSpotFleetInstancesRequest < Struct.new(
  :dry_run,
  :spot_fleet_request_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to include in another request to get the next page of items. This value is ‘null` when there are no more items to return.

Returns:

  • (String)


32135
32136
32137
32138
32139
32140
32141
32142
# File 'lib/aws-sdk-ec2/types.rb', line 32135

class DescribeSpotFleetInstancesRequest < Struct.new(
  :dry_run,
  :spot_fleet_request_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#spot_fleet_request_idString

The ID of the Spot Fleet request.

Returns:

  • (String)


32135
32136
32137
32138
32139
32140
32141
32142
# File 'lib/aws-sdk-ec2/types.rb', line 32135

class DescribeSpotFleetInstancesRequest < Struct.new(
  :dry_run,
  :spot_fleet_request_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end