Class: Aws::EC2::Types::DescribeSpotFleetInstancesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeSpotFleetInstancesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the output of DescribeSpotFleetInstances.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#active_instances ⇒ Array<Types::ActiveInstance>
The running instances.
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#spot_fleet_request_id ⇒ String
The ID of the Spot Fleet request.
Instance Attribute Details
#active_instances ⇒ Array<Types::ActiveInstance>
The running instances. This list is refreshed periodically and might be out of date.
32748 32749 32750 32751 32752 32753 32754 |
# File 'lib/aws-sdk-ec2/types.rb', line 32748 class DescribeSpotFleetInstancesResponse < Struct.new( :active_instances, :next_token, :spot_fleet_request_id) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
32748 32749 32750 32751 32752 32753 32754 |
# File 'lib/aws-sdk-ec2/types.rb', line 32748 class DescribeSpotFleetInstancesResponse < Struct.new( :active_instances, :next_token, :spot_fleet_request_id) SENSITIVE = [] include Aws::Structure end |
#spot_fleet_request_id ⇒ String
The ID of the Spot Fleet request.
32748 32749 32750 32751 32752 32753 32754 |
# File 'lib/aws-sdk-ec2/types.rb', line 32748 class DescribeSpotFleetInstancesResponse < Struct.new( :active_instances, :next_token, :spot_fleet_request_id) SENSITIVE = [] include Aws::Structure end |