Class: Aws::EC2::Types::DescribeSpotFleetRequestHistoryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for DescribeSpotFleetRequestHistory.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


32796
32797
32798
32799
32800
32801
32802
32803
32804
32805
# File 'lib/aws-sdk-ec2/types.rb', line 32796

class DescribeSpotFleetRequestHistoryRequest < Struct.new(
  :dry_run,
  :spot_fleet_request_id,
  :event_type,
  :start_time,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#event_typeString

The type of events to describe. By default, all events are described.

Returns:

  • (String)


32796
32797
32798
32799
32800
32801
32802
32803
32804
32805
# File 'lib/aws-sdk-ec2/types.rb', line 32796

class DescribeSpotFleetRequestHistoryRequest < Struct.new(
  :dry_run,
  :spot_fleet_request_id,
  :event_type,
  :start_time,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.

Returns:

  • (Integer)


32796
32797
32798
32799
32800
32801
32802
32803
32804
32805
# File 'lib/aws-sdk-ec2/types.rb', line 32796

class DescribeSpotFleetRequestHistoryRequest < Struct.new(
  :dry_run,
  :spot_fleet_request_id,
  :event_type,
  :start_time,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to include in another request to get the next page of items. This value is null when there are no more items to return.

Returns:

  • (String)


32796
32797
32798
32799
32800
32801
32802
32803
32804
32805
# File 'lib/aws-sdk-ec2/types.rb', line 32796

class DescribeSpotFleetRequestHistoryRequest < Struct.new(
  :dry_run,
  :spot_fleet_request_id,
  :event_type,
  :start_time,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#spot_fleet_request_idString

The ID of the Spot Fleet request.

Returns:

  • (String)


32796
32797
32798
32799
32800
32801
32802
32803
32804
32805
# File 'lib/aws-sdk-ec2/types.rb', line 32796

class DescribeSpotFleetRequestHistoryRequest < Struct.new(
  :dry_run,
  :spot_fleet_request_id,
  :event_type,
  :start_time,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The starting date and time for the events, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ).

Returns:

  • (Time)


32796
32797
32798
32799
32800
32801
32802
32803
32804
32805
# File 'lib/aws-sdk-ec2/types.rb', line 32796

class DescribeSpotFleetRequestHistoryRequest < Struct.new(
  :dry_run,
  :spot_fleet_request_id,
  :event_type,
  :start_time,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end