Class: Aws::EC2::Types::DescribeSpotFleetRequestHistoryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeSpotFleetRequestHistoryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for DescribeSpotFleetRequestHistory.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#event_type ⇒ String
The type of events to describe.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#spot_fleet_request_id ⇒ String
The ID of the Spot Fleet request.
-
#start_time ⇒ Time
The starting date and time for the events, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ).
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
32755 32756 32757 32758 32759 32760 32761 32762 32763 32764 |
# File 'lib/aws-sdk-ec2/types.rb', line 32755 class DescribeSpotFleetRequestHistoryRequest < Struct.new( :dry_run, :spot_fleet_request_id, :event_type, :start_time, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#event_type ⇒ String
The type of events to describe. By default, all events are described.
32755 32756 32757 32758 32759 32760 32761 32762 32763 32764 |
# File 'lib/aws-sdk-ec2/types.rb', line 32755 class DescribeSpotFleetRequestHistoryRequest < Struct.new( :dry_run, :spot_fleet_request_id, :event_type, :start_time, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
32755 32756 32757 32758 32759 32760 32761 32762 32763 32764 |
# File 'lib/aws-sdk-ec2/types.rb', line 32755 class DescribeSpotFleetRequestHistoryRequest < Struct.new( :dry_run, :spot_fleet_request_id, :event_type, :start_time, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
32755 32756 32757 32758 32759 32760 32761 32762 32763 32764 |
# File 'lib/aws-sdk-ec2/types.rb', line 32755 class DescribeSpotFleetRequestHistoryRequest < Struct.new( :dry_run, :spot_fleet_request_id, :event_type, :start_time, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#spot_fleet_request_id ⇒ String
The ID of the Spot Fleet request.
32755 32756 32757 32758 32759 32760 32761 32762 32763 32764 |
# File 'lib/aws-sdk-ec2/types.rb', line 32755 class DescribeSpotFleetRequestHistoryRequest < Struct.new( :dry_run, :spot_fleet_request_id, :event_type, :start_time, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The starting date and time for the events, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ).
32755 32756 32757 32758 32759 32760 32761 32762 32763 32764 |
# File 'lib/aws-sdk-ec2/types.rb', line 32755 class DescribeSpotFleetRequestHistoryRequest < Struct.new( :dry_run, :spot_fleet_request_id, :event_type, :start_time, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |