Class: Aws::EC2::Types::DescribeSpotFleetRequestHistoryResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeSpotFleetRequestHistoryResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the output of DescribeSpotFleetRequestHistory.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#history_records ⇒ Array<Types::HistoryRecord>
Information about the events in the history of the Spot Fleet request.
-
#last_evaluated_time ⇒ Time
The last date and time for the events, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ).
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#spot_fleet_request_id ⇒ String
The ID of the Spot Fleet request.
-
#start_time ⇒ Time
The starting date and time for the events, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ).
Instance Attribute Details
#history_records ⇒ Array<Types::HistoryRecord>
Information about the events in the history of the Spot Fleet request.
32825 32826 32827 32828 32829 32830 32831 32832 32833 |
# File 'lib/aws-sdk-ec2/types.rb', line 32825 class DescribeSpotFleetRequestHistoryResponse < Struct.new( :history_records, :last_evaluated_time, :next_token, :spot_fleet_request_id, :start_time) SENSITIVE = [] include Aws::Structure end |
#last_evaluated_time ⇒ Time
The last date and time for the events, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ). All records up to this time were retrieved.
If nextToken indicates that there are more items, this value is
not present.
32825 32826 32827 32828 32829 32830 32831 32832 32833 |
# File 'lib/aws-sdk-ec2/types.rb', line 32825 class DescribeSpotFleetRequestHistoryResponse < Struct.new( :history_records, :last_evaluated_time, :next_token, :spot_fleet_request_id, :start_time) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
32825 32826 32827 32828 32829 32830 32831 32832 32833 |
# File 'lib/aws-sdk-ec2/types.rb', line 32825 class DescribeSpotFleetRequestHistoryResponse < Struct.new( :history_records, :last_evaluated_time, :next_token, :spot_fleet_request_id, :start_time) SENSITIVE = [] include Aws::Structure end |
#spot_fleet_request_id ⇒ String
The ID of the Spot Fleet request.
32825 32826 32827 32828 32829 32830 32831 32832 32833 |
# File 'lib/aws-sdk-ec2/types.rb', line 32825 class DescribeSpotFleetRequestHistoryResponse < Struct.new( :history_records, :last_evaluated_time, :next_token, :spot_fleet_request_id, :start_time) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The starting date and time for the events, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ).
32825 32826 32827 32828 32829 32830 32831 32832 32833 |
# File 'lib/aws-sdk-ec2/types.rb', line 32825 class DescribeSpotFleetRequestHistoryResponse < Struct.new( :history_records, :last_evaluated_time, :next_token, :spot_fleet_request_id, :start_time) SENSITIVE = [] include Aws::Structure end |