Class: Aws::EC2::Types::DescribeSpotFleetRequestsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeSpotFleetRequestsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for DescribeSpotFleetRequests.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#spot_fleet_request_ids ⇒ Array<String>
The IDs of the Spot Fleet requests.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
32253 32254 32255 32256 32257 32258 32259 32260 |
# File 'lib/aws-sdk-ec2/types.rb', line 32253 class DescribeSpotFleetRequestsRequest < Struct.new( :dry_run, :spot_fleet_request_ids, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination
32253 32254 32255 32256 32257 32258 32259 32260 |
# File 'lib/aws-sdk-ec2/types.rb', line 32253 class DescribeSpotFleetRequestsRequest < Struct.new( :dry_run, :spot_fleet_request_ids, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of items. This value is ‘null` when there are no more items to return.
32253 32254 32255 32256 32257 32258 32259 32260 |
# File 'lib/aws-sdk-ec2/types.rb', line 32253 class DescribeSpotFleetRequestsRequest < Struct.new( :dry_run, :spot_fleet_request_ids, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#spot_fleet_request_ids ⇒ Array<String>
The IDs of the Spot Fleet requests.
32253 32254 32255 32256 32257 32258 32259 32260 |
# File 'lib/aws-sdk-ec2/types.rb', line 32253 class DescribeSpotFleetRequestsRequest < Struct.new( :dry_run, :spot_fleet_request_ids, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |