Class: Aws::EC2::Types::DescribeSpotFleetRequestsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeSpotFleetRequestsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the output of DescribeSpotFleetRequests.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#spot_fleet_request_configs ⇒ Array<Types::SpotFleetRequestConfig>
Information about the configuration of your Spot Fleet.
Instance Attribute Details
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
32926 32927 32928 32929 32930 32931 |
# File 'lib/aws-sdk-ec2/types.rb', line 32926 class DescribeSpotFleetRequestsResponse < Struct.new( :next_token, :spot_fleet_request_configs) SENSITIVE = [] include Aws::Structure end |
#spot_fleet_request_configs ⇒ Array<Types::SpotFleetRequestConfig>
Information about the configuration of your Spot Fleet.
32926 32927 32928 32929 32930 32931 |
# File 'lib/aws-sdk-ec2/types.rb', line 32926 class DescribeSpotFleetRequestsResponse < Struct.new( :next_token, :spot_fleet_request_configs) SENSITIVE = [] include Aws::Structure end |