Class: Aws::EC2::Types::DescribeSpotPriceHistoryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeSpotPriceHistoryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for DescribeSpotPriceHistory.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone ⇒ String
Filters the results by the specified Availability Zone.
-
#availability_zone_id ⇒ String
Filters the results by the specified ID of the Availability Zone.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#end_time ⇒ Time
The date and time, up to the current date, from which to stop retrieving the price history data, in UTC format (for example, YYYY-MM-*DD*T*HH*:MM:*SS*Z).
-
#filters ⇒ Array<Types::Filter>
The filters.
-
#instance_types ⇒ Array<String>
Filters the results by the specified instance types.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token returned from a previous paginated request.
-
#product_descriptions ⇒ Array<String>
Filters the results by the specified basic product descriptions.
-
#start_time ⇒ Time
The date and time, up to the past 90 days, from which to start retrieving the price history data, in UTC format (for example, YYYY-MM-*DD*T*HH*:MM:*SS*Z).
Instance Attribute Details
#availability_zone ⇒ String
Filters the results by the specified Availability Zone.
Either ‘AvailabilityZone` or `AvailabilityZoneId` can be specified, but not both
32304 32305 32306 32307 32308 32309 32310 32311 32312 32313 32314 32315 32316 32317 |
# File 'lib/aws-sdk-ec2/types.rb', line 32304 class DescribeSpotPriceHistoryRequest < Struct.new( :availability_zone_id, :dry_run, :start_time, :end_time, :instance_types, :product_descriptions, :filters, :availability_zone, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
Filters the results by the specified ID of the Availability Zone.
Either ‘AvailabilityZone` or `AvailabilityZoneId` can be specified, but not both
32304 32305 32306 32307 32308 32309 32310 32311 32312 32313 32314 32315 32316 32317 |
# File 'lib/aws-sdk-ec2/types.rb', line 32304 class DescribeSpotPriceHistoryRequest < Struct.new( :availability_zone_id, :dry_run, :start_time, :end_time, :instance_types, :product_descriptions, :filters, :availability_zone, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
32304 32305 32306 32307 32308 32309 32310 32311 32312 32313 32314 32315 32316 32317 |
# File 'lib/aws-sdk-ec2/types.rb', line 32304 class DescribeSpotPriceHistoryRequest < Struct.new( :availability_zone_id, :dry_run, :start_time, :end_time, :instance_types, :product_descriptions, :filters, :availability_zone, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
The date and time, up to the current date, from which to stop retrieving the price history data, in UTC format (for example, YYYY-MM-*DD*T*HH*:MM:*SS*Z).
32304 32305 32306 32307 32308 32309 32310 32311 32312 32313 32314 32315 32316 32317 |
# File 'lib/aws-sdk-ec2/types.rb', line 32304 class DescribeSpotPriceHistoryRequest < Struct.new( :availability_zone_id, :dry_run, :start_time, :end_time, :instance_types, :product_descriptions, :filters, :availability_zone, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters.
-
‘availability-zone` - The Availability Zone for which prices should be returned.
-
‘availability-zone-id` - The ID of the Availability Zone for which prices should be returned.
-
‘instance-type` - The type of instance (for example, `m3.medium`).
-
‘product-description` - The product description for the Spot price (`Linux/UNIX` | `Red Hat Enterprise Linux` | `SUSE Linux` | `Windows` | `Linux/UNIX (Amazon VPC)` | `Red Hat Enterprise Linux (Amazon VPC)` | `SUSE Linux (Amazon VPC)` | `Windows (Amazon VPC)`).
-
‘spot-price` - The Spot price. The value must match exactly (or use wildcards; greater than or less than comparison is not supported).
-
‘timestamp` - The time stamp of the Spot price history, in UTC format (for example, *ddd MMM dd HH*:mm:ss UTC YYYY). You can use wildcards (`*` and `?`). Greater than or less than comparison is not supported.
32304 32305 32306 32307 32308 32309 32310 32311 32312 32313 32314 32315 32316 32317 |
# File 'lib/aws-sdk-ec2/types.rb', line 32304 class DescribeSpotPriceHistoryRequest < Struct.new( :availability_zone_id, :dry_run, :start_time, :end_time, :instance_types, :product_descriptions, :filters, :availability_zone, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#instance_types ⇒ Array<String>
Filters the results by the specified instance types.
32304 32305 32306 32307 32308 32309 32310 32311 32312 32313 32314 32315 32316 32317 |
# File 'lib/aws-sdk-ec2/types.rb', line 32304 class DescribeSpotPriceHistoryRequest < Struct.new( :availability_zone_id, :dry_run, :start_time, :end_time, :instance_types, :product_descriptions, :filters, :availability_zone, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination
32304 32305 32306 32307 32308 32309 32310 32311 32312 32313 32314 32315 32316 32317 |
# File 'lib/aws-sdk-ec2/types.rb', line 32304 class DescribeSpotPriceHistoryRequest < Struct.new( :availability_zone_id, :dry_run, :start_time, :end_time, :instance_types, :product_descriptions, :filters, :availability_zone, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
32304 32305 32306 32307 32308 32309 32310 32311 32312 32313 32314 32315 32316 32317 |
# File 'lib/aws-sdk-ec2/types.rb', line 32304 class DescribeSpotPriceHistoryRequest < Struct.new( :availability_zone_id, :dry_run, :start_time, :end_time, :instance_types, :product_descriptions, :filters, :availability_zone, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#product_descriptions ⇒ Array<String>
Filters the results by the specified basic product descriptions.
32304 32305 32306 32307 32308 32309 32310 32311 32312 32313 32314 32315 32316 32317 |
# File 'lib/aws-sdk-ec2/types.rb', line 32304 class DescribeSpotPriceHistoryRequest < Struct.new( :availability_zone_id, :dry_run, :start_time, :end_time, :instance_types, :product_descriptions, :filters, :availability_zone, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The date and time, up to the past 90 days, from which to start retrieving the price history data, in UTC format (for example, YYYY-MM-*DD*T*HH*:MM:*SS*Z).
32304 32305 32306 32307 32308 32309 32310 32311 32312 32313 32314 32315 32316 32317 |
# File 'lib/aws-sdk-ec2/types.rb', line 32304 class DescribeSpotPriceHistoryRequest < Struct.new( :availability_zone_id, :dry_run, :start_time, :end_time, :instance_types, :product_descriptions, :filters, :availability_zone, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |