Class: Aws::EC2::Types::DescribeSpotPriceHistoryResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the output of DescribeSpotPriceHistory.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The token to include in another request to get the next page of items. This value is an empty string ("") or null when there are no more items to return.

Returns:

  • (String)


33237
33238
33239
33240
33241
33242
# File 'lib/aws-sdk-ec2/types.rb', line 33237

class DescribeSpotPriceHistoryResult < Struct.new(
  :next_token,
  :spot_price_history)
  SENSITIVE = []
  include Aws::Structure
end

#spot_price_historyArray<Types::SpotPrice>

The historical Spot prices.

Returns:



33237
33238
33239
33240
33241
33242
# File 'lib/aws-sdk-ec2/types.rb', line 33237

class DescribeSpotPriceHistoryResult < Struct.new(
  :next_token,
  :spot_price_history)
  SENSITIVE = []
  include Aws::Structure
end