Class: Aws::EC2::Types::DescribeSpotPriceHistoryResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeSpotPriceHistoryResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the output of DescribeSpotPriceHistory.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#spot_price_history ⇒ Array<Types::SpotPrice>
The historical Spot prices.
Instance Attribute Details
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is an empty string ("") or null when there are
no more items to return.
33198 33199 33200 33201 33202 33203 |
# File 'lib/aws-sdk-ec2/types.rb', line 33198 class DescribeSpotPriceHistoryResult < Struct.new( :next_token, :spot_price_history) SENSITIVE = [] include Aws::Structure end |
#spot_price_history ⇒ Array<Types::SpotPrice>
The historical Spot prices.
33198 33199 33200 33201 33202 33203 |
# File 'lib/aws-sdk-ec2/types.rb', line 33198 class DescribeSpotPriceHistoryResult < Struct.new( :next_token, :spot_price_history) SENSITIVE = [] include Aws::Structure end |