Class: Aws::EC2::Types::DescribeStaleSecurityGroupsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


33273
33274
33275
33276
33277
33278
33279
33280
# File 'lib/aws-sdk-ec2/types.rb', line 33273

class DescribeStaleSecurityGroupsRequest < Struct.new(
  :dry_run,
  :max_results,
  :next_token,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.

Returns:

  • (Integer)


33273
33274
33275
33276
33277
33278
33279
33280
# File 'lib/aws-sdk-ec2/types.rb', line 33273

class DescribeStaleSecurityGroupsRequest < Struct.new(
  :dry_run,
  :max_results,
  :next_token,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Returns:

  • (String)


33273
33274
33275
33276
33277
33278
33279
33280
# File 'lib/aws-sdk-ec2/types.rb', line 33273

class DescribeStaleSecurityGroupsRequest < Struct.new(
  :dry_run,
  :max_results,
  :next_token,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC.

Returns:

  • (String)


33273
33274
33275
33276
33277
33278
33279
33280
# File 'lib/aws-sdk-ec2/types.rb', line 33273

class DescribeStaleSecurityGroupsRequest < Struct.new(
  :dry_run,
  :max_results,
  :next_token,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end