Class: Aws::EC2::Types::DescribeStaleSecurityGroupsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeStaleSecurityGroupsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token returned from a previous paginated request.
-
#vpc_id ⇒ String
The ID of the VPC.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
32763 32764 32765 32766 32767 32768 32769 32770 |
# File 'lib/aws-sdk-ec2/types.rb', line 32763 class DescribeStaleSecurityGroupsRequest < Struct.new( :dry_run, :max_results, :next_token, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination
32763 32764 32765 32766 32767 32768 32769 32770 |
# File 'lib/aws-sdk-ec2/types.rb', line 32763 class DescribeStaleSecurityGroupsRequest < Struct.new( :dry_run, :max_results, :next_token, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
32763 32764 32765 32766 32767 32768 32769 32770 |
# File 'lib/aws-sdk-ec2/types.rb', line 32763 class DescribeStaleSecurityGroupsRequest < Struct.new( :dry_run, :max_results, :next_token, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC.
32763 32764 32765 32766 32767 32768 32769 32770 |
# File 'lib/aws-sdk-ec2/types.rb', line 32763 class DescribeStaleSecurityGroupsRequest < Struct.new( :dry_run, :max_results, :next_token, :vpc_id) SENSITIVE = [] include Aws::Structure end |