Class: Aws::EC2::Types::DescribeStaleSecurityGroupsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeStaleSecurityGroupsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#stale_security_group_set ⇒ Array<Types::StaleSecurityGroup>
Information about the stale security groups.
Instance Attribute Details
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
33089 33090 33091 33092 33093 33094 |
# File 'lib/aws-sdk-ec2/types.rb', line 33089 class DescribeStaleSecurityGroupsResult < Struct.new( :next_token, :stale_security_group_set) SENSITIVE = [] include Aws::Structure end |
#stale_security_group_set ⇒ Array<Types::StaleSecurityGroup>
Information about the stale security groups.
33089 33090 33091 33092 33093 33094 |
# File 'lib/aws-sdk-ec2/types.rb', line 33089 class DescribeStaleSecurityGroupsResult < Struct.new( :next_token, :stale_security_group_set) SENSITIVE = [] include Aws::Structure end |