Class: Aws::EC2::Types::DescribeStoreImageTasksRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeStoreImageTasksRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The filters.
-
#image_ids ⇒ Array<String>
The AMI IDs for which to show progress.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token returned from a previous paginated request.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
31831 31832 31833 31834 31835 31836 31837 31838 31839 |
# File 'lib/aws-sdk-ec2/types.rb', line 31831 class DescribeStoreImageTasksRequest < Struct.new( :image_ids, :dry_run, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters.
-
‘task-state` - Returns tasks in a certain state (`InProgress` | `Completed` | `Failed`)
-
‘bucket` - Returns task information for tasks that targeted a specific bucket. For the filter value, specify the bucket name.
<note markdown=“1”> When you specify the ‘ImageIds` parameter, any filters that you specify are ignored. To use the filters, you must remove the `ImageIds` parameter.
</note>
31831 31832 31833 31834 31835 31836 31837 31838 31839 |
# File 'lib/aws-sdk-ec2/types.rb', line 31831 class DescribeStoreImageTasksRequest < Struct.new( :image_ids, :dry_run, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#image_ids ⇒ Array<String>
The AMI IDs for which to show progress. Up to 20 AMI IDs can be included in a request.
31831 31832 31833 31834 31835 31836 31837 31838 31839 |
# File 'lib/aws-sdk-ec2/types.rb', line 31831 class DescribeStoreImageTasksRequest < Struct.new( :image_ids, :dry_run, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].
You cannot specify this parameter and the ‘ImageIds` parameter in the same call.
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination
31831 31832 31833 31834 31835 31836 31837 31838 31839 |
# File 'lib/aws-sdk-ec2/types.rb', line 31831 class DescribeStoreImageTasksRequest < Struct.new( :image_ids, :dry_run, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
31831 31832 31833 31834 31835 31836 31837 31838 31839 |
# File 'lib/aws-sdk-ec2/types.rb', line 31831 class DescribeStoreImageTasksRequest < Struct.new( :image_ids, :dry_run, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |