Class: Aws::EC2::Types::DescribeStoreImageTasksRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


31825
31826
31827
31828
31829
31830
31831
31832
31833
# File 'lib/aws-sdk-ec2/types.rb', line 31825

class DescribeStoreImageTasksRequest < Struct.new(
  :image_ids,
  :dry_run,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters.

  • ‘task-state` - Returns tasks in a certain state (`InProgress` | `Completed` | `Failed`)

  • ‘bucket` - Returns task information for tasks that targeted a specific bucket. For the filter value, specify the bucket name.

<note markdown=“1”> When you specify the ‘ImageIds` parameter, any filters that you specify are ignored. To use the filters, you must remove the `ImageIds` parameter.

</note>

Returns:



31825
31826
31827
31828
31829
31830
31831
31832
31833
# File 'lib/aws-sdk-ec2/types.rb', line 31825

class DescribeStoreImageTasksRequest < Struct.new(
  :image_ids,
  :dry_run,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#image_idsArray<String>

The AMI IDs for which to show progress. Up to 20 AMI IDs can be included in a request.

Returns:

  • (Array<String>)


31825
31826
31827
31828
31829
31830
31831
31832
31833
# File 'lib/aws-sdk-ec2/types.rb', line 31825

class DescribeStoreImageTasksRequest < Struct.new(
  :image_ids,
  :dry_run,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].

You cannot specify this parameter and the ‘ImageIds` parameter in the same call.

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination

Returns:

  • (Integer)


31825
31826
31827
31828
31829
31830
31831
31832
31833
# File 'lib/aws-sdk-ec2/types.rb', line 31825

class DescribeStoreImageTasksRequest < Struct.new(
  :image_ids,
  :dry_run,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Returns:

  • (String)


31825
31826
31827
31828
31829
31830
31831
31832
31833
# File 'lib/aws-sdk-ec2/types.rb', line 31825

class DescribeStoreImageTasksRequest < Struct.new(
  :image_ids,
  :dry_run,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end