Class: Aws::EC2::Types::DescribeSubnetsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeSubnetsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#subnets ⇒ Array<Types::Subnet>
Information about the subnets.
Instance Attribute Details
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
33495 33496 33497 33498 33499 33500 |
# File 'lib/aws-sdk-ec2/types.rb', line 33495 class DescribeSubnetsResult < Struct.new( :next_token, :subnets) SENSITIVE = [] include Aws::Structure end |
#subnets ⇒ Array<Types::Subnet>
Information about the subnets.
33495 33496 33497 33498 33499 33500 |
# File 'lib/aws-sdk-ec2/types.rb', line 33495 class DescribeSubnetsResult < Struct.new( :next_token, :subnets) SENSITIVE = [] include Aws::Structure end |