Class: Aws::EC2::Types::DescribeSubnetsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeSubnetsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#subnets ⇒ Array<Types::Subnet>
Information about the subnets.
Instance Attribute Details
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
33316 33317 33318 33319 33320 33321 |
# File 'lib/aws-sdk-ec2/types.rb', line 33316 class DescribeSubnetsResult < Struct.new( :next_token, :subnets) SENSITIVE = [] include Aws::Structure end |
#subnets ⇒ Array<Types::Subnet>
Information about the subnets.
33316 33317 33318 33319 33320 33321 |
# File 'lib/aws-sdk-ec2/types.rb', line 33316 class DescribeSubnetsResult < Struct.new( :next_token, :subnets) SENSITIVE = [] include Aws::Structure end |