Class: Aws::EC2::Types::DescribeTrafficMirrorSessionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeTrafficMirrorSessionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
-
#traffic_mirror_session_ids ⇒ Array<String>
The ID of the Traffic Mirror session.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
33590 33591 33592 33593 33594 33595 33596 33597 33598 |
# File 'lib/aws-sdk-ec2/types.rb', line 33590 class DescribeTrafficMirrorSessionsRequest < Struct.new( :traffic_mirror_session_ids, :dry_run, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters. The possible values are:
-
description: The Traffic Mirror session description. -
network-interface-id: The ID of the Traffic Mirror session network interface. -
owner-id: The ID of the account that owns the Traffic Mirror session. -
packet-length: The assigned number of packets to mirror. -
session-number: The assigned session number. -
traffic-mirror-filter-id: The ID of the Traffic Mirror filter. -
traffic-mirror-session-id: The ID of the Traffic Mirror session. -
traffic-mirror-target-id: The ID of the Traffic Mirror target. -
virtual-network-id: The virtual network ID of the Traffic Mirror session.
33590 33591 33592 33593 33594 33595 33596 33597 33598 |
# File 'lib/aws-sdk-ec2/types.rb', line 33590 class DescribeTrafficMirrorSessionsRequest < Struct.new( :traffic_mirror_session_ids, :dry_run, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To
retrieve the remaining results, make another call with the returned
nextToken value.
33590 33591 33592 33593 33594 33595 33596 33597 33598 |
# File 'lib/aws-sdk-ec2/types.rb', line 33590 class DescribeTrafficMirrorSessionsRequest < Struct.new( :traffic_mirror_session_ids, :dry_run, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
33590 33591 33592 33593 33594 33595 33596 33597 33598 |
# File 'lib/aws-sdk-ec2/types.rb', line 33590 class DescribeTrafficMirrorSessionsRequest < Struct.new( :traffic_mirror_session_ids, :dry_run, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#traffic_mirror_session_ids ⇒ Array<String>
The ID of the Traffic Mirror session.
33590 33591 33592 33593 33594 33595 33596 33597 33598 |
# File 'lib/aws-sdk-ec2/types.rb', line 33590 class DescribeTrafficMirrorSessionsRequest < Struct.new( :traffic_mirror_session_ids, :dry_run, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |