Class: Aws::EC2::Types::DescribeTrafficMirrorTargetsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


33654
33655
33656
33657
33658
33659
33660
33661
33662
# File 'lib/aws-sdk-ec2/types.rb', line 33654

class DescribeTrafficMirrorTargetsRequest < Struct.new(
  :traffic_mirror_target_ids,
  :dry_run,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters. The possible values are:

  • ‘description`: The Traffic Mirror target description.

  • ‘network-interface-id`: The ID of the Traffic Mirror session network interface.

  • ‘network-load-balancer-arn`: The Amazon Resource Name (ARN) of the Network Load Balancer that is associated with the session.

  • ‘owner-id`: The ID of the account that owns the Traffic Mirror session.

  • ‘traffic-mirror-target-id`: The ID of the Traffic Mirror target.

Returns:



33654
33655
33656
33657
33658
33659
33660
33661
33662
# File 'lib/aws-sdk-ec2/types.rb', line 33654

class DescribeTrafficMirrorTargetsRequest < Struct.new(
  :traffic_mirror_target_ids,
  :dry_run,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.

Returns:

  • (Integer)


33654
33655
33656
33657
33658
33659
33660
33661
33662
# File 'lib/aws-sdk-ec2/types.rb', line 33654

class DescribeTrafficMirrorTargetsRequest < Struct.new(
  :traffic_mirror_target_ids,
  :dry_run,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


33654
33655
33656
33657
33658
33659
33660
33661
33662
# File 'lib/aws-sdk-ec2/types.rb', line 33654

class DescribeTrafficMirrorTargetsRequest < Struct.new(
  :traffic_mirror_target_ids,
  :dry_run,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#traffic_mirror_target_idsArray<String>

The ID of the Traffic Mirror targets.

Returns:

  • (Array<String>)


33654
33655
33656
33657
33658
33659
33660
33661
33662
# File 'lib/aws-sdk-ec2/types.rb', line 33654

class DescribeTrafficMirrorTargetsRequest < Struct.new(
  :traffic_mirror_target_ids,
  :dry_run,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end