Class: Aws::EC2::Types::DescribeTrafficMirrorTargetsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeTrafficMirrorTargetsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
-
#traffic_mirror_target_ids ⇒ Array<String>
The ID of the Traffic Mirror targets.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
33605 33606 33607 33608 33609 33610 33611 33612 33613 |
# File 'lib/aws-sdk-ec2/types.rb', line 33605 class DescribeTrafficMirrorTargetsRequest < Struct.new( :traffic_mirror_target_ids, :dry_run, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters. The possible values are:
-
‘description`: The Traffic Mirror target description.
-
‘network-interface-id`: The ID of the Traffic Mirror session network interface.
-
‘network-load-balancer-arn`: The Amazon Resource Name (ARN) of the Network Load Balancer that is associated with the session.
-
‘owner-id`: The ID of the account that owns the Traffic Mirror session.
-
‘traffic-mirror-target-id`: The ID of the Traffic Mirror target.
33605 33606 33607 33608 33609 33610 33611 33612 33613 |
# File 'lib/aws-sdk-ec2/types.rb', line 33605 class DescribeTrafficMirrorTargetsRequest < Struct.new( :traffic_mirror_target_ids, :dry_run, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.
33605 33606 33607 33608 33609 33610 33611 33612 33613 |
# File 'lib/aws-sdk-ec2/types.rb', line 33605 class DescribeTrafficMirrorTargetsRequest < Struct.new( :traffic_mirror_target_ids, :dry_run, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
33605 33606 33607 33608 33609 33610 33611 33612 33613 |
# File 'lib/aws-sdk-ec2/types.rb', line 33605 class DescribeTrafficMirrorTargetsRequest < Struct.new( :traffic_mirror_target_ids, :dry_run, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#traffic_mirror_target_ids ⇒ Array<String>
The ID of the Traffic Mirror targets.
33605 33606 33607 33608 33609 33610 33611 33612 33613 |
# File 'lib/aws-sdk-ec2/types.rb', line 33605 class DescribeTrafficMirrorTargetsRequest < Struct.new( :traffic_mirror_target_ids, :dry_run, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |