Class: Aws::EC2::Types::DescribeTransitGatewayConnectPeersRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


34991
34992
34993
34994
34995
34996
34997
34998
34999
# File 'lib/aws-sdk-ec2/types.rb', line 34991

class DescribeTransitGatewayConnectPeersRequest < Struct.new(
  :transit_gateway_connect_peer_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters. The possible values are:

  • state - The state of the Connect peer (pending | available | deleting | deleted).

  • transit-gateway-attachment-id - The ID of the attachment.

  • transit-gateway-connect-peer-id - The ID of the Connect peer.

Returns:



34991
34992
34993
34994
34995
34996
34997
34998
34999
# File 'lib/aws-sdk-ec2/types.rb', line 34991

class DescribeTransitGatewayConnectPeersRequest < Struct.new(
  :transit_gateway_connect_peer_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.

Returns:

  • (Integer)


34991
34992
34993
34994
34995
34996
34997
34998
34999
# File 'lib/aws-sdk-ec2/types.rb', line 34991

class DescribeTransitGatewayConnectPeersRequest < Struct.new(
  :transit_gateway_connect_peer_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


34991
34992
34993
34994
34995
34996
34997
34998
34999
# File 'lib/aws-sdk-ec2/types.rb', line 34991

class DescribeTransitGatewayConnectPeersRequest < Struct.new(
  :transit_gateway_connect_peer_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_connect_peer_idsArray<String>

The IDs of the Connect peers.

Returns:

  • (Array<String>)


34991
34992
34993
34994
34995
34996
34997
34998
34999
# File 'lib/aws-sdk-ec2/types.rb', line 34991

class DescribeTransitGatewayConnectPeersRequest < Struct.new(
  :transit_gateway_connect_peer_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end