Class: Aws::EC2::Types::DescribeTransitGatewayConnectPeersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeTransitGatewayConnectPeersRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
-
#transit_gateway_connect_peer_ids ⇒ Array<String>
The IDs of the Connect peers.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
33803 33804 33805 33806 33807 33808 33809 33810 33811 |
# File 'lib/aws-sdk-ec2/types.rb', line 33803 class DescribeTransitGatewayConnectPeersRequest < Struct.new( :transit_gateway_connect_peer_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters. The possible values are:
-
state- The state of the Connect peer (pending|available|deleting|deleted). -
transit-gateway-attachment-id- The ID of the attachment. -
transit-gateway-connect-peer-id- The ID of the Connect peer.
33803 33804 33805 33806 33807 33808 33809 33810 33811 |
# File 'lib/aws-sdk-ec2/types.rb', line 33803 class DescribeTransitGatewayConnectPeersRequest < Struct.new( :transit_gateway_connect_peer_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To
retrieve the remaining results, make another call with the returned
nextToken value.
33803 33804 33805 33806 33807 33808 33809 33810 33811 |
# File 'lib/aws-sdk-ec2/types.rb', line 33803 class DescribeTransitGatewayConnectPeersRequest < Struct.new( :transit_gateway_connect_peer_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
33803 33804 33805 33806 33807 33808 33809 33810 33811 |
# File 'lib/aws-sdk-ec2/types.rb', line 33803 class DescribeTransitGatewayConnectPeersRequest < Struct.new( :transit_gateway_connect_peer_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_connect_peer_ids ⇒ Array<String>
The IDs of the Connect peers.
33803 33804 33805 33806 33807 33808 33809 33810 33811 |
# File 'lib/aws-sdk-ec2/types.rb', line 33803 class DescribeTransitGatewayConnectPeersRequest < Struct.new( :transit_gateway_connect_peer_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |