Class: Aws::EC2::Types::DescribeTransitGatewayConnectsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


33466
33467
33468
33469
33470
33471
33472
33473
33474
# File 'lib/aws-sdk-ec2/types.rb', line 33466

class DescribeTransitGatewayConnectsRequest < Struct.new(
  :transit_gateway_attachment_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters. The possible values are:

  • ‘options.protocol` - The tunnel protocol (`gre`).

  • ‘state` - The state of the attachment (`initiating` | `initiatingRequest` | `pendingAcceptance` | `rollingBack` | `pending` | `available` | `modifying` | `deleting` | `deleted` | `failed` | `rejected` | `rejecting` | `failing`).

  • ‘transit-gateway-attachment-id` - The ID of the Connect attachment.

  • ‘transit-gateway-id` - The ID of the transit gateway.

  • ‘transport-transit-gateway-attachment-id` - The ID of the transit gateway attachment from which the Connect attachment was created.

Returns:



33466
33467
33468
33469
33470
33471
33472
33473
33474
# File 'lib/aws-sdk-ec2/types.rb', line 33466

class DescribeTransitGatewayConnectsRequest < Struct.new(
  :transit_gateway_attachment_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.

Returns:

  • (Integer)


33466
33467
33468
33469
33470
33471
33472
33473
33474
# File 'lib/aws-sdk-ec2/types.rb', line 33466

class DescribeTransitGatewayConnectsRequest < Struct.new(
  :transit_gateway_attachment_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


33466
33467
33468
33469
33470
33471
33472
33473
33474
# File 'lib/aws-sdk-ec2/types.rb', line 33466

class DescribeTransitGatewayConnectsRequest < Struct.new(
  :transit_gateway_attachment_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_attachment_idsArray<String>

The IDs of the attachments.

Returns:

  • (Array<String>)


33466
33467
33468
33469
33470
33471
33472
33473
33474
# File 'lib/aws-sdk-ec2/types.rb', line 33466

class DescribeTransitGatewayConnectsRequest < Struct.new(
  :transit_gateway_attachment_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end