Class: Aws::EC2::Types::DescribeTransitGatewayConnectsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeTransitGatewayConnectsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
-
#transit_gateway_attachment_ids ⇒ Array<String>
The IDs of the attachments.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
33426 33427 33428 33429 33430 33431 33432 33433 33434 |
# File 'lib/aws-sdk-ec2/types.rb', line 33426 class DescribeTransitGatewayConnectsRequest < Struct.new( :transit_gateway_attachment_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters. The possible values are:
-
‘options.protocol` - The tunnel protocol (`gre`).
-
‘state` - The state of the attachment (`initiating` | `initiatingRequest` | `pendingAcceptance` | `rollingBack` | `pending` | `available` | `modifying` | `deleting` | `deleted` | `failed` | `rejected` | `rejecting` | `failing`).
-
‘transit-gateway-attachment-id` - The ID of the Connect attachment.
-
‘transit-gateway-id` - The ID of the transit gateway.
-
‘transport-transit-gateway-attachment-id` - The ID of the transit gateway attachment from which the Connect attachment was created.
33426 33427 33428 33429 33430 33431 33432 33433 33434 |
# File 'lib/aws-sdk-ec2/types.rb', line 33426 class DescribeTransitGatewayConnectsRequest < Struct.new( :transit_gateway_attachment_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.
33426 33427 33428 33429 33430 33431 33432 33433 33434 |
# File 'lib/aws-sdk-ec2/types.rb', line 33426 class DescribeTransitGatewayConnectsRequest < Struct.new( :transit_gateway_attachment_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
33426 33427 33428 33429 33430 33431 33432 33433 33434 |
# File 'lib/aws-sdk-ec2/types.rb', line 33426 class DescribeTransitGatewayConnectsRequest < Struct.new( :transit_gateway_attachment_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_attachment_ids ⇒ Array<String>
The IDs of the attachments.
33426 33427 33428 33429 33430 33431 33432 33433 33434 |
# File 'lib/aws-sdk-ec2/types.rb', line 33426 class DescribeTransitGatewayConnectsRequest < Struct.new( :transit_gateway_attachment_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |