Class: Aws::EC2::Types::DescribeTransitGatewayMeteringPoliciesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


35488
35489
35490
35491
35492
35493
35494
35495
35496
# File 'lib/aws-sdk-ec2/types.rb', line 35488

class DescribeTransitGatewayMeteringPoliciesRequest < Struct.new(
  :transit_gateway_metering_policy_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters to apply when describing transit gateway metering policies.

Returns:



35488
35489
35490
35491
35492
35493
35494
35495
35496
# File 'lib/aws-sdk-ec2/types.rb', line 35488

class DescribeTransitGatewayMeteringPoliciesRequest < Struct.new(
  :transit_gateway_metering_policy_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.

Returns:

  • (Integer)


35488
35489
35490
35491
35492
35493
35494
35495
35496
# File 'lib/aws-sdk-ec2/types.rb', line 35488

class DescribeTransitGatewayMeteringPoliciesRequest < Struct.new(
  :transit_gateway_metering_policy_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


35488
35489
35490
35491
35492
35493
35494
35495
35496
# File 'lib/aws-sdk-ec2/types.rb', line 35488

class DescribeTransitGatewayMeteringPoliciesRequest < Struct.new(
  :transit_gateway_metering_policy_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_metering_policy_idsArray<String>

The IDs of the transit gateway metering policies to describe.

Returns:

  • (Array<String>)


35488
35489
35490
35491
35492
35493
35494
35495
35496
# File 'lib/aws-sdk-ec2/types.rb', line 35488

class DescribeTransitGatewayMeteringPoliciesRequest < Struct.new(
  :transit_gateway_metering_policy_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end