Class: Aws::EC2::Types::DescribeTransitGatewayMeteringPoliciesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


34067
34068
34069
34070
34071
34072
34073
34074
34075
# File 'lib/aws-sdk-ec2/types.rb', line 34067

class DescribeTransitGatewayMeteringPoliciesRequest < Struct.new(
  :transit_gateway_metering_policy_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters to apply when describing transit gateway metering policies.

Returns:



34067
34068
34069
34070
34071
34072
34073
34074
34075
# File 'lib/aws-sdk-ec2/types.rb', line 34067

class DescribeTransitGatewayMeteringPoliciesRequest < Struct.new(
  :transit_gateway_metering_policy_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.

Returns:

  • (Integer)


34067
34068
34069
34070
34071
34072
34073
34074
34075
# File 'lib/aws-sdk-ec2/types.rb', line 34067

class DescribeTransitGatewayMeteringPoliciesRequest < Struct.new(
  :transit_gateway_metering_policy_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


34067
34068
34069
34070
34071
34072
34073
34074
34075
# File 'lib/aws-sdk-ec2/types.rb', line 34067

class DescribeTransitGatewayMeteringPoliciesRequest < Struct.new(
  :transit_gateway_metering_policy_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_metering_policy_idsArray<String>

The IDs of the transit gateway metering policies to describe.

Returns:

  • (Array<String>)


34067
34068
34069
34070
34071
34072
34073
34074
34075
# File 'lib/aws-sdk-ec2/types.rb', line 34067

class DescribeTransitGatewayMeteringPoliciesRequest < Struct.new(
  :transit_gateway_metering_policy_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end