Class: Aws::EC2::Types::DescribeTransitGatewayMeteringPoliciesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


33923
33924
33925
33926
33927
33928
33929
33930
33931
# File 'lib/aws-sdk-ec2/types.rb', line 33923

class DescribeTransitGatewayMeteringPoliciesRequest < Struct.new(
  :transit_gateway_metering_policy_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters to apply when describing transit gateway metering policies.

Returns:



33923
33924
33925
33926
33927
33928
33929
33930
33931
# File 'lib/aws-sdk-ec2/types.rb', line 33923

class DescribeTransitGatewayMeteringPoliciesRequest < Struct.new(
  :transit_gateway_metering_policy_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.

Returns:

  • (Integer)


33923
33924
33925
33926
33927
33928
33929
33930
33931
# File 'lib/aws-sdk-ec2/types.rb', line 33923

class DescribeTransitGatewayMeteringPoliciesRequest < Struct.new(
  :transit_gateway_metering_policy_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


33923
33924
33925
33926
33927
33928
33929
33930
33931
# File 'lib/aws-sdk-ec2/types.rb', line 33923

class DescribeTransitGatewayMeteringPoliciesRequest < Struct.new(
  :transit_gateway_metering_policy_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_metering_policy_idsArray<String>

The IDs of the transit gateway metering policies to describe.

Returns:

  • (Array<String>)


33923
33924
33925
33926
33927
33928
33929
33930
33931
# File 'lib/aws-sdk-ec2/types.rb', line 33923

class DescribeTransitGatewayMeteringPoliciesRequest < Struct.new(
  :transit_gateway_metering_policy_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end