Class: Aws::EC2::Types::DescribeTransitGatewayMeteringPoliciesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeTransitGatewayMeteringPoliciesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters to apply when describing transit gateway metering policies.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
-
#transit_gateway_metering_policy_ids ⇒ Array<String>
The IDs of the transit gateway metering policies to describe.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
33229 33230 33231 33232 33233 33234 33235 33236 33237 |
# File 'lib/aws-sdk-ec2/types.rb', line 33229 class DescribeTransitGatewayMeteringPoliciesRequest < Struct.new( :transit_gateway_metering_policy_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters to apply when describing transit gateway metering policies.
33229 33230 33231 33232 33233 33234 33235 33236 33237 |
# File 'lib/aws-sdk-ec2/types.rb', line 33229 class DescribeTransitGatewayMeteringPoliciesRequest < Struct.new( :transit_gateway_metering_policy_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.
33229 33230 33231 33232 33233 33234 33235 33236 33237 |
# File 'lib/aws-sdk-ec2/types.rb', line 33229 class DescribeTransitGatewayMeteringPoliciesRequest < Struct.new( :transit_gateway_metering_policy_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
33229 33230 33231 33232 33233 33234 33235 33236 33237 |
# File 'lib/aws-sdk-ec2/types.rb', line 33229 class DescribeTransitGatewayMeteringPoliciesRequest < Struct.new( :transit_gateway_metering_policy_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_metering_policy_ids ⇒ Array<String>
The IDs of the transit gateway metering policies to describe.
33229 33230 33231 33232 33233 33234 33235 33236 33237 |
# File 'lib/aws-sdk-ec2/types.rb', line 33229 class DescribeTransitGatewayMeteringPoliciesRequest < Struct.new( :transit_gateway_metering_policy_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |