Class: Aws::EC2::Types::DescribeTransitGatewayMulticastDomainsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


34157
34158
34159
34160
34161
34162
34163
34164
34165
# File 'lib/aws-sdk-ec2/types.rb', line 34157

class DescribeTransitGatewayMulticastDomainsRequest < Struct.new(
  :transit_gateway_multicast_domain_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters. The possible values are:

  • state - The state of the transit gateway multicast domain. Valid values are pending | available | deleting | deleted.

  • transit-gateway-id - The ID of the transit gateway.

  • transit-gateway-multicast-domain-id - The ID of the transit gateway multicast domain.

Returns:



34157
34158
34159
34160
34161
34162
34163
34164
34165
# File 'lib/aws-sdk-ec2/types.rb', line 34157

class DescribeTransitGatewayMulticastDomainsRequest < Struct.new(
  :transit_gateway_multicast_domain_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.

Returns:

  • (Integer)


34157
34158
34159
34160
34161
34162
34163
34164
34165
# File 'lib/aws-sdk-ec2/types.rb', line 34157

class DescribeTransitGatewayMulticastDomainsRequest < Struct.new(
  :transit_gateway_multicast_domain_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


34157
34158
34159
34160
34161
34162
34163
34164
34165
# File 'lib/aws-sdk-ec2/types.rb', line 34157

class DescribeTransitGatewayMulticastDomainsRequest < Struct.new(
  :transit_gateway_multicast_domain_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_multicast_domain_idsArray<String>

The ID of the transit gateway multicast domain.

Returns:

  • (Array<String>)


34157
34158
34159
34160
34161
34162
34163
34164
34165
# File 'lib/aws-sdk-ec2/types.rb', line 34157

class DescribeTransitGatewayMulticastDomainsRequest < Struct.new(
  :transit_gateway_multicast_domain_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end