Class: Aws::EC2::Types::DescribeTransitGatewayPolicyTablesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeTransitGatewayPolicyTablesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The filters associated with the transit gateway policy table.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
-
#transit_gateway_policy_table_ids ⇒ Array<String>
The IDs of the transit gateway policy tables.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
34292 34293 34294 34295 34296 34297 34298 34299 34300 |
# File 'lib/aws-sdk-ec2/types.rb', line 34292 class DescribeTransitGatewayPolicyTablesRequest < Struct.new( :transit_gateway_policy_table_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters associated with the transit gateway policy table.
34292 34293 34294 34295 34296 34297 34298 34299 34300 |
# File 'lib/aws-sdk-ec2/types.rb', line 34292 class DescribeTransitGatewayPolicyTablesRequest < Struct.new( :transit_gateway_policy_table_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To
retrieve the remaining results, make another call with the returned
nextToken value.
34292 34293 34294 34295 34296 34297 34298 34299 34300 |
# File 'lib/aws-sdk-ec2/types.rb', line 34292 class DescribeTransitGatewayPolicyTablesRequest < Struct.new( :transit_gateway_policy_table_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
34292 34293 34294 34295 34296 34297 34298 34299 34300 |
# File 'lib/aws-sdk-ec2/types.rb', line 34292 class DescribeTransitGatewayPolicyTablesRequest < Struct.new( :transit_gateway_policy_table_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_policy_table_ids ⇒ Array<String>
The IDs of the transit gateway policy tables.
34292 34293 34294 34295 34296 34297 34298 34299 34300 |
# File 'lib/aws-sdk-ec2/types.rb', line 34292 class DescribeTransitGatewayPolicyTablesRequest < Struct.new( :transit_gateway_policy_table_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |