Class: Aws::EC2::Types::DescribeTransitGatewayRouteTableAnnouncementsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


35741
35742
35743
35744
35745
35746
35747
35748
35749
# File 'lib/aws-sdk-ec2/types.rb', line 35741

class DescribeTransitGatewayRouteTableAnnouncementsRequest < Struct.new(
  :transit_gateway_route_table_announcement_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters associated with the transit gateway policy table.

Returns:



35741
35742
35743
35744
35745
35746
35747
35748
35749
# File 'lib/aws-sdk-ec2/types.rb', line 35741

class DescribeTransitGatewayRouteTableAnnouncementsRequest < Struct.new(
  :transit_gateway_route_table_announcement_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.

Returns:

  • (Integer)


35741
35742
35743
35744
35745
35746
35747
35748
35749
# File 'lib/aws-sdk-ec2/types.rb', line 35741

class DescribeTransitGatewayRouteTableAnnouncementsRequest < Struct.new(
  :transit_gateway_route_table_announcement_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


35741
35742
35743
35744
35745
35746
35747
35748
35749
# File 'lib/aws-sdk-ec2/types.rb', line 35741

class DescribeTransitGatewayRouteTableAnnouncementsRequest < Struct.new(
  :transit_gateway_route_table_announcement_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_route_table_announcement_idsArray<String>

The IDs of the transit gateway route tables that are being advertised.

Returns:

  • (Array<String>)


35741
35742
35743
35744
35745
35746
35747
35748
35749
# File 'lib/aws-sdk-ec2/types.rb', line 35741

class DescribeTransitGatewayRouteTableAnnouncementsRequest < Struct.new(
  :transit_gateway_route_table_announcement_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end