Class: Aws::EC2::Types::DescribeTransitGatewayRouteTableAnnouncementsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeTransitGatewayRouteTableAnnouncementsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The filters associated with the transit gateway policy table.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
-
#transit_gateway_route_table_announcement_ids ⇒ Array<String>
The IDs of the transit gateway route tables that are being advertised.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
35732 35733 35734 35735 35736 35737 35738 35739 35740 |
# File 'lib/aws-sdk-ec2/types.rb', line 35732 class DescribeTransitGatewayRouteTableAnnouncementsRequest < Struct.new( :transit_gateway_route_table_announcement_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters associated with the transit gateway policy table.
35732 35733 35734 35735 35736 35737 35738 35739 35740 |
# File 'lib/aws-sdk-ec2/types.rb', line 35732 class DescribeTransitGatewayRouteTableAnnouncementsRequest < Struct.new( :transit_gateway_route_table_announcement_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To
retrieve the remaining results, make another call with the returned
nextToken value.
35732 35733 35734 35735 35736 35737 35738 35739 35740 |
# File 'lib/aws-sdk-ec2/types.rb', line 35732 class DescribeTransitGatewayRouteTableAnnouncementsRequest < Struct.new( :transit_gateway_route_table_announcement_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
35732 35733 35734 35735 35736 35737 35738 35739 35740 |
# File 'lib/aws-sdk-ec2/types.rb', line 35732 class DescribeTransitGatewayRouteTableAnnouncementsRequest < Struct.new( :transit_gateway_route_table_announcement_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_route_table_announcement_ids ⇒ Array<String>
The IDs of the transit gateway route tables that are being advertised.
35732 35733 35734 35735 35736 35737 35738 35739 35740 |
# File 'lib/aws-sdk-ec2/types.rb', line 35732 class DescribeTransitGatewayRouteTableAnnouncementsRequest < Struct.new( :transit_gateway_route_table_announcement_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |