Class: Aws::EC2::Types::DescribeTransitGatewayRouteTablesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


34417
34418
34419
34420
34421
34422
34423
34424
34425
# File 'lib/aws-sdk-ec2/types.rb', line 34417

class DescribeTransitGatewayRouteTablesRequest < Struct.new(
  :transit_gateway_route_table_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters. The possible values are:

  • default-association-route-table - Indicates whether this is the default association route table for the transit gateway (true | false).

  • default-propagation-route-table - Indicates whether this is the default propagation route table for the transit gateway (true | false).

  • state - The state of the route table (available | deleting | deleted | pending).

  • transit-gateway-id - The ID of the transit gateway.

  • transit-gateway-route-table-id - The ID of the transit gateway route table.

Returns:



34417
34418
34419
34420
34421
34422
34423
34424
34425
# File 'lib/aws-sdk-ec2/types.rb', line 34417

class DescribeTransitGatewayRouteTablesRequest < Struct.new(
  :transit_gateway_route_table_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.

Returns:

  • (Integer)


34417
34418
34419
34420
34421
34422
34423
34424
34425
# File 'lib/aws-sdk-ec2/types.rb', line 34417

class DescribeTransitGatewayRouteTablesRequest < Struct.new(
  :transit_gateway_route_table_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


34417
34418
34419
34420
34421
34422
34423
34424
34425
# File 'lib/aws-sdk-ec2/types.rb', line 34417

class DescribeTransitGatewayRouteTablesRequest < Struct.new(
  :transit_gateway_route_table_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_route_table_idsArray<String>

The IDs of the transit gateway route tables.

Returns:

  • (Array<String>)


34417
34418
34419
34420
34421
34422
34423
34424
34425
# File 'lib/aws-sdk-ec2/types.rb', line 34417

class DescribeTransitGatewayRouteTablesRequest < Struct.new(
  :transit_gateway_route_table_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end