Class: Aws::EC2::Types::DescribeTransitGatewayVpcAttachmentsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeTransitGatewayVpcAttachmentsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
-
#transit_gateway_attachment_ids ⇒ Array<String>
The IDs of the attachments.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
35506 35507 35508 35509 35510 35511 35512 35513 35514 |
# File 'lib/aws-sdk-ec2/types.rb', line 35506 class DescribeTransitGatewayVpcAttachmentsRequest < Struct.new( :transit_gateway_attachment_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters. The possible values are:
-
state- The state of the attachment. Valid values areavailable|deleted|deleting|failed|failing|initiatingRequest|modifying|pendingAcceptance|pending|rollingBack|rejected|rejecting. -
transit-gateway-attachment-id- The ID of the attachment. -
transit-gateway-id- The ID of the transit gateway. -
vpc-id- The ID of the VPC.
35506 35507 35508 35509 35510 35511 35512 35513 35514 |
# File 'lib/aws-sdk-ec2/types.rb', line 35506 class DescribeTransitGatewayVpcAttachmentsRequest < Struct.new( :transit_gateway_attachment_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To
retrieve the remaining results, make another call with the returned
nextToken value.
35506 35507 35508 35509 35510 35511 35512 35513 35514 |
# File 'lib/aws-sdk-ec2/types.rb', line 35506 class DescribeTransitGatewayVpcAttachmentsRequest < Struct.new( :transit_gateway_attachment_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
35506 35507 35508 35509 35510 35511 35512 35513 35514 |
# File 'lib/aws-sdk-ec2/types.rb', line 35506 class DescribeTransitGatewayVpcAttachmentsRequest < Struct.new( :transit_gateway_attachment_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_attachment_ids ⇒ Array<String>
The IDs of the attachments.
35506 35507 35508 35509 35510 35511 35512 35513 35514 |
# File 'lib/aws-sdk-ec2/types.rb', line 35506 class DescribeTransitGatewayVpcAttachmentsRequest < Struct.new( :transit_gateway_attachment_ids, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |