Class: Aws::EC2::Types::DescribeTransitGatewayVpcAttachmentsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


34269
34270
34271
34272
34273
34274
34275
34276
34277
# File 'lib/aws-sdk-ec2/types.rb', line 34269

class DescribeTransitGatewayVpcAttachmentsRequest < Struct.new(
  :transit_gateway_attachment_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters. The possible values are:

  • ‘state` - The state of the attachment. Valid values are `available` | `deleted` | `deleting` | `failed` | `failing` | `initiatingRequest` | `modifying` | `pendingAcceptance` | `pending` | `rollingBack` | `rejected` | `rejecting`.

  • ‘transit-gateway-attachment-id` - The ID of the attachment.

  • ‘transit-gateway-id` - The ID of the transit gateway.

  • ‘vpc-id` - The ID of the VPC.

Returns:



34269
34270
34271
34272
34273
34274
34275
34276
34277
# File 'lib/aws-sdk-ec2/types.rb', line 34269

class DescribeTransitGatewayVpcAttachmentsRequest < Struct.new(
  :transit_gateway_attachment_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.

Returns:

  • (Integer)


34269
34270
34271
34272
34273
34274
34275
34276
34277
# File 'lib/aws-sdk-ec2/types.rb', line 34269

class DescribeTransitGatewayVpcAttachmentsRequest < Struct.new(
  :transit_gateway_attachment_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


34269
34270
34271
34272
34273
34274
34275
34276
34277
# File 'lib/aws-sdk-ec2/types.rb', line 34269

class DescribeTransitGatewayVpcAttachmentsRequest < Struct.new(
  :transit_gateway_attachment_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_attachment_idsArray<String>

The IDs of the attachments.

Returns:

  • (Array<String>)


34269
34270
34271
34272
34273
34274
34275
34276
34277
# File 'lib/aws-sdk-ec2/types.rb', line 34269

class DescribeTransitGatewayVpcAttachmentsRequest < Struct.new(
  :transit_gateway_attachment_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end