Class: Aws::EC2::Types::DescribeTrunkInterfaceAssociationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#association_idsArray<String>

The IDs of the associations.

Returns:

  • (Array<String>)


34067
34068
34069
34070
34071
34072
34073
34074
34075
# File 'lib/aws-sdk-ec2/types.rb', line 34067

class DescribeTrunkInterfaceAssociationsRequest < Struct.new(
  :association_ids,
  :dry_run,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


34067
34068
34069
34070
34071
34072
34073
34074
34075
# File 'lib/aws-sdk-ec2/types.rb', line 34067

class DescribeTrunkInterfaceAssociationsRequest < Struct.new(
  :association_ids,
  :dry_run,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters.

  • ‘gre-key` - The ID of a trunk interface association.

  • ‘interface-protocol` - The interface protocol. Valid values are `VLAN` and `GRE`.

Returns:



34067
34068
34069
34070
34071
34072
34073
34074
34075
# File 'lib/aws-sdk-ec2/types.rb', line 34067

class DescribeTrunkInterfaceAssociationsRequest < Struct.new(
  :association_ids,
  :dry_run,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.

Returns:

  • (Integer)


34067
34068
34069
34070
34071
34072
34073
34074
34075
# File 'lib/aws-sdk-ec2/types.rb', line 34067

class DescribeTrunkInterfaceAssociationsRequest < Struct.new(
  :association_ids,
  :dry_run,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


34067
34068
34069
34070
34071
34072
34073
34074
34075
# File 'lib/aws-sdk-ec2/types.rb', line 34067

class DescribeTrunkInterfaceAssociationsRequest < Struct.new(
  :association_ids,
  :dry_run,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end