Class: Aws::EC2::Types::DescribeVerifiedAccessEndpointsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeVerifiedAccessEndpointsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
-
#verified_access_endpoint_ids ⇒ Array<String>
The ID of the Verified Access endpoint.
-
#verified_access_group_id ⇒ String
The ID of the Verified Access group.
-
#verified_access_instance_id ⇒ String
The ID of the Verified Access instance.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
34716 34717 34718 34719 34720 34721 34722 34723 34724 34725 34726 |
# File 'lib/aws-sdk-ec2/types.rb', line 34716 class DescribeVerifiedAccessEndpointsRequest < Struct.new( :verified_access_endpoint_ids, :verified_access_instance_id, :verified_access_group_id, :max_results, :next_token, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters. Filter names and values are case-sensitive.
34716 34717 34718 34719 34720 34721 34722 34723 34724 34725 34726 |
# File 'lib/aws-sdk-ec2/types.rb', line 34716 class DescribeVerifiedAccessEndpointsRequest < Struct.new( :verified_access_endpoint_ids, :verified_access_instance_id, :verified_access_group_id, :max_results, :next_token, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To
retrieve the remaining results, make another call with the returned
nextToken value.
34716 34717 34718 34719 34720 34721 34722 34723 34724 34725 34726 |
# File 'lib/aws-sdk-ec2/types.rb', line 34716 class DescribeVerifiedAccessEndpointsRequest < Struct.new( :verified_access_endpoint_ids, :verified_access_instance_id, :verified_access_group_id, :max_results, :next_token, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
34716 34717 34718 34719 34720 34721 34722 34723 34724 34725 34726 |
# File 'lib/aws-sdk-ec2/types.rb', line 34716 class DescribeVerifiedAccessEndpointsRequest < Struct.new( :verified_access_endpoint_ids, :verified_access_instance_id, :verified_access_group_id, :max_results, :next_token, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#verified_access_endpoint_ids ⇒ Array<String>
The ID of the Verified Access endpoint.
34716 34717 34718 34719 34720 34721 34722 34723 34724 34725 34726 |
# File 'lib/aws-sdk-ec2/types.rb', line 34716 class DescribeVerifiedAccessEndpointsRequest < Struct.new( :verified_access_endpoint_ids, :verified_access_instance_id, :verified_access_group_id, :max_results, :next_token, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#verified_access_group_id ⇒ String
The ID of the Verified Access group.
34716 34717 34718 34719 34720 34721 34722 34723 34724 34725 34726 |
# File 'lib/aws-sdk-ec2/types.rb', line 34716 class DescribeVerifiedAccessEndpointsRequest < Struct.new( :verified_access_endpoint_ids, :verified_access_instance_id, :verified_access_group_id, :max_results, :next_token, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#verified_access_instance_id ⇒ String
The ID of the Verified Access instance.
34716 34717 34718 34719 34720 34721 34722 34723 34724 34725 34726 |
# File 'lib/aws-sdk-ec2/types.rb', line 34716 class DescribeVerifiedAccessEndpointsRequest < Struct.new( :verified_access_endpoint_ids, :verified_access_instance_id, :verified_access_group_id, :max_results, :next_token, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |