Class: Aws::EC2::Types::DescribeVerifiedAccessGroupsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


34598
34599
34600
34601
34602
34603
34604
34605
34606
34607
# File 'lib/aws-sdk-ec2/types.rb', line 34598

class DescribeVerifiedAccessGroupsRequest < Struct.new(
  :verified_access_group_ids,
  :verified_access_instance_id,
  :max_results,
  :next_token,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters. Filter names and values are case-sensitive.

Returns:



34598
34599
34600
34601
34602
34603
34604
34605
34606
34607
# File 'lib/aws-sdk-ec2/types.rb', line 34598

class DescribeVerifiedAccessGroupsRequest < Struct.new(
  :verified_access_group_ids,
  :verified_access_instance_id,
  :max_results,
  :next_token,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.

Returns:

  • (Integer)


34598
34599
34600
34601
34602
34603
34604
34605
34606
34607
# File 'lib/aws-sdk-ec2/types.rb', line 34598

class DescribeVerifiedAccessGroupsRequest < Struct.new(
  :verified_access_group_ids,
  :verified_access_instance_id,
  :max_results,
  :next_token,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


34598
34599
34600
34601
34602
34603
34604
34605
34606
34607
# File 'lib/aws-sdk-ec2/types.rb', line 34598

class DescribeVerifiedAccessGroupsRequest < Struct.new(
  :verified_access_group_ids,
  :verified_access_instance_id,
  :max_results,
  :next_token,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#verified_access_group_idsArray<String>

The ID of the Verified Access groups.

Returns:

  • (Array<String>)


34598
34599
34600
34601
34602
34603
34604
34605
34606
34607
# File 'lib/aws-sdk-ec2/types.rb', line 34598

class DescribeVerifiedAccessGroupsRequest < Struct.new(
  :verified_access_group_ids,
  :verified_access_instance_id,
  :max_results,
  :next_token,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#verified_access_instance_idString

The ID of the Verified Access instance.

Returns:

  • (String)


34598
34599
34600
34601
34602
34603
34604
34605
34606
34607
# File 'lib/aws-sdk-ec2/types.rb', line 34598

class DescribeVerifiedAccessGroupsRequest < Struct.new(
  :verified_access_group_ids,
  :verified_access_instance_id,
  :max_results,
  :next_token,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end