Class: Aws::EC2::Types::DescribeVerifiedAccessGroupsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeVerifiedAccessGroupsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
-
#verified_access_group_ids ⇒ Array<String>
The ID of the Verified Access groups.
-
#verified_access_instance_id ⇒ String
The ID of the Verified Access instance.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
34549 34550 34551 34552 34553 34554 34555 34556 34557 34558 |
# File 'lib/aws-sdk-ec2/types.rb', line 34549 class DescribeVerifiedAccessGroupsRequest < Struct.new( :verified_access_group_ids, :verified_access_instance_id, :max_results, :next_token, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters. Filter names and values are case-sensitive.
34549 34550 34551 34552 34553 34554 34555 34556 34557 34558 |
# File 'lib/aws-sdk-ec2/types.rb', line 34549 class DescribeVerifiedAccessGroupsRequest < Struct.new( :verified_access_group_ids, :verified_access_instance_id, :max_results, :next_token, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.
34549 34550 34551 34552 34553 34554 34555 34556 34557 34558 |
# File 'lib/aws-sdk-ec2/types.rb', line 34549 class DescribeVerifiedAccessGroupsRequest < Struct.new( :verified_access_group_ids, :verified_access_instance_id, :max_results, :next_token, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
34549 34550 34551 34552 34553 34554 34555 34556 34557 34558 |
# File 'lib/aws-sdk-ec2/types.rb', line 34549 class DescribeVerifiedAccessGroupsRequest < Struct.new( :verified_access_group_ids, :verified_access_instance_id, :max_results, :next_token, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#verified_access_group_ids ⇒ Array<String>
The ID of the Verified Access groups.
34549 34550 34551 34552 34553 34554 34555 34556 34557 34558 |
# File 'lib/aws-sdk-ec2/types.rb', line 34549 class DescribeVerifiedAccessGroupsRequest < Struct.new( :verified_access_group_ids, :verified_access_instance_id, :max_results, :next_token, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#verified_access_instance_id ⇒ String
The ID of the Verified Access instance.
34549 34550 34551 34552 34553 34554 34555 34556 34557 34558 |
# File 'lib/aws-sdk-ec2/types.rb', line 34549 class DescribeVerifiedAccessGroupsRequest < Struct.new( :verified_access_group_ids, :verified_access_instance_id, :max_results, :next_token, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |