Class: Aws::EC2::Types::DescribeVerifiedAccessInstanceLoggingConfigurationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


34348
34349
34350
34351
34352
34353
34354
34355
34356
# File 'lib/aws-sdk-ec2/types.rb', line 34348

class DescribeVerifiedAccessInstanceLoggingConfigurationsRequest < Struct.new(
  :verified_access_instance_ids,
  :max_results,
  :next_token,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters. Filter names and values are case-sensitive.

Returns:



34348
34349
34350
34351
34352
34353
34354
34355
34356
# File 'lib/aws-sdk-ec2/types.rb', line 34348

class DescribeVerifiedAccessInstanceLoggingConfigurationsRequest < Struct.new(
  :verified_access_instance_ids,
  :max_results,
  :next_token,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.

Returns:

  • (Integer)


34348
34349
34350
34351
34352
34353
34354
34355
34356
# File 'lib/aws-sdk-ec2/types.rb', line 34348

class DescribeVerifiedAccessInstanceLoggingConfigurationsRequest < Struct.new(
  :verified_access_instance_ids,
  :max_results,
  :next_token,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


34348
34349
34350
34351
34352
34353
34354
34355
34356
# File 'lib/aws-sdk-ec2/types.rb', line 34348

class DescribeVerifiedAccessInstanceLoggingConfigurationsRequest < Struct.new(
  :verified_access_instance_ids,
  :max_results,
  :next_token,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#verified_access_instance_idsArray<String>

The IDs of the Verified Access instances.

Returns:

  • (Array<String>)


34348
34349
34350
34351
34352
34353
34354
34355
34356
# File 'lib/aws-sdk-ec2/types.rb', line 34348

class DescribeVerifiedAccessInstanceLoggingConfigurationsRequest < Struct.new(
  :verified_access_instance_ids,
  :max_results,
  :next_token,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end