Class: Aws::EC2::Types::DescribeVerifiedAccessInstancesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeVerifiedAccessInstancesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
-
#verified_access_instance_ids ⇒ Array<String>
The IDs of the Verified Access instances.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
34009 34010 34011 34012 34013 34014 34015 34016 34017 |
# File 'lib/aws-sdk-ec2/types.rb', line 34009 class DescribeVerifiedAccessInstancesRequest < Struct.new( :verified_access_instance_ids, :max_results, :next_token, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters. Filter names and values are case-sensitive.
34009 34010 34011 34012 34013 34014 34015 34016 34017 |
# File 'lib/aws-sdk-ec2/types.rb', line 34009 class DescribeVerifiedAccessInstancesRequest < Struct.new( :verified_access_instance_ids, :max_results, :next_token, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.
34009 34010 34011 34012 34013 34014 34015 34016 34017 |
# File 'lib/aws-sdk-ec2/types.rb', line 34009 class DescribeVerifiedAccessInstancesRequest < Struct.new( :verified_access_instance_ids, :max_results, :next_token, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
34009 34010 34011 34012 34013 34014 34015 34016 34017 |
# File 'lib/aws-sdk-ec2/types.rb', line 34009 class DescribeVerifiedAccessInstancesRequest < Struct.new( :verified_access_instance_ids, :max_results, :next_token, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#verified_access_instance_ids ⇒ Array<String>
The IDs of the Verified Access instances.
34009 34010 34011 34012 34013 34014 34015 34016 34017 |
# File 'lib/aws-sdk-ec2/types.rb', line 34009 class DescribeVerifiedAccessInstancesRequest < Struct.new( :verified_access_instance_ids, :max_results, :next_token, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |