Class: Aws::EC2::Types::DescribeVerifiedAccessInstancesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


33395
33396
33397
33398
33399
33400
33401
33402
33403
# File 'lib/aws-sdk-ec2/types.rb', line 33395

class DescribeVerifiedAccessInstancesRequest < Struct.new(
  :verified_access_instance_ids,
  :max_results,
  :next_token,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters. Filter names and values are case-sensitive.

Returns:



33395
33396
33397
33398
33399
33400
33401
33402
33403
# File 'lib/aws-sdk-ec2/types.rb', line 33395

class DescribeVerifiedAccessInstancesRequest < Struct.new(
  :verified_access_instance_ids,
  :max_results,
  :next_token,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.

Returns:

  • (Integer)


33395
33396
33397
33398
33399
33400
33401
33402
33403
# File 'lib/aws-sdk-ec2/types.rb', line 33395

class DescribeVerifiedAccessInstancesRequest < Struct.new(
  :verified_access_instance_ids,
  :max_results,
  :next_token,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


33395
33396
33397
33398
33399
33400
33401
33402
33403
# File 'lib/aws-sdk-ec2/types.rb', line 33395

class DescribeVerifiedAccessInstancesRequest < Struct.new(
  :verified_access_instance_ids,
  :max_results,
  :next_token,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#verified_access_instance_idsArray<String>

The IDs of the Verified Access instances.

Returns:

  • (Array<String>)


33395
33396
33397
33398
33399
33400
33401
33402
33403
# File 'lib/aws-sdk-ec2/types.rb', line 33395

class DescribeVerifiedAccessInstancesRequest < Struct.new(
  :verified_access_instance_ids,
  :max_results,
  :next_token,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end