Class: Aws::EC2::Types::DescribeVolumeAttributeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributeString

The attribute of the volume. This parameter is required.

Returns:

  • (String)


35013
35014
35015
35016
35017
35018
35019
# File 'lib/aws-sdk-ec2/types.rb', line 35013

class DescribeVolumeAttributeRequest < Struct.new(
  :attribute,
  :volume_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


35013
35014
35015
35016
35017
35018
35019
# File 'lib/aws-sdk-ec2/types.rb', line 35013

class DescribeVolumeAttributeRequest < Struct.new(
  :attribute,
  :volume_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#volume_idString

The ID of the volume.

Returns:

  • (String)


35013
35014
35015
35016
35017
35018
35019
# File 'lib/aws-sdk-ec2/types.rb', line 35013

class DescribeVolumeAttributeRequest < Struct.new(
  :attribute,
  :volume_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end