Class: Aws::EC2::Types::DescribeVolumeAttributeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeVolumeAttributeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute ⇒ String
The attribute of the volume.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#volume_id ⇒ String
The ID of the volume.
Instance Attribute Details
#attribute ⇒ String
The attribute of the volume. This parameter is required.
34409 34410 34411 34412 34413 34414 34415 |
# File 'lib/aws-sdk-ec2/types.rb', line 34409 class DescribeVolumeAttributeRequest < Struct.new( :attribute, :volume_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
34409 34410 34411 34412 34413 34414 34415 |
# File 'lib/aws-sdk-ec2/types.rb', line 34409 class DescribeVolumeAttributeRequest < Struct.new( :attribute, :volume_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#volume_id ⇒ String
The ID of the volume.
34409 34410 34411 34412 34413 34414 34415 |
# File 'lib/aws-sdk-ec2/types.rb', line 34409 class DescribeVolumeAttributeRequest < Struct.new( :attribute, :volume_id, :dry_run) SENSITIVE = [] include Aws::Structure end |