Class: Aws::EC2::Types::DescribeVolumeAttributeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeVolumeAttributeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute ⇒ String
The attribute of the volume.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#volume_id ⇒ String
The ID of the volume.
Instance Attribute Details
#attribute ⇒ String
The attribute of the volume. This parameter is required.
33489 33490 33491 33492 33493 33494 33495 |
# File 'lib/aws-sdk-ec2/types.rb', line 33489 class DescribeVolumeAttributeRequest < Struct.new( :attribute, :volume_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
33489 33490 33491 33492 33493 33494 33495 |
# File 'lib/aws-sdk-ec2/types.rb', line 33489 class DescribeVolumeAttributeRequest < Struct.new( :attribute, :volume_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#volume_id ⇒ String
The ID of the volume.
33489 33490 33491 33492 33493 33494 33495 |
# File 'lib/aws-sdk-ec2/types.rb', line 33489 class DescribeVolumeAttributeRequest < Struct.new( :attribute, :volume_id, :dry_run) SENSITIVE = [] include Aws::Structure end |