Class: Aws::EC2::Types::DescribeVolumeStatusRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


35092
35093
35094
35095
35096
35097
35098
35099
35100
35101
# File 'lib/aws-sdk-ec2/types.rb', line 35092

class DescribeVolumeStatusRequest < Struct.new(
  :max_results,
  :next_token,
  :volume_ids,
  :include_managed_resources,
  :dry_run,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters.

  • action.code - The action code for the event (for example, enable-volume-io).

  • action.description - A description of the action.

  • action.event-id - The event ID associated with the action.

  • availability-zone - The Availability Zone of the instance.

  • event.description - A description of the event.

  • event.event-id - The event ID.

  • event.event-type - The event type (for io-enabled: passed | failed; for io-performance: io-performance:degraded | io-performance:severely-degraded | io-performance:stalled).

  • event.not-after - The latest end time for the event.

  • event.not-before - The earliest start time for the event.

  • volume-status.details-name - The cause for volume-status.status (io-enabled | io-performance).

  • volume-status.details-status - The status of volume-status.details-name (for io-enabled: passed | failed; for io-performance: normal | degraded | severely-degraded | stalled).

  • volume-status.status - The status of the volume (ok | impaired | warning | insufficient-data).

Returns:



35092
35093
35094
35095
35096
35097
35098
35099
35100
35101
# File 'lib/aws-sdk-ec2/types.rb', line 35092

class DescribeVolumeStatusRequest < Struct.new(
  :max_results,
  :next_token,
  :volume_ids,
  :include_managed_resources,
  :dry_run,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#include_managed_resourcesBoolean

Indicates whether to include managed resources in the output. If this parameter is set to true, the output includes resources that are managed by Amazon Web Services services, even if managed resource visibility is set to hidden.

Returns:

  • (Boolean)


35092
35093
35094
35095
35096
35097
35098
35099
35100
35101
# File 'lib/aws-sdk-ec2/types.rb', line 35092

class DescribeVolumeStatusRequest < Struct.new(
  :max_results,
  :next_token,
  :volume_ids,
  :include_managed_resources,
  :dry_run,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.

Returns:

  • (Integer)


35092
35093
35094
35095
35096
35097
35098
35099
35100
35101
# File 'lib/aws-sdk-ec2/types.rb', line 35092

class DescribeVolumeStatusRequest < Struct.new(
  :max_results,
  :next_token,
  :volume_ids,
  :include_managed_resources,
  :dry_run,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Returns:

  • (String)


35092
35093
35094
35095
35096
35097
35098
35099
35100
35101
# File 'lib/aws-sdk-ec2/types.rb', line 35092

class DescribeVolumeStatusRequest < Struct.new(
  :max_results,
  :next_token,
  :volume_ids,
  :include_managed_resources,
  :dry_run,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#volume_idsArray<String>

The IDs of the volumes.

Default: Describes all your volumes.

Returns:

  • (Array<String>)


35092
35093
35094
35095
35096
35097
35098
35099
35100
35101
# File 'lib/aws-sdk-ec2/types.rb', line 35092

class DescribeVolumeStatusRequest < Struct.new(
  :max_results,
  :next_token,
  :volume_ids,
  :include_managed_resources,
  :dry_run,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end