Class: Aws::EC2::Types::DescribeVolumeStatusRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeVolumeStatusRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The filters.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token returned from a previous paginated request.
-
#volume_ids ⇒ Array<String>
The IDs of the volumes.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
34206 34207 34208 34209 34210 34211 34212 34213 34214 |
# File 'lib/aws-sdk-ec2/types.rb', line 34206 class DescribeVolumeStatusRequest < Struct.new( :max_results, :next_token, :volume_ids, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters.
-
‘action.code` - The action code for the event (for example, `enable-volume-io`).
-
‘action.description` - A description of the action.
-
‘action.event-id` - The event ID associated with the action.
-
‘availability-zone` - The Availability Zone of the instance.
-
‘event.description` - A description of the event.
-
‘event.event-id` - The event ID.
-
‘event.event-type` - The event type (for `io-enabled`: `passed` | `failed`; for `io-performance`: `io-performance:degraded` | `io-performance:severely-degraded` | `io-performance:stalled`).
-
‘event.not-after` - The latest end time for the event.
-
‘event.not-before` - The earliest start time for the event.
-
‘volume-status.details-name` - The cause for `volume-status.status` (`io-enabled` | `io-performance`).
-
‘volume-status.details-status` - The status of `volume-status.details-name` (for `io-enabled`: `passed` | `failed`; for `io-performance`: `normal` | `degraded` | `severely-degraded` | `stalled`).
-
‘volume-status.status` - The status of the volume (`ok` | `impaired` | `warning` | `insufficient-data`).
34206 34207 34208 34209 34210 34211 34212 34213 34214 |
# File 'lib/aws-sdk-ec2/types.rb', line 34206 class DescribeVolumeStatusRequest < Struct.new( :max_results, :next_token, :volume_ids, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination
34206 34207 34208 34209 34210 34211 34212 34213 34214 |
# File 'lib/aws-sdk-ec2/types.rb', line 34206 class DescribeVolumeStatusRequest < Struct.new( :max_results, :next_token, :volume_ids, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
34206 34207 34208 34209 34210 34211 34212 34213 34214 |
# File 'lib/aws-sdk-ec2/types.rb', line 34206 class DescribeVolumeStatusRequest < Struct.new( :max_results, :next_token, :volume_ids, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |
#volume_ids ⇒ Array<String>
The IDs of the volumes.
Default: Describes all your volumes.
34206 34207 34208 34209 34210 34211 34212 34213 34214 |
# File 'lib/aws-sdk-ec2/types.rb', line 34206 class DescribeVolumeStatusRequest < Struct.new( :max_results, :next_token, :volume_ids, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |