Class: Aws::EC2::Types::DescribeVolumeStatusResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeVolumeStatusResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#volume_statuses ⇒ Array<Types::VolumeStatusItem>
Information about the status of the volumes.
Instance Attribute Details
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
36485 36486 36487 36488 36489 36490 |
# File 'lib/aws-sdk-ec2/types.rb', line 36485 class DescribeVolumeStatusResult < Struct.new( :next_token, :volume_statuses) SENSITIVE = [] include Aws::Structure end |
#volume_statuses ⇒ Array<Types::VolumeStatusItem>
Information about the status of the volumes.
36485 36486 36487 36488 36489 36490 |
# File 'lib/aws-sdk-ec2/types.rb', line 36485 class DescribeVolumeStatusResult < Struct.new( :next_token, :volume_statuses) SENSITIVE = [] include Aws::Structure end |