Class: Aws::EC2::Types::DescribeVolumesModificationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


34695
34696
34697
34698
34699
34700
34701
34702
34703
# File 'lib/aws-sdk-ec2/types.rb', line 34695

class DescribeVolumesModificationsRequest < Struct.new(
  :dry_run,
  :volume_ids,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters.

  • ‘modification-state` - The current modification state (modifying | optimizing | completed | failed).

  • ‘original-iops` - The original IOPS rate of the volume.

  • ‘original-size` - The original size of the volume, in GiB.

  • ‘original-volume-type` - The original volume type of the volume (standard | io1 | io2 | gp2 | sc1 | st1).

  • ‘originalMultiAttachEnabled` - Indicates whether Multi-Attach support was enabled (true | false).

  • ‘start-time` - The modification start time.

  • ‘target-iops` - The target IOPS rate of the volume.

  • ‘target-size` - The target size of the volume, in GiB.

  • ‘target-volume-type` - The target volume type of the volume (standard | io1 | io2 | gp2 | sc1 | st1).

  • ‘targetMultiAttachEnabled` - Indicates whether Multi-Attach support is to be enabled (true | false).

  • ‘volume-id` - The ID of the volume.

Returns:



34695
34696
34697
34698
34699
34700
34701
34702
34703
# File 'lib/aws-sdk-ec2/types.rb', line 34695

class DescribeVolumesModificationsRequest < Struct.new(
  :dry_run,
  :volume_ids,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results (up to a limit of 500) to be returned in a paginated request. For more information, see [Pagination].

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination

Returns:

  • (Integer)


34695
34696
34697
34698
34699
34700
34701
34702
34703
# File 'lib/aws-sdk-ec2/types.rb', line 34695

class DescribeVolumesModificationsRequest < Struct.new(
  :dry_run,
  :volume_ids,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Returns:

  • (String)


34695
34696
34697
34698
34699
34700
34701
34702
34703
# File 'lib/aws-sdk-ec2/types.rb', line 34695

class DescribeVolumesModificationsRequest < Struct.new(
  :dry_run,
  :volume_ids,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#volume_idsArray<String>

The IDs of the volumes.

Returns:

  • (Array<String>)


34695
34696
34697
34698
34699
34700
34701
34702
34703
# File 'lib/aws-sdk-ec2/types.rb', line 34695

class DescribeVolumesModificationsRequest < Struct.new(
  :dry_run,
  :volume_ids,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end