Class: Aws::EC2::Types::DescribeVolumesModificationsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeVolumesModificationsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#volumes_modifications ⇒ Array<Types::VolumeModification>
Information about the volume modifications.
Instance Attribute Details
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
35209 35210 35211 35212 35213 35214 |
# File 'lib/aws-sdk-ec2/types.rb', line 35209 class DescribeVolumesModificationsResult < Struct.new( :next_token, :volumes_modifications) SENSITIVE = [] include Aws::Structure end |
#volumes_modifications ⇒ Array<Types::VolumeModification>
Information about the volume modifications.
35209 35210 35211 35212 35213 35214 |
# File 'lib/aws-sdk-ec2/types.rb', line 35209 class DescribeVolumesModificationsResult < Struct.new( :next_token, :volumes_modifications) SENSITIVE = [] include Aws::Structure end |