Class: Aws::EC2::Types::DescribeVolumesResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeVolumesResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#volumes ⇒ Array<Types::Volume>
Information about the volumes.
Instance Attribute Details
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
36349 36350 36351 36352 36353 36354 |
# File 'lib/aws-sdk-ec2/types.rb', line 36349 class DescribeVolumesResult < Struct.new( :next_token, :volumes) SENSITIVE = [] include Aws::Structure end |
#volumes ⇒ Array<Types::Volume>
Information about the volumes.
36349 36350 36351 36352 36353 36354 |
# File 'lib/aws-sdk-ec2/types.rb', line 36349 class DescribeVolumesResult < Struct.new( :next_token, :volumes) SENSITIVE = [] include Aws::Structure end |