Class: Aws::EC2::Types::DescribeVolumesResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeVolumesResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#volumes ⇒ Array<Types::Volume>
Information about the volumes.
Instance Attribute Details
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
35340 35341 35342 35343 35344 35345 |
# File 'lib/aws-sdk-ec2/types.rb', line 35340 class DescribeVolumesResult < Struct.new( :next_token, :volumes) SENSITIVE = [] include Aws::Structure end |
#volumes ⇒ Array<Types::Volume>
Information about the volumes.
35340 35341 35342 35343 35344 35345 |
# File 'lib/aws-sdk-ec2/types.rb', line 35340 class DescribeVolumesResult < Struct.new( :next_token, :volumes) SENSITIVE = [] include Aws::Structure end |