Class: Aws::EC2::Types::DescribeVpcAttributeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeVpcAttributeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute ⇒ String
The VPC attribute.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#vpc_id ⇒ String
The ID of the VPC.
Instance Attribute Details
#attribute ⇒ String
The VPC attribute.
36756 36757 36758 36759 36760 36761 36762 |
# File 'lib/aws-sdk-ec2/types.rb', line 36756 class DescribeVpcAttributeRequest < Struct.new( :attribute, :vpc_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
36756 36757 36758 36759 36760 36761 36762 |
# File 'lib/aws-sdk-ec2/types.rb', line 36756 class DescribeVpcAttributeRequest < Struct.new( :attribute, :vpc_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC.
36756 36757 36758 36759 36760 36761 36762 |
# File 'lib/aws-sdk-ec2/types.rb', line 36756 class DescribeVpcAttributeRequest < Struct.new( :attribute, :vpc_id, :dry_run) SENSITIVE = [] include Aws::Structure end |