Class: Aws::EC2::Types::DescribeVpcAttributeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributeString

The VPC attribute.

Returns:

  • (String)


36744
36745
36746
36747
36748
36749
36750
# File 'lib/aws-sdk-ec2/types.rb', line 36744

class DescribeVpcAttributeRequest < Struct.new(
  :attribute,
  :vpc_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


36744
36745
36746
36747
36748
36749
36750
# File 'lib/aws-sdk-ec2/types.rb', line 36744

class DescribeVpcAttributeRequest < Struct.new(
  :attribute,
  :vpc_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC.

Returns:

  • (String)


36744
36745
36746
36747
36748
36749
36750
# File 'lib/aws-sdk-ec2/types.rb', line 36744

class DescribeVpcAttributeRequest < Struct.new(
  :attribute,
  :vpc_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end