Class: Aws::EC2::Types::DescribeVpcAttributeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributeString

The VPC attribute.

Returns:

  • (String)


35389
35390
35391
35392
35393
35394
35395
# File 'lib/aws-sdk-ec2/types.rb', line 35389

class DescribeVpcAttributeRequest < Struct.new(
  :attribute,
  :vpc_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


35389
35390
35391
35392
35393
35394
35395
# File 'lib/aws-sdk-ec2/types.rb', line 35389

class DescribeVpcAttributeRequest < Struct.new(
  :attribute,
  :vpc_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC.

Returns:

  • (String)


35389
35390
35391
35392
35393
35394
35395
# File 'lib/aws-sdk-ec2/types.rb', line 35389

class DescribeVpcAttributeRequest < Struct.new(
  :attribute,
  :vpc_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end