Class: Aws::EC2::Types::DescribeVpcBlockPublicAccessExclusionsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeVpcBlockPublicAccessExclusionsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#vpc_block_public_access_exclusions ⇒ Array<Types::VpcBlockPublicAccessExclusion>
Details related to the exclusions.
Instance Attribute Details
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
35296 35297 35298 35299 35300 35301 |
# File 'lib/aws-sdk-ec2/types.rb', line 35296 class DescribeVpcBlockPublicAccessExclusionsResult < Struct.new( :vpc_block_public_access_exclusions, :next_token) SENSITIVE = [] include Aws::Structure end |
#vpc_block_public_access_exclusions ⇒ Array<Types::VpcBlockPublicAccessExclusion>
Details related to the exclusions.
35296 35297 35298 35299 35300 35301 |
# File 'lib/aws-sdk-ec2/types.rb', line 35296 class DescribeVpcBlockPublicAccessExclusionsResult < Struct.new( :vpc_block_public_access_exclusions, :next_token) SENSITIVE = [] include Aws::Structure end |