Class: Aws::EC2::Types::DescribeVpcClassicLinkDnsSupportRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination

Returns:

  • (Integer)


35297
35298
35299
35300
35301
35302
35303
# File 'lib/aws-sdk-ec2/types.rb', line 35297

class DescribeVpcClassicLinkDnsSupportRequest < Struct.new(
  :vpc_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Returns:

  • (String)


35297
35298
35299
35300
35301
35302
35303
# File 'lib/aws-sdk-ec2/types.rb', line 35297

class DescribeVpcClassicLinkDnsSupportRequest < Struct.new(
  :vpc_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idsArray<String>

The IDs of the VPCs.

Returns:

  • (Array<String>)


35297
35298
35299
35300
35301
35302
35303
# File 'lib/aws-sdk-ec2/types.rb', line 35297

class DescribeVpcClassicLinkDnsSupportRequest < Struct.new(
  :vpc_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end