Class: Aws::EC2::Types::DescribeVpcClassicLinkDnsSupportRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeVpcClassicLinkDnsSupportRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token returned from a previous paginated request.
-
#vpc_ids ⇒ Array<String>
The IDs of the VPCs.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination
34022 34023 34024 34025 34026 34027 34028 |
# File 'lib/aws-sdk-ec2/types.rb', line 34022 class DescribeVpcClassicLinkDnsSupportRequest < Struct.new( :vpc_ids, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
34022 34023 34024 34025 34026 34027 34028 |
# File 'lib/aws-sdk-ec2/types.rb', line 34022 class DescribeVpcClassicLinkDnsSupportRequest < Struct.new( :vpc_ids, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#vpc_ids ⇒ Array<String>
The IDs of the VPCs.
34022 34023 34024 34025 34026 34027 34028 |
# File 'lib/aws-sdk-ec2/types.rb', line 34022 class DescribeVpcClassicLinkDnsSupportRequest < Struct.new( :vpc_ids, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |