Class: Aws::EC2::Types::DescribeVpcEncryptionControlsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeVpcEncryptionControlsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The filters to apply to the request.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token returned from a previous paginated request.
-
#vpc_encryption_control_ids ⇒ Array<String>
The IDs of the VPC Encryption Control configurations to describe.
-
#vpc_ids ⇒ Array<String>
The IDs of the VPCs to describe encryption control configurations for.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
37024 37025 37026 37027 37028 37029 37030 37031 37032 37033 |
# File 'lib/aws-sdk-ec2/types.rb', line 37024 class DescribeVpcEncryptionControlsRequest < Struct.new( :dry_run, :filters, :vpc_encryption_control_ids, :vpc_ids, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters to apply to the request.
37024 37025 37026 37027 37028 37029 37030 37031 37032 37033 |
# File 'lib/aws-sdk-ec2/types.rb', line 37024 class DescribeVpcEncryptionControlsRequest < Struct.new( :dry_run, :filters, :vpc_encryption_control_ids, :vpc_ids, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
37024 37025 37026 37027 37028 37029 37030 37031 37032 37033 |
# File 'lib/aws-sdk-ec2/types.rb', line 37024 class DescribeVpcEncryptionControlsRequest < Struct.new( :dry_run, :filters, :vpc_encryption_control_ids, :vpc_ids, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
37024 37025 37026 37027 37028 37029 37030 37031 37032 37033 |
# File 'lib/aws-sdk-ec2/types.rb', line 37024 class DescribeVpcEncryptionControlsRequest < Struct.new( :dry_run, :filters, :vpc_encryption_control_ids, :vpc_ids, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#vpc_encryption_control_ids ⇒ Array<String>
The IDs of the VPC Encryption Control configurations to describe.
37024 37025 37026 37027 37028 37029 37030 37031 37032 37033 |
# File 'lib/aws-sdk-ec2/types.rb', line 37024 class DescribeVpcEncryptionControlsRequest < Struct.new( :dry_run, :filters, :vpc_encryption_control_ids, :vpc_ids, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#vpc_ids ⇒ Array<String>
The IDs of the VPCs to describe encryption control configurations for.
37024 37025 37026 37027 37028 37029 37030 37031 37032 37033 |
# File 'lib/aws-sdk-ec2/types.rb', line 37024 class DescribeVpcEncryptionControlsRequest < Struct.new( :dry_run, :filters, :vpc_encryption_control_ids, :vpc_ids, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |