Class: Aws::EC2::Types::DescribeVpcEncryptionControlsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


35653
35654
35655
35656
35657
35658
35659
35660
35661
35662
# File 'lib/aws-sdk-ec2/types.rb', line 35653

class DescribeVpcEncryptionControlsRequest < Struct.new(
  :dry_run,
  :filters,
  :vpc_encryption_control_ids,
  :vpc_ids,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters to apply to the request.

Returns:



35653
35654
35655
35656
35657
35658
35659
35660
35661
35662
# File 'lib/aws-sdk-ec2/types.rb', line 35653

class DescribeVpcEncryptionControlsRequest < Struct.new(
  :dry_run,
  :filters,
  :vpc_encryption_control_ids,
  :vpc_ids,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.

Returns:

  • (Integer)


35653
35654
35655
35656
35657
35658
35659
35660
35661
35662
# File 'lib/aws-sdk-ec2/types.rb', line 35653

class DescribeVpcEncryptionControlsRequest < Struct.new(
  :dry_run,
  :filters,
  :vpc_encryption_control_ids,
  :vpc_ids,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Returns:

  • (String)


35653
35654
35655
35656
35657
35658
35659
35660
35661
35662
# File 'lib/aws-sdk-ec2/types.rb', line 35653

class DescribeVpcEncryptionControlsRequest < Struct.new(
  :dry_run,
  :filters,
  :vpc_encryption_control_ids,
  :vpc_ids,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_encryption_control_idsArray<String>

The IDs of the VPC Encryption Control configurations to describe.

Returns:

  • (Array<String>)


35653
35654
35655
35656
35657
35658
35659
35660
35661
35662
# File 'lib/aws-sdk-ec2/types.rb', line 35653

class DescribeVpcEncryptionControlsRequest < Struct.new(
  :dry_run,
  :filters,
  :vpc_encryption_control_ids,
  :vpc_ids,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idsArray<String>

The IDs of the VPCs to describe encryption control configurations for.

Returns:

  • (Array<String>)


35653
35654
35655
35656
35657
35658
35659
35660
35661
35662
# File 'lib/aws-sdk-ec2/types.rb', line 35653

class DescribeVpcEncryptionControlsRequest < Struct.new(
  :dry_run,
  :filters,
  :vpc_encryption_control_ids,
  :vpc_ids,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end