Class: Aws::EC2::Types::DescribeVpcEncryptionControlsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeVpcEncryptionControlsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#vpc_encryption_controls ⇒ Array<Types::VpcEncryptionControl>
Information about the VPC Encryption Control configurations.
Instance Attribute Details
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
35488 35489 35490 35491 35492 35493 |
# File 'lib/aws-sdk-ec2/types.rb', line 35488 class DescribeVpcEncryptionControlsResult < Struct.new( :vpc_encryption_controls, :next_token) SENSITIVE = [] include Aws::Structure end |
#vpc_encryption_controls ⇒ Array<Types::VpcEncryptionControl>
Information about the VPC Encryption Control configurations.
35488 35489 35490 35491 35492 35493 |
# File 'lib/aws-sdk-ec2/types.rb', line 35488 class DescribeVpcEncryptionControlsResult < Struct.new( :vpc_encryption_controls, :next_token) SENSITIVE = [] include Aws::Structure end |