Class: Aws::EC2::Types::DescribeVpcEndpointAssociationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeVpcEndpointAssociationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The filters.
-
#max_results ⇒ Integer
The maximum page size.
-
#next_token ⇒ String
The pagination token.
-
#vpc_endpoint_ids ⇒ Array<String>
The IDs of the VPC endpoints.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
35538 35539 35540 35541 35542 35543 35544 35545 35546 |
# File 'lib/aws-sdk-ec2/types.rb', line 35538 class DescribeVpcEndpointAssociationsRequest < Struct.new( :dry_run, :vpc_endpoint_ids, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters.
-
vpc-endpoint-id- The ID of the VPC endpoint. -
associated-resource-accessibility- The association state. When the state isaccessible, it returnsAVAILABLE. When the state isinaccessible, it returnsPENDINGorFAILED. -
association-id- The ID of the VPC endpoint association. -
associated-resource-id- The ID of the associated resource configuration. -
service-network-arn- The Amazon Resource Name (ARN) of the associated service network. Only VPC endpoints of type service network will be returned. -
resource-configuration-group-arn- The Amazon Resource Name (ARN) of the resource configuration of type GROUP.
35538 35539 35540 35541 35542 35543 35544 35545 35546 |
# File 'lib/aws-sdk-ec2/types.rb', line 35538 class DescribeVpcEndpointAssociationsRequest < Struct.new( :dry_run, :vpc_endpoint_ids, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum page size.
35538 35539 35540 35541 35542 35543 35544 35545 35546 |
# File 'lib/aws-sdk-ec2/types.rb', line 35538 class DescribeVpcEndpointAssociationsRequest < Struct.new( :dry_run, :vpc_endpoint_ids, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token.
35538 35539 35540 35541 35542 35543 35544 35545 35546 |
# File 'lib/aws-sdk-ec2/types.rb', line 35538 class DescribeVpcEndpointAssociationsRequest < Struct.new( :dry_run, :vpc_endpoint_ids, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#vpc_endpoint_ids ⇒ Array<String>
The IDs of the VPC endpoints.
35538 35539 35540 35541 35542 35543 35544 35545 35546 |
# File 'lib/aws-sdk-ec2/types.rb', line 35538 class DescribeVpcEndpointAssociationsRequest < Struct.new( :dry_run, :vpc_endpoint_ids, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |