Class: Aws::EC2::Types::DescribeVpcEndpointAssociationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


35232
35233
35234
35235
35236
35237
35238
35239
35240
# File 'lib/aws-sdk-ec2/types.rb', line 35232

class DescribeVpcEndpointAssociationsRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_ids,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters.

  • ‘vpc-endpoint-id` - The ID of the VPC endpoint.

  • ‘associated-resource-accessibility` - The association state. When the state is `accessible`, it returns `AVAILABLE`. When the state is `inaccessible`, it returns `PENDING` or `FAILED`.

  • ‘association-id` - The ID of the VPC endpoint association.

  • ‘associated-resource-id` - The ID of the associated resource configuration.

  • ‘service-network-arn` - The Amazon Resource Name (ARN) of the associated service network. Only VPC endpoints of type service network will be returned.

  • ‘resource-configuration-group-arn` - The Amazon Resource Name (ARN) of the resource configuration of type GROUP.

Returns:



35232
35233
35234
35235
35236
35237
35238
35239
35240
# File 'lib/aws-sdk-ec2/types.rb', line 35232

class DescribeVpcEndpointAssociationsRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_ids,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum page size.

Returns:

  • (Integer)


35232
35233
35234
35235
35236
35237
35238
35239
35240
# File 'lib/aws-sdk-ec2/types.rb', line 35232

class DescribeVpcEndpointAssociationsRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_ids,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token.

Returns:

  • (String)


35232
35233
35234
35235
35236
35237
35238
35239
35240
# File 'lib/aws-sdk-ec2/types.rb', line 35232

class DescribeVpcEndpointAssociationsRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_ids,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_endpoint_idsArray<String>

The IDs of the VPC endpoints.

Returns:

  • (Array<String>)


35232
35233
35234
35235
35236
35237
35238
35239
35240
# File 'lib/aws-sdk-ec2/types.rb', line 35232

class DescribeVpcEndpointAssociationsRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_ids,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end