Class: Aws::EC2::Types::DescribeVpcEndpointConnectionNotificationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeVpcEndpointConnectionNotificationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection_notification_id ⇒ String
The ID of the notification.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The filters.
-
#max_results ⇒ Integer
The maximum number of results to return in a single call.
-
#next_token ⇒ String
The token to request the next page of results.
Instance Attribute Details
#connection_notification_id ⇒ String
The ID of the notification.
34277 34278 34279 34280 34281 34282 34283 34284 34285 |
# File 'lib/aws-sdk-ec2/types.rb', line 34277 class DescribeVpcEndpointConnectionNotificationsRequest < Struct.new( :dry_run, :connection_notification_id, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
34277 34278 34279 34280 34281 34282 34283 34284 34285 |
# File 'lib/aws-sdk-ec2/types.rb', line 34277 class DescribeVpcEndpointConnectionNotificationsRequest < Struct.new( :dry_run, :connection_notification_id, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters.
-
‘connection-notification-arn` - The ARN of the SNS topic for the notification.
-
‘connection-notification-id` - The ID of the notification.
-
‘connection-notification-state` - The state of the notification (`Enabled` | `Disabled`).
-
‘connection-notification-type` - The type of notification (`Topic`).
-
‘service-id` - The ID of the endpoint service.
-
‘vpc-endpoint-id` - The ID of the VPC endpoint.
34277 34278 34279 34280 34281 34282 34283 34284 34285 |
# File 'lib/aws-sdk-ec2/types.rb', line 34277 class DescribeVpcEndpointConnectionNotificationsRequest < Struct.new( :dry_run, :connection_notification_id, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in a single call. To retrieve the remaining results, make another request with the returned ‘NextToken` value.
34277 34278 34279 34280 34281 34282 34283 34284 34285 |
# File 'lib/aws-sdk-ec2/types.rb', line 34277 class DescribeVpcEndpointConnectionNotificationsRequest < Struct.new( :dry_run, :connection_notification_id, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to request the next page of results.
34277 34278 34279 34280 34281 34282 34283 34284 34285 |
# File 'lib/aws-sdk-ec2/types.rb', line 34277 class DescribeVpcEndpointConnectionNotificationsRequest < Struct.new( :dry_run, :connection_notification_id, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |