Class: Aws::EC2::Types::DescribeVpcEndpointConnectionNotificationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#connection_notification_idString

The ID of the notification.

Returns:

  • (String)


34271
34272
34273
34274
34275
34276
34277
34278
34279
# File 'lib/aws-sdk-ec2/types.rb', line 34271

class DescribeVpcEndpointConnectionNotificationsRequest < Struct.new(
  :dry_run,
  :connection_notification_id,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


34271
34272
34273
34274
34275
34276
34277
34278
34279
# File 'lib/aws-sdk-ec2/types.rb', line 34271

class DescribeVpcEndpointConnectionNotificationsRequest < Struct.new(
  :dry_run,
  :connection_notification_id,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters.

  • ‘connection-notification-arn` - The ARN of the SNS topic for the notification.

  • ‘connection-notification-id` - The ID of the notification.

  • ‘connection-notification-state` - The state of the notification (`Enabled` | `Disabled`).

  • ‘connection-notification-type` - The type of notification (`Topic`).

  • ‘service-id` - The ID of the endpoint service.

  • ‘vpc-endpoint-id` - The ID of the VPC endpoint.

Returns:



34271
34272
34273
34274
34275
34276
34277
34278
34279
# File 'lib/aws-sdk-ec2/types.rb', line 34271

class DescribeVpcEndpointConnectionNotificationsRequest < Struct.new(
  :dry_run,
  :connection_notification_id,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in a single call. To retrieve the remaining results, make another request with the returned ‘NextToken` value.

Returns:

  • (Integer)


34271
34272
34273
34274
34275
34276
34277
34278
34279
# File 'lib/aws-sdk-ec2/types.rb', line 34271

class DescribeVpcEndpointConnectionNotificationsRequest < Struct.new(
  :dry_run,
  :connection_notification_id,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to request the next page of results.

Returns:

  • (String)


34271
34272
34273
34274
34275
34276
34277
34278
34279
# File 'lib/aws-sdk-ec2/types.rb', line 34271

class DescribeVpcEndpointConnectionNotificationsRequest < Struct.new(
  :dry_run,
  :connection_notification_id,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end