Class: Aws::EC2::Types::DescribeVpcEndpointConnectionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


35269
35270
35271
35272
35273
35274
35275
35276
# File 'lib/aws-sdk-ec2/types.rb', line 35269

class DescribeVpcEndpointConnectionsRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters.

  • ‘ip-address-type` - The IP address type (`ipv4` | `ipv6`).

  • ‘service-id` - The ID of the service.

  • ‘vpc-endpoint-owner` - The ID of the Amazon Web Services account ID that owns the endpoint.

  • ‘vpc-endpoint-region` - The Region of the endpoint or `cross-region` to find endpoints for other Regions.

  • ‘vpc-endpoint-state` - The state of the endpoint (`pendingAcceptance` | `pending` | `available` | `deleting` | `deleted` | `rejected` | `failed`).

  • ‘vpc-endpoint-id` - The ID of the endpoint.

Returns:



35269
35270
35271
35272
35273
35274
35275
35276
# File 'lib/aws-sdk-ec2/types.rb', line 35269

class DescribeVpcEndpointConnectionsRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return for the request in a single page. The remaining results of the initial request can be seen by sending another request with the returned ‘NextToken` value. This value can be between 5 and 1,000; if `MaxResults` is given a value larger than 1,000, only 1,000 results are returned.

Returns:

  • (Integer)


35269
35270
35271
35272
35273
35274
35275
35276
# File 'lib/aws-sdk-ec2/types.rb', line 35269

class DescribeVpcEndpointConnectionsRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to retrieve the next page of results.

Returns:

  • (String)


35269
35270
35271
35272
35273
35274
35275
35276
# File 'lib/aws-sdk-ec2/types.rb', line 35269

class DescribeVpcEndpointConnectionsRequest < Struct.new(
  :dry_run,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end