Class: Aws::EC2::Types::DescribeVpcEndpointServicePermissionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


35765
35766
35767
35768
35769
35770
35771
35772
35773
# File 'lib/aws-sdk-ec2/types.rb', line 35765

class DescribeVpcEndpointServicePermissionsRequest < Struct.new(
  :dry_run,
  :service_id,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters.

  • ‘principal` - The ARN of the principal.

  • ‘principal-type` - The principal type (`All` | `Service` | `OrganizationUnit` | `Account` | `User` | `Role`).

Returns:



35765
35766
35767
35768
35769
35770
35771
35772
35773
# File 'lib/aws-sdk-ec2/types.rb', line 35765

class DescribeVpcEndpointServicePermissionsRequest < Struct.new(
  :dry_run,
  :service_id,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return for the request in a single page. The remaining results of the initial request can be seen by sending another request with the returned ‘NextToken` value. This value can be between 5 and 1,000; if `MaxResults` is given a value larger than 1,000, only 1,000 results are returned.

Returns:

  • (Integer)


35765
35766
35767
35768
35769
35770
35771
35772
35773
# File 'lib/aws-sdk-ec2/types.rb', line 35765

class DescribeVpcEndpointServicePermissionsRequest < Struct.new(
  :dry_run,
  :service_id,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to retrieve the next page of results.

Returns:

  • (String)


35765
35766
35767
35768
35769
35770
35771
35772
35773
# File 'lib/aws-sdk-ec2/types.rb', line 35765

class DescribeVpcEndpointServicePermissionsRequest < Struct.new(
  :dry_run,
  :service_id,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#service_idString

The ID of the service.

Returns:

  • (String)


35765
35766
35767
35768
35769
35770
35771
35772
35773
# File 'lib/aws-sdk-ec2/types.rb', line 35765

class DescribeVpcEndpointServicePermissionsRequest < Struct.new(
  :dry_run,
  :service_id,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end