Class: Aws::EC2::Types::DescribeVpcEndpointServicePermissionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeVpcEndpointServicePermissionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The filters.
-
#max_results ⇒ Integer
The maximum number of results to return for the request in a single page.
-
#next_token ⇒ String
The token to retrieve the next page of results.
-
#service_id ⇒ String
The ID of the service.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
35407 35408 35409 35410 35411 35412 35413 35414 35415 |
# File 'lib/aws-sdk-ec2/types.rb', line 35407 class DescribeVpcEndpointServicePermissionsRequest < Struct.new( :dry_run, :service_id, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters.
-
‘principal` - The ARN of the principal.
-
‘principal-type` - The principal type (`All` | `Service` | `OrganizationUnit` | `Account` | `User` | `Role`).
35407 35408 35409 35410 35411 35412 35413 35414 35415 |
# File 'lib/aws-sdk-ec2/types.rb', line 35407 class DescribeVpcEndpointServicePermissionsRequest < Struct.new( :dry_run, :service_id, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return for the request in a single page. The remaining results of the initial request can be seen by sending another request with the returned ‘NextToken` value. This value can be between 5 and 1,000; if `MaxResults` is given a value larger than 1,000, only 1,000 results are returned.
35407 35408 35409 35410 35411 35412 35413 35414 35415 |
# File 'lib/aws-sdk-ec2/types.rb', line 35407 class DescribeVpcEndpointServicePermissionsRequest < Struct.new( :dry_run, :service_id, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to retrieve the next page of results.
35407 35408 35409 35410 35411 35412 35413 35414 35415 |
# File 'lib/aws-sdk-ec2/types.rb', line 35407 class DescribeVpcEndpointServicePermissionsRequest < Struct.new( :dry_run, :service_id, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#service_id ⇒ String
The ID of the service.
35407 35408 35409 35410 35411 35412 35413 35414 35415 |
# File 'lib/aws-sdk-ec2/types.rb', line 35407 class DescribeVpcEndpointServicePermissionsRequest < Struct.new( :dry_run, :service_id, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |