Class: Aws::EC2::Types::DescribeVpcEndpointServicesResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeVpcEndpointServicesResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to use when requesting the next set of items.
-
#service_details ⇒ Array<Types::ServiceDetail>
Information about the service.
-
#service_names ⇒ Array<String>
The supported services.
Instance Attribute Details
#next_token ⇒ String
The token to use when requesting the next set of items. If there are no additional items to return, the string is empty.
36230 36231 36232 36233 36234 36235 36236 |
# File 'lib/aws-sdk-ec2/types.rb', line 36230 class DescribeVpcEndpointServicesResult < Struct.new( :service_names, :service_details, :next_token) SENSITIVE = [] include Aws::Structure end |
#service_details ⇒ Array<Types::ServiceDetail>
Information about the service.
36230 36231 36232 36233 36234 36235 36236 |
# File 'lib/aws-sdk-ec2/types.rb', line 36230 class DescribeVpcEndpointServicesResult < Struct.new( :service_names, :service_details, :next_token) SENSITIVE = [] include Aws::Structure end |
#service_names ⇒ Array<String>
The supported services.
36230 36231 36232 36233 36234 36235 36236 |
# File 'lib/aws-sdk-ec2/types.rb', line 36230 class DescribeVpcEndpointServicesResult < Struct.new( :service_names, :service_details, :next_token) SENSITIVE = [] include Aws::Structure end |