Class: Aws::EC2::Types::DescribeVpcEndpointServicesResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeVpcEndpointServicesResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to use when requesting the next set of items.
-
#service_details ⇒ Array<Types::ServiceDetail>
Information about the service.
-
#service_names ⇒ Array<String>
The supported services.
Instance Attribute Details
#next_token ⇒ String
The token to use when requesting the next set of items. If there are no additional items to return, the string is empty.
35926 35927 35928 35929 35930 35931 35932 |
# File 'lib/aws-sdk-ec2/types.rb', line 35926 class DescribeVpcEndpointServicesResult < Struct.new( :service_names, :service_details, :next_token) SENSITIVE = [] include Aws::Structure end |
#service_details ⇒ Array<Types::ServiceDetail>
Information about the service.
35926 35927 35928 35929 35930 35931 35932 |
# File 'lib/aws-sdk-ec2/types.rb', line 35926 class DescribeVpcEndpointServicesResult < Struct.new( :service_names, :service_details, :next_token) SENSITIVE = [] include Aws::Structure end |
#service_names ⇒ Array<String>
The supported services.
35926 35927 35928 35929 35930 35931 35932 |
# File 'lib/aws-sdk-ec2/types.rb', line 35926 class DescribeVpcEndpointServicesResult < Struct.new( :service_names, :service_details, :next_token) SENSITIVE = [] include Aws::Structure end |