Class: Aws::EC2::Types::DescribeVpcEndpointServicesResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeVpcEndpointServicesResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to use when requesting the next set of items.
-
#service_details ⇒ Array<Types::ServiceDetail>
Information about the service.
-
#service_names ⇒ Array<String>
The supported services.
Instance Attribute Details
#next_token ⇒ String
The token to use when requesting the next set of items. If there are no additional items to return, the string is empty.
35877 35878 35879 35880 35881 35882 35883 |
# File 'lib/aws-sdk-ec2/types.rb', line 35877 class DescribeVpcEndpointServicesResult < Struct.new( :service_names, :service_details, :next_token) SENSITIVE = [] include Aws::Structure end |
#service_details ⇒ Array<Types::ServiceDetail>
Information about the service.
35877 35878 35879 35880 35881 35882 35883 |
# File 'lib/aws-sdk-ec2/types.rb', line 35877 class DescribeVpcEndpointServicesResult < Struct.new( :service_names, :service_details, :next_token) SENSITIVE = [] include Aws::Structure end |
#service_names ⇒ Array<String>
The supported services.
35877 35878 35879 35880 35881 35882 35883 |
# File 'lib/aws-sdk-ec2/types.rb', line 35877 class DescribeVpcEndpointServicesResult < Struct.new( :service_names, :service_details, :next_token) SENSITIVE = [] include Aws::Structure end |