Class: Aws::EC2::Types::DescribeVpcPeeringConnectionsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeVpcPeeringConnectionsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#vpc_peering_connections ⇒ Array<Types::VpcPeeringConnection>
Information about the VPC peering connections.
Instance Attribute Details
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
36289 36290 36291 36292 36293 36294 |
# File 'lib/aws-sdk-ec2/types.rb', line 36289 class DescribeVpcPeeringConnectionsResult < Struct.new( :vpc_peering_connections, :next_token) SENSITIVE = [] include Aws::Structure end |
#vpc_peering_connections ⇒ Array<Types::VpcPeeringConnection>
Information about the VPC peering connections.
36289 36290 36291 36292 36293 36294 |
# File 'lib/aws-sdk-ec2/types.rb', line 36289 class DescribeVpcPeeringConnectionsResult < Struct.new( :vpc_peering_connections, :next_token) SENSITIVE = [] include Aws::Structure end |