Class: Aws::EC2::Types::DescribeVpcsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DescribeVpcsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#vpcs ⇒ Array<Types::Vpc>
Information about the VPCs.
Instance Attribute Details
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
36411 36412 36413 36414 36415 36416 |
# File 'lib/aws-sdk-ec2/types.rb', line 36411 class DescribeVpcsResult < Struct.new( :next_token, :vpcs) SENSITIVE = [] include Aws::Structure end |
#vpcs ⇒ Array<Types::Vpc>
Information about the VPCs.
36411 36412 36413 36414 36415 36416 |
# File 'lib/aws-sdk-ec2/types.rb', line 36411 class DescribeVpcsResult < Struct.new( :next_token, :vpcs) SENSITIVE = [] include Aws::Structure end |