Class: Aws::EC2::Types::DescribeVpnConcentratorsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


37454
37455
37456
37457
37458
37459
37460
37461
37462
# File 'lib/aws-sdk-ec2/types.rb', line 37454

class DescribeVpnConcentratorsRequest < Struct.new(
  :vpn_concentrator_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters to limit the results.

Returns:



37454
37455
37456
37457
37458
37459
37460
37461
37462
# File 'lib/aws-sdk-ec2/types.rb', line 37454

class DescribeVpnConcentratorsRequest < Struct.new(
  :vpn_concentrator_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.

Returns:

  • (Integer)


37454
37455
37456
37457
37458
37459
37460
37461
37462
# File 'lib/aws-sdk-ec2/types.rb', line 37454

class DescribeVpnConcentratorsRequest < Struct.new(
  :vpn_concentrator_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


37454
37455
37456
37457
37458
37459
37460
37461
37462
# File 'lib/aws-sdk-ec2/types.rb', line 37454

class DescribeVpnConcentratorsRequest < Struct.new(
  :vpn_concentrator_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpn_concentrator_idsArray<String>

One or more VPN concentrator IDs.

Returns:

  • (Array<String>)


37454
37455
37456
37457
37458
37459
37460
37461
37462
# File 'lib/aws-sdk-ec2/types.rb', line 37454

class DescribeVpnConcentratorsRequest < Struct.new(
  :vpn_concentrator_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end