Class: Aws::EC2::Types::DescribeVpnConcentratorsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


35952
35953
35954
35955
35956
35957
35958
35959
35960
# File 'lib/aws-sdk-ec2/types.rb', line 35952

class DescribeVpnConcentratorsRequest < Struct.new(
  :vpn_concentrator_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters to limit the results.

Returns:



35952
35953
35954
35955
35956
35957
35958
35959
35960
# File 'lib/aws-sdk-ec2/types.rb', line 35952

class DescribeVpnConcentratorsRequest < Struct.new(
  :vpn_concentrator_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.

Returns:

  • (Integer)


35952
35953
35954
35955
35956
35957
35958
35959
35960
# File 'lib/aws-sdk-ec2/types.rb', line 35952

class DescribeVpnConcentratorsRequest < Struct.new(
  :vpn_concentrator_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


35952
35953
35954
35955
35956
35957
35958
35959
35960
# File 'lib/aws-sdk-ec2/types.rb', line 35952

class DescribeVpnConcentratorsRequest < Struct.new(
  :vpn_concentrator_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpn_concentrator_idsArray<String>

One or more VPN concentrator IDs.

Returns:

  • (Array<String>)


35952
35953
35954
35955
35956
35957
35958
35959
35960
# File 'lib/aws-sdk-ec2/types.rb', line 35952

class DescribeVpnConcentratorsRequest < Struct.new(
  :vpn_concentrator_ids,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end