Class: Aws::EC2::Types::DetachClassicLinkVpcRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DetachClassicLinkVpcRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#instance_id ⇒ String
The ID of the instance to unlink from the VPC.
-
#vpc_id ⇒ String
The ID of the VPC to which the instance is linked.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
38068 38069 38070 38071 38072 38073 38074 |
# File 'lib/aws-sdk-ec2/types.rb', line 38068 class DetachClassicLinkVpcRequest < Struct.new( :dry_run, :instance_id, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the instance to unlink from the VPC.
38068 38069 38070 38071 38072 38073 38074 |
# File 'lib/aws-sdk-ec2/types.rb', line 38068 class DetachClassicLinkVpcRequest < Struct.new( :dry_run, :instance_id, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC to which the instance is linked.
38068 38069 38070 38071 38072 38073 38074 |
# File 'lib/aws-sdk-ec2/types.rb', line 38068 class DetachClassicLinkVpcRequest < Struct.new( :dry_run, :instance_id, :vpc_id) SENSITIVE = [] include Aws::Structure end |