Class: Aws::EC2::Types::DetachClassicLinkVpcRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


36656
36657
36658
36659
36660
36661
36662
# File 'lib/aws-sdk-ec2/types.rb', line 36656

class DetachClassicLinkVpcRequest < Struct.new(
  :dry_run,
  :instance_id,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The ID of the instance to unlink from the VPC.

Returns:

  • (String)


36656
36657
36658
36659
36660
36661
36662
# File 'lib/aws-sdk-ec2/types.rb', line 36656

class DetachClassicLinkVpcRequest < Struct.new(
  :dry_run,
  :instance_id,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC to which the instance is linked.

Returns:

  • (String)


36656
36657
36658
36659
36660
36661
36662
# File 'lib/aws-sdk-ec2/types.rb', line 36656

class DetachClassicLinkVpcRequest < Struct.new(
  :dry_run,
  :instance_id,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end