Class: Aws::EC2::Types::DetachClassicLinkVpcRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DetachClassicLinkVpcRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#instance_id ⇒ String
The ID of the instance to unlink from the VPC.
-
#vpc_id ⇒ String
The ID of the VPC to which the instance is linked.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
36656 36657 36658 36659 36660 36661 36662 |
# File 'lib/aws-sdk-ec2/types.rb', line 36656 class DetachClassicLinkVpcRequest < Struct.new( :dry_run, :instance_id, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the instance to unlink from the VPC.
36656 36657 36658 36659 36660 36661 36662 |
# File 'lib/aws-sdk-ec2/types.rb', line 36656 class DetachClassicLinkVpcRequest < Struct.new( :dry_run, :instance_id, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC to which the instance is linked.
36656 36657 36658 36659 36660 36661 36662 |
# File 'lib/aws-sdk-ec2/types.rb', line 36656 class DetachClassicLinkVpcRequest < Struct.new( :dry_run, :instance_id, :vpc_id) SENSITIVE = [] include Aws::Structure end |