Class: Aws::EC2::Types::DetachClassicLinkVpcRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DetachClassicLinkVpcRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#instance_id ⇒ String
The ID of the instance to unlink from the VPC.
-
#vpc_id ⇒ String
The ID of the VPC to which the instance is linked.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
36110 36111 36112 36113 36114 36115 36116 |
# File 'lib/aws-sdk-ec2/types.rb', line 36110 class DetachClassicLinkVpcRequest < Struct.new( :dry_run, :instance_id, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the instance to unlink from the VPC.
36110 36111 36112 36113 36114 36115 36116 |
# File 'lib/aws-sdk-ec2/types.rb', line 36110 class DetachClassicLinkVpcRequest < Struct.new( :dry_run, :instance_id, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC to which the instance is linked.
36110 36111 36112 36113 36114 36115 36116 |
# File 'lib/aws-sdk-ec2/types.rb', line 36110 class DetachClassicLinkVpcRequest < Struct.new( :dry_run, :instance_id, :vpc_id) SENSITIVE = [] include Aws::Structure end |