Class: Aws::EC2::Types::DetachImageWatermarkRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DetachImageWatermarkRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#image_id ⇒ String
The ID of the AMI.
-
#watermark_key ⇒ String
The watermark key to remove, in
accountId:watermarkNameformat (for example,123456789012:approvedAmi).
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
38116 38117 38118 38119 38120 38121 38122 |
# File 'lib/aws-sdk-ec2/types.rb', line 38116 class DetachImageWatermarkRequest < Struct.new( :image_id, :watermark_key, :dry_run) SENSITIVE = [] include Aws::Structure end |
#image_id ⇒ String
The ID of the AMI.
38116 38117 38118 38119 38120 38121 38122 |
# File 'lib/aws-sdk-ec2/types.rb', line 38116 class DetachImageWatermarkRequest < Struct.new( :image_id, :watermark_key, :dry_run) SENSITIVE = [] include Aws::Structure end |
#watermark_key ⇒ String
The watermark key to remove, in accountId:watermarkName format
(for example, 123456789012:approvedAmi).
38116 38117 38118 38119 38120 38121 38122 |
# File 'lib/aws-sdk-ec2/types.rb', line 38116 class DetachImageWatermarkRequest < Struct.new( :image_id, :watermark_key, :dry_run) SENSITIVE = [] include Aws::Structure end |