Class: Aws::EC2::Types::DetachImageWatermarkRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


36543
36544
36545
36546
36547
36548
36549
# File 'lib/aws-sdk-ec2/types.rb', line 36543

class DetachImageWatermarkRequest < Struct.new(
  :image_id,
  :watermark_key,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#image_idString

The ID of the AMI.

Returns:

  • (String)


36543
36544
36545
36546
36547
36548
36549
# File 'lib/aws-sdk-ec2/types.rb', line 36543

class DetachImageWatermarkRequest < Struct.new(
  :image_id,
  :watermark_key,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#watermark_keyString

The watermark key to remove, in ‘accountId:watermarkName` format (for example, `123456789012:approvedAmi`).

Returns:

  • (String)


36543
36544
36545
36546
36547
36548
36549
# File 'lib/aws-sdk-ec2/types.rb', line 36543

class DetachImageWatermarkRequest < Struct.new(
  :image_id,
  :watermark_key,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end