Class: Aws::EC2::Types::DetachInternetGatewayRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


37783
37784
37785
37786
37787
37788
37789
# File 'lib/aws-sdk-ec2/types.rb', line 37783

class DetachInternetGatewayRequest < Struct.new(
  :dry_run,
  :internet_gateway_id,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#internet_gateway_idString

The ID of the internet gateway.

Returns:

  • (String)


37783
37784
37785
37786
37787
37788
37789
# File 'lib/aws-sdk-ec2/types.rb', line 37783

class DetachInternetGatewayRequest < Struct.new(
  :dry_run,
  :internet_gateway_id,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC.

Returns:

  • (String)


37783
37784
37785
37786
37787
37788
37789
# File 'lib/aws-sdk-ec2/types.rb', line 37783

class DetachInternetGatewayRequest < Struct.new(
  :dry_run,
  :internet_gateway_id,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end