Class: Aws::EC2::Types::DetachInternetGatewayRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DetachInternetGatewayRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#internet_gateway_id ⇒ String
The ID of the internet gateway.
-
#vpc_id ⇒ String
The ID of the VPC.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
36148 36149 36150 36151 36152 36153 36154 |
# File 'lib/aws-sdk-ec2/types.rb', line 36148 class DetachInternetGatewayRequest < Struct.new( :dry_run, :internet_gateway_id, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#internet_gateway_id ⇒ String
The ID of the internet gateway.
36148 36149 36150 36151 36152 36153 36154 |
# File 'lib/aws-sdk-ec2/types.rb', line 36148 class DetachInternetGatewayRequest < Struct.new( :dry_run, :internet_gateway_id, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC.
36148 36149 36150 36151 36152 36153 36154 |
# File 'lib/aws-sdk-ec2/types.rb', line 36148 class DetachInternetGatewayRequest < Struct.new( :dry_run, :internet_gateway_id, :vpc_id) SENSITIVE = [] include Aws::Structure end |