Class: Aws::EC2::Types::DetachNetworkInterfaceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DetachNetworkInterfaceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for DetachNetworkInterface.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attachment_id ⇒ String
The ID of the attachment.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#force ⇒ Boolean
Specifies whether to force a detachment.
Instance Attribute Details
#attachment_id ⇒ String
The ID of the attachment.
36634 36635 36636 36637 36638 36639 36640 |
# File 'lib/aws-sdk-ec2/types.rb', line 36634 class DetachNetworkInterfaceRequest < Struct.new( :dry_run, :attachment_id, :force) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
36634 36635 36636 36637 36638 36639 36640 |
# File 'lib/aws-sdk-ec2/types.rb', line 36634 class DetachNetworkInterfaceRequest < Struct.new( :dry_run, :attachment_id, :force) SENSITIVE = [] include Aws::Structure end |
#force ⇒ Boolean
Specifies whether to force a detachment.
Force parameter only as a last resort to detach a
network interface from a failed instance.
-
If you use the
Forceparameter to detach a network interface, you might not be able to attach a different network interface to the same index on the instance without first stopping and starting the instance. -
If you force the detachment of a network interface, the instance metadata might not get updated. This means that the attributes associated with the detached network interface might still be visible. The instance metadata will get updated when you stop and start the instance.
36634 36635 36636 36637 36638 36639 36640 |
# File 'lib/aws-sdk-ec2/types.rb', line 36634 class DetachNetworkInterfaceRequest < Struct.new( :dry_run, :attachment_id, :force) SENSITIVE = [] include Aws::Structure end |