Class: Aws::EC2::Types::DetachVerifiedAccessTrustProviderRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


36672
36673
36674
36675
36676
36677
36678
36679
# File 'lib/aws-sdk-ec2/types.rb', line 36672

class DetachVerifiedAccessTrustProviderRequest < Struct.new(
  :verified_access_instance_id,
  :verified_access_trust_provider_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


36672
36673
36674
36675
36676
36677
36678
36679
# File 'lib/aws-sdk-ec2/types.rb', line 36672

class DetachVerifiedAccessTrustProviderRequest < Struct.new(
  :verified_access_instance_id,
  :verified_access_trust_provider_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#verified_access_instance_idString

The ID of the Verified Access instance.

Returns:

  • (String)


36672
36673
36674
36675
36676
36677
36678
36679
# File 'lib/aws-sdk-ec2/types.rb', line 36672

class DetachVerifiedAccessTrustProviderRequest < Struct.new(
  :verified_access_instance_id,
  :verified_access_trust_provider_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#verified_access_trust_provider_idString

The ID of the Verified Access trust provider.

Returns:

  • (String)


36672
36673
36674
36675
36676
36677
36678
36679
# File 'lib/aws-sdk-ec2/types.rb', line 36672

class DetachVerifiedAccessTrustProviderRequest < Struct.new(
  :verified_access_instance_id,
  :verified_access_trust_provider_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end