Class: Aws::EC2::Types::DetachVerifiedAccessTrustProviderRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DetachVerifiedAccessTrustProviderRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#verified_access_instance_id ⇒ String
The ID of the Verified Access instance.
-
#verified_access_trust_provider_id ⇒ String
The ID of the Verified Access trust provider.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see [Ensuring idempotency].
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html
36233 36234 36235 36236 36237 36238 36239 36240 |
# File 'lib/aws-sdk-ec2/types.rb', line 36233 class DetachVerifiedAccessTrustProviderRequest < Struct.new( :verified_access_instance_id, :verified_access_trust_provider_id, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
36233 36234 36235 36236 36237 36238 36239 36240 |
# File 'lib/aws-sdk-ec2/types.rb', line 36233 class DetachVerifiedAccessTrustProviderRequest < Struct.new( :verified_access_instance_id, :verified_access_trust_provider_id, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#verified_access_instance_id ⇒ String
The ID of the Verified Access instance.
36233 36234 36235 36236 36237 36238 36239 36240 |
# File 'lib/aws-sdk-ec2/types.rb', line 36233 class DetachVerifiedAccessTrustProviderRequest < Struct.new( :verified_access_instance_id, :verified_access_trust_provider_id, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#verified_access_trust_provider_id ⇒ String
The ID of the Verified Access trust provider.
36233 36234 36235 36236 36237 36238 36239 36240 |
# File 'lib/aws-sdk-ec2/types.rb', line 36233 class DetachVerifiedAccessTrustProviderRequest < Struct.new( :verified_access_instance_id, :verified_access_trust_provider_id, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |