Class: Aws::EC2::Types::DetachVpnGatewayRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for DetachVpnGateway.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


36760
36761
36762
36763
36764
36765
36766
# File 'lib/aws-sdk-ec2/types.rb', line 36760

class DetachVpnGatewayRequest < Struct.new(
  :vpc_id,
  :vpn_gateway_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC.

Returns:

  • (String)


36760
36761
36762
36763
36764
36765
36766
# File 'lib/aws-sdk-ec2/types.rb', line 36760

class DetachVpnGatewayRequest < Struct.new(
  :vpc_id,
  :vpn_gateway_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpn_gateway_idString

The ID of the virtual private gateway.

Returns:

  • (String)


36760
36761
36762
36763
36764
36765
36766
# File 'lib/aws-sdk-ec2/types.rb', line 36760

class DetachVpnGatewayRequest < Struct.new(
  :vpc_id,
  :vpn_gateway_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end