Class: Aws::EC2::Types::DisableAddressTransferRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisableAddressTransferRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allocation_id ⇒ String
The allocation ID of an Elastic IP address.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#allocation_id ⇒ String
The allocation ID of an Elastic IP address.
36819 36820 36821 36822 36823 36824 |
# File 'lib/aws-sdk-ec2/types.rb', line 36819 class DisableAddressTransferRequest < Struct.new( :allocation_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
36819 36820 36821 36822 36823 36824 |
# File 'lib/aws-sdk-ec2/types.rb', line 36819 class DisableAddressTransferRequest < Struct.new( :allocation_id, :dry_run) SENSITIVE = [] include Aws::Structure end |