Class: Aws::EC2::Types::DisableApplicationStatusCheckSuppressionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure that the operation completes no more than one time. If you retry a request with the same token, the service ignores the request but does not return an error. For more information, see Ensuring idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


38556
38557
38558
38559
38560
38561
38562
# File 'lib/aws-sdk-ec2/types.rb', line 38556

class DisableApplicationStatusCheckSuppressionRequest < Struct.new(
  :instance_ids,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


38556
38557
38558
38559
38560
38561
38562
# File 'lib/aws-sdk-ec2/types.rb', line 38556

class DisableApplicationStatusCheckSuppressionRequest < Struct.new(
  :instance_ids,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idsArray<String>

The IDs of the instances for which to disable application status check suppression.

Returns:

  • (Array<String>)


38556
38557
38558
38559
38560
38561
38562
# File 'lib/aws-sdk-ec2/types.rb', line 38556

class DisableApplicationStatusCheckSuppressionRequest < Struct.new(
  :instance_ids,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end