Class: Aws::EC2::Types::DisableApplicationStatusCheckSuppressionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisableApplicationStatusCheckSuppressionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#instance_ids ⇒ Array<String>
The IDs of the instances for which to disable application status check suppression.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring idempotency.
A suitable default value is auto-generated. You should normally not need to pass this option.
38548 38549 38550 38551 38552 38553 38554 |
# File 'lib/aws-sdk-ec2/types.rb', line 38548 class DisableApplicationStatusCheckSuppressionRequest < Struct.new( :instance_ids, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
38548 38549 38550 38551 38552 38553 38554 |
# File 'lib/aws-sdk-ec2/types.rb', line 38548 class DisableApplicationStatusCheckSuppressionRequest < Struct.new( :instance_ids, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#instance_ids ⇒ Array<String>
The IDs of the instances for which to disable application status check suppression.
38548 38549 38550 38551 38552 38553 38554 |
# File 'lib/aws-sdk-ec2/types.rb', line 38548 class DisableApplicationStatusCheckSuppressionRequest < Struct.new( :instance_ids, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |