Class: Aws::EC2::Types::DisableCapacityManagerRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


38268
38269
38270
38271
38272
38273
# File 'lib/aws-sdk-ec2/types.rb', line 38268

class DisableCapacityManagerRequest < Struct.new(
  :dry_run,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


38268
38269
38270
38271
38272
38273
# File 'lib/aws-sdk-ec2/types.rb', line 38268

class DisableCapacityManagerRequest < Struct.new(
  :dry_run,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end