Class: Aws::EC2::Types::DisableCapacityManagerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisableCapacityManagerRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
A suitable default value is auto-generated. You should normally not need to pass this option.
37193 37194 37195 37196 37197 37198 |
# File 'lib/aws-sdk-ec2/types.rb', line 37193 class DisableCapacityManagerRequest < Struct.new( :dry_run, :client_token) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
37193 37194 37195 37196 37197 37198 |
# File 'lib/aws-sdk-ec2/types.rb', line 37193 class DisableCapacityManagerRequest < Struct.new( :dry_run, :client_token) SENSITIVE = [] include Aws::Structure end |