Class: Aws::EC2::Types::DisableFastLaunchRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisableFastLaunchRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#force ⇒ Boolean
Forces the image settings to turn off Windows fast launch for your Windows AMI.
-
#image_id ⇒ String
Specify the ID of the image for which to disable Windows fast launch.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
37004 37005 37006 37007 37008 37009 37010 |
# File 'lib/aws-sdk-ec2/types.rb', line 37004 class DisableFastLaunchRequest < Struct.new( :image_id, :force, :dry_run) SENSITIVE = [] include Aws::Structure end |
#force ⇒ Boolean
Forces the image settings to turn off Windows fast launch for your Windows AMI. This parameter overrides any errors that are encountered while cleaning up resources in your account.
37004 37005 37006 37007 37008 37009 37010 |
# File 'lib/aws-sdk-ec2/types.rb', line 37004 class DisableFastLaunchRequest < Struct.new( :image_id, :force, :dry_run) SENSITIVE = [] include Aws::Structure end |
#image_id ⇒ String
Specify the ID of the image for which to disable Windows fast launch.
37004 37005 37006 37007 37008 37009 37010 |
# File 'lib/aws-sdk-ec2/types.rb', line 37004 class DisableFastLaunchRequest < Struct.new( :image_id, :force, :dry_run) SENSITIVE = [] include Aws::Structure end |