Class: Aws::EC2::Types::DisableFastLaunchRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


36337
36338
36339
36340
36341
36342
36343
# File 'lib/aws-sdk-ec2/types.rb', line 36337

class DisableFastLaunchRequest < Struct.new(
  :image_id,
  :force,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#forceBoolean

Forces the image settings to turn off Windows fast launch for your Windows AMI. This parameter overrides any errors that are encountered while cleaning up resources in your account.

Returns:

  • (Boolean)


36337
36338
36339
36340
36341
36342
36343
# File 'lib/aws-sdk-ec2/types.rb', line 36337

class DisableFastLaunchRequest < Struct.new(
  :image_id,
  :force,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#image_idString

Specify the ID of the image for which to disable Windows fast launch.

Returns:

  • (String)


36337
36338
36339
36340
36341
36342
36343
# File 'lib/aws-sdk-ec2/types.rb', line 36337

class DisableFastLaunchRequest < Struct.new(
  :image_id,
  :force,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end