Class: Aws::EC2::Types::DisableFastSnapshotRestoresRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisableFastSnapshotRestoresRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone_ids ⇒ Array<String>
One or more Availability Zone IDs.
-
#availability_zones ⇒ Array<String>
One or more Availability Zones.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#source_snapshot_ids ⇒ Array<String>
The IDs of one or more snapshots.
Instance Attribute Details
#availability_zone_ids ⇒ Array<String>
One or more Availability Zone IDs. For example, ‘use2-az1`.
Either ‘AvailabilityZone` or `AvailabilityZoneId` must be specified in the request, but not both.
36838 36839 36840 36841 36842 36843 36844 36845 |
# File 'lib/aws-sdk-ec2/types.rb', line 36838 class DisableFastSnapshotRestoresRequest < Struct.new( :availability_zones, :availability_zone_ids, :source_snapshot_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#availability_zones ⇒ Array<String>
One or more Availability Zones. For example, ‘us-east-2a`.
Either ‘AvailabilityZone` or `AvailabilityZoneId` must be specified in the request, but not both.
36838 36839 36840 36841 36842 36843 36844 36845 |
# File 'lib/aws-sdk-ec2/types.rb', line 36838 class DisableFastSnapshotRestoresRequest < Struct.new( :availability_zones, :availability_zone_ids, :source_snapshot_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
36838 36839 36840 36841 36842 36843 36844 36845 |
# File 'lib/aws-sdk-ec2/types.rb', line 36838 class DisableFastSnapshotRestoresRequest < Struct.new( :availability_zones, :availability_zone_ids, :source_snapshot_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#source_snapshot_ids ⇒ Array<String>
The IDs of one or more snapshots. For example, ‘snap-1234567890abcdef0`.
36838 36839 36840 36841 36842 36843 36844 36845 |
# File 'lib/aws-sdk-ec2/types.rb', line 36838 class DisableFastSnapshotRestoresRequest < Struct.new( :availability_zones, :availability_zone_ids, :source_snapshot_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |