Class: Aws::EC2::Types::DisableImageBlockPublicAccessRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisableImageBlockPublicAccessRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
37377 37378 37379 37380 37381 |
# File 'lib/aws-sdk-ec2/types.rb', line 37377 class DisableImageBlockPublicAccessRequest < Struct.new( :dry_run) SENSITIVE = [] include Aws::Structure end |