Class: Aws::EC2::Types::DisableImageDeprecationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisableImageDeprecationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#image_id ⇒ String
The ID of the AMI.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
39019 39020 39021 39022 39023 39024 |
# File 'lib/aws-sdk-ec2/types.rb', line 39019 class DisableImageDeprecationRequest < Struct.new( :image_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#image_id ⇒ String
The ID of the AMI.
39019 39020 39021 39022 39023 39024 |
# File 'lib/aws-sdk-ec2/types.rb', line 39019 class DisableImageDeprecationRequest < Struct.new( :image_id, :dry_run) SENSITIVE = [] include Aws::Structure end |