Class: Aws::EC2::Types::DisableImageDeprecationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


36040
36041
36042
36043
36044
36045
# File 'lib/aws-sdk-ec2/types.rb', line 36040

class DisableImageDeprecationRequest < Struct.new(
  :image_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#image_idString

The ID of the AMI.

Returns:

  • (String)


36040
36041
36042
36043
36044
36045
# File 'lib/aws-sdk-ec2/types.rb', line 36040

class DisableImageDeprecationRequest < Struct.new(
  :image_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end