Class: Aws::EC2::Types::DisableImageDeregistrationProtectionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisableImageDeregistrationProtectionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#image_id ⇒ String
The ID of the AMI.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
37746 37747 37748 37749 37750 37751 |
# File 'lib/aws-sdk-ec2/types.rb', line 37746 class DisableImageDeregistrationProtectionRequest < Struct.new( :image_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#image_id ⇒ String
The ID of the AMI.
37746 37747 37748 37749 37750 37751 |
# File 'lib/aws-sdk-ec2/types.rb', line 37746 class DisableImageDeregistrationProtectionRequest < Struct.new( :image_id, :dry_run) SENSITIVE = [] include Aws::Structure end |