Class: Aws::EC2::Types::DisableImageDeregistrationProtectionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


37436
37437
37438
37439
37440
37441
# File 'lib/aws-sdk-ec2/types.rb', line 37436

class DisableImageDeregistrationProtectionRequest < Struct.new(
  :image_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#image_idString

The ID of the AMI.

Returns:

  • (String)


37436
37437
37438
37439
37440
37441
# File 'lib/aws-sdk-ec2/types.rb', line 37436

class DisableImageDeregistrationProtectionRequest < Struct.new(
  :image_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end