Class: Aws::EC2::Types::DisableImageDeregistrationProtectionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisableImageDeregistrationProtectionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#image_id ⇒ String
The ID of the AMI.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
36687 36688 36689 36690 36691 36692 |
# File 'lib/aws-sdk-ec2/types.rb', line 36687 class DisableImageDeregistrationProtectionRequest < Struct.new( :image_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#image_id ⇒ String
The ID of the AMI.
36687 36688 36689 36690 36691 36692 |
# File 'lib/aws-sdk-ec2/types.rb', line 36687 class DisableImageDeregistrationProtectionRequest < Struct.new( :image_id, :dry_run) SENSITIVE = [] include Aws::Structure end |