Class: Aws::EC2::Types::DisableImageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisableImageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#image_id ⇒ String
The ID of the AMI.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
39094 39095 39096 39097 39098 39099 |
# File 'lib/aws-sdk-ec2/types.rb', line 39094 class DisableImageRequest < Struct.new( :image_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#image_id ⇒ String
The ID of the AMI.
39094 39095 39096 39097 39098 39099 |
# File 'lib/aws-sdk-ec2/types.rb', line 39094 class DisableImageRequest < Struct.new( :image_id, :dry_run) SENSITIVE = [] include Aws::Structure end |