Class: Aws::EC2::Types::DisableInstanceSqlHaStandbyDetectionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


37696
37697
37698
37699
37700
37701
# File 'lib/aws-sdk-ec2/types.rb', line 37696

class DisableInstanceSqlHaStandbyDetectionsRequest < Struct.new(
  :instance_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idsArray<String>

The IDs of the instances to disable from SQL Server High Availability standby detection monitoring.

Returns:

  • (Array<String>)


37696
37697
37698
37699
37700
37701
# File 'lib/aws-sdk-ec2/types.rb', line 37696

class DisableInstanceSqlHaStandbyDetectionsRequest < Struct.new(
  :instance_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end