Class: Aws::EC2::Types::DisableInstanceSqlHaStandbyDetectionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisableInstanceSqlHaStandbyDetectionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#instance_ids ⇒ Array<String>
The IDs of the instances to disable from SQL Server High Availability standby detection monitoring.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
37007 37008 37009 37010 37011 37012 |
# File 'lib/aws-sdk-ec2/types.rb', line 37007 class DisableInstanceSqlHaStandbyDetectionsRequest < Struct.new( :instance_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#instance_ids ⇒ Array<String>
The IDs of the instances to disable from SQL Server High Availability standby detection monitoring.
37007 37008 37009 37010 37011 37012 |
# File 'lib/aws-sdk-ec2/types.rb', line 37007 class DisableInstanceSqlHaStandbyDetectionsRequest < Struct.new( :instance_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |