Class: Aws::EC2::Types::DisableInstanceSqlHaStandbyDetectionsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisableInstanceSqlHaStandbyDetectionsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instances ⇒ Array<Types::RegisteredInstance>
Information about the instances that were disabled from SQL Server High Availability standby detection monitoring.
Instance Attribute Details
#instances ⇒ Array<Types::RegisteredInstance>
Information about the instances that were disabled from SQL Server High Availability standby detection monitoring.
36148 36149 36150 36151 36152 |
# File 'lib/aws-sdk-ec2/types.rb', line 36148 class DisableInstanceSqlHaStandbyDetectionsResult < Struct.new( :instances) SENSITIVE = [] include Aws::Structure end |