Class: Aws::EC2::Types::DisableIpamOrganizationAdminAccountRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#delegated_admin_account_idString

The Organizations member account ID that you want to disable as IPAM account.

Returns:

  • (String)


39153
39154
39155
39156
39157
39158
# File 'lib/aws-sdk-ec2/types.rb', line 39153

class DisableIpamOrganizationAdminAccountRequest < Struct.new(
  :dry_run,
  :delegated_admin_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


39153
39154
39155
39156
39157
39158
# File 'lib/aws-sdk-ec2/types.rb', line 39153

class DisableIpamOrganizationAdminAccountRequest < Struct.new(
  :dry_run,
  :delegated_admin_account_id)
  SENSITIVE = []
  include Aws::Structure
end