Class: Aws::EC2::Types::DisableIpamOrganizationAdminAccountRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisableIpamOrganizationAdminAccountRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#delegated_admin_account_id ⇒ String
The Organizations member account ID that you want to disable as IPAM account.
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
Instance Attribute Details
#delegated_admin_account_id ⇒ String
The Organizations member account ID that you want to disable as IPAM account.
37198 37199 37200 37201 37202 37203 |
# File 'lib/aws-sdk-ec2/types.rb', line 37198 class DisableIpamOrganizationAdminAccountRequest < Struct.new( :dry_run, :delegated_admin_account_id) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
37198 37199 37200 37201 37202 37203 |
# File 'lib/aws-sdk-ec2/types.rb', line 37198 class DisableIpamOrganizationAdminAccountRequest < Struct.new( :dry_run, :delegated_admin_account_id) SENSITIVE = [] include Aws::Structure end |