Class: Aws::EC2::Types::DisableRouteServerPropagationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


39235
39236
39237
39238
39239
39240
39241
# File 'lib/aws-sdk-ec2/types.rb', line 39235

class DisableRouteServerPropagationRequest < Struct.new(
  :route_server_id,
  :route_table_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#route_server_idString

The ID of the route server for which to disable propagation.

Returns:

  • (String)


39235
39236
39237
39238
39239
39240
39241
# File 'lib/aws-sdk-ec2/types.rb', line 39235

class DisableRouteServerPropagationRequest < Struct.new(
  :route_server_id,
  :route_table_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#route_table_idString

The ID of the route table for which to disable route server propagation.

Returns:

  • (String)


39235
39236
39237
39238
39239
39240
39241
# File 'lib/aws-sdk-ec2/types.rb', line 39235

class DisableRouteServerPropagationRequest < Struct.new(
  :route_server_id,
  :route_table_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end