Class: Aws::EC2::Types::DisableRouteServerPropagationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisableRouteServerPropagationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#route_server_id ⇒ String
The ID of the route server for which to disable propagation.
-
#route_table_id ⇒ String
The ID of the route table for which to disable route server propagation.
Instance Attribute Details
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
36870 36871 36872 36873 36874 36875 36876 |
# File 'lib/aws-sdk-ec2/types.rb', line 36870 class DisableRouteServerPropagationRequest < Struct.new( :route_server_id, :route_table_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#route_server_id ⇒ String
The ID of the route server for which to disable propagation.
36870 36871 36872 36873 36874 36875 36876 |
# File 'lib/aws-sdk-ec2/types.rb', line 36870 class DisableRouteServerPropagationRequest < Struct.new( :route_server_id, :route_table_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#route_table_id ⇒ String
The ID of the route table for which to disable route server propagation.
36870 36871 36872 36873 36874 36875 36876 |
# File 'lib/aws-sdk-ec2/types.rb', line 36870 class DisableRouteServerPropagationRequest < Struct.new( :route_server_id, :route_table_id, :dry_run) SENSITIVE = [] include Aws::Structure end |