Class: Aws::EC2::Types::DisableSerialConsoleAccessRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


37958
37959
37960
37961
37962
# File 'lib/aws-sdk-ec2/types.rb', line 37958

class DisableSerialConsoleAccessRequest < Struct.new(
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end