Class: Aws::EC2::Types::DisableSnapshotBlockPublicAccessRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisableSnapshotBlockPublicAccessRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
39316 39317 39318 39319 39320 |
# File 'lib/aws-sdk-ec2/types.rb', line 39316 class DisableSnapshotBlockPublicAccessRequest < Struct.new( :dry_run) SENSITIVE = [] include Aws::Structure end |