Class: Aws::EC2::Types::DisableSnapshotBlockPublicAccessRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisableSnapshotBlockPublicAccessRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
37856 37857 37858 37859 37860 |
# File 'lib/aws-sdk-ec2/types.rb', line 37856 class DisableSnapshotBlockPublicAccessRequest < Struct.new( :dry_run) SENSITIVE = [] include Aws::Structure end |