Class: Aws::EC2::Types::DisableTransitGatewayRouteTablePropagationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisableTransitGatewayRouteTablePropagationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#transit_gateway_attachment_id ⇒ String
The ID of the attachment.
-
#transit_gateway_route_table_announcement_id ⇒ String
The ID of the route table announcement.
-
#transit_gateway_route_table_id ⇒ String
The ID of the propagation route table.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
39332 39333 39334 39335 39336 39337 39338 39339 |
# File 'lib/aws-sdk-ec2/types.rb', line 39332 class DisableTransitGatewayRouteTablePropagationRequest < Struct.new( :transit_gateway_route_table_id, :transit_gateway_attachment_id, :dry_run, :transit_gateway_route_table_announcement_id) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_attachment_id ⇒ String
The ID of the attachment.
39332 39333 39334 39335 39336 39337 39338 39339 |
# File 'lib/aws-sdk-ec2/types.rb', line 39332 class DisableTransitGatewayRouteTablePropagationRequest < Struct.new( :transit_gateway_route_table_id, :transit_gateway_attachment_id, :dry_run, :transit_gateway_route_table_announcement_id) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_route_table_announcement_id ⇒ String
The ID of the route table announcement.
39332 39333 39334 39335 39336 39337 39338 39339 |
# File 'lib/aws-sdk-ec2/types.rb', line 39332 class DisableTransitGatewayRouteTablePropagationRequest < Struct.new( :transit_gateway_route_table_id, :transit_gateway_attachment_id, :dry_run, :transit_gateway_route_table_announcement_id) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_route_table_id ⇒ String
The ID of the propagation route table.
39332 39333 39334 39335 39336 39337 39338 39339 |
# File 'lib/aws-sdk-ec2/types.rb', line 39332 class DisableTransitGatewayRouteTablePropagationRequest < Struct.new( :transit_gateway_route_table_id, :transit_gateway_attachment_id, :dry_run, :transit_gateway_route_table_announcement_id) SENSITIVE = [] include Aws::Structure end |