Class: Aws::EC2::Types::DisableTransitGatewayRouteTablePropagationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


37909
37910
37911
37912
37913
37914
37915
37916
# File 'lib/aws-sdk-ec2/types.rb', line 37909

class DisableTransitGatewayRouteTablePropagationRequest < Struct.new(
  :transit_gateway_route_table_id,
  :transit_gateway_attachment_id,
  :dry_run,
  :transit_gateway_route_table_announcement_id)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_attachment_idString

The ID of the attachment.

Returns:

  • (String)


37909
37910
37911
37912
37913
37914
37915
37916
# File 'lib/aws-sdk-ec2/types.rb', line 37909

class DisableTransitGatewayRouteTablePropagationRequest < Struct.new(
  :transit_gateway_route_table_id,
  :transit_gateway_attachment_id,
  :dry_run,
  :transit_gateway_route_table_announcement_id)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_route_table_announcement_idString

The ID of the route table announcement.

Returns:

  • (String)


37909
37910
37911
37912
37913
37914
37915
37916
# File 'lib/aws-sdk-ec2/types.rb', line 37909

class DisableTransitGatewayRouteTablePropagationRequest < Struct.new(
  :transit_gateway_route_table_id,
  :transit_gateway_attachment_id,
  :dry_run,
  :transit_gateway_route_table_announcement_id)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_route_table_idString

The ID of the propagation route table.

Returns:

  • (String)


37909
37910
37911
37912
37913
37914
37915
37916
# File 'lib/aws-sdk-ec2/types.rb', line 37909

class DisableTransitGatewayRouteTablePropagationRequest < Struct.new(
  :transit_gateway_route_table_id,
  :transit_gateway_attachment_id,
  :dry_run,
  :transit_gateway_route_table_announcement_id)
  SENSITIVE = []
  include Aws::Structure
end