Class: Aws::EC2::Types::DisableVgwRoutePropagationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisableVgwRoutePropagationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for DisableVgwRoutePropagation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#gateway_id ⇒ String
The ID of the virtual private gateway.
-
#route_table_id ⇒ String
The ID of the route table.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
38066 38067 38068 38069 38070 38071 38072 |
# File 'lib/aws-sdk-ec2/types.rb', line 38066 class DisableVgwRoutePropagationRequest < Struct.new( :gateway_id, :route_table_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#gateway_id ⇒ String
The ID of the virtual private gateway.
38066 38067 38068 38069 38070 38071 38072 |
# File 'lib/aws-sdk-ec2/types.rb', line 38066 class DisableVgwRoutePropagationRequest < Struct.new( :gateway_id, :route_table_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#route_table_id ⇒ String
The ID of the route table.
38066 38067 38068 38069 38070 38071 38072 |
# File 'lib/aws-sdk-ec2/types.rb', line 38066 class DisableVgwRoutePropagationRequest < Struct.new( :gateway_id, :route_table_id, :dry_run) SENSITIVE = [] include Aws::Structure end |