Class: Aws::EC2::Types::DisableVgwRoutePropagationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for DisableVgwRoutePropagation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


37260
37261
37262
37263
37264
37265
37266
# File 'lib/aws-sdk-ec2/types.rb', line 37260

class DisableVgwRoutePropagationRequest < Struct.new(
  :gateway_id,
  :route_table_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#gateway_idString

The ID of the virtual private gateway.

Returns:

  • (String)


37260
37261
37262
37263
37264
37265
37266
# File 'lib/aws-sdk-ec2/types.rb', line 37260

class DisableVgwRoutePropagationRequest < Struct.new(
  :gateway_id,
  :route_table_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#route_table_idString

The ID of the route table.

Returns:

  • (String)


37260
37261
37262
37263
37264
37265
37266
# File 'lib/aws-sdk-ec2/types.rb', line 37260

class DisableVgwRoutePropagationRequest < Struct.new(
  :gateway_id,
  :route_table_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end