Class: Aws::EC2::Types::DisableVpcClassicLinkRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


37720
37721
37722
37723
37724
37725
# File 'lib/aws-sdk-ec2/types.rb', line 37720

class DisableVpcClassicLinkRequest < Struct.new(
  :dry_run,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC.

Returns:

  • (String)


37720
37721
37722
37723
37724
37725
# File 'lib/aws-sdk-ec2/types.rb', line 37720

class DisableVpcClassicLinkRequest < Struct.new(
  :dry_run,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end