Class: Aws::EC2::Types::DisableVpcClassicLinkRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisableVpcClassicLinkRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#vpc_id ⇒ String
The ID of the VPC.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
37362 37363 37364 37365 37366 37367 |
# File 'lib/aws-sdk-ec2/types.rb', line 37362 class DisableVpcClassicLinkRequest < Struct.new( :dry_run, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC.
37362 37363 37364 37365 37366 37367 |
# File 'lib/aws-sdk-ec2/types.rb', line 37362 class DisableVpcClassicLinkRequest < Struct.new( :dry_run, :vpc_id) SENSITIVE = [] include Aws::Structure end |