Class: Aws::EC2::Types::DisassociateAddressRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisassociateAddressRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#association_id ⇒ String
The association ID.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#public_ip ⇒ String
Deprecated.
Instance Attribute Details
#association_id ⇒ String
The association ID. This parameter is required.
39472 39473 39474 39475 39476 39477 39478 |
# File 'lib/aws-sdk-ec2/types.rb', line 39472 class DisassociateAddressRequest < Struct.new( :association_id, :public_ip, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
39472 39473 39474 39475 39476 39477 39478 |
# File 'lib/aws-sdk-ec2/types.rb', line 39472 class DisassociateAddressRequest < Struct.new( :association_id, :public_ip, :dry_run) SENSITIVE = [] include Aws::Structure end |
#public_ip ⇒ String
Deprecated.
39472 39473 39474 39475 39476 39477 39478 |
# File 'lib/aws-sdk-ec2/types.rb', line 39472 class DisassociateAddressRequest < Struct.new( :association_id, :public_ip, :dry_run) SENSITIVE = [] include Aws::Structure end |