Class: Aws::EC2::Types::DisassociateAddressRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisassociateAddressRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#association_id ⇒ String
The association ID.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#public_ip ⇒ String
Deprecated.
Instance Attribute Details
#association_id ⇒ String
The association ID. This parameter is required.
39093 39094 39095 39096 39097 39098 39099 |
# File 'lib/aws-sdk-ec2/types.rb', line 39093 class DisassociateAddressRequest < Struct.new( :association_id, :public_ip, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
39093 39094 39095 39096 39097 39098 39099 |
# File 'lib/aws-sdk-ec2/types.rb', line 39093 class DisassociateAddressRequest < Struct.new( :association_id, :public_ip, :dry_run) SENSITIVE = [] include Aws::Structure end |
#public_ip ⇒ String
Deprecated.
39093 39094 39095 39096 39097 39098 39099 |
# File 'lib/aws-sdk-ec2/types.rb', line 39093 class DisassociateAddressRequest < Struct.new( :association_id, :public_ip, :dry_run) SENSITIVE = [] include Aws::Structure end |