Class: Aws::EC2::Types::DisassociateAddressRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#association_idString

The association ID. This parameter is required.

Returns:

  • (String)


37845
37846
37847
37848
37849
37850
37851
# File 'lib/aws-sdk-ec2/types.rb', line 37845

class DisassociateAddressRequest < Struct.new(
  :association_id,
  :public_ip,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


37845
37846
37847
37848
37849
37850
37851
# File 'lib/aws-sdk-ec2/types.rb', line 37845

class DisassociateAddressRequest < Struct.new(
  :association_id,
  :public_ip,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#public_ipString

Deprecated.

Returns:

  • (String)


37845
37846
37847
37848
37849
37850
37851
# File 'lib/aws-sdk-ec2/types.rb', line 37845

class DisassociateAddressRequest < Struct.new(
  :association_id,
  :public_ip,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end