Class: Aws::EC2::Types::DisassociateApplicationStatusCheckRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisassociateApplicationStatusCheckRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_status_check_id ⇒ String
The ID of the application status check to disassociate.
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#instance_ids ⇒ Array<String>
The IDs of the instances to disassociate from the application status check.
-
#target_tag_associations ⇒ Array<Types::CustomTagKeyValueRequestPair>
The [tags][1] to disassociate from the application status check.
Instance Attribute Details
#application_status_check_id ⇒ String
The ID of the application status check to disassociate.
39503 39504 39505 39506 39507 39508 39509 39510 39511 |
# File 'lib/aws-sdk-ec2/types.rb', line 39503 class DisassociateApplicationStatusCheckRequest < Struct.new( :application_status_check_id, :target_tag_associations, :instance_ids, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring idempotency.
A suitable default value is auto-generated. You should normally not need to pass this option.
39503 39504 39505 39506 39507 39508 39509 39510 39511 |
# File 'lib/aws-sdk-ec2/types.rb', line 39503 class DisassociateApplicationStatusCheckRequest < Struct.new( :application_status_check_id, :target_tag_associations, :instance_ids, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
39503 39504 39505 39506 39507 39508 39509 39510 39511 |
# File 'lib/aws-sdk-ec2/types.rb', line 39503 class DisassociateApplicationStatusCheckRequest < Struct.new( :application_status_check_id, :target_tag_associations, :instance_ids, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#instance_ids ⇒ Array<String>
The IDs of the instances to disassociate from the application status check.
39503 39504 39505 39506 39507 39508 39509 39510 39511 |
# File 'lib/aws-sdk-ec2/types.rb', line 39503 class DisassociateApplicationStatusCheckRequest < Struct.new( :application_status_check_id, :target_tag_associations, :instance_ids, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#target_tag_associations ⇒ Array<Types::CustomTagKeyValueRequestPair>
The tags to disassociate from the application status check. Specify the same key-value pairs that were used during association.
39503 39504 39505 39506 39507 39508 39509 39510 39511 |
# File 'lib/aws-sdk-ec2/types.rb', line 39503 class DisassociateApplicationStatusCheckRequest < Struct.new( :application_status_check_id, :target_tag_associations, :instance_ids, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |