Class: Aws::EC2::Types::DisassociateApplicationStatusCheckRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_status_check_idString

The ID of the application status check to disassociate.

Returns:

  • (String)


39141
39142
39143
39144
39145
39146
39147
39148
39149
# File 'lib/aws-sdk-ec2/types.rb', line 39141

class DisassociateApplicationStatusCheckRequest < Struct.new(
  :application_status_check_id,
  :target_tag_associations,
  :instance_ids,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


39141
39142
39143
39144
39145
39146
39147
39148
39149
# File 'lib/aws-sdk-ec2/types.rb', line 39141

class DisassociateApplicationStatusCheckRequest < Struct.new(
  :application_status_check_id,
  :target_tag_associations,
  :instance_ids,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


39141
39142
39143
39144
39145
39146
39147
39148
39149
# File 'lib/aws-sdk-ec2/types.rb', line 39141

class DisassociateApplicationStatusCheckRequest < Struct.new(
  :application_status_check_id,
  :target_tag_associations,
  :instance_ids,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idsArray<String>

The IDs of the instances to disassociate from the application status check.

Returns:

  • (Array<String>)


39141
39142
39143
39144
39145
39146
39147
39148
39149
# File 'lib/aws-sdk-ec2/types.rb', line 39141

class DisassociateApplicationStatusCheckRequest < Struct.new(
  :application_status_check_id,
  :target_tag_associations,
  :instance_ids,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#target_tag_associationsArray<Types::CustomTagKeyValueRequestPair>

The tags to disassociate from the application status check. Specify the same key-value pairs that were used during association.



39141
39142
39143
39144
39145
39146
39147
39148
39149
# File 'lib/aws-sdk-ec2/types.rb', line 39141

class DisassociateApplicationStatusCheckRequest < Struct.new(
  :application_status_check_id,
  :target_tag_associations,
  :instance_ids,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end