Class: Aws::EC2::Types::DisassociateCapacityReservationBillingOwnerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisassociateCapacityReservationBillingOwnerRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_reservation_id ⇒ String
The ID of the Capacity Reservation.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#unused_reservation_billing_owner_id ⇒ String
The ID of the consumer account to which the request was sent.
Instance Attribute Details
#capacity_reservation_id ⇒ String
The ID of the Capacity Reservation.
39572 39573 39574 39575 39576 39577 39578 |
# File 'lib/aws-sdk-ec2/types.rb', line 39572 class DisassociateCapacityReservationBillingOwnerRequest < Struct.new( :dry_run, :capacity_reservation_id, :unused_reservation_billing_owner_id) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
39572 39573 39574 39575 39576 39577 39578 |
# File 'lib/aws-sdk-ec2/types.rb', line 39572 class DisassociateCapacityReservationBillingOwnerRequest < Struct.new( :dry_run, :capacity_reservation_id, :unused_reservation_billing_owner_id) SENSITIVE = [] include Aws::Structure end |
#unused_reservation_billing_owner_id ⇒ String
The ID of the consumer account to which the request was sent.
39572 39573 39574 39575 39576 39577 39578 |
# File 'lib/aws-sdk-ec2/types.rb', line 39572 class DisassociateCapacityReservationBillingOwnerRequest < Struct.new( :dry_run, :capacity_reservation_id, :unused_reservation_billing_owner_id) SENSITIVE = [] include Aws::Structure end |