Class: Aws::EC2::Types::DisassociateCapacityReservationBillingOwnerRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_reservation_idString

The ID of the Capacity Reservation.

Returns:

  • (String)


38057
38058
38059
38060
38061
38062
38063
# File 'lib/aws-sdk-ec2/types.rb', line 38057

class DisassociateCapacityReservationBillingOwnerRequest < Struct.new(
  :dry_run,
  :capacity_reservation_id,
  :unused_reservation_billing_owner_id)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


38057
38058
38059
38060
38061
38062
38063
# File 'lib/aws-sdk-ec2/types.rb', line 38057

class DisassociateCapacityReservationBillingOwnerRequest < Struct.new(
  :dry_run,
  :capacity_reservation_id,
  :unused_reservation_billing_owner_id)
  SENSITIVE = []
  include Aws::Structure
end

#unused_reservation_billing_owner_idString

The ID of the consumer account to which the request was sent.

Returns:

  • (String)


38057
38058
38059
38060
38061
38062
38063
# File 'lib/aws-sdk-ec2/types.rb', line 38057

class DisassociateCapacityReservationBillingOwnerRequest < Struct.new(
  :dry_run,
  :capacity_reservation_id,
  :unused_reservation_billing_owner_id)
  SENSITIVE = []
  include Aws::Structure
end