Class: Aws::EC2::Types::DisassociateClientVpnTargetNetworkRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisassociateClientVpnTargetNetworkRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#association_id ⇒ String
The ID of the target network association.
-
#client_vpn_endpoint_id ⇒ String
The ID of the Client VPN endpoint from which to disassociate the target network.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#association_id ⇒ String
The ID of the target network association.
37815 37816 37817 37818 37819 37820 37821 |
# File 'lib/aws-sdk-ec2/types.rb', line 37815 class DisassociateClientVpnTargetNetworkRequest < Struct.new( :client_vpn_endpoint_id, :association_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#client_vpn_endpoint_id ⇒ String
The ID of the Client VPN endpoint from which to disassociate the target network.
37815 37816 37817 37818 37819 37820 37821 |
# File 'lib/aws-sdk-ec2/types.rb', line 37815 class DisassociateClientVpnTargetNetworkRequest < Struct.new( :client_vpn_endpoint_id, :association_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
37815 37816 37817 37818 37819 37820 37821 |
# File 'lib/aws-sdk-ec2/types.rb', line 37815 class DisassociateClientVpnTargetNetworkRequest < Struct.new( :client_vpn_endpoint_id, :association_id, :dry_run) SENSITIVE = [] include Aws::Structure end |