Class: Aws::EC2::Types::DisassociateEnclaveCertificateIamRoleRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisassociateEnclaveCertificateIamRoleRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_arn ⇒ String
The ARN of the ACM certificate from which to disassociate the IAM role.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#role_arn ⇒ String
The ARN of the IAM role to disassociate.
Instance Attribute Details
#certificate_arn ⇒ String
The ARN of the ACM certificate from which to disassociate the IAM role.
37946 37947 37948 37949 37950 37951 37952 |
# File 'lib/aws-sdk-ec2/types.rb', line 37946 class DisassociateEnclaveCertificateIamRoleRequest < Struct.new( :certificate_arn, :role_arn, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
37946 37947 37948 37949 37950 37951 37952 |
# File 'lib/aws-sdk-ec2/types.rb', line 37946 class DisassociateEnclaveCertificateIamRoleRequest < Struct.new( :certificate_arn, :role_arn, :dry_run) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The ARN of the IAM role to disassociate.
37946 37947 37948 37949 37950 37951 37952 |
# File 'lib/aws-sdk-ec2/types.rb', line 37946 class DisassociateEnclaveCertificateIamRoleRequest < Struct.new( :certificate_arn, :role_arn, :dry_run) SENSITIVE = [] include Aws::Structure end |