Class: Aws::EC2::Types::DisassociateEnclaveCertificateIamRoleRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#certificate_arnString

The ARN of the ACM certificate from which to disassociate the IAM role.

Returns:

  • (String)


37506
37507
37508
37509
37510
37511
37512
# File 'lib/aws-sdk-ec2/types.rb', line 37506

class DisassociateEnclaveCertificateIamRoleRequest < Struct.new(
  :certificate_arn,
  :role_arn,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


37506
37507
37508
37509
37510
37511
37512
# File 'lib/aws-sdk-ec2/types.rb', line 37506

class DisassociateEnclaveCertificateIamRoleRequest < Struct.new(
  :certificate_arn,
  :role_arn,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The ARN of the IAM role to disassociate.

Returns:

  • (String)


37506
37507
37508
37509
37510
37511
37512
# File 'lib/aws-sdk-ec2/types.rb', line 37506

class DisassociateEnclaveCertificateIamRoleRequest < Struct.new(
  :certificate_arn,
  :role_arn,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end