Class: Aws::EC2::Types::DisassociateInstanceEventWindowRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisassociateInstanceEventWindowRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#association_target ⇒ Types::InstanceEventWindowDisassociationRequest
One or more targets to disassociate from the specified event window.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#instance_event_window_id ⇒ String
The ID of the event window.
Instance Attribute Details
#association_target ⇒ Types::InstanceEventWindowDisassociationRequest
One or more targets to disassociate from the specified event window.
38318 38319 38320 38321 38322 38323 38324 |
# File 'lib/aws-sdk-ec2/types.rb', line 38318 class DisassociateInstanceEventWindowRequest < Struct.new( :dry_run, :instance_event_window_id, :association_target) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
38318 38319 38320 38321 38322 38323 38324 |
# File 'lib/aws-sdk-ec2/types.rb', line 38318 class DisassociateInstanceEventWindowRequest < Struct.new( :dry_run, :instance_event_window_id, :association_target) SENSITIVE = [] include Aws::Structure end |
#instance_event_window_id ⇒ String
The ID of the event window.
38318 38319 38320 38321 38322 38323 38324 |
# File 'lib/aws-sdk-ec2/types.rb', line 38318 class DisassociateInstanceEventWindowRequest < Struct.new( :dry_run, :instance_event_window_id, :association_target) SENSITIVE = [] include Aws::Structure end |