Class: Aws::EC2::Types::DisassociateIpamByoasnRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisassociateIpamByoasnRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asn ⇒ String
A public 2-byte or 4-byte ASN.
-
#cidr ⇒ String
A BYOIP CIDR.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#asn ⇒ String
A public 2-byte or 4-byte ASN.
39737 39738 39739 39740 39741 39742 39743 |
# File 'lib/aws-sdk-ec2/types.rb', line 39737 class DisassociateIpamByoasnRequest < Struct.new( :dry_run, :asn, :cidr) SENSITIVE = [] include Aws::Structure end |
#cidr ⇒ String
A BYOIP CIDR.
39737 39738 39739 39740 39741 39742 39743 |
# File 'lib/aws-sdk-ec2/types.rb', line 39737 class DisassociateIpamByoasnRequest < Struct.new( :dry_run, :asn, :cidr) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
39737 39738 39739 39740 39741 39742 39743 |
# File 'lib/aws-sdk-ec2/types.rb', line 39737 class DisassociateIpamByoasnRequest < Struct.new( :dry_run, :asn, :cidr) SENSITIVE = [] include Aws::Structure end |