Class: Aws::EC2::Types::DisassociateIpamByoasnRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#asnString

A public 2-byte or 4-byte ASN.

Returns:

  • (String)


38224
38225
38226
38227
38228
38229
38230
# File 'lib/aws-sdk-ec2/types.rb', line 38224

class DisassociateIpamByoasnRequest < Struct.new(
  :dry_run,
  :asn,
  :cidr)
  SENSITIVE = []
  include Aws::Structure
end

#cidrString

A BYOIP CIDR.

Returns:

  • (String)


38224
38225
38226
38227
38228
38229
38230
# File 'lib/aws-sdk-ec2/types.rb', line 38224

class DisassociateIpamByoasnRequest < Struct.new(
  :dry_run,
  :asn,
  :cidr)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


38224
38225
38226
38227
38228
38229
38230
# File 'lib/aws-sdk-ec2/types.rb', line 38224

class DisassociateIpamByoasnRequest < Struct.new(
  :dry_run,
  :asn,
  :cidr)
  SENSITIVE = []
  include Aws::Structure
end