Class: Aws::EC2::Types::DisassociateIpamResourceDiscoveryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


39761
39762
39763
39764
39765
39766
# File 'lib/aws-sdk-ec2/types.rb', line 39761

class DisassociateIpamResourceDiscoveryRequest < Struct.new(
  :dry_run,
  :ipam_resource_discovery_association_id)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_resource_discovery_association_idString

A resource discovery association ID.

Returns:

  • (String)


39761
39762
39763
39764
39765
39766
# File 'lib/aws-sdk-ec2/types.rb', line 39761

class DisassociateIpamResourceDiscoveryRequest < Struct.new(
  :dry_run,
  :ipam_resource_discovery_association_id)
  SENSITIVE = []
  include Aws::Structure
end