Class: Aws::EC2::Types::DisassociateIpamResourceDiscoveryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisassociateIpamResourceDiscoveryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#ipam_resource_discovery_association_id ⇒ String
A resource discovery association ID.
Instance Attribute Details
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action
without actually making the request and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
38257 38258 38259 38260 38261 38262 |
# File 'lib/aws-sdk-ec2/types.rb', line 38257 class DisassociateIpamResourceDiscoveryRequest < Struct.new( :dry_run, :ipam_resource_discovery_association_id) SENSITIVE = [] include Aws::Structure end |
#ipam_resource_discovery_association_id ⇒ String
A resource discovery association ID.
38257 38258 38259 38260 38261 38262 |
# File 'lib/aws-sdk-ec2/types.rb', line 38257 class DisassociateIpamResourceDiscoveryRequest < Struct.new( :dry_run, :ipam_resource_discovery_association_id) SENSITIVE = [] include Aws::Structure end |