Class: Aws::EC2::Types::DisassociateNatGatewayAddressRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#association_idsArray<String>

The association IDs of EIPs that have been associated with the NAT gateway.

Returns:

  • (Array<String>)


37372
37373
37374
37375
37376
37377
37378
37379
# File 'lib/aws-sdk-ec2/types.rb', line 37372

class DisassociateNatGatewayAddressRequest < Struct.new(
  :nat_gateway_id,
  :association_ids,
  :max_drain_duration_seconds,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


37372
37373
37374
37375
37376
37377
37378
37379
# File 'lib/aws-sdk-ec2/types.rb', line 37372

class DisassociateNatGatewayAddressRequest < Struct.new(
  :nat_gateway_id,
  :association_ids,
  :max_drain_duration_seconds,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_drain_duration_secondsInteger

The maximum amount of time to wait (in seconds) before forcibly releasing the IP addresses if connections are still in progress. Default value is 350 seconds.

Returns:

  • (Integer)


37372
37373
37374
37375
37376
37377
37378
37379
# File 'lib/aws-sdk-ec2/types.rb', line 37372

class DisassociateNatGatewayAddressRequest < Struct.new(
  :nat_gateway_id,
  :association_ids,
  :max_drain_duration_seconds,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#nat_gateway_idString

The ID of the NAT gateway.

Returns:

  • (String)


37372
37373
37374
37375
37376
37377
37378
37379
# File 'lib/aws-sdk-ec2/types.rb', line 37372

class DisassociateNatGatewayAddressRequest < Struct.new(
  :nat_gateway_id,
  :association_ids,
  :max_drain_duration_seconds,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end