Class: Aws::EC2::Types::DisassociateRouteServerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisassociateRouteServerRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#route_server_id ⇒ String
The ID of the route server to disassociate.
-
#vpc_id ⇒ String
The ID of the VPC to disassociate from the route server.
Instance Attribute Details
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action
without actually making the request and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
38343 38344 38345 38346 38347 38348 38349 |
# File 'lib/aws-sdk-ec2/types.rb', line 38343 class DisassociateRouteServerRequest < Struct.new( :route_server_id, :vpc_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#route_server_id ⇒ String
The ID of the route server to disassociate.
38343 38344 38345 38346 38347 38348 38349 |
# File 'lib/aws-sdk-ec2/types.rb', line 38343 class DisassociateRouteServerRequest < Struct.new( :route_server_id, :vpc_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC to disassociate from the route server.
38343 38344 38345 38346 38347 38348 38349 |
# File 'lib/aws-sdk-ec2/types.rb', line 38343 class DisassociateRouteServerRequest < Struct.new( :route_server_id, :vpc_id, :dry_run) SENSITIVE = [] include Aws::Structure end |