Class: Aws::EC2::Types::DisassociateRouteServerRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


37724
37725
37726
37727
37728
37729
37730
# File 'lib/aws-sdk-ec2/types.rb', line 37724

class DisassociateRouteServerRequest < Struct.new(
  :route_server_id,
  :vpc_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#route_server_idString

The ID of the route server to disassociate.

Returns:

  • (String)


37724
37725
37726
37727
37728
37729
37730
# File 'lib/aws-sdk-ec2/types.rb', line 37724

class DisassociateRouteServerRequest < Struct.new(
  :route_server_id,
  :vpc_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC to disassociate from the route server.

Returns:

  • (String)


37724
37725
37726
37727
37728
37729
37730
# File 'lib/aws-sdk-ec2/types.rb', line 37724

class DisassociateRouteServerRequest < Struct.new(
  :route_server_id,
  :vpc_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end