Class: Aws::EC2::Types::DisassociateRouteTableRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#association_idString

The association ID representing the current association between the route table and subnet or gateway.

Returns:

  • (String)


37765
37766
37767
37768
37769
37770
# File 'lib/aws-sdk-ec2/types.rb', line 37765

class DisassociateRouteTableRequest < Struct.new(
  :dry_run,
  :association_id)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


37765
37766
37767
37768
37769
37770
# File 'lib/aws-sdk-ec2/types.rb', line 37765

class DisassociateRouteTableRequest < Struct.new(
  :dry_run,
  :association_id)
  SENSITIVE = []
  include Aws::Structure
end