Class: Aws::EC2::Types::DisassociateRouteTableRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#association_idString

The association ID representing the current association between the route table and subnet or gateway.

Returns:

  • (String)


37758
37759
37760
37761
37762
37763
# File 'lib/aws-sdk-ec2/types.rb', line 37758

class DisassociateRouteTableRequest < Struct.new(
  :dry_run,
  :association_id)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


37758
37759
37760
37761
37762
37763
# File 'lib/aws-sdk-ec2/types.rb', line 37758

class DisassociateRouteTableRequest < Struct.new(
  :dry_run,
  :association_id)
  SENSITIVE = []
  include Aws::Structure
end