Class: Aws::EC2::Types::DisassociateSecurityGroupVpcRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


39905
39906
39907
39908
39909
39910
39911
# File 'lib/aws-sdk-ec2/types.rb', line 39905

class DisassociateSecurityGroupVpcRequest < Struct.new(
  :group_id,
  :vpc_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#group_idString

A security group ID.

Returns:

  • (String)


39905
39906
39907
39908
39909
39910
39911
# File 'lib/aws-sdk-ec2/types.rb', line 39905

class DisassociateSecurityGroupVpcRequest < Struct.new(
  :group_id,
  :vpc_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

A VPC ID.

Returns:

  • (String)


39905
39906
39907
39908
39909
39910
39911
# File 'lib/aws-sdk-ec2/types.rb', line 39905

class DisassociateSecurityGroupVpcRequest < Struct.new(
  :group_id,
  :vpc_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end