Class: Aws::EC2::Types::DisassociateSecurityGroupVpcRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


38222
38223
38224
38225
38226
38227
38228
# File 'lib/aws-sdk-ec2/types.rb', line 38222

class DisassociateSecurityGroupVpcRequest < Struct.new(
  :group_id,
  :vpc_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#group_idString

A security group ID.

Returns:

  • (String)


38222
38223
38224
38225
38226
38227
38228
# File 'lib/aws-sdk-ec2/types.rb', line 38222

class DisassociateSecurityGroupVpcRequest < Struct.new(
  :group_id,
  :vpc_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

A VPC ID.

Returns:

  • (String)


38222
38223
38224
38225
38226
38227
38228
# File 'lib/aws-sdk-ec2/types.rb', line 38222

class DisassociateSecurityGroupVpcRequest < Struct.new(
  :group_id,
  :vpc_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end