Class: Aws::EC2::Types::DisassociateSecurityGroupVpcRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisassociateSecurityGroupVpcRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#group_id ⇒ String
A security group ID.
-
#vpc_id ⇒ String
A VPC ID.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
37473 37474 37475 37476 37477 37478 37479 |
# File 'lib/aws-sdk-ec2/types.rb', line 37473 class DisassociateSecurityGroupVpcRequest < Struct.new( :group_id, :vpc_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#group_id ⇒ String
A security group ID.
37473 37474 37475 37476 37477 37478 37479 |
# File 'lib/aws-sdk-ec2/types.rb', line 37473 class DisassociateSecurityGroupVpcRequest < Struct.new( :group_id, :vpc_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
A VPC ID.
37473 37474 37475 37476 37477 37478 37479 |
# File 'lib/aws-sdk-ec2/types.rb', line 37473 class DisassociateSecurityGroupVpcRequest < Struct.new( :group_id, :vpc_id, :dry_run) SENSITIVE = [] include Aws::Structure end |