Class: Aws::EC2::Types::DisassociateTransitGatewayMulticastDomainRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisassociateTransitGatewayMulticastDomainRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#subnet_ids ⇒ Array<String>
The IDs of the subnets;.
-
#transit_gateway_attachment_id ⇒ String
The ID of the attachment.
-
#transit_gateway_multicast_domain_id ⇒ String
The ID of the transit gateway multicast domain.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
38510 38511 38512 38513 38514 38515 38516 38517 |
# File 'lib/aws-sdk-ec2/types.rb', line 38510 class DisassociateTransitGatewayMulticastDomainRequest < Struct.new( :transit_gateway_multicast_domain_id, :transit_gateway_attachment_id, :subnet_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#subnet_ids ⇒ Array<String>
The IDs of the subnets;
38510 38511 38512 38513 38514 38515 38516 38517 |
# File 'lib/aws-sdk-ec2/types.rb', line 38510 class DisassociateTransitGatewayMulticastDomainRequest < Struct.new( :transit_gateway_multicast_domain_id, :transit_gateway_attachment_id, :subnet_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_attachment_id ⇒ String
The ID of the attachment.
38510 38511 38512 38513 38514 38515 38516 38517 |
# File 'lib/aws-sdk-ec2/types.rb', line 38510 class DisassociateTransitGatewayMulticastDomainRequest < Struct.new( :transit_gateway_multicast_domain_id, :transit_gateway_attachment_id, :subnet_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_multicast_domain_id ⇒ String
The ID of the transit gateway multicast domain.
38510 38511 38512 38513 38514 38515 38516 38517 |
# File 'lib/aws-sdk-ec2/types.rb', line 38510 class DisassociateTransitGatewayMulticastDomainRequest < Struct.new( :transit_gateway_multicast_domain_id, :transit_gateway_attachment_id, :subnet_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |