Class: Aws::EC2::Types::DisassociateTransitGatewayMulticastDomainRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


36929
36930
36931
36932
36933
36934
36935
36936
# File 'lib/aws-sdk-ec2/types.rb', line 36929

class DisassociateTransitGatewayMulticastDomainRequest < Struct.new(
  :transit_gateway_multicast_domain_id,
  :transit_gateway_attachment_id,
  :subnet_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idsArray<String>

The IDs of the subnets;

Returns:

  • (Array<String>)


36929
36930
36931
36932
36933
36934
36935
36936
# File 'lib/aws-sdk-ec2/types.rb', line 36929

class DisassociateTransitGatewayMulticastDomainRequest < Struct.new(
  :transit_gateway_multicast_domain_id,
  :transit_gateway_attachment_id,
  :subnet_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_attachment_idString

The ID of the attachment.

Returns:

  • (String)


36929
36930
36931
36932
36933
36934
36935
36936
# File 'lib/aws-sdk-ec2/types.rb', line 36929

class DisassociateTransitGatewayMulticastDomainRequest < Struct.new(
  :transit_gateway_multicast_domain_id,
  :transit_gateway_attachment_id,
  :subnet_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_multicast_domain_idString

The ID of the transit gateway multicast domain.

Returns:

  • (String)


36929
36930
36931
36932
36933
36934
36935
36936
# File 'lib/aws-sdk-ec2/types.rb', line 36929

class DisassociateTransitGatewayMulticastDomainRequest < Struct.new(
  :transit_gateway_multicast_domain_id,
  :transit_gateway_attachment_id,
  :subnet_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end