Class: Aws::EC2::Types::DisassociateTransitGatewayPolicyTableRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


38524
38525
38526
38527
38528
38529
38530
# File 'lib/aws-sdk-ec2/types.rb', line 38524

class DisassociateTransitGatewayPolicyTableRequest < Struct.new(
  :transit_gateway_policy_table_id,
  :transit_gateway_attachment_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_attachment_idString

The ID of the transit gateway attachment to disassociate from the policy table.

Returns:

  • (String)


38524
38525
38526
38527
38528
38529
38530
# File 'lib/aws-sdk-ec2/types.rb', line 38524

class DisassociateTransitGatewayPolicyTableRequest < Struct.new(
  :transit_gateway_policy_table_id,
  :transit_gateway_attachment_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_policy_table_idString

The ID of the disassociated policy table.

Returns:

  • (String)


38524
38525
38526
38527
38528
38529
38530
# File 'lib/aws-sdk-ec2/types.rb', line 38524

class DisassociateTransitGatewayPolicyTableRequest < Struct.new(
  :transit_gateway_policy_table_id,
  :transit_gateway_attachment_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end