Class: Aws::EC2::Types::DisassociateTransitGatewayPolicyTableRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisassociateTransitGatewayPolicyTableRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#transit_gateway_attachment_id ⇒ String
The ID of the transit gateway attachment to disassociate from the policy table.
-
#transit_gateway_policy_table_id ⇒ String
The ID of the disassociated policy table.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
37898 37899 37900 37901 37902 37903 37904 |
# File 'lib/aws-sdk-ec2/types.rb', line 37898 class DisassociateTransitGatewayPolicyTableRequest < Struct.new( :transit_gateway_policy_table_id, :transit_gateway_attachment_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_attachment_id ⇒ String
The ID of the transit gateway attachment to disassociate from the policy table.
37898 37899 37900 37901 37902 37903 37904 |
# File 'lib/aws-sdk-ec2/types.rb', line 37898 class DisassociateTransitGatewayPolicyTableRequest < Struct.new( :transit_gateway_policy_table_id, :transit_gateway_attachment_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_policy_table_id ⇒ String
The ID of the disassociated policy table.
37898 37899 37900 37901 37902 37903 37904 |
# File 'lib/aws-sdk-ec2/types.rb', line 37898 class DisassociateTransitGatewayPolicyTableRequest < Struct.new( :transit_gateway_policy_table_id, :transit_gateway_attachment_id, :dry_run) SENSITIVE = [] include Aws::Structure end |