Class: Aws::EC2::Types::DisassociateTransitGatewayRouteTableRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisassociateTransitGatewayRouteTableRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#transit_gateway_attachment_id ⇒ String
The ID of the attachment.
-
#transit_gateway_route_table_id ⇒ String
The ID of the transit gateway route table.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
40071 40072 40073 40074 40075 40076 40077 |
# File 'lib/aws-sdk-ec2/types.rb', line 40071 class DisassociateTransitGatewayRouteTableRequest < Struct.new( :transit_gateway_route_table_id, :transit_gateway_attachment_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_attachment_id ⇒ String
The ID of the attachment.
40071 40072 40073 40074 40075 40076 40077 |
# File 'lib/aws-sdk-ec2/types.rb', line 40071 class DisassociateTransitGatewayRouteTableRequest < Struct.new( :transit_gateway_route_table_id, :transit_gateway_attachment_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_route_table_id ⇒ String
The ID of the transit gateway route table.
40071 40072 40073 40074 40075 40076 40077 |
# File 'lib/aws-sdk-ec2/types.rb', line 40071 class DisassociateTransitGatewayRouteTableRequest < Struct.new( :transit_gateway_route_table_id, :transit_gateway_attachment_id, :dry_run) SENSITIVE = [] include Aws::Structure end |