Class: Aws::EC2::Types::DisassociateTrunkInterfaceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#association_idString

The ID of the association

Returns:

  • (String)


38594
38595
38596
38597
38598
38599
38600
# File 'lib/aws-sdk-ec2/types.rb', line 38594

class DisassociateTrunkInterfaceRequest < Struct.new(
  :association_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


38594
38595
38596
38597
38598
38599
38600
# File 'lib/aws-sdk-ec2/types.rb', line 38594

class DisassociateTrunkInterfaceRequest < Struct.new(
  :association_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


38594
38595
38596
38597
38598
38599
38600
# File 'lib/aws-sdk-ec2/types.rb', line 38594

class DisassociateTrunkInterfaceRequest < Struct.new(
  :association_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end