Class: Aws::EC2::Types::DisassociateTrunkInterfaceResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DisassociateTrunkInterfaceResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#return ⇒ Boolean
Is ‘true` if the request succeeds and an error otherwise.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [Ensuring idempotency].
[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html
37070 37071 37072 37073 37074 37075 |
# File 'lib/aws-sdk-ec2/types.rb', line 37070 class DisassociateTrunkInterfaceResult < Struct.new( :return, :client_token) SENSITIVE = [] include Aws::Structure end |
#return ⇒ Boolean
Is ‘true` if the request succeeds and an error otherwise.
37070 37071 37072 37073 37074 37075 |
# File 'lib/aws-sdk-ec2/types.rb', line 37070 class DisassociateTrunkInterfaceResult < Struct.new( :return, :client_token) SENSITIVE = [] include Aws::Structure end |