Class: Aws::EC2::Types::DiskImageDescription
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DiskImageDescription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a disk image.
Constant Summary collapse
- SENSITIVE =
[:import_manifest_url]
Instance Attribute Summary collapse
-
#checksum ⇒ String
The checksum computed for the disk image.
-
#format ⇒ String
The disk image format.
-
#import_manifest_url ⇒ String
A presigned URL for the import manifest stored in Amazon S3.
-
#size ⇒ Integer
The size of the disk image, in GiB.
Instance Attribute Details
#checksum ⇒ String
The checksum computed for the disk image.
40219 40220 40221 40222 40223 40224 40225 40226 |
# File 'lib/aws-sdk-ec2/types.rb', line 40219 class DiskImageDescription < Struct.new( :checksum, :format, :import_manifest_url, :size) SENSITIVE = [:import_manifest_url] include Aws::Structure end |
#format ⇒ String
The disk image format.
40219 40220 40221 40222 40223 40224 40225 40226 |
# File 'lib/aws-sdk-ec2/types.rb', line 40219 class DiskImageDescription < Struct.new( :checksum, :format, :import_manifest_url, :size) SENSITIVE = [:import_manifest_url] include Aws::Structure end |
#import_manifest_url ⇒ String
A presigned URL for the import manifest stored in Amazon S3. For information about creating a presigned URL for an Amazon S3 object, read the "Query String Request Authentication Alternative" section of the Authenticating REST Requests topic in the Amazon Simple Storage Service Developer Guide.
For information about the import manifest referenced by this API action, see VM Import Manifest.
40219 40220 40221 40222 40223 40224 40225 40226 |
# File 'lib/aws-sdk-ec2/types.rb', line 40219 class DiskImageDescription < Struct.new( :checksum, :format, :import_manifest_url, :size) SENSITIVE = [:import_manifest_url] include Aws::Structure end |
#size ⇒ Integer
The size of the disk image, in GiB.
40219 40220 40221 40222 40223 40224 40225 40226 |
# File 'lib/aws-sdk-ec2/types.rb', line 40219 class DiskImageDescription < Struct.new( :checksum, :format, :import_manifest_url, :size) SENSITIVE = [:import_manifest_url] include Aws::Structure end |