Class: Aws::EC2::Types::DiskImageDescription

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes a disk image.

Constant Summary collapse

SENSITIVE =
[:import_manifest_url]

Instance Attribute Summary collapse

Instance Attribute Details

#checksumString

The checksum computed for the disk image.

Returns:

  • (String)


38754
38755
38756
38757
38758
38759
38760
38761
# File 'lib/aws-sdk-ec2/types.rb', line 38754

class DiskImageDescription < Struct.new(
  :checksum,
  :format,
  :import_manifest_url,
  :size)
  SENSITIVE = [:import_manifest_url]
  include Aws::Structure
end

#formatString

The disk image format.

Returns:

  • (String)


38754
38755
38756
38757
38758
38759
38760
38761
# File 'lib/aws-sdk-ec2/types.rb', line 38754

class DiskImageDescription < Struct.new(
  :checksum,
  :format,
  :import_manifest_url,
  :size)
  SENSITIVE = [:import_manifest_url]
  include Aws::Structure
end

#import_manifest_urlString

A presigned URL for the import manifest stored in Amazon S3. For information about creating a presigned URL for an Amazon S3 object, read the "Query String Request Authentication Alternative" section of the Authenticating REST Requests topic in the Amazon Simple Storage Service Developer Guide.

For information about the import manifest referenced by this API action, see VM Import Manifest.

Returns:

  • (String)


38754
38755
38756
38757
38758
38759
38760
38761
# File 'lib/aws-sdk-ec2/types.rb', line 38754

class DiskImageDescription < Struct.new(
  :checksum,
  :format,
  :import_manifest_url,
  :size)
  SENSITIVE = [:import_manifest_url]
  include Aws::Structure
end

#sizeInteger

The size of the disk image, in GiB.

Returns:

  • (Integer)


38754
38755
38756
38757
38758
38759
38760
38761
# File 'lib/aws-sdk-ec2/types.rb', line 38754

class DiskImageDescription < Struct.new(
  :checksum,
  :format,
  :import_manifest_url,
  :size)
  SENSITIVE = [:import_manifest_url]
  include Aws::Structure
end