Class: Aws::EC2::Types::DiskImageDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::DiskImageDetail
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a disk image.
Constant Summary collapse
- SENSITIVE =
[:import_manifest_url]
Instance Attribute Summary collapse
-
#bytes ⇒ Integer
The size of the disk image, in GiB.
-
#format ⇒ String
The disk image format.
-
#import_manifest_url ⇒ String
A presigned URL for the import manifest stored in Amazon S3 and presented here as an Amazon S3 presigned URL.
Instance Attribute Details
#bytes ⇒ Integer
The size of the disk image, in GiB.
38753 38754 38755 38756 38757 38758 38759 |
# File 'lib/aws-sdk-ec2/types.rb', line 38753 class DiskImageDetail < Struct.new( :format, :bytes, :import_manifest_url) SENSITIVE = [:import_manifest_url] include Aws::Structure end |
#format ⇒ String
The disk image format.
38753 38754 38755 38756 38757 38758 38759 |
# File 'lib/aws-sdk-ec2/types.rb', line 38753 class DiskImageDetail < Struct.new( :format, :bytes, :import_manifest_url) SENSITIVE = [:import_manifest_url] include Aws::Structure end |
#import_manifest_url ⇒ String
A presigned URL for the import manifest stored in Amazon S3 and presented here as an Amazon S3 presigned URL. For information about creating a presigned URL for an Amazon S3 object, read the "Query String Request Authentication Alternative" section of the Authenticating REST Requests topic in the Amazon Simple Storage Service Developer Guide.
For information about the import manifest referenced by this API action, see VM Import Manifest.
38753 38754 38755 38756 38757 38758 38759 |
# File 'lib/aws-sdk-ec2/types.rb', line 38753 class DiskImageDetail < Struct.new( :format, :bytes, :import_manifest_url) SENSITIVE = [:import_manifest_url] include Aws::Structure end |