Class: Aws::EC2::Types::EbsBlockDeviceResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::EbsBlockDeviceResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a block device for an EBS volume.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#delete_on_termination ⇒ Boolean
Indicates whether the volume is deleted on instance termination.
-
#encrypted ⇒ Boolean
Indicates whether the volume is encrypted.
-
#iops ⇒ Integer
The number of I/O operations per second (IOPS).
-
#kms_key_id ⇒ String
Identifier (key ID, key alias, key ARN, or alias ARN) of the customer managed KMS key to use for EBS encryption.
-
#snapshot_id ⇒ String
The ID of the snapshot.
-
#throughput ⇒ Integer
The throughput that the volume supports, in MiB/s.
-
#volume_size ⇒ Integer
The size of the volume, in GiBs.
-
#volume_type ⇒ String
The volume type.
Instance Attribute Details
#delete_on_termination ⇒ Boolean
Indicates whether the volume is deleted on instance termination.
38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 38345 |
# File 'lib/aws-sdk-ec2/types.rb', line 38334 class EbsBlockDeviceResponse < Struct.new( :encrypted, :delete_on_termination, :iops, :throughput, :kms_key_id, :snapshot_id, :volume_size, :volume_type) SENSITIVE = [] include Aws::Structure end |
#encrypted ⇒ Boolean
Indicates whether the volume is encrypted.
38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 38345 |
# File 'lib/aws-sdk-ec2/types.rb', line 38334 class EbsBlockDeviceResponse < Struct.new( :encrypted, :delete_on_termination, :iops, :throughput, :kms_key_id, :snapshot_id, :volume_size, :volume_type) SENSITIVE = [] include Aws::Structure end |
#iops ⇒ Integer
The number of I/O operations per second (IOPS). For ‘gp3`, `io1`, and `io2` volumes, this represents the number of IOPS that are provisioned for the volume. For `gp2` volumes, this represents the baseline performance of the volume and the rate at which the volume accumulates I/O credits for bursting.
38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 38345 |
# File 'lib/aws-sdk-ec2/types.rb', line 38334 class EbsBlockDeviceResponse < Struct.new( :encrypted, :delete_on_termination, :iops, :throughput, :kms_key_id, :snapshot_id, :volume_size, :volume_type) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
Identifier (key ID, key alias, key ARN, or alias ARN) of the customer managed KMS key to use for EBS encryption.
38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 38345 |
# File 'lib/aws-sdk-ec2/types.rb', line 38334 class EbsBlockDeviceResponse < Struct.new( :encrypted, :delete_on_termination, :iops, :throughput, :kms_key_id, :snapshot_id, :volume_size, :volume_type) SENSITIVE = [] include Aws::Structure end |
#snapshot_id ⇒ String
The ID of the snapshot.
38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 38345 |
# File 'lib/aws-sdk-ec2/types.rb', line 38334 class EbsBlockDeviceResponse < Struct.new( :encrypted, :delete_on_termination, :iops, :throughput, :kms_key_id, :snapshot_id, :volume_size, :volume_type) SENSITIVE = [] include Aws::Structure end |
#throughput ⇒ Integer
The throughput that the volume supports, in MiB/s.
38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 38345 |
# File 'lib/aws-sdk-ec2/types.rb', line 38334 class EbsBlockDeviceResponse < Struct.new( :encrypted, :delete_on_termination, :iops, :throughput, :kms_key_id, :snapshot_id, :volume_size, :volume_type) SENSITIVE = [] include Aws::Structure end |
#volume_size ⇒ Integer
The size of the volume, in GiBs.
38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 38345 |
# File 'lib/aws-sdk-ec2/types.rb', line 38334 class EbsBlockDeviceResponse < Struct.new( :encrypted, :delete_on_termination, :iops, :throughput, :kms_key_id, :snapshot_id, :volume_size, :volume_type) SENSITIVE = [] include Aws::Structure end |
#volume_type ⇒ String
The volume type. For more information, see [Amazon EBS volume types] in the *Amazon EBS User Guide*.
[1]: docs.aws.amazon.com/ebs/latest/userguide/ebs-volume-types.html
38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 38345 |
# File 'lib/aws-sdk-ec2/types.rb', line 38334 class EbsBlockDeviceResponse < Struct.new( :encrypted, :delete_on_termination, :iops, :throughput, :kms_key_id, :snapshot_id, :volume_size, :volume_type) SENSITIVE = [] include Aws::Structure end |