Class: Aws::EC2::Types::EbsInfo

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes the Amazon EBS features supported by the instance type.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attachment_limit_typeString

Indicates whether the instance type features a shared or dedicated Amazon EBS volume attachment limit. For more information, see

Amazon EBS volume limits for Amazon EC2 instances][1

in the

*Amazon EC2 User Guide*.

[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/volume_limits.html

Returns:

  • (String)


37834
37835
37836
37837
37838
37839
37840
37841
37842
37843
37844
37845
# File 'lib/aws-sdk-ec2/types.rb', line 37834

class EbsInfo < Struct.new(
  :ebs_optimized_support,
  :encryption_support,
  :ebs_optimized_info,
  :nvme_support,
  :maximum_ebs_attachments,
  :attachment_limit_type,
  :maximum_ebs_cards,
  :ebs_cards)
  SENSITIVE = []
  include Aws::Structure
end

#ebs_cardsArray<Types::EbsCardInfo>

Describes the EBS cards available for the instance type.

Returns:



37834
37835
37836
37837
37838
37839
37840
37841
37842
37843
37844
37845
# File 'lib/aws-sdk-ec2/types.rb', line 37834

class EbsInfo < Struct.new(
  :ebs_optimized_support,
  :encryption_support,
  :ebs_optimized_info,
  :nvme_support,
  :maximum_ebs_attachments,
  :attachment_limit_type,
  :maximum_ebs_cards,
  :ebs_cards)
  SENSITIVE = []
  include Aws::Structure
end

#ebs_optimized_infoTypes::EbsOptimizedInfo

Describes the optimized EBS performance for the instance type.



37834
37835
37836
37837
37838
37839
37840
37841
37842
37843
37844
37845
# File 'lib/aws-sdk-ec2/types.rb', line 37834

class EbsInfo < Struct.new(
  :ebs_optimized_support,
  :encryption_support,
  :ebs_optimized_info,
  :nvme_support,
  :maximum_ebs_attachments,
  :attachment_limit_type,
  :maximum_ebs_cards,
  :ebs_cards)
  SENSITIVE = []
  include Aws::Structure
end

#ebs_optimized_supportString

Indicates whether the instance type is Amazon EBS-optimized. For more information, see [Amazon EBS-optimized instances] in *Amazon EC2 User Guide*.

[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSOptimized.html

Returns:

  • (String)


37834
37835
37836
37837
37838
37839
37840
37841
37842
37843
37844
37845
# File 'lib/aws-sdk-ec2/types.rb', line 37834

class EbsInfo < Struct.new(
  :ebs_optimized_support,
  :encryption_support,
  :ebs_optimized_info,
  :nvme_support,
  :maximum_ebs_attachments,
  :attachment_limit_type,
  :maximum_ebs_cards,
  :ebs_cards)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_supportString

Indicates whether Amazon EBS encryption is supported.

Returns:

  • (String)


37834
37835
37836
37837
37838
37839
37840
37841
37842
37843
37844
37845
# File 'lib/aws-sdk-ec2/types.rb', line 37834

class EbsInfo < Struct.new(
  :ebs_optimized_support,
  :encryption_support,
  :ebs_optimized_info,
  :nvme_support,
  :maximum_ebs_attachments,
  :attachment_limit_type,
  :maximum_ebs_cards,
  :ebs_cards)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_ebs_attachmentsInteger

Indicates the maximum number of Amazon EBS volumes that can be attached to the instance type. For more information, see [Amazon EBS volume limits for Amazon EC2 instances] in the *Amazon EC2 User Guide*.

[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/volume_limits.html

Returns:

  • (Integer)


37834
37835
37836
37837
37838
37839
37840
37841
37842
37843
37844
37845
# File 'lib/aws-sdk-ec2/types.rb', line 37834

class EbsInfo < Struct.new(
  :ebs_optimized_support,
  :encryption_support,
  :ebs_optimized_info,
  :nvme_support,
  :maximum_ebs_attachments,
  :attachment_limit_type,
  :maximum_ebs_cards,
  :ebs_cards)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_ebs_cardsInteger

Indicates the number of EBS cards supported by the instance type.

Returns:

  • (Integer)


37834
37835
37836
37837
37838
37839
37840
37841
37842
37843
37844
37845
# File 'lib/aws-sdk-ec2/types.rb', line 37834

class EbsInfo < Struct.new(
  :ebs_optimized_support,
  :encryption_support,
  :ebs_optimized_info,
  :nvme_support,
  :maximum_ebs_attachments,
  :attachment_limit_type,
  :maximum_ebs_cards,
  :ebs_cards)
  SENSITIVE = []
  include Aws::Structure
end

#nvme_supportString

Indicates whether non-volatile memory express (NVMe) is supported.

Returns:

  • (String)


37834
37835
37836
37837
37838
37839
37840
37841
37842
37843
37844
37845
# File 'lib/aws-sdk-ec2/types.rb', line 37834

class EbsInfo < Struct.new(
  :ebs_optimized_support,
  :encryption_support,
  :ebs_optimized_info,
  :nvme_support,
  :maximum_ebs_attachments,
  :attachment_limit_type,
  :maximum_ebs_cards,
  :ebs_cards)
  SENSITIVE = []
  include Aws::Structure
end