Class: Aws::EC2::Types::EbsInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::EbsInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the Amazon EBS features supported by the instance type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attachment_limit_type ⇒ String
Indicates whether the instance type features a shared or dedicated Amazon EBS volume attachment limit.
-
#ebs_optimized_info ⇒ Types::EbsOptimizedInfo
Describes the optimized EBS performance for the instance type.
-
#ebs_optimized_support ⇒ String
Indicates whether the instance type is Amazon EBS-optimized.
-
#encryption_support ⇒ String
Indicates whether Amazon EBS encryption is supported.
-
#maximum_ebs_attachments ⇒ Integer
Indicates the maximum number of Amazon EBS volumes that can be attached to the instance type.
-
#nvme_support ⇒ String
Indicates whether non-volatile memory express (NVMe) is supported.
Instance Attribute Details
#attachment_limit_type ⇒ String
Indicates whether the instance type features a shared or dedicated Amazon EBS volume attachment limit. For more information, see
- Amazon EBS volume limits for Amazon EC2 instances][1
-
in the
*Amazon EC2 User Guide*.
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/volume_limits.html
37769 37770 37771 37772 37773 37774 37775 37776 37777 37778 |
# File 'lib/aws-sdk-ec2/types.rb', line 37769 class EbsInfo < Struct.new( :ebs_optimized_support, :encryption_support, :ebs_optimized_info, :nvme_support, :maximum_ebs_attachments, :attachment_limit_type) SENSITIVE = [] include Aws::Structure end |
#ebs_optimized_info ⇒ Types::EbsOptimizedInfo
Describes the optimized EBS performance for the instance type.
37769 37770 37771 37772 37773 37774 37775 37776 37777 37778 |
# File 'lib/aws-sdk-ec2/types.rb', line 37769 class EbsInfo < Struct.new( :ebs_optimized_support, :encryption_support, :ebs_optimized_info, :nvme_support, :maximum_ebs_attachments, :attachment_limit_type) SENSITIVE = [] include Aws::Structure end |
#ebs_optimized_support ⇒ String
Indicates whether the instance type is Amazon EBS-optimized. For more information, see [Amazon EBS-optimized instances] in *Amazon EC2 User Guide*.
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSOptimized.html
37769 37770 37771 37772 37773 37774 37775 37776 37777 37778 |
# File 'lib/aws-sdk-ec2/types.rb', line 37769 class EbsInfo < Struct.new( :ebs_optimized_support, :encryption_support, :ebs_optimized_info, :nvme_support, :maximum_ebs_attachments, :attachment_limit_type) SENSITIVE = [] include Aws::Structure end |
#encryption_support ⇒ String
Indicates whether Amazon EBS encryption is supported.
37769 37770 37771 37772 37773 37774 37775 37776 37777 37778 |
# File 'lib/aws-sdk-ec2/types.rb', line 37769 class EbsInfo < Struct.new( :ebs_optimized_support, :encryption_support, :ebs_optimized_info, :nvme_support, :maximum_ebs_attachments, :attachment_limit_type) SENSITIVE = [] include Aws::Structure end |
#maximum_ebs_attachments ⇒ Integer
Indicates the maximum number of Amazon EBS volumes that can be attached to the instance type. For more information, see [Amazon EBS volume limits for Amazon EC2 instances] in the *Amazon EC2 User Guide*.
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/volume_limits.html
37769 37770 37771 37772 37773 37774 37775 37776 37777 37778 |
# File 'lib/aws-sdk-ec2/types.rb', line 37769 class EbsInfo < Struct.new( :ebs_optimized_support, :encryption_support, :ebs_optimized_info, :nvme_support, :maximum_ebs_attachments, :attachment_limit_type) SENSITIVE = [] include Aws::Structure end |
#nvme_support ⇒ String
Indicates whether non-volatile memory express (NVMe) is supported.
37769 37770 37771 37772 37773 37774 37775 37776 37777 37778 |
# File 'lib/aws-sdk-ec2/types.rb', line 37769 class EbsInfo < Struct.new( :ebs_optimized_support, :encryption_support, :ebs_optimized_info, :nvme_support, :maximum_ebs_attachments, :attachment_limit_type) SENSITIVE = [] include Aws::Structure end |