Class: Aws::EC2::Types::EbsInstanceBlockDevice
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::EbsInstanceBlockDevice
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a parameter used to set up an EBS volume in a block device mapping.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#associated_resource ⇒ String
The ARN of the Amazon Web Services-managed resource to which the volume is attached.
-
#attach_time ⇒ Time
The time stamp when the attachment initiated.
-
#delete_on_termination ⇒ Boolean
Indicates whether the volume is deleted on instance termination.
-
#ebs_card_index ⇒ Integer
The index of the EBS card.
-
#operator ⇒ Types::OperatorResponse
The service provider that manages the EBS volume.
-
#status ⇒ String
The attachment state.
-
#volume_id ⇒ String
The ID of the EBS volume.
-
#volume_owner_id ⇒ String
The ID of the Amazon Web Services account that owns the volume.
Instance Attribute Details
#associated_resource ⇒ String
The ARN of the Amazon Web Services-managed resource to which the volume is attached.
40573 40574 40575 40576 40577 40578 40579 40580 40581 40582 40583 40584 |
# File 'lib/aws-sdk-ec2/types.rb', line 40573 class EbsInstanceBlockDevice < Struct.new( :attach_time, :delete_on_termination, :status, :volume_id, :associated_resource, :volume_owner_id, :operator, :ebs_card_index) SENSITIVE = [] include Aws::Structure end |
#attach_time ⇒ Time
The time stamp when the attachment initiated.
40573 40574 40575 40576 40577 40578 40579 40580 40581 40582 40583 40584 |
# File 'lib/aws-sdk-ec2/types.rb', line 40573 class EbsInstanceBlockDevice < Struct.new( :attach_time, :delete_on_termination, :status, :volume_id, :associated_resource, :volume_owner_id, :operator, :ebs_card_index) SENSITIVE = [] include Aws::Structure end |
#delete_on_termination ⇒ Boolean
Indicates whether the volume is deleted on instance termination.
40573 40574 40575 40576 40577 40578 40579 40580 40581 40582 40583 40584 |
# File 'lib/aws-sdk-ec2/types.rb', line 40573 class EbsInstanceBlockDevice < Struct.new( :attach_time, :delete_on_termination, :status, :volume_id, :associated_resource, :volume_owner_id, :operator, :ebs_card_index) SENSITIVE = [] include Aws::Structure end |
#ebs_card_index ⇒ Integer
The index of the EBS card. Some instance types support multiple EBS cards. The default EBS card index is 0.
40573 40574 40575 40576 40577 40578 40579 40580 40581 40582 40583 40584 |
# File 'lib/aws-sdk-ec2/types.rb', line 40573 class EbsInstanceBlockDevice < Struct.new( :attach_time, :delete_on_termination, :status, :volume_id, :associated_resource, :volume_owner_id, :operator, :ebs_card_index) SENSITIVE = [] include Aws::Structure end |
#operator ⇒ Types::OperatorResponse
The service provider that manages the EBS volume.
40573 40574 40575 40576 40577 40578 40579 40580 40581 40582 40583 40584 |
# File 'lib/aws-sdk-ec2/types.rb', line 40573 class EbsInstanceBlockDevice < Struct.new( :attach_time, :delete_on_termination, :status, :volume_id, :associated_resource, :volume_owner_id, :operator, :ebs_card_index) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The attachment state.
40573 40574 40575 40576 40577 40578 40579 40580 40581 40582 40583 40584 |
# File 'lib/aws-sdk-ec2/types.rb', line 40573 class EbsInstanceBlockDevice < Struct.new( :attach_time, :delete_on_termination, :status, :volume_id, :associated_resource, :volume_owner_id, :operator, :ebs_card_index) SENSITIVE = [] include Aws::Structure end |
#volume_id ⇒ String
The ID of the EBS volume.
40573 40574 40575 40576 40577 40578 40579 40580 40581 40582 40583 40584 |
# File 'lib/aws-sdk-ec2/types.rb', line 40573 class EbsInstanceBlockDevice < Struct.new( :attach_time, :delete_on_termination, :status, :volume_id, :associated_resource, :volume_owner_id, :operator, :ebs_card_index) SENSITIVE = [] include Aws::Structure end |
#volume_owner_id ⇒ String
The ID of the Amazon Web Services account that owns the volume.
This parameter is returned only for volumes that are attached to Amazon Web Services-managed resources.
40573 40574 40575 40576 40577 40578 40579 40580 40581 40582 40583 40584 |
# File 'lib/aws-sdk-ec2/types.rb', line 40573 class EbsInstanceBlockDevice < Struct.new( :attach_time, :delete_on_termination, :status, :volume_id, :associated_resource, :volume_owner_id, :operator, :ebs_card_index) SENSITIVE = [] include Aws::Structure end |