Class: Aws::EC2::Types::EnableAddressTransferRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::EnableAddressTransferRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allocation_id ⇒ String
The allocation ID of an Elastic IP address.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#transfer_account_id ⇒ String
The ID of the account that you want to transfer the Elastic IP address to.
Instance Attribute Details
#allocation_id ⇒ String
The allocation ID of an Elastic IP address.
40066 40067 40068 40069 40070 40071 40072 |
# File 'lib/aws-sdk-ec2/types.rb', line 40066 class EnableAddressTransferRequest < Struct.new( :allocation_id, :transfer_account_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
40066 40067 40068 40069 40070 40071 40072 |
# File 'lib/aws-sdk-ec2/types.rb', line 40066 class EnableAddressTransferRequest < Struct.new( :allocation_id, :transfer_account_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transfer_account_id ⇒ String
The ID of the account that you want to transfer the Elastic IP address to.
40066 40067 40068 40069 40070 40071 40072 |
# File 'lib/aws-sdk-ec2/types.rb', line 40066 class EnableAddressTransferRequest < Struct.new( :allocation_id, :transfer_account_id, :dry_run) SENSITIVE = [] include Aws::Structure end |