Class: Aws::EC2::Types::EnableAddressTransferRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allocation_idString

The allocation ID of an Elastic IP address.

Returns:

  • (String)


39848
39849
39850
39851
39852
39853
39854
# File 'lib/aws-sdk-ec2/types.rb', line 39848

class EnableAddressTransferRequest < Struct.new(
  :allocation_id,
  :transfer_account_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


39848
39849
39850
39851
39852
39853
39854
# File 'lib/aws-sdk-ec2/types.rb', line 39848

class EnableAddressTransferRequest < Struct.new(
  :allocation_id,
  :transfer_account_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transfer_account_idString

The ID of the account that you want to transfer the Elastic IP address to.

Returns:

  • (String)


39848
39849
39850
39851
39852
39853
39854
# File 'lib/aws-sdk-ec2/types.rb', line 39848

class EnableAddressTransferRequest < Struct.new(
  :allocation_id,
  :transfer_account_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end