Class: Aws::EC2::Types::EnableAddressTransferRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::EnableAddressTransferRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allocation_id ⇒ String
The allocation ID of an Elastic IP address.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#transfer_account_id ⇒ String
The ID of the account that you want to transfer the Elastic IP address to.
Instance Attribute Details
#allocation_id ⇒ String
The allocation ID of an Elastic IP address.
39766 39767 39768 39769 39770 39771 39772 |
# File 'lib/aws-sdk-ec2/types.rb', line 39766 class EnableAddressTransferRequest < Struct.new( :allocation_id, :transfer_account_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
39766 39767 39768 39769 39770 39771 39772 |
# File 'lib/aws-sdk-ec2/types.rb', line 39766 class EnableAddressTransferRequest < Struct.new( :allocation_id, :transfer_account_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transfer_account_id ⇒ String
The ID of the account that you want to transfer the Elastic IP address to.
39766 39767 39768 39769 39770 39771 39772 |
# File 'lib/aws-sdk-ec2/types.rb', line 39766 class EnableAddressTransferRequest < Struct.new( :allocation_id, :transfer_account_id, :dry_run) SENSITIVE = [] include Aws::Structure end |