Class: Aws::EC2::Types::EnableAllowedImagesSettingsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::EnableAllowedImagesSettingsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allowed_images_settings_state ⇒ String
Specify
enabledto apply the image criteria specified by the Allowed AMIs settings. -
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#allowed_images_settings_state ⇒ String
Specify enabled to apply the image criteria specified by the
Allowed AMIs settings. Specify audit-mode so that you can check
which AMIs will be allowed or not allowed by the image criteria.
40035 40036 40037 40038 40039 40040 |
# File 'lib/aws-sdk-ec2/types.rb', line 40035 class EnableAllowedImagesSettingsRequest < Struct.new( :allowed_images_settings_state, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
40035 40036 40037 40038 40039 40040 |
# File 'lib/aws-sdk-ec2/types.rb', line 40035 class EnableAllowedImagesSettingsRequest < Struct.new( :allowed_images_settings_state, :dry_run) SENSITIVE = [] include Aws::Structure end |