Class: Aws::EC2::Types::EnableAllowedImagesSettingsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allowed_images_settings_stateString

Specify ‘enabled` to apply the image criteria specified by the Allowed AMIs settings. Specify `audit-mode` so that you can check which AMIs will be allowed or not allowed by the image criteria.

Returns:

  • (String)


39450
39451
39452
39453
39454
39455
# File 'lib/aws-sdk-ec2/types.rb', line 39450

class EnableAllowedImagesSettingsRequest < Struct.new(
  :allowed_images_settings_state,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


39450
39451
39452
39453
39454
39455
# File 'lib/aws-sdk-ec2/types.rb', line 39450

class EnableAllowedImagesSettingsRequest < Struct.new(
  :allowed_images_settings_state,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end