Class: Aws::EC2::Types::EnableApplicationStatusCheckSuppressionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


41258
41259
41260
41261
41262
41263
41264
41265
# File 'lib/aws-sdk-ec2/types.rb', line 41258

class EnableApplicationStatusCheckSuppressionRequest < Struct.new(
  :instance_ids,
  :duration_seconds,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


41258
41259
41260
41261
41262
41263
41264
41265
# File 'lib/aws-sdk-ec2/types.rb', line 41258

class EnableApplicationStatusCheckSuppressionRequest < Struct.new(
  :instance_ids,
  :duration_seconds,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#duration_secondsInteger

The duration, in seconds, for which to suppress application status checks. If omitted, the application status check is suppressed indefinitely until you call DisableApplicationStatusCheckSuppression.

Returns:

  • (Integer)


41258
41259
41260
41261
41262
41263
41264
41265
# File 'lib/aws-sdk-ec2/types.rb', line 41258

class EnableApplicationStatusCheckSuppressionRequest < Struct.new(
  :instance_ids,
  :duration_seconds,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idsArray<String>

The IDs of the instances for which to suppress application status checks.

Returns:

  • (Array<String>)


41258
41259
41260
41261
41262
41263
41264
41265
# File 'lib/aws-sdk-ec2/types.rb', line 41258

class EnableApplicationStatusCheckSuppressionRequest < Struct.new(
  :instance_ids,
  :duration_seconds,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end