Class: Aws::EC2::Types::EnableApplicationStatusCheckSuppressionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::EnableApplicationStatusCheckSuppressionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#duration_seconds ⇒ Integer
The duration, in seconds, for which to suppress application status checks.
-
#instance_ids ⇒ Array<String>
The IDs of the instances for which to suppress application status checks.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring idempotency.
A suitable default value is auto-generated. You should normally not need to pass this option.
41258 41259 41260 41261 41262 41263 41264 41265 |
# File 'lib/aws-sdk-ec2/types.rb', line 41258 class EnableApplicationStatusCheckSuppressionRequest < Struct.new( :instance_ids, :duration_seconds, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
41258 41259 41260 41261 41262 41263 41264 41265 |
# File 'lib/aws-sdk-ec2/types.rb', line 41258 class EnableApplicationStatusCheckSuppressionRequest < Struct.new( :instance_ids, :duration_seconds, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#duration_seconds ⇒ Integer
The duration, in seconds, for which to suppress application status
checks. If omitted, the application status check is suppressed
indefinitely until you call
DisableApplicationStatusCheckSuppression.
41258 41259 41260 41261 41262 41263 41264 41265 |
# File 'lib/aws-sdk-ec2/types.rb', line 41258 class EnableApplicationStatusCheckSuppressionRequest < Struct.new( :instance_ids, :duration_seconds, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#instance_ids ⇒ Array<String>
The IDs of the instances for which to suppress application status checks.
41258 41259 41260 41261 41262 41263 41264 41265 |
# File 'lib/aws-sdk-ec2/types.rb', line 41258 class EnableApplicationStatusCheckSuppressionRequest < Struct.new( :instance_ids, :duration_seconds, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |