Class: Aws::EC2::Types::EnableCapacityManagerRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


40172
40173
40174
40175
40176
40177
40178
# File 'lib/aws-sdk-ec2/types.rb', line 40172

class EnableCapacityManagerRequest < Struct.new(
  :organizations_access,
  :dry_run,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


40172
40173
40174
40175
40176
40177
40178
# File 'lib/aws-sdk-ec2/types.rb', line 40172

class EnableCapacityManagerRequest < Struct.new(
  :organizations_access,
  :dry_run,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#organizations_accessBoolean

Specifies whether to enable cross-account access for Amazon Web Services Organizations. When enabled, Capacity Manager can aggregate data from all accounts in your organization. Default is false.

Returns:

  • (Boolean)


40172
40173
40174
40175
40176
40177
40178
# File 'lib/aws-sdk-ec2/types.rb', line 40172

class EnableCapacityManagerRequest < Struct.new(
  :organizations_access,
  :dry_run,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end