Class: Aws::EC2::Types::EnableFastLaunchRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


39629
39630
39631
39632
39633
39634
39635
39636
39637
39638
# File 'lib/aws-sdk-ec2/types.rb', line 39629

class EnableFastLaunchRequest < Struct.new(
  :image_id,
  :resource_type,
  :snapshot_configuration,
  :launch_template,
  :max_parallel_launches,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#image_idString

Specify the ID of the image for which to enable Windows fast launch.

Returns:

  • (String)


39629
39630
39631
39632
39633
39634
39635
39636
39637
39638
# File 'lib/aws-sdk-ec2/types.rb', line 39629

class EnableFastLaunchRequest < Struct.new(
  :image_id,
  :resource_type,
  :snapshot_configuration,
  :launch_template,
  :max_parallel_launches,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#launch_templateTypes::FastLaunchLaunchTemplateSpecificationRequest

The launch template to use when launching Windows instances from pre-provisioned snapshots. Launch template parameters can include either the name or ID of the launch template, but not both.



39629
39630
39631
39632
39633
39634
39635
39636
39637
39638
# File 'lib/aws-sdk-ec2/types.rb', line 39629

class EnableFastLaunchRequest < Struct.new(
  :image_id,
  :resource_type,
  :snapshot_configuration,
  :launch_template,
  :max_parallel_launches,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_parallel_launchesInteger

The maximum number of instances that Amazon EC2 can launch at the same time to create pre-provisioned snapshots for Windows fast launch. Value must be ‘6` or greater.

Returns:

  • (Integer)


39629
39630
39631
39632
39633
39634
39635
39636
39637
39638
# File 'lib/aws-sdk-ec2/types.rb', line 39629

class EnableFastLaunchRequest < Struct.new(
  :image_id,
  :resource_type,
  :snapshot_configuration,
  :launch_template,
  :max_parallel_launches,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The type of resource to use for pre-provisioning the AMI for Windows fast launch. Supported values include: ‘snapshot`, which is the default value.

Returns:

  • (String)


39629
39630
39631
39632
39633
39634
39635
39636
39637
39638
# File 'lib/aws-sdk-ec2/types.rb', line 39629

class EnableFastLaunchRequest < Struct.new(
  :image_id,
  :resource_type,
  :snapshot_configuration,
  :launch_template,
  :max_parallel_launches,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_configurationTypes::FastLaunchSnapshotConfigurationRequest

Configuration settings for creating and managing the snapshots that are used for pre-provisioning the AMI for Windows fast launch. The associated ‘ResourceType` must be `snapshot`.



39629
39630
39631
39632
39633
39634
39635
39636
39637
39638
# File 'lib/aws-sdk-ec2/types.rb', line 39629

class EnableFastLaunchRequest < Struct.new(
  :image_id,
  :resource_type,
  :snapshot_configuration,
  :launch_template,
  :max_parallel_launches,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end