Class: Aws::EC2::Types::EnableFastSnapshotRestoreSuccessItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::EnableFastSnapshotRestoreSuccessItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes fast snapshot restores that were successfully enabled.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone ⇒ String
The Availability Zone.
-
#availability_zone_id ⇒ String
The ID of the Availability Zone.
-
#disabled_time ⇒ Time
The time at which fast snapshot restores entered the
disabledstate. -
#disabling_time ⇒ Time
The time at which fast snapshot restores entered the
disablingstate. -
#enabled_time ⇒ Time
The time at which fast snapshot restores entered the
enabledstate. -
#enabling_time ⇒ Time
The time at which fast snapshot restores entered the
enablingstate. -
#optimizing_time ⇒ Time
The time at which fast snapshot restores entered the
optimizingstate. -
#owner_alias ⇒ String
The Amazon Web Services owner alias that enabled fast snapshot restores on the snapshot.
-
#owner_id ⇒ String
The ID of the Amazon Web Services account that enabled fast snapshot restores on the snapshot.
-
#snapshot_id ⇒ String
The ID of the snapshot.
-
#state ⇒ String
The state of fast snapshot restores.
-
#state_transition_reason ⇒ String
The reason for the state transition.
Instance Attribute Details
#availability_zone ⇒ String
The Availability Zone.
40465 40466 40467 40468 40469 40470 40471 40472 40473 40474 40475 40476 40477 40478 40479 40480 |
# File 'lib/aws-sdk-ec2/types.rb', line 40465 class EnableFastSnapshotRestoreSuccessItem < Struct.new( :snapshot_id, :availability_zone, :availability_zone_id, :state, :state_transition_reason, :owner_id, :owner_alias, :enabling_time, :optimizing_time, :enabled_time, :disabling_time, :disabled_time) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
The ID of the Availability Zone.
40465 40466 40467 40468 40469 40470 40471 40472 40473 40474 40475 40476 40477 40478 40479 40480 |
# File 'lib/aws-sdk-ec2/types.rb', line 40465 class EnableFastSnapshotRestoreSuccessItem < Struct.new( :snapshot_id, :availability_zone, :availability_zone_id, :state, :state_transition_reason, :owner_id, :owner_alias, :enabling_time, :optimizing_time, :enabled_time, :disabling_time, :disabled_time) SENSITIVE = [] include Aws::Structure end |
#disabled_time ⇒ Time
The time at which fast snapshot restores entered the disabled
state.
40465 40466 40467 40468 40469 40470 40471 40472 40473 40474 40475 40476 40477 40478 40479 40480 |
# File 'lib/aws-sdk-ec2/types.rb', line 40465 class EnableFastSnapshotRestoreSuccessItem < Struct.new( :snapshot_id, :availability_zone, :availability_zone_id, :state, :state_transition_reason, :owner_id, :owner_alias, :enabling_time, :optimizing_time, :enabled_time, :disabling_time, :disabled_time) SENSITIVE = [] include Aws::Structure end |
#disabling_time ⇒ Time
The time at which fast snapshot restores entered the disabling
state.
40465 40466 40467 40468 40469 40470 40471 40472 40473 40474 40475 40476 40477 40478 40479 40480 |
# File 'lib/aws-sdk-ec2/types.rb', line 40465 class EnableFastSnapshotRestoreSuccessItem < Struct.new( :snapshot_id, :availability_zone, :availability_zone_id, :state, :state_transition_reason, :owner_id, :owner_alias, :enabling_time, :optimizing_time, :enabled_time, :disabling_time, :disabled_time) SENSITIVE = [] include Aws::Structure end |
#enabled_time ⇒ Time
The time at which fast snapshot restores entered the enabled
state.
40465 40466 40467 40468 40469 40470 40471 40472 40473 40474 40475 40476 40477 40478 40479 40480 |
# File 'lib/aws-sdk-ec2/types.rb', line 40465 class EnableFastSnapshotRestoreSuccessItem < Struct.new( :snapshot_id, :availability_zone, :availability_zone_id, :state, :state_transition_reason, :owner_id, :owner_alias, :enabling_time, :optimizing_time, :enabled_time, :disabling_time, :disabled_time) SENSITIVE = [] include Aws::Structure end |
#enabling_time ⇒ Time
The time at which fast snapshot restores entered the enabling
state.
40465 40466 40467 40468 40469 40470 40471 40472 40473 40474 40475 40476 40477 40478 40479 40480 |
# File 'lib/aws-sdk-ec2/types.rb', line 40465 class EnableFastSnapshotRestoreSuccessItem < Struct.new( :snapshot_id, :availability_zone, :availability_zone_id, :state, :state_transition_reason, :owner_id, :owner_alias, :enabling_time, :optimizing_time, :enabled_time, :disabling_time, :disabled_time) SENSITIVE = [] include Aws::Structure end |
#optimizing_time ⇒ Time
The time at which fast snapshot restores entered the optimizing
state.
40465 40466 40467 40468 40469 40470 40471 40472 40473 40474 40475 40476 40477 40478 40479 40480 |
# File 'lib/aws-sdk-ec2/types.rb', line 40465 class EnableFastSnapshotRestoreSuccessItem < Struct.new( :snapshot_id, :availability_zone, :availability_zone_id, :state, :state_transition_reason, :owner_id, :owner_alias, :enabling_time, :optimizing_time, :enabled_time, :disabling_time, :disabled_time) SENSITIVE = [] include Aws::Structure end |
#owner_alias ⇒ String
The Amazon Web Services owner alias that enabled fast snapshot restores on the snapshot. This is intended for future use.
40465 40466 40467 40468 40469 40470 40471 40472 40473 40474 40475 40476 40477 40478 40479 40480 |
# File 'lib/aws-sdk-ec2/types.rb', line 40465 class EnableFastSnapshotRestoreSuccessItem < Struct.new( :snapshot_id, :availability_zone, :availability_zone_id, :state, :state_transition_reason, :owner_id, :owner_alias, :enabling_time, :optimizing_time, :enabled_time, :disabling_time, :disabled_time) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
The ID of the Amazon Web Services account that enabled fast snapshot restores on the snapshot.
40465 40466 40467 40468 40469 40470 40471 40472 40473 40474 40475 40476 40477 40478 40479 40480 |
# File 'lib/aws-sdk-ec2/types.rb', line 40465 class EnableFastSnapshotRestoreSuccessItem < Struct.new( :snapshot_id, :availability_zone, :availability_zone_id, :state, :state_transition_reason, :owner_id, :owner_alias, :enabling_time, :optimizing_time, :enabled_time, :disabling_time, :disabled_time) SENSITIVE = [] include Aws::Structure end |
#snapshot_id ⇒ String
The ID of the snapshot.
40465 40466 40467 40468 40469 40470 40471 40472 40473 40474 40475 40476 40477 40478 40479 40480 |
# File 'lib/aws-sdk-ec2/types.rb', line 40465 class EnableFastSnapshotRestoreSuccessItem < Struct.new( :snapshot_id, :availability_zone, :availability_zone_id, :state, :state_transition_reason, :owner_id, :owner_alias, :enabling_time, :optimizing_time, :enabled_time, :disabling_time, :disabled_time) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of fast snapshot restores.
40465 40466 40467 40468 40469 40470 40471 40472 40473 40474 40475 40476 40477 40478 40479 40480 |
# File 'lib/aws-sdk-ec2/types.rb', line 40465 class EnableFastSnapshotRestoreSuccessItem < Struct.new( :snapshot_id, :availability_zone, :availability_zone_id, :state, :state_transition_reason, :owner_id, :owner_alias, :enabling_time, :optimizing_time, :enabled_time, :disabling_time, :disabled_time) SENSITIVE = [] include Aws::Structure end |
#state_transition_reason ⇒ String
The reason for the state transition. The possible values are as follows:
-
Client.UserInitiated- The state successfully transitioned toenablingordisabling. -
Client.UserInitiated - Lifecycle state transition- The state successfully transitioned tooptimizing,enabled, ordisabled.
40465 40466 40467 40468 40469 40470 40471 40472 40473 40474 40475 40476 40477 40478 40479 40480 |
# File 'lib/aws-sdk-ec2/types.rb', line 40465 class EnableFastSnapshotRestoreSuccessItem < Struct.new( :snapshot_id, :availability_zone, :availability_zone_id, :state, :state_transition_reason, :owner_id, :owner_alias, :enabling_time, :optimizing_time, :enabled_time, :disabling_time, :disabled_time) SENSITIVE = [] include Aws::Structure end |