Class: Aws::EC2::Types::EnableFastSnapshotRestoresRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_zone_idsArray<String>

One or more Availability Zone IDs. For example, use2-az1.

Either AvailabilityZone or AvailabilityZoneId must be specified in the request, but not both.

Returns:

  • (Array<String>)


40470
40471
40472
40473
40474
40475
40476
40477
# File 'lib/aws-sdk-ec2/types.rb', line 40470

class EnableFastSnapshotRestoresRequest < Struct.new(
  :availability_zones,
  :availability_zone_ids,
  :source_snapshot_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zonesArray<String>

One or more Availability Zones. For example, us-east-2a.

Either AvailabilityZone or AvailabilityZoneId must be specified in the request, but not both.

Returns:

  • (Array<String>)


40470
40471
40472
40473
40474
40475
40476
40477
# File 'lib/aws-sdk-ec2/types.rb', line 40470

class EnableFastSnapshotRestoresRequest < Struct.new(
  :availability_zones,
  :availability_zone_ids,
  :source_snapshot_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


40470
40471
40472
40473
40474
40475
40476
40477
# File 'lib/aws-sdk-ec2/types.rb', line 40470

class EnableFastSnapshotRestoresRequest < Struct.new(
  :availability_zones,
  :availability_zone_ids,
  :source_snapshot_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#source_snapshot_idsArray<String>

The IDs of one or more snapshots. For example, snap-1234567890abcdef0. You can specify a snapshot that was shared with you from another Amazon Web Services account.

Returns:

  • (Array<String>)


40470
40471
40472
40473
40474
40475
40476
40477
# File 'lib/aws-sdk-ec2/types.rb', line 40470

class EnableFastSnapshotRestoresRequest < Struct.new(
  :availability_zones,
  :availability_zone_ids,
  :source_snapshot_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end