Class: Aws::EC2::Types::EnableImageBlockPublicAccessRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::EnableImageBlockPublicAccessRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#image_block_public_access_state ⇒ String
Specify
block-new-sharingto enable block public access for AMIs at the account level in the specified Region.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
40554 40555 40556 40557 40558 40559 |
# File 'lib/aws-sdk-ec2/types.rb', line 40554 class EnableImageBlockPublicAccessRequest < Struct.new( :image_block_public_access_state, :dry_run) SENSITIVE = [] include Aws::Structure end |
#image_block_public_access_state ⇒ String
Specify block-new-sharing to enable block public access for AMIs
at the account level in the specified Region. This will block any
attempt to publicly share your AMIs in the specified Region.
40554 40555 40556 40557 40558 40559 |
# File 'lib/aws-sdk-ec2/types.rb', line 40554 class EnableImageBlockPublicAccessRequest < Struct.new( :image_block_public_access_state, :dry_run) SENSITIVE = [] include Aws::Structure end |