Class: Aws::EC2::Types::EnableImageBlockPublicAccessRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


38998
38999
39000
39001
39002
39003
# File 'lib/aws-sdk-ec2/types.rb', line 38998

class EnableImageBlockPublicAccessRequest < Struct.new(
  :image_block_public_access_state,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#image_block_public_access_stateString

Specify ‘block-new-sharing` to enable block public access for AMIs at the account level in the specified Region. This will block any attempt to publicly share your AMIs in the specified Region.

Returns:

  • (String)


38998
38999
39000
39001
39002
39003
# File 'lib/aws-sdk-ec2/types.rb', line 38998

class EnableImageBlockPublicAccessRequest < Struct.new(
  :image_block_public_access_state,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end