Class: Aws::EC2::Types::EnableImageDeprecationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#deprecate_atTime

The date and time to deprecate the AMI, in UTC, in the following format: YYYY-MM-DDTHH:MM:SSZ. If you specify a value for seconds, Amazon EC2 rounds the seconds to the nearest minute.

You can’t specify a date in the past. The upper limit for DeprecateAt is 10 years from now, except for public AMIs, where the upper limit is 2 years from the creation date.

Returns:

  • (Time)


40583
40584
40585
40586
40587
40588
40589
# File 'lib/aws-sdk-ec2/types.rb', line 40583

class EnableImageDeprecationRequest < Struct.new(
  :image_id,
  :deprecate_at,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


40583
40584
40585
40586
40587
40588
40589
# File 'lib/aws-sdk-ec2/types.rb', line 40583

class EnableImageDeprecationRequest < Struct.new(
  :image_id,
  :deprecate_at,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#image_idString

The ID of the AMI.

Returns:

  • (String)


40583
40584
40585
40586
40587
40588
40589
# File 'lib/aws-sdk-ec2/types.rb', line 40583

class EnableImageDeprecationRequest < Struct.new(
  :image_id,
  :deprecate_at,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end