Class: Aws::EC2::Types::EnableImageDeprecationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::EnableImageDeprecationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#deprecate_at ⇒ Time
The date and time to deprecate the AMI, in UTC, in the following format: YYYY-MM-*DD*T*HH*:MM:*SS*Z.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#image_id ⇒ String
The ID of the AMI.
Instance Attribute Details
#deprecate_at ⇒ Time
The date and time to deprecate the AMI, in UTC, in the following format: YYYY-MM-*DD*T*HH*:MM:*SS*Z. If you specify a value for seconds, Amazon EC2 rounds the seconds to the nearest minute.
You can’t specify a date in the past. The upper limit for ‘DeprecateAt` is 10 years from now, except for public AMIs, where the upper limit is 2 years from the creation date.
39971 39972 39973 39974 39975 39976 39977 |
# File 'lib/aws-sdk-ec2/types.rb', line 39971 class EnableImageDeprecationRequest < Struct.new( :image_id, :deprecate_at, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
39971 39972 39973 39974 39975 39976 39977 |
# File 'lib/aws-sdk-ec2/types.rb', line 39971 class EnableImageDeprecationRequest < Struct.new( :image_id, :deprecate_at, :dry_run) SENSITIVE = [] include Aws::Structure end |
#image_id ⇒ String
The ID of the AMI.
39971 39972 39973 39974 39975 39976 39977 |
# File 'lib/aws-sdk-ec2/types.rb', line 39971 class EnableImageDeprecationRequest < Struct.new( :image_id, :deprecate_at, :dry_run) SENSITIVE = [] include Aws::Structure end |