Class: Aws::EC2::Types::EnableImageDeregistrationProtectionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::EnableImageDeregistrationProtectionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#image_id ⇒ String
The ID of the AMI.
-
#with_cooldown ⇒ Boolean
If
true, enforces deregistration protection for 24 hours after deregistration protection is disabled.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
42186 42187 42188 42189 42190 42191 42192 |
# File 'lib/aws-sdk-ec2/types.rb', line 42186 class EnableImageDeregistrationProtectionRequest < Struct.new( :image_id, :with_cooldown, :dry_run) SENSITIVE = [] include Aws::Structure end |
#image_id ⇒ String
The ID of the AMI.
42186 42187 42188 42189 42190 42191 42192 |
# File 'lib/aws-sdk-ec2/types.rb', line 42186 class EnableImageDeregistrationProtectionRequest < Struct.new( :image_id, :with_cooldown, :dry_run) SENSITIVE = [] include Aws::Structure end |
#with_cooldown ⇒ Boolean
If true, enforces deregistration protection for 24 hours after
deregistration protection is disabled.
42186 42187 42188 42189 42190 42191 42192 |
# File 'lib/aws-sdk-ec2/types.rb', line 42186 class EnableImageDeregistrationProtectionRequest < Struct.new( :image_id, :with_cooldown, :dry_run) SENSITIVE = [] include Aws::Structure end |