Class: Aws::EC2::Types::EnableImageDeregistrationProtectionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


39694
39695
39696
39697
39698
39699
39700
# File 'lib/aws-sdk-ec2/types.rb', line 39694

class EnableImageDeregistrationProtectionRequest < Struct.new(
  :image_id,
  :with_cooldown,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#image_idString

The ID of the AMI.

Returns:

  • (String)


39694
39695
39696
39697
39698
39699
39700
# File 'lib/aws-sdk-ec2/types.rb', line 39694

class EnableImageDeregistrationProtectionRequest < Struct.new(
  :image_id,
  :with_cooldown,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#with_cooldownBoolean

If ‘true`, enforces deregistration protection for 24 hours after deregistration protection is disabled.

Returns:

  • (Boolean)


39694
39695
39696
39697
39698
39699
39700
# File 'lib/aws-sdk-ec2/types.rb', line 39694

class EnableImageDeregistrationProtectionRequest < Struct.new(
  :image_id,
  :with_cooldown,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end