Class: Aws::EC2::Types::EnableImageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::EnableImageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#image_id ⇒ String
The ID of the AMI.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
42229 42230 42231 42232 42233 42234 |
# File 'lib/aws-sdk-ec2/types.rb', line 42229 class EnableImageRequest < Struct.new( :image_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#image_id ⇒ String
The ID of the AMI.
42229 42230 42231 42232 42233 42234 |
# File 'lib/aws-sdk-ec2/types.rb', line 42229 class EnableImageRequest < Struct.new( :image_id, :dry_run) SENSITIVE = [] include Aws::Structure end |