Class: Aws::EC2::Types::EnableImageRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


40695
40696
40697
40698
40699
40700
# File 'lib/aws-sdk-ec2/types.rb', line 40695

class EnableImageRequest < Struct.new(
  :image_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#image_idString

The ID of the AMI.

Returns:

  • (String)


40695
40696
40697
40698
40699
40700
# File 'lib/aws-sdk-ec2/types.rb', line 40695

class EnableImageRequest < Struct.new(
  :image_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end