Class: Aws::EC2::Types::EnableInstanceSqlHaStandbyDetectionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::EnableInstanceSqlHaStandbyDetectionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#instance_ids ⇒ Array<String>
The IDs of the instances to enable for SQL Server High Availability standby detection monitoring.
-
#sql_server_credentials ⇒ String
The ARN of the Secrets Manager secret containing the SQL Server access credentials.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
39084 39085 39086 39087 39088 39089 39090 |
# File 'lib/aws-sdk-ec2/types.rb', line 39084 class EnableInstanceSqlHaStandbyDetectionsRequest < Struct.new( :instance_ids, :sql_server_credentials, :dry_run) SENSITIVE = [] include Aws::Structure end |
#instance_ids ⇒ Array<String>
The IDs of the instances to enable for SQL Server High Availability standby detection monitoring.
39084 39085 39086 39087 39088 39089 39090 |
# File 'lib/aws-sdk-ec2/types.rb', line 39084 class EnableInstanceSqlHaStandbyDetectionsRequest < Struct.new( :instance_ids, :sql_server_credentials, :dry_run) SENSITIVE = [] include Aws::Structure end |
#sql_server_credentials ⇒ String
The ARN of the Secrets Manager secret containing the SQL Server access credentials. The specified secret must contain valid SQL Server credentials for the specified instances. If not specified, deafult local user credentials will be used by the Amazon Web Services Systems Manager agent. To enable instances with different credentials, you must make separate requests.
39084 39085 39086 39087 39088 39089 39090 |
# File 'lib/aws-sdk-ec2/types.rb', line 39084 class EnableInstanceSqlHaStandbyDetectionsRequest < Struct.new( :instance_ids, :sql_server_credentials, :dry_run) SENSITIVE = [] include Aws::Structure end |