Class: Aws::EC2::Types::EnableIpamInternetRegistryAssociationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::EnableIpamInternetRegistryAssociationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#child_handle ⇒ String
The child handle for the BPKI certificate hierarchy from the Parent Response XML.
-
#client_token ⇒ String
A unique, case-sensitive identifier to ensure that the operation completes no more than one time.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#ipam_internet_registry_association_id ⇒ String
The ID of the IPAM internet registry association to enable.
-
#parent_bpki_ta ⇒ String
The parent BPKI Trust Anchor certificate in PEM format from the Parent Response XML.
-
#parent_handle ⇒ String
The parent handle for the BPKI certificate hierarchy from the Parent Response XML.
-
#rpki_version ⇒ String
The RPKI version to use from the Parent Response XML.
-
#service_uri ⇒ String
The RPKI service URI for the publication point from the Parent Response XML.
Instance Attribute Details
#child_handle ⇒ String
The child handle for the BPKI certificate hierarchy from the Parent Response XML.
42340 42341 42342 42343 42344 42345 42346 42347 42348 42349 42350 42351 |
# File 'lib/aws-sdk-ec2/types.rb', line 42340 class EnableIpamInternetRegistryAssociationRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id, :rpki_version, :service_uri, :child_handle, :parent_handle, :parent_bpki_ta, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, the operation ignores the request, but does not return an error.
A suitable default value is auto-generated. You should normally not need to pass this option.
42340 42341 42342 42343 42344 42345 42346 42347 42348 42349 42350 42351 |
# File 'lib/aws-sdk-ec2/types.rb', line 42340 class EnableIpamInternetRegistryAssociationRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id, :rpki_version, :service_uri, :child_handle, :parent_handle, :parent_bpki_ta, :client_token) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
42340 42341 42342 42343 42344 42345 42346 42347 42348 42349 42350 42351 |
# File 'lib/aws-sdk-ec2/types.rb', line 42340 class EnableIpamInternetRegistryAssociationRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id, :rpki_version, :service_uri, :child_handle, :parent_handle, :parent_bpki_ta, :client_token) SENSITIVE = [] include Aws::Structure end |
#ipam_internet_registry_association_id ⇒ String
The ID of the IPAM internet registry association to enable.
42340 42341 42342 42343 42344 42345 42346 42347 42348 42349 42350 42351 |
# File 'lib/aws-sdk-ec2/types.rb', line 42340 class EnableIpamInternetRegistryAssociationRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id, :rpki_version, :service_uri, :child_handle, :parent_handle, :parent_bpki_ta, :client_token) SENSITIVE = [] include Aws::Structure end |
#parent_bpki_ta ⇒ String
The parent BPKI Trust Anchor certificate in PEM format from the Parent Response XML.
42340 42341 42342 42343 42344 42345 42346 42347 42348 42349 42350 42351 |
# File 'lib/aws-sdk-ec2/types.rb', line 42340 class EnableIpamInternetRegistryAssociationRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id, :rpki_version, :service_uri, :child_handle, :parent_handle, :parent_bpki_ta, :client_token) SENSITIVE = [] include Aws::Structure end |
#parent_handle ⇒ String
The parent handle for the BPKI certificate hierarchy from the Parent Response XML.
42340 42341 42342 42343 42344 42345 42346 42347 42348 42349 42350 42351 |
# File 'lib/aws-sdk-ec2/types.rb', line 42340 class EnableIpamInternetRegistryAssociationRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id, :rpki_version, :service_uri, :child_handle, :parent_handle, :parent_bpki_ta, :client_token) SENSITIVE = [] include Aws::Structure end |
#rpki_version ⇒ String
The RPKI version to use from the Parent Response XML.
42340 42341 42342 42343 42344 42345 42346 42347 42348 42349 42350 42351 |
# File 'lib/aws-sdk-ec2/types.rb', line 42340 class EnableIpamInternetRegistryAssociationRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id, :rpki_version, :service_uri, :child_handle, :parent_handle, :parent_bpki_ta, :client_token) SENSITIVE = [] include Aws::Structure end |
#service_uri ⇒ String
The RPKI service URI for the publication point from the Parent Response XML.
42340 42341 42342 42343 42344 42345 42346 42347 42348 42349 42350 42351 |
# File 'lib/aws-sdk-ec2/types.rb', line 42340 class EnableIpamInternetRegistryAssociationRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id, :rpki_version, :service_uri, :child_handle, :parent_handle, :parent_bpki_ta, :client_token) SENSITIVE = [] include Aws::Structure end |