Class: Aws::EC2::Types::EnableIpamInternetRegistryAssociationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#child_handleString

The child handle for the BPKI certificate hierarchy from the Parent Response XML.

Returns:

  • (String)


42331
42332
42333
42334
42335
42336
42337
42338
42339
42340
42341
42342
# File 'lib/aws-sdk-ec2/types.rb', line 42331

class EnableIpamInternetRegistryAssociationRequest < Struct.new(
  :dry_run,
  :ipam_internet_registry_association_id,
  :rpki_version,
  :service_uri,
  :child_handle,
  :parent_handle,
  :parent_bpki_ta,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, the operation ignores the request, but does not return an error.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


42331
42332
42333
42334
42335
42336
42337
42338
42339
42340
42341
42342
# File 'lib/aws-sdk-ec2/types.rb', line 42331

class EnableIpamInternetRegistryAssociationRequest < Struct.new(
  :dry_run,
  :ipam_internet_registry_association_id,
  :rpki_version,
  :service_uri,
  :child_handle,
  :parent_handle,
  :parent_bpki_ta,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


42331
42332
42333
42334
42335
42336
42337
42338
42339
42340
42341
42342
# File 'lib/aws-sdk-ec2/types.rb', line 42331

class EnableIpamInternetRegistryAssociationRequest < Struct.new(
  :dry_run,
  :ipam_internet_registry_association_id,
  :rpki_version,
  :service_uri,
  :child_handle,
  :parent_handle,
  :parent_bpki_ta,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_internet_registry_association_idString

The ID of the IPAM internet registry association to enable.

Returns:

  • (String)


42331
42332
42333
42334
42335
42336
42337
42338
42339
42340
42341
42342
# File 'lib/aws-sdk-ec2/types.rb', line 42331

class EnableIpamInternetRegistryAssociationRequest < Struct.new(
  :dry_run,
  :ipam_internet_registry_association_id,
  :rpki_version,
  :service_uri,
  :child_handle,
  :parent_handle,
  :parent_bpki_ta,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#parent_bpki_taString

The parent BPKI Trust Anchor certificate in PEM format from the Parent Response XML.

Returns:

  • (String)


42331
42332
42333
42334
42335
42336
42337
42338
42339
42340
42341
42342
# File 'lib/aws-sdk-ec2/types.rb', line 42331

class EnableIpamInternetRegistryAssociationRequest < Struct.new(
  :dry_run,
  :ipam_internet_registry_association_id,
  :rpki_version,
  :service_uri,
  :child_handle,
  :parent_handle,
  :parent_bpki_ta,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#parent_handleString

The parent handle for the BPKI certificate hierarchy from the Parent Response XML.

Returns:

  • (String)


42331
42332
42333
42334
42335
42336
42337
42338
42339
42340
42341
42342
# File 'lib/aws-sdk-ec2/types.rb', line 42331

class EnableIpamInternetRegistryAssociationRequest < Struct.new(
  :dry_run,
  :ipam_internet_registry_association_id,
  :rpki_version,
  :service_uri,
  :child_handle,
  :parent_handle,
  :parent_bpki_ta,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#rpki_versionString

The RPKI version to use from the Parent Response XML.

Returns:

  • (String)


42331
42332
42333
42334
42335
42336
42337
42338
42339
42340
42341
42342
# File 'lib/aws-sdk-ec2/types.rb', line 42331

class EnableIpamInternetRegistryAssociationRequest < Struct.new(
  :dry_run,
  :ipam_internet_registry_association_id,
  :rpki_version,
  :service_uri,
  :child_handle,
  :parent_handle,
  :parent_bpki_ta,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#service_uriString

The RPKI service URI for the publication point from the Parent Response XML.

Returns:

  • (String)


42331
42332
42333
42334
42335
42336
42337
42338
42339
42340
42341
42342
# File 'lib/aws-sdk-ec2/types.rb', line 42331

class EnableIpamInternetRegistryAssociationRequest < Struct.new(
  :dry_run,
  :ipam_internet_registry_association_id,
  :rpki_version,
  :service_uri,
  :child_handle,
  :parent_handle,
  :parent_bpki_ta,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end