Class: Aws::EC2::Types::EnableIpamOrganizationAdminAccountRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::EnableIpamOrganizationAdminAccountRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#delegated_admin_account_id ⇒ String
The Organizations member account ID that you want to enable as the IPAM account.
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
Instance Attribute Details
#delegated_admin_account_id ⇒ String
The Organizations member account ID that you want to enable as the IPAM account.
40561 40562 40563 40564 40565 40566 |
# File 'lib/aws-sdk-ec2/types.rb', line 40561 class EnableIpamOrganizationAdminAccountRequest < Struct.new( :dry_run, :delegated_admin_account_id) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action
without actually making the request and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
40561 40562 40563 40564 40565 40566 |
# File 'lib/aws-sdk-ec2/types.rb', line 40561 class EnableIpamOrganizationAdminAccountRequest < Struct.new( :dry_run, :delegated_admin_account_id) SENSITIVE = [] include Aws::Structure end |