Class: Aws::EC2::Types::EnableIpamOrganizationAdminAccountRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::EnableIpamOrganizationAdminAccountRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#delegated_admin_account_id ⇒ String
The Organizations member account ID that you want to enable as the IPAM account.
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
Instance Attribute Details
#delegated_admin_account_id ⇒ String
The Organizations member account ID that you want to enable as the IPAM account.
40122 40123 40124 40125 40126 40127 |
# File 'lib/aws-sdk-ec2/types.rb', line 40122 class EnableIpamOrganizationAdminAccountRequest < Struct.new( :dry_run, :delegated_admin_account_id) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
40122 40123 40124 40125 40126 40127 |
# File 'lib/aws-sdk-ec2/types.rb', line 40122 class EnableIpamOrganizationAdminAccountRequest < Struct.new( :dry_run, :delegated_admin_account_id) SENSITIVE = [] include Aws::Structure end |