Class: Aws::EC2::Types::EnableIpamOrganizationAdminAccountRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#delegated_admin_account_idString

The Organizations member account ID that you want to enable as the IPAM account.

Returns:

  • (String)


40059
40060
40061
40062
40063
40064
# File 'lib/aws-sdk-ec2/types.rb', line 40059

class EnableIpamOrganizationAdminAccountRequest < Struct.new(
  :dry_run,
  :delegated_admin_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


40059
40060
40061
40062
40063
40064
# File 'lib/aws-sdk-ec2/types.rb', line 40059

class EnableIpamOrganizationAdminAccountRequest < Struct.new(
  :dry_run,
  :delegated_admin_account_id)
  SENSITIVE = []
  include Aws::Structure
end