Class: Aws::EC2::Types::EnableIpamPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::EnableIpamPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#ipam_policy_id ⇒ String
The ID of the IPAM policy to enable.
-
#organization_target_id ⇒ String
The ID of the Amazon Web Services Organizations target for which to enable the IPAM policy.
Instance Attribute Details
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
39236 39237 39238 39239 39240 39241 39242 |
# File 'lib/aws-sdk-ec2/types.rb', line 39236 class EnableIpamPolicyRequest < Struct.new( :dry_run, :ipam_policy_id, :organization_target_id) SENSITIVE = [] include Aws::Structure end |
#ipam_policy_id ⇒ String
The ID of the IPAM policy to enable.
39236 39237 39238 39239 39240 39241 39242 |
# File 'lib/aws-sdk-ec2/types.rb', line 39236 class EnableIpamPolicyRequest < Struct.new( :dry_run, :ipam_policy_id, :organization_target_id) SENSITIVE = [] include Aws::Structure end |
#organization_target_id ⇒ String
The ID of the Amazon Web Services Organizations target for which to enable the IPAM policy. This parameter is required only when IPAM is integrated with Amazon Web Services Organizations. When IPAM is not integrated with Amazon Web Services Organizations, omit this parameter and the policy will apply to the current account.
A target can be an individual Amazon Web Services account or an entity within an Amazon Web Services Organization to which an IPAM policy can be applied.
39236 39237 39238 39239 39240 39241 39242 |
# File 'lib/aws-sdk-ec2/types.rb', line 39236 class EnableIpamPolicyRequest < Struct.new( :dry_run, :ipam_policy_id, :organization_target_id) SENSITIVE = [] include Aws::Structure end |