Class: Aws::EC2::Types::EnableReachabilityAnalyzerOrganizationSharingRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::EnableReachabilityAnalyzerOrganizationSharingRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
40807 40808 40809 40810 40811 |
# File 'lib/aws-sdk-ec2/types.rb', line 40807 class EnableReachabilityAnalyzerOrganizationSharingRequest < Struct.new( :dry_run) SENSITIVE = [] include Aws::Structure end |