Class: Aws::EC2::Types::EnableRouteServerPropagationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::EnableRouteServerPropagationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#route_server_id ⇒ String
The ID of the route server for which to enable propagation.
-
#route_table_id ⇒ String
The ID of the route table to which route server will propagate routes.
Instance Attribute Details
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
40325 40326 40327 40328 40329 40330 40331 |
# File 'lib/aws-sdk-ec2/types.rb', line 40325 class EnableRouteServerPropagationRequest < Struct.new( :route_server_id, :route_table_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#route_server_id ⇒ String
The ID of the route server for which to enable propagation.
40325 40326 40327 40328 40329 40330 40331 |
# File 'lib/aws-sdk-ec2/types.rb', line 40325 class EnableRouteServerPropagationRequest < Struct.new( :route_server_id, :route_table_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#route_table_id ⇒ String
The ID of the route table to which route server will propagate routes.
40325 40326 40327 40328 40329 40330 40331 |
# File 'lib/aws-sdk-ec2/types.rb', line 40325 class EnableRouteServerPropagationRequest < Struct.new( :route_server_id, :route_table_id, :dry_run) SENSITIVE = [] include Aws::Structure end |