Class: Aws::EC2::Types::EnableRouteServerPropagationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


40231
40232
40233
40234
40235
40236
40237
# File 'lib/aws-sdk-ec2/types.rb', line 40231

class EnableRouteServerPropagationRequest < Struct.new(
  :route_server_id,
  :route_table_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#route_server_idString

The ID of the route server for which to enable propagation.

Returns:

  • (String)


40231
40232
40233
40234
40235
40236
40237
# File 'lib/aws-sdk-ec2/types.rb', line 40231

class EnableRouteServerPropagationRequest < Struct.new(
  :route_server_id,
  :route_table_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#route_table_idString

The ID of the route table to which route server will propagate routes.

Returns:

  • (String)


40231
40232
40233
40234
40235
40236
40237
# File 'lib/aws-sdk-ec2/types.rb', line 40231

class EnableRouteServerPropagationRequest < Struct.new(
  :route_server_id,
  :route_table_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end