Class: Aws::EC2::Types::EnableSerialConsoleAccessRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


40260
40261
40262
40263
40264
# File 'lib/aws-sdk-ec2/types.rb', line 40260

class EnableSerialConsoleAccessRequest < Struct.new(
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end