Class: Aws::EC2::Types::EnableSnapshotBlockPublicAccessRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::EnableSnapshotBlockPublicAccessRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#state ⇒ String
The mode in which to enable block public access for snapshots for the Region.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
39992 39993 39994 39995 39996 39997 |
# File 'lib/aws-sdk-ec2/types.rb', line 39992 class EnableSnapshotBlockPublicAccessRequest < Struct.new( :state, :dry_run) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The mode in which to enable block public access for snapshots for the Region. Specify one of the following values:
-
‘block-all-sharing` - Prevents all public sharing of snapshots in the Region. Users in the account will no longer be able to request new public sharing. Additionally, snapshots that are already publicly shared are treated as private and they are no longer publicly available.
-
‘block-new-sharing` - Prevents only new public sharing of snapshots in the Region. Users in the account will no longer be able to request new public sharing. However, snapshots that are already publicly shared, remain publicly available.
‘unblocked` is not a valid value for EnableSnapshotBlockPublicAccess.
39992 39993 39994 39995 39996 39997 |
# File 'lib/aws-sdk-ec2/types.rb', line 39992 class EnableSnapshotBlockPublicAccessRequest < Struct.new( :state, :dry_run) SENSITIVE = [] include Aws::Structure end |