Class: Aws::EC2::Types::EnableTransitGatewayRouteTablePropagationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


40783
40784
40785
40786
40787
40788
40789
40790
# File 'lib/aws-sdk-ec2/types.rb', line 40783

class EnableTransitGatewayRouteTablePropagationRequest < Struct.new(
  :transit_gateway_route_table_id,
  :transit_gateway_attachment_id,
  :dry_run,
  :transit_gateway_route_table_announcement_id)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_attachment_idString

The ID of the attachment.

Returns:

  • (String)


40783
40784
40785
40786
40787
40788
40789
40790
# File 'lib/aws-sdk-ec2/types.rb', line 40783

class EnableTransitGatewayRouteTablePropagationRequest < Struct.new(
  :transit_gateway_route_table_id,
  :transit_gateway_attachment_id,
  :dry_run,
  :transit_gateway_route_table_announcement_id)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_route_table_announcement_idString

The ID of the transit gateway route table announcement.

Returns:

  • (String)


40783
40784
40785
40786
40787
40788
40789
40790
# File 'lib/aws-sdk-ec2/types.rb', line 40783

class EnableTransitGatewayRouteTablePropagationRequest < Struct.new(
  :transit_gateway_route_table_id,
  :transit_gateway_attachment_id,
  :dry_run,
  :transit_gateway_route_table_announcement_id)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_route_table_idString

The ID of the propagation route table.

Returns:

  • (String)


40783
40784
40785
40786
40787
40788
40789
40790
# File 'lib/aws-sdk-ec2/types.rb', line 40783

class EnableTransitGatewayRouteTablePropagationRequest < Struct.new(
  :transit_gateway_route_table_id,
  :transit_gateway_attachment_id,
  :dry_run,
  :transit_gateway_route_table_announcement_id)
  SENSITIVE = []
  include Aws::Structure
end