Class: Aws::EC2::Types::EnableVgwRoutePropagationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for EnableVgwRoutePropagation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


41019
41020
41021
41022
41023
41024
41025
# File 'lib/aws-sdk-ec2/types.rb', line 41019

class EnableVgwRoutePropagationRequest < Struct.new(
  :gateway_id,
  :route_table_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#gateway_idString

The ID of the virtual private gateway that is attached to a VPC. The virtual private gateway must be attached to the same VPC that the routing tables are associated with.

Returns:

  • (String)


41019
41020
41021
41022
41023
41024
41025
# File 'lib/aws-sdk-ec2/types.rb', line 41019

class EnableVgwRoutePropagationRequest < Struct.new(
  :gateway_id,
  :route_table_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#route_table_idString

The ID of the route table. The routing table must be associated with the same VPC that the virtual private gateway is attached to.

Returns:

  • (String)


41019
41020
41021
41022
41023
41024
41025
# File 'lib/aws-sdk-ec2/types.rb', line 41019

class EnableVgwRoutePropagationRequest < Struct.new(
  :gateway_id,
  :route_table_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end