Class: Aws::EC2::Types::EnableVgwRoutePropagationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::EnableVgwRoutePropagationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for EnableVgwRoutePropagation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#gateway_id ⇒ String
The ID of the virtual private gateway that is attached to a VPC.
-
#route_table_id ⇒ String
The ID of the route table.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
39463 39464 39465 39466 39467 39468 39469 |
# File 'lib/aws-sdk-ec2/types.rb', line 39463 class EnableVgwRoutePropagationRequest < Struct.new( :gateway_id, :route_table_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#gateway_id ⇒ String
The ID of the virtual private gateway that is attached to a VPC. The virtual private gateway must be attached to the same VPC that the routing tables are associated with.
39463 39464 39465 39466 39467 39468 39469 |
# File 'lib/aws-sdk-ec2/types.rb', line 39463 class EnableVgwRoutePropagationRequest < Struct.new( :gateway_id, :route_table_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#route_table_id ⇒ String
The ID of the route table. The routing table must be associated with the same VPC that the virtual private gateway is attached to.
39463 39464 39465 39466 39467 39468 39469 |
# File 'lib/aws-sdk-ec2/types.rb', line 39463 class EnableVgwRoutePropagationRequest < Struct.new( :gateway_id, :route_table_id, :dry_run) SENSITIVE = [] include Aws::Structure end |