Class: Aws::EC2::Types::EnableVolumeIORequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


42662
42663
42664
42665
42666
42667
# File 'lib/aws-sdk-ec2/types.rb', line 42662

class EnableVolumeIORequest < Struct.new(
  :dry_run,
  :volume_id)
  SENSITIVE = []
  include Aws::Structure
end

#volume_idString

The ID of the volume.

Returns:

  • (String)


42662
42663
42664
42665
42666
42667
# File 'lib/aws-sdk-ec2/types.rb', line 42662

class EnableVolumeIORequest < Struct.new(
  :dry_run,
  :volume_id)
  SENSITIVE = []
  include Aws::Structure
end