Class: Aws::EC2::Types::EnableVolumeIORequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::EnableVolumeIORequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#volume_id ⇒ String
The ID of the volume.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
42228 42229 42230 42231 42232 42233 |
# File 'lib/aws-sdk-ec2/types.rb', line 42228 class EnableVolumeIORequest < Struct.new( :dry_run, :volume_id) SENSITIVE = [] include Aws::Structure end |
#volume_id ⇒ String
The ID of the volume.
42228 42229 42230 42231 42232 42233 |
# File 'lib/aws-sdk-ec2/types.rb', line 42228 class EnableVolumeIORequest < Struct.new( :dry_run, :volume_id) SENSITIVE = [] include Aws::Structure end |