Class: Aws::EC2::Types::EnableVpcClassicLinkRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


41085
41086
41087
41088
41089
41090
# File 'lib/aws-sdk-ec2/types.rb', line 41085

class EnableVpcClassicLinkRequest < Struct.new(
  :dry_run,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC.

Returns:

  • (String)


41085
41086
41087
41088
41089
41090
# File 'lib/aws-sdk-ec2/types.rb', line 41085

class EnableVpcClassicLinkRequest < Struct.new(
  :dry_run,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end