Class: Aws::EC2::Types::EnableVpcClassicLinkRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::EnableVpcClassicLinkRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#vpc_id ⇒ String
The ID of the VPC.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
40459 40460 40461 40462 40463 40464 |
# File 'lib/aws-sdk-ec2/types.rb', line 40459 class EnableVpcClassicLinkRequest < Struct.new( :dry_run, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC.
40459 40460 40461 40462 40463 40464 |
# File 'lib/aws-sdk-ec2/types.rb', line 40459 class EnableVpcClassicLinkRequest < Struct.new( :dry_run, :vpc_id) SENSITIVE = [] include Aws::Structure end |