Class: Aws::EC2::Types::EnableVpcClassicLinkRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::EnableVpcClassicLinkRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#vpc_id ⇒ String
The ID of the VPC.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
40396 40397 40398 40399 40400 40401 |
# File 'lib/aws-sdk-ec2/types.rb', line 40396 class EnableVpcClassicLinkRequest < Struct.new( :dry_run, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC.
40396 40397 40398 40399 40400 40401 |
# File 'lib/aws-sdk-ec2/types.rb', line 40396 class EnableVpcClassicLinkRequest < Struct.new( :dry_run, :vpc_id) SENSITIVE = [] include Aws::Structure end |