Class: Aws::EC2::Types::EnableVpcClassicLinkRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


39529
39530
39531
39532
39533
39534
# File 'lib/aws-sdk-ec2/types.rb', line 39529

class EnableVpcClassicLinkRequest < Struct.new(
  :dry_run,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC.

Returns:

  • (String)


39529
39530
39531
39532
39533
39534
# File 'lib/aws-sdk-ec2/types.rb', line 39529

class EnableVpcClassicLinkRequest < Struct.new(
  :dry_run,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end