Class: Aws::EC2::Types::EnclaveOptionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Indicates whether the instance is enabled for Amazon Web Services Nitro Enclaves. For more information, see What is Amazon Web Services Nitro Enclaves? in the Amazon Web Services Nitro Enclaves User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enabledBoolean

To enable the instance for Amazon Web Services Nitro Enclaves, set this parameter to true.

Returns:

  • (Boolean)


41255
41256
41257
41258
41259
# File 'lib/aws-sdk-ec2/types.rb', line 41255

class EnclaveOptionsRequest < Struct.new(
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end