Class: Aws::EC2::Types::ExportClientVpnClientConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_vpn_endpoint_idString

The ID of the Client VPN endpoint.

Returns:

  • (String)


42809
42810
42811
42812
42813
42814
# File 'lib/aws-sdk-ec2/types.rb', line 42809

class ExportClientVpnClientConfigurationRequest < Struct.new(
  :client_vpn_endpoint_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


42809
42810
42811
42812
42813
42814
# File 'lib/aws-sdk-ec2/types.rb', line 42809

class ExportClientVpnClientConfigurationRequest < Struct.new(
  :client_vpn_endpoint_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end