Class: Aws::EC2::Types::ExportClientVpnClientConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ExportClientVpnClientConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_vpn_endpoint_id ⇒ String
The ID of the Client VPN endpoint.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#client_vpn_endpoint_id ⇒ String
The ID of the Client VPN endpoint.
41646 41647 41648 41649 41650 41651 |
# File 'lib/aws-sdk-ec2/types.rb', line 41646 class ExportClientVpnClientConfigurationRequest < Struct.new( :client_vpn_endpoint_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
41646 41647 41648 41649 41650 41651 |
# File 'lib/aws-sdk-ec2/types.rb', line 41646 class ExportClientVpnClientConfigurationRequest < Struct.new( :client_vpn_endpoint_id, :dry_run) SENSITIVE = [] include Aws::Structure end |