Class: Aws::EC2::Types::ExportImageRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Token to enable idempotency for export image requests.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


40995
40996
40997
40998
40999
41000
41001
41002
41003
41004
41005
41006
# File 'lib/aws-sdk-ec2/types.rb', line 40995

class ExportImageRequest < Struct.new(
  :client_token,
  :description,
  :disk_image_format,
  :dry_run,
  :image_id,
  :s3_export_location,
  :role_name,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the image being exported. The maximum length is 255 characters.

Returns:

  • (String)


40995
40996
40997
40998
40999
41000
41001
41002
41003
41004
41005
41006
# File 'lib/aws-sdk-ec2/types.rb', line 40995

class ExportImageRequest < Struct.new(
  :client_token,
  :description,
  :disk_image_format,
  :dry_run,
  :image_id,
  :s3_export_location,
  :role_name,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#disk_image_formatString

The disk image format.

Returns:

  • (String)


40995
40996
40997
40998
40999
41000
41001
41002
41003
41004
41005
41006
# File 'lib/aws-sdk-ec2/types.rb', line 40995

class ExportImageRequest < Struct.new(
  :client_token,
  :description,
  :disk_image_format,
  :dry_run,
  :image_id,
  :s3_export_location,
  :role_name,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


40995
40996
40997
40998
40999
41000
41001
41002
41003
41004
41005
41006
# File 'lib/aws-sdk-ec2/types.rb', line 40995

class ExportImageRequest < Struct.new(
  :client_token,
  :description,
  :disk_image_format,
  :dry_run,
  :image_id,
  :s3_export_location,
  :role_name,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#image_idString

The ID of the image.

Returns:

  • (String)


40995
40996
40997
40998
40999
41000
41001
41002
41003
41004
41005
41006
# File 'lib/aws-sdk-ec2/types.rb', line 40995

class ExportImageRequest < Struct.new(
  :client_token,
  :description,
  :disk_image_format,
  :dry_run,
  :image_id,
  :s3_export_location,
  :role_name,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#role_nameString

The name of the role that grants VM Import/Export permission to export images to your Amazon S3 bucket. If this parameter is not specified, the default role is named ‘vmimport’.

Returns:

  • (String)


40995
40996
40997
40998
40999
41000
41001
41002
41003
41004
41005
41006
# File 'lib/aws-sdk-ec2/types.rb', line 40995

class ExportImageRequest < Struct.new(
  :client_token,
  :description,
  :disk_image_format,
  :dry_run,
  :image_id,
  :s3_export_location,
  :role_name,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#s3_export_locationTypes::ExportTaskS3LocationRequest

The Amazon S3 bucket for the destination image. The destination bucket must exist.



40995
40996
40997
40998
40999
41000
41001
41002
41003
41004
41005
41006
# File 'lib/aws-sdk-ec2/types.rb', line 40995

class ExportImageRequest < Struct.new(
  :client_token,
  :description,
  :disk_image_format,
  :dry_run,
  :image_id,
  :s3_export_location,
  :role_name,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the export image task during creation.

Returns:



40995
40996
40997
40998
40999
41000
41001
41002
41003
41004
41005
41006
# File 'lib/aws-sdk-ec2/types.rb', line 40995

class ExportImageRequest < Struct.new(
  :client_token,
  :description,
  :disk_image_format,
  :dry_run,
  :image_id,
  :s3_export_location,
  :role_name,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end