Class: Aws::EC2::Types::ExportImageResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ExportImageResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the image being exported.
-
#disk_image_format ⇒ String
The disk image format for the exported image.
-
#export_image_task_id ⇒ String
The ID of the export image task.
-
#image_id ⇒ String
The ID of the image.
-
#progress ⇒ String
The percent complete of the export image task.
-
#role_name ⇒ String
The name of the role that grants VM Import/Export permission to export images to your Amazon S3 bucket.
-
#s3_export_location ⇒ Types::ExportTaskS3Location
Information about the destination Amazon S3 bucket.
-
#status ⇒ String
The status of the export image task.
-
#status_message ⇒ String
The status message for the export image task.
-
#tags ⇒ Array<Types::Tag>
Any tags assigned to the export image task.
Instance Attribute Details
#description ⇒ String
A description of the image being exported.
43363 43364 43365 43366 43367 43368 43369 43370 43371 43372 43373 43374 43375 43376 |
# File 'lib/aws-sdk-ec2/types.rb', line 43363 class ExportImageResult < Struct.new( :description, :disk_image_format, :export_image_task_id, :image_id, :role_name, :progress, :s3_export_location, :status, :status_message, :tags) SENSITIVE = [] include Aws::Structure end |
#disk_image_format ⇒ String
The disk image format for the exported image.
43363 43364 43365 43366 43367 43368 43369 43370 43371 43372 43373 43374 43375 43376 |
# File 'lib/aws-sdk-ec2/types.rb', line 43363 class ExportImageResult < Struct.new( :description, :disk_image_format, :export_image_task_id, :image_id, :role_name, :progress, :s3_export_location, :status, :status_message, :tags) SENSITIVE = [] include Aws::Structure end |
#export_image_task_id ⇒ String
The ID of the export image task.
43363 43364 43365 43366 43367 43368 43369 43370 43371 43372 43373 43374 43375 43376 |
# File 'lib/aws-sdk-ec2/types.rb', line 43363 class ExportImageResult < Struct.new( :description, :disk_image_format, :export_image_task_id, :image_id, :role_name, :progress, :s3_export_location, :status, :status_message, :tags) SENSITIVE = [] include Aws::Structure end |
#image_id ⇒ String
The ID of the image.
43363 43364 43365 43366 43367 43368 43369 43370 43371 43372 43373 43374 43375 43376 |
# File 'lib/aws-sdk-ec2/types.rb', line 43363 class ExportImageResult < Struct.new( :description, :disk_image_format, :export_image_task_id, :image_id, :role_name, :progress, :s3_export_location, :status, :status_message, :tags) SENSITIVE = [] include Aws::Structure end |
#progress ⇒ String
The percent complete of the export image task.
43363 43364 43365 43366 43367 43368 43369 43370 43371 43372 43373 43374 43375 43376 |
# File 'lib/aws-sdk-ec2/types.rb', line 43363 class ExportImageResult < Struct.new( :description, :disk_image_format, :export_image_task_id, :image_id, :role_name, :progress, :s3_export_location, :status, :status_message, :tags) SENSITIVE = [] include Aws::Structure end |
#role_name ⇒ String
The name of the role that grants VM Import/Export permission to export images to your Amazon S3 bucket.
43363 43364 43365 43366 43367 43368 43369 43370 43371 43372 43373 43374 43375 43376 |
# File 'lib/aws-sdk-ec2/types.rb', line 43363 class ExportImageResult < Struct.new( :description, :disk_image_format, :export_image_task_id, :image_id, :role_name, :progress, :s3_export_location, :status, :status_message, :tags) SENSITIVE = [] include Aws::Structure end |
#s3_export_location ⇒ Types::ExportTaskS3Location
Information about the destination Amazon S3 bucket.
43363 43364 43365 43366 43367 43368 43369 43370 43371 43372 43373 43374 43375 43376 |
# File 'lib/aws-sdk-ec2/types.rb', line 43363 class ExportImageResult < Struct.new( :description, :disk_image_format, :export_image_task_id, :image_id, :role_name, :progress, :s3_export_location, :status, :status_message, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the export image task. The possible values are
active, completed, deleting, and deleted.
43363 43364 43365 43366 43367 43368 43369 43370 43371 43372 43373 43374 43375 43376 |
# File 'lib/aws-sdk-ec2/types.rb', line 43363 class ExportImageResult < Struct.new( :description, :disk_image_format, :export_image_task_id, :image_id, :role_name, :progress, :s3_export_location, :status, :status_message, :tags) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
The status message for the export image task.
43363 43364 43365 43366 43367 43368 43369 43370 43371 43372 43373 43374 43375 43376 |
# File 'lib/aws-sdk-ec2/types.rb', line 43363 class ExportImageResult < Struct.new( :description, :disk_image_format, :export_image_task_id, :image_id, :role_name, :progress, :s3_export_location, :status, :status_message, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Any tags assigned to the export image task.
43363 43364 43365 43366 43367 43368 43369 43370 43371 43372 43373 43374 43375 43376 |
# File 'lib/aws-sdk-ec2/types.rb', line 43363 class ExportImageResult < Struct.new( :description, :disk_image_format, :export_image_task_id, :image_id, :role_name, :progress, :s3_export_location, :status, :status_message, :tags) SENSITIVE = [] include Aws::Structure end |