Class: Aws::EC2::Types::ExportVerifiedAccessInstanceClientConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


42034
42035
42036
42037
42038
42039
# File 'lib/aws-sdk-ec2/types.rb', line 42034

class ExportVerifiedAccessInstanceClientConfigurationRequest < Struct.new(
  :verified_access_instance_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#verified_access_instance_idString

The ID of the Verified Access instance.

Returns:

  • (String)


42034
42035
42036
42037
42038
42039
# File 'lib/aws-sdk-ec2/types.rb', line 42034

class ExportVerifiedAccessInstanceClientConfigurationRequest < Struct.new(
  :verified_access_instance_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end