Class: Aws::EC2::Types::ExportVerifiedAccessInstanceClientConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ExportVerifiedAccessInstanceClientConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#verified_access_instance_id ⇒ String
The ID of the Verified Access instance.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
41773 41774 41775 41776 41777 41778 |
# File 'lib/aws-sdk-ec2/types.rb', line 41773 class ExportVerifiedAccessInstanceClientConfigurationRequest < Struct.new( :verified_access_instance_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#verified_access_instance_id ⇒ String
The ID of the Verified Access instance.
41773 41774 41775 41776 41777 41778 |
# File 'lib/aws-sdk-ec2/types.rb', line 41773 class ExportVerifiedAccessInstanceClientConfigurationRequest < Struct.new( :verified_access_instance_id, :dry_run) SENSITIVE = [] include Aws::Structure end |