Class: Aws::EC2::Types::ExternalAuthorityConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ExternalAuthorityConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
The configuration that links an Amazon VPC IPAM scope to an external authority system. It specifies the type of external system and the external resource identifier that identifies your account or instance in that system.
For more information, see [Integrate VPC IPAM with Infoblox infrastructure] in the *Amazon VPC IPAM User Guide*.
[1]: docs.aws.amazon.com/vpc/latest/ipam/integrate-infoblox-ipam.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#external_resource_identifier ⇒ String
The identifier for the external resource managing this scope.
-
#type ⇒ String
The type of external authority.
Instance Attribute Details
#external_resource_identifier ⇒ String
The identifier for the external resource managing this scope. For Infoblox integrations, this is the Infoblox resource identifier in the format ‘<version>.identity.account.<entity_realm>.<entity_id>`.
41483 41484 41485 41486 41487 41488 |
# File 'lib/aws-sdk-ec2/types.rb', line 41483 class ExternalAuthorityConfiguration < Struct.new( :type, :external_resource_identifier) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of external authority.
41483 41484 41485 41486 41487 41488 |
# File 'lib/aws-sdk-ec2/types.rb', line 41483 class ExternalAuthorityConfiguration < Struct.new( :type, :external_resource_identifier) SENSITIVE = [] include Aws::Structure end |