Class: Aws::EC2::Types::FleetData
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::FleetData
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes an EC2 Fleet.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#activity_status ⇒ String
The progress of the EC2 Fleet.
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#context ⇒ String
Reserved.
-
#create_time ⇒ Time
The creation date and time of the EC2 Fleet.
-
#errors ⇒ Array<Types::DescribeFleetError>
Information about the instances that could not be launched by the fleet.
-
#excess_capacity_termination_policy ⇒ String
Indicates whether running instances should be terminated if the target capacity of the EC2 Fleet is decreased below the current size of the EC2 Fleet.
-
#fleet_id ⇒ String
The ID of the EC2 Fleet.
-
#fleet_state ⇒ String
The state of the EC2 Fleet.
-
#fulfilled_capacity ⇒ Float
The number of units fulfilled by this request compared to the set target capacity.
-
#fulfilled_on_demand_capacity ⇒ Float
The number of units fulfilled by this request compared to the set target On-Demand capacity.
-
#instances ⇒ Array<Types::DescribeFleetsInstances>
Information about the instances that were launched by the fleet.
-
#launch_template_configs ⇒ Array<Types::FleetLaunchTemplateConfig>
The launch template and overrides.
-
#on_demand_options ⇒ Types::OnDemandOptions
The allocation strategy of On-Demand Instances in an EC2 Fleet.
-
#replace_unhealthy_instances ⇒ Boolean
Indicates whether EC2 Fleet should replace unhealthy Spot Instances.
-
#spot_options ⇒ Types::SpotOptions
The configuration of Spot Instances in an EC2 Fleet.
-
#tags ⇒ Array<Types::Tag>
The tags for an EC2 Fleet resource.
-
#target_capacity_specification ⇒ Types::TargetCapacitySpecification
The number of units to request.
-
#terminate_instances_with_expiration ⇒ Boolean
Indicates whether running instances should be terminated when the EC2 Fleet expires.
-
#type ⇒ String
The type of request.
-
#valid_from ⇒ Time
The start date and time of the request, in UTC format (for example, YYYY-MM-*DD*T*HH*:MM:*SS*Z).
-
#valid_until ⇒ Time
The end date and time of the request, in UTC format (for example, YYYY-MM-*DD*T*HH*:MM:*SS*Z).
Instance Attribute Details
#activity_status ⇒ String
The progress of the EC2 Fleet.
For fleets of type ‘instant`, the status is `fulfilled` after all requests are placed, regardless of whether target capacity is met (this is the only possible status for `instant` fleets).
For fleets of type ‘request` or `maintain`, the status is `pending_fulfillment` after all requests are placed, `fulfilled` when the fleet size meets or exceeds target capacity, `pending_termination` while instances are terminating when fleet size is decreased, and `error` if there’s an error.
41112 41113 41114 41115 41116 41117 41118 41119 41120 41121 41122 41123 41124 41125 41126 41127 41128 41129 41130 41131 41132 41133 41134 41135 41136 |
# File 'lib/aws-sdk-ec2/types.rb', line 41112 class FleetData < Struct.new( :activity_status, :create_time, :fleet_id, :fleet_state, :client_token, :excess_capacity_termination_policy, :fulfilled_capacity, :fulfilled_on_demand_capacity, :launch_template_configs, :target_capacity_specification, :terminate_instances_with_expiration, :type, :valid_from, :valid_until, :replace_unhealthy_instances, :spot_options, :on_demand_options, :tags, :errors, :instances, :context) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [Ensuring idempotency].
Constraints: Maximum 64 ASCII characters
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html
41112 41113 41114 41115 41116 41117 41118 41119 41120 41121 41122 41123 41124 41125 41126 41127 41128 41129 41130 41131 41132 41133 41134 41135 41136 |
# File 'lib/aws-sdk-ec2/types.rb', line 41112 class FleetData < Struct.new( :activity_status, :create_time, :fleet_id, :fleet_state, :client_token, :excess_capacity_termination_policy, :fulfilled_capacity, :fulfilled_on_demand_capacity, :launch_template_configs, :target_capacity_specification, :terminate_instances_with_expiration, :type, :valid_from, :valid_until, :replace_unhealthy_instances, :spot_options, :on_demand_options, :tags, :errors, :instances, :context) SENSITIVE = [] include Aws::Structure end |
#context ⇒ String
Reserved.
41112 41113 41114 41115 41116 41117 41118 41119 41120 41121 41122 41123 41124 41125 41126 41127 41128 41129 41130 41131 41132 41133 41134 41135 41136 |
# File 'lib/aws-sdk-ec2/types.rb', line 41112 class FleetData < Struct.new( :activity_status, :create_time, :fleet_id, :fleet_state, :client_token, :excess_capacity_termination_policy, :fulfilled_capacity, :fulfilled_on_demand_capacity, :launch_template_configs, :target_capacity_specification, :terminate_instances_with_expiration, :type, :valid_from, :valid_until, :replace_unhealthy_instances, :spot_options, :on_demand_options, :tags, :errors, :instances, :context) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The creation date and time of the EC2 Fleet.
41112 41113 41114 41115 41116 41117 41118 41119 41120 41121 41122 41123 41124 41125 41126 41127 41128 41129 41130 41131 41132 41133 41134 41135 41136 |
# File 'lib/aws-sdk-ec2/types.rb', line 41112 class FleetData < Struct.new( :activity_status, :create_time, :fleet_id, :fleet_state, :client_token, :excess_capacity_termination_policy, :fulfilled_capacity, :fulfilled_on_demand_capacity, :launch_template_configs, :target_capacity_specification, :terminate_instances_with_expiration, :type, :valid_from, :valid_until, :replace_unhealthy_instances, :spot_options, :on_demand_options, :tags, :errors, :instances, :context) SENSITIVE = [] include Aws::Structure end |
#errors ⇒ Array<Types::DescribeFleetError>
Information about the instances that could not be launched by the fleet. Valid only when Type is set to ‘instant`.
41112 41113 41114 41115 41116 41117 41118 41119 41120 41121 41122 41123 41124 41125 41126 41127 41128 41129 41130 41131 41132 41133 41134 41135 41136 |
# File 'lib/aws-sdk-ec2/types.rb', line 41112 class FleetData < Struct.new( :activity_status, :create_time, :fleet_id, :fleet_state, :client_token, :excess_capacity_termination_policy, :fulfilled_capacity, :fulfilled_on_demand_capacity, :launch_template_configs, :target_capacity_specification, :terminate_instances_with_expiration, :type, :valid_from, :valid_until, :replace_unhealthy_instances, :spot_options, :on_demand_options, :tags, :errors, :instances, :context) SENSITIVE = [] include Aws::Structure end |
#excess_capacity_termination_policy ⇒ String
Indicates whether running instances should be terminated if the target capacity of the EC2 Fleet is decreased below the current size of the EC2 Fleet.
Supported only for fleets of type ‘maintain`.
41112 41113 41114 41115 41116 41117 41118 41119 41120 41121 41122 41123 41124 41125 41126 41127 41128 41129 41130 41131 41132 41133 41134 41135 41136 |
# File 'lib/aws-sdk-ec2/types.rb', line 41112 class FleetData < Struct.new( :activity_status, :create_time, :fleet_id, :fleet_state, :client_token, :excess_capacity_termination_policy, :fulfilled_capacity, :fulfilled_on_demand_capacity, :launch_template_configs, :target_capacity_specification, :terminate_instances_with_expiration, :type, :valid_from, :valid_until, :replace_unhealthy_instances, :spot_options, :on_demand_options, :tags, :errors, :instances, :context) SENSITIVE = [] include Aws::Structure end |
#fleet_id ⇒ String
The ID of the EC2 Fleet.
41112 41113 41114 41115 41116 41117 41118 41119 41120 41121 41122 41123 41124 41125 41126 41127 41128 41129 41130 41131 41132 41133 41134 41135 41136 |
# File 'lib/aws-sdk-ec2/types.rb', line 41112 class FleetData < Struct.new( :activity_status, :create_time, :fleet_id, :fleet_state, :client_token, :excess_capacity_termination_policy, :fulfilled_capacity, :fulfilled_on_demand_capacity, :launch_template_configs, :target_capacity_specification, :terminate_instances_with_expiration, :type, :valid_from, :valid_until, :replace_unhealthy_instances, :spot_options, :on_demand_options, :tags, :errors, :instances, :context) SENSITIVE = [] include Aws::Structure end |
#fleet_state ⇒ String
The state of the EC2 Fleet.
41112 41113 41114 41115 41116 41117 41118 41119 41120 41121 41122 41123 41124 41125 41126 41127 41128 41129 41130 41131 41132 41133 41134 41135 41136 |
# File 'lib/aws-sdk-ec2/types.rb', line 41112 class FleetData < Struct.new( :activity_status, :create_time, :fleet_id, :fleet_state, :client_token, :excess_capacity_termination_policy, :fulfilled_capacity, :fulfilled_on_demand_capacity, :launch_template_configs, :target_capacity_specification, :terminate_instances_with_expiration, :type, :valid_from, :valid_until, :replace_unhealthy_instances, :spot_options, :on_demand_options, :tags, :errors, :instances, :context) SENSITIVE = [] include Aws::Structure end |
#fulfilled_capacity ⇒ Float
The number of units fulfilled by this request compared to the set target capacity.
41112 41113 41114 41115 41116 41117 41118 41119 41120 41121 41122 41123 41124 41125 41126 41127 41128 41129 41130 41131 41132 41133 41134 41135 41136 |
# File 'lib/aws-sdk-ec2/types.rb', line 41112 class FleetData < Struct.new( :activity_status, :create_time, :fleet_id, :fleet_state, :client_token, :excess_capacity_termination_policy, :fulfilled_capacity, :fulfilled_on_demand_capacity, :launch_template_configs, :target_capacity_specification, :terminate_instances_with_expiration, :type, :valid_from, :valid_until, :replace_unhealthy_instances, :spot_options, :on_demand_options, :tags, :errors, :instances, :context) SENSITIVE = [] include Aws::Structure end |
#fulfilled_on_demand_capacity ⇒ Float
The number of units fulfilled by this request compared to the set target On-Demand capacity.
41112 41113 41114 41115 41116 41117 41118 41119 41120 41121 41122 41123 41124 41125 41126 41127 41128 41129 41130 41131 41132 41133 41134 41135 41136 |
# File 'lib/aws-sdk-ec2/types.rb', line 41112 class FleetData < Struct.new( :activity_status, :create_time, :fleet_id, :fleet_state, :client_token, :excess_capacity_termination_policy, :fulfilled_capacity, :fulfilled_on_demand_capacity, :launch_template_configs, :target_capacity_specification, :terminate_instances_with_expiration, :type, :valid_from, :valid_until, :replace_unhealthy_instances, :spot_options, :on_demand_options, :tags, :errors, :instances, :context) SENSITIVE = [] include Aws::Structure end |
#instances ⇒ Array<Types::DescribeFleetsInstances>
Information about the instances that were launched by the fleet. Valid only when Type is set to ‘instant`.
41112 41113 41114 41115 41116 41117 41118 41119 41120 41121 41122 41123 41124 41125 41126 41127 41128 41129 41130 41131 41132 41133 41134 41135 41136 |
# File 'lib/aws-sdk-ec2/types.rb', line 41112 class FleetData < Struct.new( :activity_status, :create_time, :fleet_id, :fleet_state, :client_token, :excess_capacity_termination_policy, :fulfilled_capacity, :fulfilled_on_demand_capacity, :launch_template_configs, :target_capacity_specification, :terminate_instances_with_expiration, :type, :valid_from, :valid_until, :replace_unhealthy_instances, :spot_options, :on_demand_options, :tags, :errors, :instances, :context) SENSITIVE = [] include Aws::Structure end |
#launch_template_configs ⇒ Array<Types::FleetLaunchTemplateConfig>
The launch template and overrides.
41112 41113 41114 41115 41116 41117 41118 41119 41120 41121 41122 41123 41124 41125 41126 41127 41128 41129 41130 41131 41132 41133 41134 41135 41136 |
# File 'lib/aws-sdk-ec2/types.rb', line 41112 class FleetData < Struct.new( :activity_status, :create_time, :fleet_id, :fleet_state, :client_token, :excess_capacity_termination_policy, :fulfilled_capacity, :fulfilled_on_demand_capacity, :launch_template_configs, :target_capacity_specification, :terminate_instances_with_expiration, :type, :valid_from, :valid_until, :replace_unhealthy_instances, :spot_options, :on_demand_options, :tags, :errors, :instances, :context) SENSITIVE = [] include Aws::Structure end |
#on_demand_options ⇒ Types::OnDemandOptions
The allocation strategy of On-Demand Instances in an EC2 Fleet.
41112 41113 41114 41115 41116 41117 41118 41119 41120 41121 41122 41123 41124 41125 41126 41127 41128 41129 41130 41131 41132 41133 41134 41135 41136 |
# File 'lib/aws-sdk-ec2/types.rb', line 41112 class FleetData < Struct.new( :activity_status, :create_time, :fleet_id, :fleet_state, :client_token, :excess_capacity_termination_policy, :fulfilled_capacity, :fulfilled_on_demand_capacity, :launch_template_configs, :target_capacity_specification, :terminate_instances_with_expiration, :type, :valid_from, :valid_until, :replace_unhealthy_instances, :spot_options, :on_demand_options, :tags, :errors, :instances, :context) SENSITIVE = [] include Aws::Structure end |
#replace_unhealthy_instances ⇒ Boolean
Indicates whether EC2 Fleet should replace unhealthy Spot Instances. Supported only for fleets of type ‘maintain`. For more information, see [EC2 Fleet health checks] in the *Amazon EC2 User Guide*.
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/manage-ec2-fleet.html#ec2-fleet-health-checks
41112 41113 41114 41115 41116 41117 41118 41119 41120 41121 41122 41123 41124 41125 41126 41127 41128 41129 41130 41131 41132 41133 41134 41135 41136 |
# File 'lib/aws-sdk-ec2/types.rb', line 41112 class FleetData < Struct.new( :activity_status, :create_time, :fleet_id, :fleet_state, :client_token, :excess_capacity_termination_policy, :fulfilled_capacity, :fulfilled_on_demand_capacity, :launch_template_configs, :target_capacity_specification, :terminate_instances_with_expiration, :type, :valid_from, :valid_until, :replace_unhealthy_instances, :spot_options, :on_demand_options, :tags, :errors, :instances, :context) SENSITIVE = [] include Aws::Structure end |
#spot_options ⇒ Types::SpotOptions
The configuration of Spot Instances in an EC2 Fleet.
41112 41113 41114 41115 41116 41117 41118 41119 41120 41121 41122 41123 41124 41125 41126 41127 41128 41129 41130 41131 41132 41133 41134 41135 41136 |
# File 'lib/aws-sdk-ec2/types.rb', line 41112 class FleetData < Struct.new( :activity_status, :create_time, :fleet_id, :fleet_state, :client_token, :excess_capacity_termination_policy, :fulfilled_capacity, :fulfilled_on_demand_capacity, :launch_template_configs, :target_capacity_specification, :terminate_instances_with_expiration, :type, :valid_from, :valid_until, :replace_unhealthy_instances, :spot_options, :on_demand_options, :tags, :errors, :instances, :context) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags for an EC2 Fleet resource.
41112 41113 41114 41115 41116 41117 41118 41119 41120 41121 41122 41123 41124 41125 41126 41127 41128 41129 41130 41131 41132 41133 41134 41135 41136 |
# File 'lib/aws-sdk-ec2/types.rb', line 41112 class FleetData < Struct.new( :activity_status, :create_time, :fleet_id, :fleet_state, :client_token, :excess_capacity_termination_policy, :fulfilled_capacity, :fulfilled_on_demand_capacity, :launch_template_configs, :target_capacity_specification, :terminate_instances_with_expiration, :type, :valid_from, :valid_until, :replace_unhealthy_instances, :spot_options, :on_demand_options, :tags, :errors, :instances, :context) SENSITIVE = [] include Aws::Structure end |
#target_capacity_specification ⇒ Types::TargetCapacitySpecification
The number of units to request. You can choose to set the target capacity in terms of instances or a performance characteristic that is important to your application workload, such as vCPUs, memory, or I/O. If the request type is ‘maintain`, you can specify a target capacity of 0 and add capacity later.
41112 41113 41114 41115 41116 41117 41118 41119 41120 41121 41122 41123 41124 41125 41126 41127 41128 41129 41130 41131 41132 41133 41134 41135 41136 |
# File 'lib/aws-sdk-ec2/types.rb', line 41112 class FleetData < Struct.new( :activity_status, :create_time, :fleet_id, :fleet_state, :client_token, :excess_capacity_termination_policy, :fulfilled_capacity, :fulfilled_on_demand_capacity, :launch_template_configs, :target_capacity_specification, :terminate_instances_with_expiration, :type, :valid_from, :valid_until, :replace_unhealthy_instances, :spot_options, :on_demand_options, :tags, :errors, :instances, :context) SENSITIVE = [] include Aws::Structure end |
#terminate_instances_with_expiration ⇒ Boolean
Indicates whether running instances should be terminated when the EC2 Fleet expires.
41112 41113 41114 41115 41116 41117 41118 41119 41120 41121 41122 41123 41124 41125 41126 41127 41128 41129 41130 41131 41132 41133 41134 41135 41136 |
# File 'lib/aws-sdk-ec2/types.rb', line 41112 class FleetData < Struct.new( :activity_status, :create_time, :fleet_id, :fleet_state, :client_token, :excess_capacity_termination_policy, :fulfilled_capacity, :fulfilled_on_demand_capacity, :launch_template_configs, :target_capacity_specification, :terminate_instances_with_expiration, :type, :valid_from, :valid_until, :replace_unhealthy_instances, :spot_options, :on_demand_options, :tags, :errors, :instances, :context) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of request. Indicates whether the EC2 Fleet only ‘requests` the target capacity, or also attempts to `maintain` it. If you request a certain target capacity, EC2 Fleet only places the required requests; it does not attempt to replenish instances if capacity is diminished, and it does not submit requests in alternative capacity pools if capacity is unavailable. To maintain a certain target capacity, EC2 Fleet places the required requests to meet this target capacity. It also automatically replenishes any interrupted Spot Instances. Default: `maintain`.
41112 41113 41114 41115 41116 41117 41118 41119 41120 41121 41122 41123 41124 41125 41126 41127 41128 41129 41130 41131 41132 41133 41134 41135 41136 |
# File 'lib/aws-sdk-ec2/types.rb', line 41112 class FleetData < Struct.new( :activity_status, :create_time, :fleet_id, :fleet_state, :client_token, :excess_capacity_termination_policy, :fulfilled_capacity, :fulfilled_on_demand_capacity, :launch_template_configs, :target_capacity_specification, :terminate_instances_with_expiration, :type, :valid_from, :valid_until, :replace_unhealthy_instances, :spot_options, :on_demand_options, :tags, :errors, :instances, :context) SENSITIVE = [] include Aws::Structure end |
#valid_from ⇒ Time
The start date and time of the request, in UTC format (for example, YYYY-MM-*DD*T*HH*:MM:*SS*Z). The default is to start fulfilling the request immediately.
41112 41113 41114 41115 41116 41117 41118 41119 41120 41121 41122 41123 41124 41125 41126 41127 41128 41129 41130 41131 41132 41133 41134 41135 41136 |
# File 'lib/aws-sdk-ec2/types.rb', line 41112 class FleetData < Struct.new( :activity_status, :create_time, :fleet_id, :fleet_state, :client_token, :excess_capacity_termination_policy, :fulfilled_capacity, :fulfilled_on_demand_capacity, :launch_template_configs, :target_capacity_specification, :terminate_instances_with_expiration, :type, :valid_from, :valid_until, :replace_unhealthy_instances, :spot_options, :on_demand_options, :tags, :errors, :instances, :context) SENSITIVE = [] include Aws::Structure end |
#valid_until ⇒ Time
The end date and time of the request, in UTC format (for example, YYYY-MM-*DD*T*HH*:MM:*SS*Z). At this point, no new instance requests are placed or able to fulfill the request. The default end date is 7 days from the current date.
41112 41113 41114 41115 41116 41117 41118 41119 41120 41121 41122 41123 41124 41125 41126 41127 41128 41129 41130 41131 41132 41133 41134 41135 41136 |
# File 'lib/aws-sdk-ec2/types.rb', line 41112 class FleetData < Struct.new( :activity_status, :create_time, :fleet_id, :fleet_state, :client_token, :excess_capacity_termination_policy, :fulfilled_capacity, :fulfilled_on_demand_capacity, :launch_template_configs, :target_capacity_specification, :terminate_instances_with_expiration, :type, :valid_from, :valid_until, :replace_unhealthy_instances, :spot_options, :on_demand_options, :tags, :errors, :instances, :context) SENSITIVE = [] include Aws::Structure end |