Class: Aws::EC2::Types::FleetInstanceMetadataOptionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::FleetInstanceMetadataOptionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the metadata options for the instances. Supported only for
fleets of type instant.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#http_endpoint ⇒ String
Enables or disables the HTTP metadata endpoint on your instances.
-
#http_put_response_hop_limit ⇒ Integer
The desired HTTP PUT response hop limit for instance metadata requests.
-
#http_tokens ⇒ String
Indicates whether IMDSv2 is required.
Instance Attribute Details
#http_endpoint ⇒ String
Enables or disables the HTTP metadata endpoint on your instances.
-
enabled- The HTTP metadata endpoint is enabled. -
disabled- The HTTP metadata endpoint is disabled.
43013 43014 43015 43016 43017 43018 43019 |
# File 'lib/aws-sdk-ec2/types.rb', line 43013 class FleetInstanceMetadataOptionsRequest < Struct.new( :http_tokens, :http_put_response_hop_limit, :http_endpoint) SENSITIVE = [] include Aws::Structure end |
#http_put_response_hop_limit ⇒ Integer
The desired HTTP PUT response hop limit for instance metadata requests. The larger the number, the further instance metadata requests can travel.
Default: 1
Possible values: Integers from 1 to 64
43013 43014 43015 43016 43017 43018 43019 |
# File 'lib/aws-sdk-ec2/types.rb', line 43013 class FleetInstanceMetadataOptionsRequest < Struct.new( :http_tokens, :http_put_response_hop_limit, :http_endpoint) SENSITIVE = [] include Aws::Structure end |
#http_tokens ⇒ String
Indicates whether IMDSv2 is required.
-
optional- IMDSv2 is optional, which means that you can use either IMDSv2 or IMDSv1. -
required- IMDSv2 is required, which means that IMDSv1 is disabled, and you must use IMDSv2.
43013 43014 43015 43016 43017 43018 43019 |
# File 'lib/aws-sdk-ec2/types.rb', line 43013 class FleetInstanceMetadataOptionsRequest < Struct.new( :http_tokens, :http_put_response_hop_limit, :http_endpoint) SENSITIVE = [] include Aws::Structure end |