Class: Aws::EC2::Types::FleetLaunchTemplateSpecificationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::FleetLaunchTemplateSpecificationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
The Amazon EC2 launch template that can be used by an EC2 Fleet to configure Amazon EC2 instances. You must specify either the ID or name of the launch template in the request, but not both.
For information about launch templates, see [Launch an instance from a launch template] in the *Amazon EC2 User Guide*.
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-launch-templates.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#launch_template_id ⇒ String
The ID of the launch template.
-
#launch_template_name ⇒ String
The name of the launch template.
-
#version ⇒ String
The launch template version number, ‘$Latest`, or `$Default`.
Instance Attribute Details
#launch_template_id ⇒ String
The ID of the launch template.
You must specify the ‘LaunchTemplateId` or the `LaunchTemplateName`, but not both.
43145 43146 43147 43148 43149 43150 43151 |
# File 'lib/aws-sdk-ec2/types.rb', line 43145 class FleetLaunchTemplateSpecificationRequest < Struct.new( :launch_template_id, :launch_template_name, :version) SENSITIVE = [] include Aws::Structure end |
#launch_template_name ⇒ String
The name of the launch template.
You must specify the ‘LaunchTemplateName` or the `LaunchTemplateId`, but not both.
43145 43146 43147 43148 43149 43150 43151 |
# File 'lib/aws-sdk-ec2/types.rb', line 43145 class FleetLaunchTemplateSpecificationRequest < Struct.new( :launch_template_id, :launch_template_name, :version) SENSITIVE = [] include Aws::Structure end |
#version ⇒ String
The launch template version number, ‘$Latest`, or `$Default`. You must specify a value, otherwise the request fails.
If the value is ‘$Latest`, Amazon EC2 uses the latest version of the launch template.
If the value is ‘$Default`, Amazon EC2 uses the default version of the launch template.
43145 43146 43147 43148 43149 43150 43151 |
# File 'lib/aws-sdk-ec2/types.rb', line 43145 class FleetLaunchTemplateSpecificationRequest < Struct.new( :launch_template_id, :launch_template_name, :version) SENSITIVE = [] include Aws::Structure end |