Class: Aws::EC2::Types::FlowLog
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::FlowLog
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a flow log.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
The date and time the flow log was created.
-
#deliver_cross_account_role ⇒ String
The ARN of the IAM role that allows the service to publish flow logs across accounts.
-
#deliver_logs_error_message ⇒ String
Information about the error that occurred.
-
#deliver_logs_permission_arn ⇒ String
The ARN of the IAM role allows the service to publish logs to CloudWatch Logs.
-
#deliver_logs_status ⇒ String
The status of the logs delivery (‘SUCCESS` | `FAILED`).
-
#destination_options ⇒ Types::DestinationOptionsResponse
The destination options.
-
#flow_log_id ⇒ String
The ID of the flow log.
-
#flow_log_status ⇒ String
The status of the flow log (‘ACTIVE`).
-
#log_destination ⇒ String
The Amazon Resource Name (ARN) of the destination for the flow log data.
-
#log_destination_type ⇒ String
The type of destination for the flow log data.
-
#log_format ⇒ String
The format of the flow log record.
-
#log_group_name ⇒ String
The name of the flow log group.
-
#max_aggregation_interval ⇒ Integer
The maximum interval of time, in seconds, during which a flow of packets is captured and aggregated into a flow log record.
-
#resource_id ⇒ String
The ID of the resource being monitored.
-
#tag_field_specifications ⇒ Array<Types::TagFieldSpecificationResponse>
The tag configuration associated with the Flow Logs Amazon EC2 Tags feature fields in your custom log format.
-
#tags ⇒ Array<Types::Tag>
The tags for the flow log.
-
#traffic_type ⇒ String
The type of traffic captured for the flow log.
Instance Attribute Details
#creation_time ⇒ Time
The date and time the flow log was created.
43454 43455 43456 43457 43458 43459 43460 43461 43462 43463 43464 43465 43466 43467 43468 43469 43470 43471 43472 43473 43474 |
# File 'lib/aws-sdk-ec2/types.rb', line 43454 class FlowLog < Struct.new( :creation_time, :deliver_logs_error_message, :deliver_logs_permission_arn, :deliver_cross_account_role, :deliver_logs_status, :flow_log_id, :flow_log_status, :log_group_name, :resource_id, :traffic_type, :log_destination_type, :log_destination, :log_format, :tags, :max_aggregation_interval, :destination_options, :tag_field_specifications) SENSITIVE = [] include Aws::Structure end |
#deliver_cross_account_role ⇒ String
The ARN of the IAM role that allows the service to publish flow logs across accounts.
43454 43455 43456 43457 43458 43459 43460 43461 43462 43463 43464 43465 43466 43467 43468 43469 43470 43471 43472 43473 43474 |
# File 'lib/aws-sdk-ec2/types.rb', line 43454 class FlowLog < Struct.new( :creation_time, :deliver_logs_error_message, :deliver_logs_permission_arn, :deliver_cross_account_role, :deliver_logs_status, :flow_log_id, :flow_log_status, :log_group_name, :resource_id, :traffic_type, :log_destination_type, :log_destination, :log_format, :tags, :max_aggregation_interval, :destination_options, :tag_field_specifications) SENSITIVE = [] include Aws::Structure end |
#deliver_logs_error_message ⇒ String
Information about the error that occurred. ‘Rate limited` indicates that CloudWatch Logs throttling has been applied for one or more network interfaces, or that you’ve reached the limit on the number of log groups that you can create. ‘Access error` indicates that the IAM role associated with the flow log does not have sufficient permissions to publish to CloudWatch Logs. `Unknown error` indicates an internal error.
43454 43455 43456 43457 43458 43459 43460 43461 43462 43463 43464 43465 43466 43467 43468 43469 43470 43471 43472 43473 43474 |
# File 'lib/aws-sdk-ec2/types.rb', line 43454 class FlowLog < Struct.new( :creation_time, :deliver_logs_error_message, :deliver_logs_permission_arn, :deliver_cross_account_role, :deliver_logs_status, :flow_log_id, :flow_log_status, :log_group_name, :resource_id, :traffic_type, :log_destination_type, :log_destination, :log_format, :tags, :max_aggregation_interval, :destination_options, :tag_field_specifications) SENSITIVE = [] include Aws::Structure end |
#deliver_logs_permission_arn ⇒ String
The ARN of the IAM role allows the service to publish logs to CloudWatch Logs.
43454 43455 43456 43457 43458 43459 43460 43461 43462 43463 43464 43465 43466 43467 43468 43469 43470 43471 43472 43473 43474 |
# File 'lib/aws-sdk-ec2/types.rb', line 43454 class FlowLog < Struct.new( :creation_time, :deliver_logs_error_message, :deliver_logs_permission_arn, :deliver_cross_account_role, :deliver_logs_status, :flow_log_id, :flow_log_status, :log_group_name, :resource_id, :traffic_type, :log_destination_type, :log_destination, :log_format, :tags, :max_aggregation_interval, :destination_options, :tag_field_specifications) SENSITIVE = [] include Aws::Structure end |
#deliver_logs_status ⇒ String
The status of the logs delivery (‘SUCCESS` | `FAILED`).
43454 43455 43456 43457 43458 43459 43460 43461 43462 43463 43464 43465 43466 43467 43468 43469 43470 43471 43472 43473 43474 |
# File 'lib/aws-sdk-ec2/types.rb', line 43454 class FlowLog < Struct.new( :creation_time, :deliver_logs_error_message, :deliver_logs_permission_arn, :deliver_cross_account_role, :deliver_logs_status, :flow_log_id, :flow_log_status, :log_group_name, :resource_id, :traffic_type, :log_destination_type, :log_destination, :log_format, :tags, :max_aggregation_interval, :destination_options, :tag_field_specifications) SENSITIVE = [] include Aws::Structure end |
#destination_options ⇒ Types::DestinationOptionsResponse
The destination options.
43454 43455 43456 43457 43458 43459 43460 43461 43462 43463 43464 43465 43466 43467 43468 43469 43470 43471 43472 43473 43474 |
# File 'lib/aws-sdk-ec2/types.rb', line 43454 class FlowLog < Struct.new( :creation_time, :deliver_logs_error_message, :deliver_logs_permission_arn, :deliver_cross_account_role, :deliver_logs_status, :flow_log_id, :flow_log_status, :log_group_name, :resource_id, :traffic_type, :log_destination_type, :log_destination, :log_format, :tags, :max_aggregation_interval, :destination_options, :tag_field_specifications) SENSITIVE = [] include Aws::Structure end |
#flow_log_id ⇒ String
The ID of the flow log.
43454 43455 43456 43457 43458 43459 43460 43461 43462 43463 43464 43465 43466 43467 43468 43469 43470 43471 43472 43473 43474 |
# File 'lib/aws-sdk-ec2/types.rb', line 43454 class FlowLog < Struct.new( :creation_time, :deliver_logs_error_message, :deliver_logs_permission_arn, :deliver_cross_account_role, :deliver_logs_status, :flow_log_id, :flow_log_status, :log_group_name, :resource_id, :traffic_type, :log_destination_type, :log_destination, :log_format, :tags, :max_aggregation_interval, :destination_options, :tag_field_specifications) SENSITIVE = [] include Aws::Structure end |
#flow_log_status ⇒ String
The status of the flow log (‘ACTIVE`).
43454 43455 43456 43457 43458 43459 43460 43461 43462 43463 43464 43465 43466 43467 43468 43469 43470 43471 43472 43473 43474 |
# File 'lib/aws-sdk-ec2/types.rb', line 43454 class FlowLog < Struct.new( :creation_time, :deliver_logs_error_message, :deliver_logs_permission_arn, :deliver_cross_account_role, :deliver_logs_status, :flow_log_id, :flow_log_status, :log_group_name, :resource_id, :traffic_type, :log_destination_type, :log_destination, :log_format, :tags, :max_aggregation_interval, :destination_options, :tag_field_specifications) SENSITIVE = [] include Aws::Structure end |
#log_destination ⇒ String
The Amazon Resource Name (ARN) of the destination for the flow log data.
43454 43455 43456 43457 43458 43459 43460 43461 43462 43463 43464 43465 43466 43467 43468 43469 43470 43471 43472 43473 43474 |
# File 'lib/aws-sdk-ec2/types.rb', line 43454 class FlowLog < Struct.new( :creation_time, :deliver_logs_error_message, :deliver_logs_permission_arn, :deliver_cross_account_role, :deliver_logs_status, :flow_log_id, :flow_log_status, :log_group_name, :resource_id, :traffic_type, :log_destination_type, :log_destination, :log_format, :tags, :max_aggregation_interval, :destination_options, :tag_field_specifications) SENSITIVE = [] include Aws::Structure end |
#log_destination_type ⇒ String
The type of destination for the flow log data.
43454 43455 43456 43457 43458 43459 43460 43461 43462 43463 43464 43465 43466 43467 43468 43469 43470 43471 43472 43473 43474 |
# File 'lib/aws-sdk-ec2/types.rb', line 43454 class FlowLog < Struct.new( :creation_time, :deliver_logs_error_message, :deliver_logs_permission_arn, :deliver_cross_account_role, :deliver_logs_status, :flow_log_id, :flow_log_status, :log_group_name, :resource_id, :traffic_type, :log_destination_type, :log_destination, :log_format, :tags, :max_aggregation_interval, :destination_options, :tag_field_specifications) SENSITIVE = [] include Aws::Structure end |
#log_format ⇒ String
The format of the flow log record.
43454 43455 43456 43457 43458 43459 43460 43461 43462 43463 43464 43465 43466 43467 43468 43469 43470 43471 43472 43473 43474 |
# File 'lib/aws-sdk-ec2/types.rb', line 43454 class FlowLog < Struct.new( :creation_time, :deliver_logs_error_message, :deliver_logs_permission_arn, :deliver_cross_account_role, :deliver_logs_status, :flow_log_id, :flow_log_status, :log_group_name, :resource_id, :traffic_type, :log_destination_type, :log_destination, :log_format, :tags, :max_aggregation_interval, :destination_options, :tag_field_specifications) SENSITIVE = [] include Aws::Structure end |
#log_group_name ⇒ String
The name of the flow log group.
43454 43455 43456 43457 43458 43459 43460 43461 43462 43463 43464 43465 43466 43467 43468 43469 43470 43471 43472 43473 43474 |
# File 'lib/aws-sdk-ec2/types.rb', line 43454 class FlowLog < Struct.new( :creation_time, :deliver_logs_error_message, :deliver_logs_permission_arn, :deliver_cross_account_role, :deliver_logs_status, :flow_log_id, :flow_log_status, :log_group_name, :resource_id, :traffic_type, :log_destination_type, :log_destination, :log_format, :tags, :max_aggregation_interval, :destination_options, :tag_field_specifications) SENSITIVE = [] include Aws::Structure end |
#max_aggregation_interval ⇒ Integer
The maximum interval of time, in seconds, during which a flow of packets is captured and aggregated into a flow log record.
When a network interface is attached to a [Nitro-based instance], the aggregation interval is always 60 seconds (1 minute) or less, regardless of the specified value.
Valid Values: ‘60` | `600`
[1]: docs.aws.amazon.com/ec2/latest/instancetypes/ec2-nitro-instances.html
43454 43455 43456 43457 43458 43459 43460 43461 43462 43463 43464 43465 43466 43467 43468 43469 43470 43471 43472 43473 43474 |
# File 'lib/aws-sdk-ec2/types.rb', line 43454 class FlowLog < Struct.new( :creation_time, :deliver_logs_error_message, :deliver_logs_permission_arn, :deliver_cross_account_role, :deliver_logs_status, :flow_log_id, :flow_log_status, :log_group_name, :resource_id, :traffic_type, :log_destination_type, :log_destination, :log_format, :tags, :max_aggregation_interval, :destination_options, :tag_field_specifications) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
The ID of the resource being monitored.
43454 43455 43456 43457 43458 43459 43460 43461 43462 43463 43464 43465 43466 43467 43468 43469 43470 43471 43472 43473 43474 |
# File 'lib/aws-sdk-ec2/types.rb', line 43454 class FlowLog < Struct.new( :creation_time, :deliver_logs_error_message, :deliver_logs_permission_arn, :deliver_cross_account_role, :deliver_logs_status, :flow_log_id, :flow_log_status, :log_group_name, :resource_id, :traffic_type, :log_destination_type, :log_destination, :log_format, :tags, :max_aggregation_interval, :destination_options, :tag_field_specifications) SENSITIVE = [] include Aws::Structure end |
#tag_field_specifications ⇒ Array<Types::TagFieldSpecificationResponse>
The tag configuration associated with the Flow Logs Amazon EC2 Tags feature fields in your custom log format.
43454 43455 43456 43457 43458 43459 43460 43461 43462 43463 43464 43465 43466 43467 43468 43469 43470 43471 43472 43473 43474 |
# File 'lib/aws-sdk-ec2/types.rb', line 43454 class FlowLog < Struct.new( :creation_time, :deliver_logs_error_message, :deliver_logs_permission_arn, :deliver_cross_account_role, :deliver_logs_status, :flow_log_id, :flow_log_status, :log_group_name, :resource_id, :traffic_type, :log_destination_type, :log_destination, :log_format, :tags, :max_aggregation_interval, :destination_options, :tag_field_specifications) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags for the flow log.
43454 43455 43456 43457 43458 43459 43460 43461 43462 43463 43464 43465 43466 43467 43468 43469 43470 43471 43472 43473 43474 |
# File 'lib/aws-sdk-ec2/types.rb', line 43454 class FlowLog < Struct.new( :creation_time, :deliver_logs_error_message, :deliver_logs_permission_arn, :deliver_cross_account_role, :deliver_logs_status, :flow_log_id, :flow_log_status, :log_group_name, :resource_id, :traffic_type, :log_destination_type, :log_destination, :log_format, :tags, :max_aggregation_interval, :destination_options, :tag_field_specifications) SENSITIVE = [] include Aws::Structure end |
#traffic_type ⇒ String
The type of traffic captured for the flow log.
43454 43455 43456 43457 43458 43459 43460 43461 43462 43463 43464 43465 43466 43467 43468 43469 43470 43471 43472 43473 43474 |
# File 'lib/aws-sdk-ec2/types.rb', line 43454 class FlowLog < Struct.new( :creation_time, :deliver_logs_error_message, :deliver_logs_permission_arn, :deliver_cross_account_role, :deliver_logs_status, :flow_log_id, :flow_log_status, :log_group_name, :resource_id, :traffic_type, :log_destination_type, :log_destination, :log_format, :tags, :max_aggregation_interval, :destination_options, :tag_field_specifications) SENSITIVE = [] include Aws::Structure end |