Class: Aws::EC2::Types::FpgaImage
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::FpgaImage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes an Amazon FPGA image (AFI).
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#create_time ⇒ Time
The date and time the AFI was created.
-
#data_retention_support ⇒ Boolean
Indicates whether data retention support is enabled for the AFI.
-
#description ⇒ String
The description of the AFI.
-
#fpga_image_global_id ⇒ String
The global FPGA image identifier (AGFI ID).
-
#fpga_image_id ⇒ String
The FPGA image identifier (AFI ID).
-
#instance_types ⇒ Array<String>
The instance types supported by the AFI.
-
#name ⇒ String
The name of the AFI.
-
#owner_alias ⇒ String
The alias of the AFI owner.
-
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the AFI.
-
#pci_id ⇒ Types::PciId
Information about the PCI bus.
-
#product_codes ⇒ Array<Types::ProductCode>
The product codes for the AFI.
-
#public ⇒ Boolean
Indicates whether the AFI is public.
-
#shell_version ⇒ String
The version of the Amazon Web Services Shell that was used to create the bitstream.
-
#state ⇒ Types::FpgaImageState
Information about the state of the AFI.
-
#tags ⇒ Array<Types::Tag>
Any tags assigned to the AFI.
-
#update_time ⇒ Time
The time of the most recent update to the AFI.
Instance Attribute Details
#create_time ⇒ Time
The date and time the AFI was created.
43087 43088 43089 43090 43091 43092 43093 43094 43095 43096 43097 43098 43099 43100 43101 43102 43103 43104 43105 43106 |
# File 'lib/aws-sdk-ec2/types.rb', line 43087 class FpgaImage < Struct.new( :fpga_image_id, :fpga_image_global_id, :name, :description, :shell_version, :pci_id, :state, :create_time, :update_time, :owner_id, :owner_alias, :product_codes, :tags, :public, :data_retention_support, :instance_types) SENSITIVE = [] include Aws::Structure end |
#data_retention_support ⇒ Boolean
Indicates whether data retention support is enabled for the AFI.
43087 43088 43089 43090 43091 43092 43093 43094 43095 43096 43097 43098 43099 43100 43101 43102 43103 43104 43105 43106 |
# File 'lib/aws-sdk-ec2/types.rb', line 43087 class FpgaImage < Struct.new( :fpga_image_id, :fpga_image_global_id, :name, :description, :shell_version, :pci_id, :state, :create_time, :update_time, :owner_id, :owner_alias, :product_codes, :tags, :public, :data_retention_support, :instance_types) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the AFI.
43087 43088 43089 43090 43091 43092 43093 43094 43095 43096 43097 43098 43099 43100 43101 43102 43103 43104 43105 43106 |
# File 'lib/aws-sdk-ec2/types.rb', line 43087 class FpgaImage < Struct.new( :fpga_image_id, :fpga_image_global_id, :name, :description, :shell_version, :pci_id, :state, :create_time, :update_time, :owner_id, :owner_alias, :product_codes, :tags, :public, :data_retention_support, :instance_types) SENSITIVE = [] include Aws::Structure end |
#fpga_image_global_id ⇒ String
The global FPGA image identifier (AGFI ID).
43087 43088 43089 43090 43091 43092 43093 43094 43095 43096 43097 43098 43099 43100 43101 43102 43103 43104 43105 43106 |
# File 'lib/aws-sdk-ec2/types.rb', line 43087 class FpgaImage < Struct.new( :fpga_image_id, :fpga_image_global_id, :name, :description, :shell_version, :pci_id, :state, :create_time, :update_time, :owner_id, :owner_alias, :product_codes, :tags, :public, :data_retention_support, :instance_types) SENSITIVE = [] include Aws::Structure end |
#fpga_image_id ⇒ String
The FPGA image identifier (AFI ID).
43087 43088 43089 43090 43091 43092 43093 43094 43095 43096 43097 43098 43099 43100 43101 43102 43103 43104 43105 43106 |
# File 'lib/aws-sdk-ec2/types.rb', line 43087 class FpgaImage < Struct.new( :fpga_image_id, :fpga_image_global_id, :name, :description, :shell_version, :pci_id, :state, :create_time, :update_time, :owner_id, :owner_alias, :product_codes, :tags, :public, :data_retention_support, :instance_types) SENSITIVE = [] include Aws::Structure end |
#instance_types ⇒ Array<String>
The instance types supported by the AFI.
43087 43088 43089 43090 43091 43092 43093 43094 43095 43096 43097 43098 43099 43100 43101 43102 43103 43104 43105 43106 |
# File 'lib/aws-sdk-ec2/types.rb', line 43087 class FpgaImage < Struct.new( :fpga_image_id, :fpga_image_global_id, :name, :description, :shell_version, :pci_id, :state, :create_time, :update_time, :owner_id, :owner_alias, :product_codes, :tags, :public, :data_retention_support, :instance_types) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the AFI.
43087 43088 43089 43090 43091 43092 43093 43094 43095 43096 43097 43098 43099 43100 43101 43102 43103 43104 43105 43106 |
# File 'lib/aws-sdk-ec2/types.rb', line 43087 class FpgaImage < Struct.new( :fpga_image_id, :fpga_image_global_id, :name, :description, :shell_version, :pci_id, :state, :create_time, :update_time, :owner_id, :owner_alias, :product_codes, :tags, :public, :data_retention_support, :instance_types) SENSITIVE = [] include Aws::Structure end |
#owner_alias ⇒ String
The alias of the AFI owner. Possible values include ‘self`, `amazon`, and `aws-marketplace`.
43087 43088 43089 43090 43091 43092 43093 43094 43095 43096 43097 43098 43099 43100 43101 43102 43103 43104 43105 43106 |
# File 'lib/aws-sdk-ec2/types.rb', line 43087 class FpgaImage < Struct.new( :fpga_image_id, :fpga_image_global_id, :name, :description, :shell_version, :pci_id, :state, :create_time, :update_time, :owner_id, :owner_alias, :product_codes, :tags, :public, :data_retention_support, :instance_types) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the AFI.
43087 43088 43089 43090 43091 43092 43093 43094 43095 43096 43097 43098 43099 43100 43101 43102 43103 43104 43105 43106 |
# File 'lib/aws-sdk-ec2/types.rb', line 43087 class FpgaImage < Struct.new( :fpga_image_id, :fpga_image_global_id, :name, :description, :shell_version, :pci_id, :state, :create_time, :update_time, :owner_id, :owner_alias, :product_codes, :tags, :public, :data_retention_support, :instance_types) SENSITIVE = [] include Aws::Structure end |
#pci_id ⇒ Types::PciId
Information about the PCI bus.
43087 43088 43089 43090 43091 43092 43093 43094 43095 43096 43097 43098 43099 43100 43101 43102 43103 43104 43105 43106 |
# File 'lib/aws-sdk-ec2/types.rb', line 43087 class FpgaImage < Struct.new( :fpga_image_id, :fpga_image_global_id, :name, :description, :shell_version, :pci_id, :state, :create_time, :update_time, :owner_id, :owner_alias, :product_codes, :tags, :public, :data_retention_support, :instance_types) SENSITIVE = [] include Aws::Structure end |
#product_codes ⇒ Array<Types::ProductCode>
The product codes for the AFI.
43087 43088 43089 43090 43091 43092 43093 43094 43095 43096 43097 43098 43099 43100 43101 43102 43103 43104 43105 43106 |
# File 'lib/aws-sdk-ec2/types.rb', line 43087 class FpgaImage < Struct.new( :fpga_image_id, :fpga_image_global_id, :name, :description, :shell_version, :pci_id, :state, :create_time, :update_time, :owner_id, :owner_alias, :product_codes, :tags, :public, :data_retention_support, :instance_types) SENSITIVE = [] include Aws::Structure end |
#public ⇒ Boolean
Indicates whether the AFI is public.
43087 43088 43089 43090 43091 43092 43093 43094 43095 43096 43097 43098 43099 43100 43101 43102 43103 43104 43105 43106 |
# File 'lib/aws-sdk-ec2/types.rb', line 43087 class FpgaImage < Struct.new( :fpga_image_id, :fpga_image_global_id, :name, :description, :shell_version, :pci_id, :state, :create_time, :update_time, :owner_id, :owner_alias, :product_codes, :tags, :public, :data_retention_support, :instance_types) SENSITIVE = [] include Aws::Structure end |
#shell_version ⇒ String
The version of the Amazon Web Services Shell that was used to create the bitstream.
43087 43088 43089 43090 43091 43092 43093 43094 43095 43096 43097 43098 43099 43100 43101 43102 43103 43104 43105 43106 |
# File 'lib/aws-sdk-ec2/types.rb', line 43087 class FpgaImage < Struct.new( :fpga_image_id, :fpga_image_global_id, :name, :description, :shell_version, :pci_id, :state, :create_time, :update_time, :owner_id, :owner_alias, :product_codes, :tags, :public, :data_retention_support, :instance_types) SENSITIVE = [] include Aws::Structure end |
#state ⇒ Types::FpgaImageState
Information about the state of the AFI.
43087 43088 43089 43090 43091 43092 43093 43094 43095 43096 43097 43098 43099 43100 43101 43102 43103 43104 43105 43106 |
# File 'lib/aws-sdk-ec2/types.rb', line 43087 class FpgaImage < Struct.new( :fpga_image_id, :fpga_image_global_id, :name, :description, :shell_version, :pci_id, :state, :create_time, :update_time, :owner_id, :owner_alias, :product_codes, :tags, :public, :data_retention_support, :instance_types) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Any tags assigned to the AFI.
43087 43088 43089 43090 43091 43092 43093 43094 43095 43096 43097 43098 43099 43100 43101 43102 43103 43104 43105 43106 |
# File 'lib/aws-sdk-ec2/types.rb', line 43087 class FpgaImage < Struct.new( :fpga_image_id, :fpga_image_global_id, :name, :description, :shell_version, :pci_id, :state, :create_time, :update_time, :owner_id, :owner_alias, :product_codes, :tags, :public, :data_retention_support, :instance_types) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The time of the most recent update to the AFI.
43087 43088 43089 43090 43091 43092 43093 43094 43095 43096 43097 43098 43099 43100 43101 43102 43103 43104 43105 43106 |
# File 'lib/aws-sdk-ec2/types.rb', line 43087 class FpgaImage < Struct.new( :fpga_image_id, :fpga_image_global_id, :name, :description, :shell_version, :pci_id, :state, :create_time, :update_time, :owner_id, :owner_alias, :product_codes, :tags, :public, :data_retention_support, :instance_types) SENSITIVE = [] include Aws::Structure end |