Class: Aws::EC2::Types::GetAssociatedEnclaveCertificateIamRolesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetAssociatedEnclaveCertificateIamRolesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_arn ⇒ String
The ARN of the ACM certificate for which to view the associated IAM roles, encryption keys, and Amazon S3 object information.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#certificate_arn ⇒ String
The ARN of the ACM certificate for which to view the associated IAM roles, encryption keys, and Amazon S3 object information.
45747 45748 45749 45750 45751 45752 |
# File 'lib/aws-sdk-ec2/types.rb', line 45747 class GetAssociatedEnclaveCertificateIamRolesRequest < Struct.new( :certificate_arn, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
45747 45748 45749 45750 45751 45752 |
# File 'lib/aws-sdk-ec2/types.rb', line 45747 class GetAssociatedEnclaveCertificateIamRolesRequest < Struct.new( :certificate_arn, :dry_run) SENSITIVE = [] include Aws::Structure end |