Class: Aws::EC2::Types::GetAssociatedEnclaveCertificateIamRolesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#certificate_arnString

The ARN of the ACM certificate for which to view the associated IAM roles, encryption keys, and Amazon S3 object information.

Returns:

  • (String)


43353
43354
43355
43356
43357
43358
# File 'lib/aws-sdk-ec2/types.rb', line 43353

class GetAssociatedEnclaveCertificateIamRolesRequest < Struct.new(
  :certificate_arn,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


43353
43354
43355
43356
43357
43358
# File 'lib/aws-sdk-ec2/types.rb', line 43353

class GetAssociatedEnclaveCertificateIamRolesRequest < Struct.new(
  :certificate_arn,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end