Class: Aws::EC2::Types::GetAssociatedIpv6PoolCidrsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


44171
44172
44173
44174
44175
44176
44177
44178
# File 'lib/aws-sdk-ec2/types.rb', line 44171

class GetAssociatedIpv6PoolCidrsRequest < Struct.new(
  :pool_id,
  :next_token,
  :max_results,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.

Returns:

  • (Integer)


44171
44172
44173
44174
44175
44176
44177
44178
# File 'lib/aws-sdk-ec2/types.rb', line 44171

class GetAssociatedIpv6PoolCidrsRequest < Struct.new(
  :pool_id,
  :next_token,
  :max_results,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


44171
44172
44173
44174
44175
44176
44177
44178
# File 'lib/aws-sdk-ec2/types.rb', line 44171

class GetAssociatedIpv6PoolCidrsRequest < Struct.new(
  :pool_id,
  :next_token,
  :max_results,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#pool_idString

The ID of the IPv6 address pool.

Returns:

  • (String)


44171
44172
44173
44174
44175
44176
44177
44178
# File 'lib/aws-sdk-ec2/types.rb', line 44171

class GetAssociatedIpv6PoolCidrsRequest < Struct.new(
  :pool_id,
  :next_token,
  :max_results,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end