Class: Aws::EC2::Types::GetAssociatedIpv6PoolCidrsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetAssociatedIpv6PoolCidrsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
-
#pool_id ⇒ String
The ID of the IPv6 address pool.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
44020 44021 44022 44023 44024 44025 44026 44027 |
# File 'lib/aws-sdk-ec2/types.rb', line 44020 class GetAssociatedIpv6PoolCidrsRequest < Struct.new( :pool_id, :next_token, :max_results, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To
retrieve the remaining results, make another call with the returned
nextToken value.
44020 44021 44022 44023 44024 44025 44026 44027 |
# File 'lib/aws-sdk-ec2/types.rb', line 44020 class GetAssociatedIpv6PoolCidrsRequest < Struct.new( :pool_id, :next_token, :max_results, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
44020 44021 44022 44023 44024 44025 44026 44027 |
# File 'lib/aws-sdk-ec2/types.rb', line 44020 class GetAssociatedIpv6PoolCidrsRequest < Struct.new( :pool_id, :next_token, :max_results, :dry_run) SENSITIVE = [] include Aws::Structure end |
#pool_id ⇒ String
The ID of the IPv6 address pool.
44020 44021 44022 44023 44024 44025 44026 44027 |
# File 'lib/aws-sdk-ec2/types.rb', line 44020 class GetAssociatedIpv6PoolCidrsRequest < Struct.new( :pool_id, :next_token, :max_results, :dry_run) SENSITIVE = [] include Aws::Structure end |