Class: Aws::EC2::Types::GetCapacityManagerAttributesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetCapacityManagerAttributesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
45877 45878 45879 45880 45881 |
# File 'lib/aws-sdk-ec2/types.rb', line 45877 class GetCapacityManagerAttributesRequest < Struct.new( :dry_run) SENSITIVE = [] include Aws::Structure end |