Class: Aws::EC2::Types::GetCapacityManagerAttributesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetCapacityManagerAttributesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
43180 43181 43182 43183 43184 |
# File 'lib/aws-sdk-ec2/types.rb', line 43180 class GetCapacityManagerAttributesRequest < Struct.new( :dry_run) SENSITIVE = [] include Aws::Structure end |