Class: Aws::EC2::Types::GetCapacityManagerMetricDataRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetCapacityManagerMetricDataRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#end_time ⇒ Time
The end time for the metric data query, in ISO 8601 format.
-
#filter_by ⇒ Array<Types::CapacityManagerCondition>
Conditions to filter the metric data.
-
#group_by ⇒ Array<String>
The dimensions by which to group the metric data.
-
#max_results ⇒ Integer
The maximum number of data points to return.
-
#metric_names ⇒ Array<String>
The names of the metrics to retrieve.
-
#next_token ⇒ String
The token for the next page of results.
-
#period ⇒ Integer
The granularity, in seconds, of the returned data points.
-
#start_time ⇒ Time
The start time for the metric data query, in ISO 8601 format.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
43956 43957 43958 43959 43960 43961 43962 43963 43964 43965 43966 43967 43968 |
# File 'lib/aws-sdk-ec2/types.rb', line 43956 class GetCapacityManagerMetricDataRequest < Struct.new( :metric_names, :start_time, :end_time, :period, :group_by, :filter_by, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
The end time for the metric data query, in ISO 8601 format. If the end time is beyond the latest ingested data, it will be automatically adjusted to the latest available data point.
43956 43957 43958 43959 43960 43961 43962 43963 43964 43965 43966 43967 43968 |
# File 'lib/aws-sdk-ec2/types.rb', line 43956 class GetCapacityManagerMetricDataRequest < Struct.new( :metric_names, :start_time, :end_time, :period, :group_by, :filter_by, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filter_by ⇒ Array<Types::CapacityManagerCondition>
Conditions to filter the metric data. Each filter specifies a dimension, comparison operator (‘equals’, ‘in’), and values to match against.
43956 43957 43958 43959 43960 43961 43962 43963 43964 43965 43966 43967 43968 |
# File 'lib/aws-sdk-ec2/types.rb', line 43956 class GetCapacityManagerMetricDataRequest < Struct.new( :metric_names, :start_time, :end_time, :period, :group_by, :filter_by, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#group_by ⇒ Array<String>
The dimensions by which to group the metric data. This determines how the data is aggregated and returned.
43956 43957 43958 43959 43960 43961 43962 43963 43964 43965 43966 43967 43968 |
# File 'lib/aws-sdk-ec2/types.rb', line 43956 class GetCapacityManagerMetricDataRequest < Struct.new( :metric_names, :start_time, :end_time, :period, :group_by, :filter_by, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of data points to return. Valid range is 1 to 100,000. Use with NextToken for pagination of large result sets.
43956 43957 43958 43959 43960 43961 43962 43963 43964 43965 43966 43967 43968 |
# File 'lib/aws-sdk-ec2/types.rb', line 43956 class GetCapacityManagerMetricDataRequest < Struct.new( :metric_names, :start_time, :end_time, :period, :group_by, :filter_by, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#metric_names ⇒ Array<String>
The names of the metrics to retrieve. Maximum of 10 metrics per request.
43956 43957 43958 43959 43960 43961 43962 43963 43964 43965 43966 43967 43968 |
# File 'lib/aws-sdk-ec2/types.rb', line 43956 class GetCapacityManagerMetricDataRequest < Struct.new( :metric_names, :start_time, :end_time, :period, :group_by, :filter_by, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results. Use this value in a subsequent call to retrieve additional data points.
43956 43957 43958 43959 43960 43961 43962 43963 43964 43965 43966 43967 43968 |
# File 'lib/aws-sdk-ec2/types.rb', line 43956 class GetCapacityManagerMetricDataRequest < Struct.new( :metric_names, :start_time, :end_time, :period, :group_by, :filter_by, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#period ⇒ Integer
The granularity, in seconds, of the returned data points.
43956 43957 43958 43959 43960 43961 43962 43963 43964 43965 43966 43967 43968 |
# File 'lib/aws-sdk-ec2/types.rb', line 43956 class GetCapacityManagerMetricDataRequest < Struct.new( :metric_names, :start_time, :end_time, :period, :group_by, :filter_by, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The start time for the metric data query, in ISO 8601 format. The time range (end time - start time) must be a multiple of the specified period.
43956 43957 43958 43959 43960 43961 43962 43963 43964 43965 43966 43967 43968 |
# File 'lib/aws-sdk-ec2/types.rb', line 43956 class GetCapacityManagerMetricDataRequest < Struct.new( :metric_names, :start_time, :end_time, :period, :group_by, :filter_by, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |