Class: Aws::EC2::Types::GetCapacityManagerMetricDimensionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


44553
44554
44555
44556
44557
44558
44559
44560
44561
44562
44563
44564
# File 'lib/aws-sdk-ec2/types.rb', line 44553

class GetCapacityManagerMetricDimensionsRequest < Struct.new(
  :group_by,
  :filter_by,
  :start_time,
  :end_time,
  :metric_names,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

The end time for the dimension query, in ISO 8601 format. Only dimensions with data in this time range will be returned.

Returns:

  • (Time)


44553
44554
44555
44556
44557
44558
44559
44560
44561
44562
44563
44564
# File 'lib/aws-sdk-ec2/types.rb', line 44553

class GetCapacityManagerMetricDimensionsRequest < Struct.new(
  :group_by,
  :filter_by,
  :start_time,
  :end_time,
  :metric_names,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filter_byArray<Types::CapacityManagerCondition>

Conditions to filter which dimension values are returned. Each filter specifies a dimension, comparison operator, and values to match against.



44553
44554
44555
44556
44557
44558
44559
44560
44561
44562
44563
44564
# File 'lib/aws-sdk-ec2/types.rb', line 44553

class GetCapacityManagerMetricDimensionsRequest < Struct.new(
  :group_by,
  :filter_by,
  :start_time,
  :end_time,
  :metric_names,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#group_byArray<String>

The dimensions to group by when retrieving available dimension values. This determines which dimension combinations are returned. Required parameter.

Returns:

  • (Array<String>)


44553
44554
44555
44556
44557
44558
44559
44560
44561
44562
44563
44564
# File 'lib/aws-sdk-ec2/types.rb', line 44553

class GetCapacityManagerMetricDimensionsRequest < Struct.new(
  :group_by,
  :filter_by,
  :start_time,
  :end_time,
  :metric_names,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of dimension combinations to return. Valid range is 1 to 1000. Use with NextToken for pagination.

Returns:

  • (Integer)


44553
44554
44555
44556
44557
44558
44559
44560
44561
44562
44563
44564
# File 'lib/aws-sdk-ec2/types.rb', line 44553

class GetCapacityManagerMetricDimensionsRequest < Struct.new(
  :group_by,
  :filter_by,
  :start_time,
  :end_time,
  :metric_names,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#metric_namesArray<String>

The metric names to use as an additional filter when retrieving dimensions. Only dimensions that have data for these metrics will be returned. Required parameter with maximum size of 1 for v1.

Returns:

  • (Array<String>)


44553
44554
44555
44556
44557
44558
44559
44560
44561
44562
44563
44564
# File 'lib/aws-sdk-ec2/types.rb', line 44553

class GetCapacityManagerMetricDimensionsRequest < Struct.new(
  :group_by,
  :filter_by,
  :start_time,
  :end_time,
  :metric_names,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results. Use this value in a subsequent call to retrieve additional dimension values.

Returns:

  • (String)


44553
44554
44555
44556
44557
44558
44559
44560
44561
44562
44563
44564
# File 'lib/aws-sdk-ec2/types.rb', line 44553

class GetCapacityManagerMetricDimensionsRequest < Struct.new(
  :group_by,
  :filter_by,
  :start_time,
  :end_time,
  :metric_names,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The start time for the dimension query, in ISO 8601 format. Only dimensions with data in this time range will be returned.

Returns:

  • (Time)


44553
44554
44555
44556
44557
44558
44559
44560
44561
44562
44563
44564
# File 'lib/aws-sdk-ec2/types.rb', line 44553

class GetCapacityManagerMetricDimensionsRequest < Struct.new(
  :group_by,
  :filter_by,
  :start_time,
  :end_time,
  :metric_names,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end