Class: Aws::EC2::Types::GetCapacityManagerMetricDimensionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetCapacityManagerMetricDimensionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#end_time ⇒ Time
The end time for the dimension query, in ISO 8601 format.
-
#filter_by ⇒ Array<Types::CapacityManagerCondition>
Conditions to filter which dimension values are returned.
-
#group_by ⇒ Array<String>
The dimensions to group by when retrieving available dimension values.
-
#max_results ⇒ Integer
The maximum number of dimension combinations to return.
-
#metric_names ⇒ Array<String>
The metric names to use as an additional filter when retrieving dimensions.
-
#next_token ⇒ String
The token for the next page of results.
-
#start_time ⇒ Time
The start time for the dimension query, in ISO 8601 format.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
43786 43787 43788 43789 43790 43791 43792 43793 43794 43795 43796 43797 |
# File 'lib/aws-sdk-ec2/types.rb', line 43786 class GetCapacityManagerMetricDimensionsRequest < Struct.new( :group_by, :filter_by, :start_time, :end_time, :metric_names, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
The end time for the dimension query, in ISO 8601 format. Only dimensions with data in this time range will be returned.
43786 43787 43788 43789 43790 43791 43792 43793 43794 43795 43796 43797 |
# File 'lib/aws-sdk-ec2/types.rb', line 43786 class GetCapacityManagerMetricDimensionsRequest < Struct.new( :group_by, :filter_by, :start_time, :end_time, :metric_names, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filter_by ⇒ Array<Types::CapacityManagerCondition>
Conditions to filter which dimension values are returned. Each filter specifies a dimension, comparison operator, and values to match against.
43786 43787 43788 43789 43790 43791 43792 43793 43794 43795 43796 43797 |
# File 'lib/aws-sdk-ec2/types.rb', line 43786 class GetCapacityManagerMetricDimensionsRequest < Struct.new( :group_by, :filter_by, :start_time, :end_time, :metric_names, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#group_by ⇒ Array<String>
The dimensions to group by when retrieving available dimension values. This determines which dimension combinations are returned. Required parameter.
43786 43787 43788 43789 43790 43791 43792 43793 43794 43795 43796 43797 |
# File 'lib/aws-sdk-ec2/types.rb', line 43786 class GetCapacityManagerMetricDimensionsRequest < Struct.new( :group_by, :filter_by, :start_time, :end_time, :metric_names, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of dimension combinations to return. Valid range is 1 to 1000. Use with NextToken for pagination.
43786 43787 43788 43789 43790 43791 43792 43793 43794 43795 43796 43797 |
# File 'lib/aws-sdk-ec2/types.rb', line 43786 class GetCapacityManagerMetricDimensionsRequest < Struct.new( :group_by, :filter_by, :start_time, :end_time, :metric_names, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#metric_names ⇒ Array<String>
The metric names to use as an additional filter when retrieving dimensions. Only dimensions that have data for these metrics will be returned. Required parameter with maximum size of 1 for v1.
43786 43787 43788 43789 43790 43791 43792 43793 43794 43795 43796 43797 |
# File 'lib/aws-sdk-ec2/types.rb', line 43786 class GetCapacityManagerMetricDimensionsRequest < Struct.new( :group_by, :filter_by, :start_time, :end_time, :metric_names, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results. Use this value in a subsequent call to retrieve additional dimension values.
43786 43787 43788 43789 43790 43791 43792 43793 43794 43795 43796 43797 |
# File 'lib/aws-sdk-ec2/types.rb', line 43786 class GetCapacityManagerMetricDimensionsRequest < Struct.new( :group_by, :filter_by, :start_time, :end_time, :metric_names, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The start time for the dimension query, in ISO 8601 format. Only dimensions with data in this time range will be returned.
43786 43787 43788 43789 43790 43791 43792 43793 43794 43795 43796 43797 |
# File 'lib/aws-sdk-ec2/types.rb', line 43786 class GetCapacityManagerMetricDimensionsRequest < Struct.new( :group_by, :filter_by, :start_time, :end_time, :metric_names, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |