Class: Aws::EC2::Types::GetCapacityReservationUsageRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_reservation_idString

The ID of the Capacity Reservation.

Returns:

  • (String)


44244
44245
44246
44247
44248
44249
44250
44251
# File 'lib/aws-sdk-ec2/types.rb', line 44244

class GetCapacityReservationUsageRequest < Struct.new(
  :capacity_reservation_id,
  :next_token,
  :max_results,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


44244
44245
44246
44247
44248
44249
44250
44251
# File 'lib/aws-sdk-ec2/types.rb', line 44244

class GetCapacityReservationUsageRequest < Struct.new(
  :capacity_reservation_id,
  :next_token,
  :max_results,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.

Returns:

  • (Integer)


44244
44245
44246
44247
44248
44249
44250
44251
# File 'lib/aws-sdk-ec2/types.rb', line 44244

class GetCapacityReservationUsageRequest < Struct.new(
  :capacity_reservation_id,
  :next_token,
  :max_results,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to use to retrieve the next page of results.

Returns:

  • (String)


44244
44245
44246
44247
44248
44249
44250
44251
# File 'lib/aws-sdk-ec2/types.rb', line 44244

class GetCapacityReservationUsageRequest < Struct.new(
  :capacity_reservation_id,
  :next_token,
  :max_results,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end