Class: Aws::EC2::Types::GetCoipPoolUsageResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetCoipPoolUsageResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#coip_address_usages ⇒ Array<Types::CoipAddressUsage>
Information about the address usage.
-
#coip_pool_id ⇒ String
The ID of the customer-owned address pool.
-
#local_gateway_route_table_id ⇒ String
The ID of the local gateway route table.
-
#next_token ⇒ String
The token to use to retrieve the next page of results.
Instance Attribute Details
#coip_address_usages ⇒ Array<Types::CoipAddressUsage>
Information about the address usage.
44580 44581 44582 44583 44584 44585 44586 44587 |
# File 'lib/aws-sdk-ec2/types.rb', line 44580 class GetCoipPoolUsageResult < Struct.new( :coip_pool_id, :coip_address_usages, :local_gateway_route_table_id, :next_token) SENSITIVE = [] include Aws::Structure end |
#coip_pool_id ⇒ String
The ID of the customer-owned address pool.
44580 44581 44582 44583 44584 44585 44586 44587 |
# File 'lib/aws-sdk-ec2/types.rb', line 44580 class GetCoipPoolUsageResult < Struct.new( :coip_pool_id, :coip_address_usages, :local_gateway_route_table_id, :next_token) SENSITIVE = [] include Aws::Structure end |
#local_gateway_route_table_id ⇒ String
The ID of the local gateway route table.
44580 44581 44582 44583 44584 44585 44586 44587 |
# File 'lib/aws-sdk-ec2/types.rb', line 44580 class GetCoipPoolUsageResult < Struct.new( :coip_pool_id, :coip_address_usages, :local_gateway_route_table_id, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to retrieve the next page of results. This value is
null when there are no more results to return.
44580 44581 44582 44583 44584 44585 44586 44587 |
# File 'lib/aws-sdk-ec2/types.rb', line 44580 class GetCoipPoolUsageResult < Struct.new( :coip_pool_id, :coip_address_usages, :local_gateway_route_table_id, :next_token) SENSITIVE = [] include Aws::Structure end |