Class: Aws::EC2::Types::GetConsoleOutputRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetConsoleOutputRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#instance_id ⇒ String
The ID of the instance.
-
#latest ⇒ Boolean
When enabled, retrieves the latest console output for the instance.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
46383 46384 46385 46386 46387 46388 46389 |
# File 'lib/aws-sdk-ec2/types.rb', line 46383 class GetConsoleOutputRequest < Struct.new( :instance_id, :latest, :dry_run) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the instance.
46383 46384 46385 46386 46387 46388 46389 |
# File 'lib/aws-sdk-ec2/types.rb', line 46383 class GetConsoleOutputRequest < Struct.new( :instance_id, :latest, :dry_run) SENSITIVE = [] include Aws::Structure end |
#latest ⇒ Boolean
When enabled, retrieves the latest console output for the instance.
Default: disabled (false)
46383 46384 46385 46386 46387 46388 46389 |
# File 'lib/aws-sdk-ec2/types.rb', line 46383 class GetConsoleOutputRequest < Struct.new( :instance_id, :latest, :dry_run) SENSITIVE = [] include Aws::Structure end |