Class: Aws::EC2::Types::GetConsoleOutputRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetConsoleOutputRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#instance_id ⇒ String
The ID of the instance.
-
#latest ⇒ Boolean
When enabled, retrieves the latest console output for the instance.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
44878 44879 44880 44881 44882 44883 44884 |
# File 'lib/aws-sdk-ec2/types.rb', line 44878 class GetConsoleOutputRequest < Struct.new( :instance_id, :latest, :dry_run) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the instance.
44878 44879 44880 44881 44882 44883 44884 |
# File 'lib/aws-sdk-ec2/types.rb', line 44878 class GetConsoleOutputRequest < Struct.new( :instance_id, :latest, :dry_run) SENSITIVE = [] include Aws::Structure end |
#latest ⇒ Boolean
When enabled, retrieves the latest console output for the instance.
Default: disabled (false)
44878 44879 44880 44881 44882 44883 44884 |
# File 'lib/aws-sdk-ec2/types.rb', line 44878 class GetConsoleOutputRequest < Struct.new( :instance_id, :latest, :dry_run) SENSITIVE = [] include Aws::Structure end |