Class: Aws::EC2::Types::GetConsoleOutputRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


44649
44650
44651
44652
44653
44654
44655
# File 'lib/aws-sdk-ec2/types.rb', line 44649

class GetConsoleOutputRequest < Struct.new(
  :instance_id,
  :latest,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The ID of the instance.

Returns:

  • (String)


44649
44650
44651
44652
44653
44654
44655
# File 'lib/aws-sdk-ec2/types.rb', line 44649

class GetConsoleOutputRequest < Struct.new(
  :instance_id,
  :latest,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#latestBoolean

When enabled, retrieves the latest console output for the instance.

Default: disabled (false)

Returns:

  • (Boolean)


44649
44650
44651
44652
44653
44654
44655
# File 'lib/aws-sdk-ec2/types.rb', line 44649

class GetConsoleOutputRequest < Struct.new(
  :instance_id,
  :latest,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end