Class: Aws::EC2::Types::GetConsoleScreenshotRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetConsoleScreenshotRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#instance_id ⇒ String
The ID of the instance.
-
#wake_up ⇒ Boolean
When set to
true, acts as keystroke input and wakes up an instance that's in standby or "sleep" mode.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
46432 46433 46434 46435 46436 46437 46438 |
# File 'lib/aws-sdk-ec2/types.rb', line 46432 class GetConsoleScreenshotRequest < Struct.new( :dry_run, :instance_id, :wake_up) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the instance.
46432 46433 46434 46435 46436 46437 46438 |
# File 'lib/aws-sdk-ec2/types.rb', line 46432 class GetConsoleScreenshotRequest < Struct.new( :dry_run, :instance_id, :wake_up) SENSITIVE = [] include Aws::Structure end |
#wake_up ⇒ Boolean
When set to true, acts as keystroke input and wakes up an instance
that's in standby or "sleep" mode.
46432 46433 46434 46435 46436 46437 46438 |
# File 'lib/aws-sdk-ec2/types.rb', line 46432 class GetConsoleScreenshotRequest < Struct.new( :dry_run, :instance_id, :wake_up) SENSITIVE = [] include Aws::Structure end |