Class: Aws::EC2::Types::GetConsoleScreenshotRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


43690
43691
43692
43693
43694
43695
43696
# File 'lib/aws-sdk-ec2/types.rb', line 43690

class GetConsoleScreenshotRequest < Struct.new(
  :dry_run,
  :instance_id,
  :wake_up)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The ID of the instance.

Returns:

  • (String)


43690
43691
43692
43693
43694
43695
43696
# File 'lib/aws-sdk-ec2/types.rb', line 43690

class GetConsoleScreenshotRequest < Struct.new(
  :dry_run,
  :instance_id,
  :wake_up)
  SENSITIVE = []
  include Aws::Structure
end

#wake_upBoolean

When set to ‘true`, acts as keystroke input and wakes up an instance that’s in standby or “sleep” mode.

Returns:

  • (Boolean)


43690
43691
43692
43693
43694
43695
43696
# File 'lib/aws-sdk-ec2/types.rb', line 43690

class GetConsoleScreenshotRequest < Struct.new(
  :dry_run,
  :instance_id,
  :wake_up)
  SENSITIVE = []
  include Aws::Structure
end