Class: Aws::EC2::Types::GetDeclarativePoliciesReportSummaryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


46036
46037
46038
46039
46040
46041
# File 'lib/aws-sdk-ec2/types.rb', line 46036

class GetDeclarativePoliciesReportSummaryRequest < Struct.new(
  :dry_run,
  :report_id)
  SENSITIVE = []
  include Aws::Structure
end

#report_idString

The ID of the report.

Returns:

  • (String)


46036
46037
46038
46039
46040
46041
# File 'lib/aws-sdk-ec2/types.rb', line 46036

class GetDeclarativePoliciesReportSummaryRequest < Struct.new(
  :dry_run,
  :report_id)
  SENSITIVE = []
  include Aws::Structure
end