Class: Aws::EC2::Types::GetDeclarativePoliciesReportSummaryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetDeclarativePoliciesReportSummaryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#report_id ⇒ String
The ID of the report.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
46036 46037 46038 46039 46040 46041 |
# File 'lib/aws-sdk-ec2/types.rb', line 46036 class GetDeclarativePoliciesReportSummaryRequest < Struct.new( :dry_run, :report_id) SENSITIVE = [] include Aws::Structure end |
#report_id ⇒ String
The ID of the report.
46036 46037 46038 46039 46040 46041 |
# File 'lib/aws-sdk-ec2/types.rb', line 46036 class GetDeclarativePoliciesReportSummaryRequest < Struct.new( :dry_run, :report_id) SENSITIVE = [] include Aws::Structure end |