Class: Aws::EC2::Types::GetDeclarativePoliciesReportSummaryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


44736
44737
44738
44739
44740
44741
# File 'lib/aws-sdk-ec2/types.rb', line 44736

class GetDeclarativePoliciesReportSummaryRequest < Struct.new(
  :dry_run,
  :report_id)
  SENSITIVE = []
  include Aws::Structure
end

#report_idString

The ID of the report.

Returns:

  • (String)


44736
44737
44738
44739
44740
44741
# File 'lib/aws-sdk-ec2/types.rb', line 44736

class GetDeclarativePoliciesReportSummaryRequest < Struct.new(
  :dry_run,
  :report_id)
  SENSITIVE = []
  include Aws::Structure
end