Class: Aws::EC2::Types::GetDeclarativePoliciesReportSummaryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


43728
43729
43730
43731
43732
43733
# File 'lib/aws-sdk-ec2/types.rb', line 43728

class GetDeclarativePoliciesReportSummaryRequest < Struct.new(
  :dry_run,
  :report_id)
  SENSITIVE = []
  include Aws::Structure
end

#report_idString

The ID of the report.

Returns:

  • (String)


43728
43729
43730
43731
43732
43733
# File 'lib/aws-sdk-ec2/types.rb', line 43728

class GetDeclarativePoliciesReportSummaryRequest < Struct.new(
  :dry_run,
  :report_id)
  SENSITIVE = []
  include Aws::Structure
end