Class: Aws::EC2::Types::GetDeclarativePoliciesReportSummaryResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attribute_summariesArray<Types::AttributeSummary>

The attributes described in the report.

Returns:



44777
44778
44779
44780
44781
44782
44783
44784
44785
44786
44787
44788
44789
# File 'lib/aws-sdk-ec2/types.rb', line 44777

class GetDeclarativePoliciesReportSummaryResult < Struct.new(
  :report_id,
  :s3_bucket,
  :s3_prefix,
  :target_id,
  :start_time,
  :end_time,
  :number_of_accounts,
  :number_of_failed_accounts,
  :attribute_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

The time when the report generation ended.

Returns:

  • (Time)


44777
44778
44779
44780
44781
44782
44783
44784
44785
44786
44787
44788
44789
# File 'lib/aws-sdk-ec2/types.rb', line 44777

class GetDeclarativePoliciesReportSummaryResult < Struct.new(
  :report_id,
  :s3_bucket,
  :s3_prefix,
  :target_id,
  :start_time,
  :end_time,
  :number_of_accounts,
  :number_of_failed_accounts,
  :attribute_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_accountsInteger

The total number of accounts associated with the specified targetId.

Returns:

  • (Integer)


44777
44778
44779
44780
44781
44782
44783
44784
44785
44786
44787
44788
44789
# File 'lib/aws-sdk-ec2/types.rb', line 44777

class GetDeclarativePoliciesReportSummaryResult < Struct.new(
  :report_id,
  :s3_bucket,
  :s3_prefix,
  :target_id,
  :start_time,
  :end_time,
  :number_of_accounts,
  :number_of_failed_accounts,
  :attribute_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_failed_accountsInteger

The number of accounts where attributes could not be retrieved in any Region.

Returns:

  • (Integer)


44777
44778
44779
44780
44781
44782
44783
44784
44785
44786
44787
44788
44789
# File 'lib/aws-sdk-ec2/types.rb', line 44777

class GetDeclarativePoliciesReportSummaryResult < Struct.new(
  :report_id,
  :s3_bucket,
  :s3_prefix,
  :target_id,
  :start_time,
  :end_time,
  :number_of_accounts,
  :number_of_failed_accounts,
  :attribute_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#report_idString

The ID of the report.

Returns:

  • (String)


44777
44778
44779
44780
44781
44782
44783
44784
44785
44786
44787
44788
44789
# File 'lib/aws-sdk-ec2/types.rb', line 44777

class GetDeclarativePoliciesReportSummaryResult < Struct.new(
  :report_id,
  :s3_bucket,
  :s3_prefix,
  :target_id,
  :start_time,
  :end_time,
  :number_of_accounts,
  :number_of_failed_accounts,
  :attribute_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#s3_bucketString

The name of the Amazon S3 bucket where the report is located.

Returns:

  • (String)


44777
44778
44779
44780
44781
44782
44783
44784
44785
44786
44787
44788
44789
# File 'lib/aws-sdk-ec2/types.rb', line 44777

class GetDeclarativePoliciesReportSummaryResult < Struct.new(
  :report_id,
  :s3_bucket,
  :s3_prefix,
  :target_id,
  :start_time,
  :end_time,
  :number_of_accounts,
  :number_of_failed_accounts,
  :attribute_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#s3_prefixString

The prefix for your S3 object.

Returns:

  • (String)


44777
44778
44779
44780
44781
44782
44783
44784
44785
44786
44787
44788
44789
# File 'lib/aws-sdk-ec2/types.rb', line 44777

class GetDeclarativePoliciesReportSummaryResult < Struct.new(
  :report_id,
  :s3_bucket,
  :s3_prefix,
  :target_id,
  :start_time,
  :end_time,
  :number_of_accounts,
  :number_of_failed_accounts,
  :attribute_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The time when the report generation started.

Returns:

  • (Time)


44777
44778
44779
44780
44781
44782
44783
44784
44785
44786
44787
44788
44789
# File 'lib/aws-sdk-ec2/types.rb', line 44777

class GetDeclarativePoliciesReportSummaryResult < Struct.new(
  :report_id,
  :s3_bucket,
  :s3_prefix,
  :target_id,
  :start_time,
  :end_time,
  :number_of_accounts,
  :number_of_failed_accounts,
  :attribute_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#target_idString

The root ID, organizational unit ID, or account ID.

Format:

  • For root: r-ab12

  • For OU: ou-ab12-cdef1234

  • For account: 123456789012

Returns:

  • (String)


44777
44778
44779
44780
44781
44782
44783
44784
44785
44786
44787
44788
44789
# File 'lib/aws-sdk-ec2/types.rb', line 44777

class GetDeclarativePoliciesReportSummaryResult < Struct.new(
  :report_id,
  :s3_bucket,
  :s3_prefix,
  :target_id,
  :start_time,
  :end_time,
  :number_of_accounts,
  :number_of_failed_accounts,
  :attribute_summaries)
  SENSITIVE = []
  include Aws::Structure
end