Class: Aws::EC2::Types::GetDefaultCreditSpecificationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetDefaultCreditSpecificationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#instance_family ⇒ String
The instance family.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
44625 44626 44627 44628 44629 44630 |
# File 'lib/aws-sdk-ec2/types.rb', line 44625 class GetDefaultCreditSpecificationRequest < Struct.new( :dry_run, :instance_family) SENSITIVE = [] include Aws::Structure end |
#instance_family ⇒ String
The instance family.
44625 44626 44627 44628 44629 44630 |
# File 'lib/aws-sdk-ec2/types.rb', line 44625 class GetDefaultCreditSpecificationRequest < Struct.new( :dry_run, :instance_family) SENSITIVE = [] include Aws::Structure end |