Class: Aws::EC2::Types::GetDefaultCreditSpecificationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


44543
44544
44545
44546
44547
44548
# File 'lib/aws-sdk-ec2/types.rb', line 44543

class GetDefaultCreditSpecificationRequest < Struct.new(
  :dry_run,
  :instance_family)
  SENSITIVE = []
  include Aws::Structure
end

#instance_familyString

The instance family.

Returns:

  • (String)


44543
44544
44545
44546
44547
44548
# File 'lib/aws-sdk-ec2/types.rb', line 44543

class GetDefaultCreditSpecificationRequest < Struct.new(
  :dry_run,
  :instance_family)
  SENSITIVE = []
  include Aws::Structure
end