Class: Aws::EC2::Types::GetDefaultCreditSpecificationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


44117
44118
44119
44120
44121
44122
# File 'lib/aws-sdk-ec2/types.rb', line 44117

class GetDefaultCreditSpecificationRequest < Struct.new(
  :dry_run,
  :instance_family)
  SENSITIVE = []
  include Aws::Structure
end

#instance_familyString

The instance family.

Returns:

  • (String)


44117
44118
44119
44120
44121
44122
# File 'lib/aws-sdk-ec2/types.rb', line 44117

class GetDefaultCreditSpecificationRequest < Struct.new(
  :dry_run,
  :instance_family)
  SENSITIVE = []
  include Aws::Structure
end