Class: Aws::EC2::Types::GetEbsEncryptionByDefaultRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetEbsEncryptionByDefaultRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
44229 44230 44231 44232 44233 |
# File 'lib/aws-sdk-ec2/types.rb', line 44229 class GetEbsEncryptionByDefaultRequest < Struct.new( :dry_run) SENSITIVE = [] include Aws::Structure end |