Class: Aws::EC2::Types::GetEnabledIpamPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetEnabledIpamPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
Instance Attribute Details
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
44713 44714 44715 44716 44717 |
# File 'lib/aws-sdk-ec2/types.rb', line 44713 class GetEnabledIpamPolicyRequest < Struct.new( :dry_run) SENSITIVE = [] include Aws::Structure end |