Class: Aws::EC2::Types::GetEnabledIpamPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


44268
44269
44270
44271
44272
# File 'lib/aws-sdk-ec2/types.rb', line 44268

class GetEnabledIpamPolicyRequest < Struct.new(
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end