Class: Aws::EC2::Types::GetFlowLogsIntegrationTemplateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetFlowLogsIntegrationTemplateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#config_delivery_s3_destination_arn ⇒ String
To store the CloudFormation template in Amazon S3, specify the location in Amazon S3.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#flow_log_id ⇒ String
The ID of the flow log.
-
#integrate_services ⇒ Types::IntegrateServices
Information about the service integration.
Instance Attribute Details
#config_delivery_s3_destination_arn ⇒ String
To store the CloudFormation template in Amazon S3, specify the location in Amazon S3.
45093 45094 45095 45096 45097 45098 45099 45100 |
# File 'lib/aws-sdk-ec2/types.rb', line 45093 class GetFlowLogsIntegrationTemplateRequest < Struct.new( :dry_run, :flow_log_id, :config_delivery_s3_destination_arn, :integrate_services) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
45093 45094 45095 45096 45097 45098 45099 45100 |
# File 'lib/aws-sdk-ec2/types.rb', line 45093 class GetFlowLogsIntegrationTemplateRequest < Struct.new( :dry_run, :flow_log_id, :config_delivery_s3_destination_arn, :integrate_services) SENSITIVE = [] include Aws::Structure end |
#flow_log_id ⇒ String
The ID of the flow log.
45093 45094 45095 45096 45097 45098 45099 45100 |
# File 'lib/aws-sdk-ec2/types.rb', line 45093 class GetFlowLogsIntegrationTemplateRequest < Struct.new( :dry_run, :flow_log_id, :config_delivery_s3_destination_arn, :integrate_services) SENSITIVE = [] include Aws::Structure end |
#integrate_services ⇒ Types::IntegrateServices
Information about the service integration.
45093 45094 45095 45096 45097 45098 45099 45100 |
# File 'lib/aws-sdk-ec2/types.rb', line 45093 class GetFlowLogsIntegrationTemplateRequest < Struct.new( :dry_run, :flow_log_id, :config_delivery_s3_destination_arn, :integrate_services) SENSITIVE = [] include Aws::Structure end |