Class: Aws::EC2::Types::GetFlowLogsIntegrationTemplateRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#config_delivery_s3_destination_arnString

To store the CloudFormation template in Amazon S3, specify the location in Amazon S3.

Returns:

  • (String)


44769
44770
44771
44772
44773
44774
44775
44776
# File 'lib/aws-sdk-ec2/types.rb', line 44769

class GetFlowLogsIntegrationTemplateRequest < Struct.new(
  :dry_run,
  :flow_log_id,
  :config_delivery_s3_destination_arn,
  :integrate_services)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


44769
44770
44771
44772
44773
44774
44775
44776
# File 'lib/aws-sdk-ec2/types.rb', line 44769

class GetFlowLogsIntegrationTemplateRequest < Struct.new(
  :dry_run,
  :flow_log_id,
  :config_delivery_s3_destination_arn,
  :integrate_services)
  SENSITIVE = []
  include Aws::Structure
end

#flow_log_idString

The ID of the flow log.

Returns:

  • (String)


44769
44770
44771
44772
44773
44774
44775
44776
# File 'lib/aws-sdk-ec2/types.rb', line 44769

class GetFlowLogsIntegrationTemplateRequest < Struct.new(
  :dry_run,
  :flow_log_id,
  :config_delivery_s3_destination_arn,
  :integrate_services)
  SENSITIVE = []
  include Aws::Structure
end

#integrate_servicesTypes::IntegrateServices

Information about the service integration.



44769
44770
44771
44772
44773
44774
44775
44776
# File 'lib/aws-sdk-ec2/types.rb', line 44769

class GetFlowLogsIntegrationTemplateRequest < Struct.new(
  :dry_run,
  :flow_log_id,
  :config_delivery_s3_destination_arn,
  :integrate_services)
  SENSITIVE = []
  include Aws::Structure
end