Class: Aws::EC2::Types::GetFlowLogsIntegrationTemplateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetFlowLogsIntegrationTemplateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#config_delivery_s3_destination_arn ⇒ String
To store the CloudFormation template in Amazon S3, specify the location in Amazon S3.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#flow_log_id ⇒ String
The ID of the flow log.
-
#integrate_services ⇒ Types::IntegrateServices
Information about the service integration.
Instance Attribute Details
#config_delivery_s3_destination_arn ⇒ String
To store the CloudFormation template in Amazon S3, specify the location in Amazon S3.
43948 43949 43950 43951 43952 43953 43954 43955 |
# File 'lib/aws-sdk-ec2/types.rb', line 43948 class GetFlowLogsIntegrationTemplateRequest < Struct.new( :dry_run, :flow_log_id, :config_delivery_s3_destination_arn, :integrate_services) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
43948 43949 43950 43951 43952 43953 43954 43955 |
# File 'lib/aws-sdk-ec2/types.rb', line 43948 class GetFlowLogsIntegrationTemplateRequest < Struct.new( :dry_run, :flow_log_id, :config_delivery_s3_destination_arn, :integrate_services) SENSITIVE = [] include Aws::Structure end |
#flow_log_id ⇒ String
The ID of the flow log.
43948 43949 43950 43951 43952 43953 43954 43955 |
# File 'lib/aws-sdk-ec2/types.rb', line 43948 class GetFlowLogsIntegrationTemplateRequest < Struct.new( :dry_run, :flow_log_id, :config_delivery_s3_destination_arn, :integrate_services) SENSITIVE = [] include Aws::Structure end |
#integrate_services ⇒ Types::IntegrateServices
Information about the service integration.
43948 43949 43950 43951 43952 43953 43954 43955 |
# File 'lib/aws-sdk-ec2/types.rb', line 43948 class GetFlowLogsIntegrationTemplateRequest < Struct.new( :dry_run, :flow_log_id, :config_delivery_s3_destination_arn, :integrate_services) SENSITIVE = [] include Aws::Structure end |