Class: Aws::EC2::Types::GetGroupsForCapacityReservationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_reservation_idString

The ID of the Capacity Reservation. If you specify a Capacity Reservation that is shared with you, the operation returns only Capacity Reservation groups that you own.

Returns:

  • (String)


45235
45236
45237
45238
45239
45240
45241
45242
# File 'lib/aws-sdk-ec2/types.rb', line 45235

class GetGroupsForCapacityReservationRequest < Struct.new(
  :capacity_reservation_id,
  :next_token,
  :max_results,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


45235
45236
45237
45238
45239
45240
45241
45242
# File 'lib/aws-sdk-ec2/types.rb', line 45235

class GetGroupsForCapacityReservationRequest < Struct.new(
  :capacity_reservation_id,
  :next_token,
  :max_results,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.

Returns:

  • (Integer)


45235
45236
45237
45238
45239
45240
45241
45242
# File 'lib/aws-sdk-ec2/types.rb', line 45235

class GetGroupsForCapacityReservationRequest < Struct.new(
  :capacity_reservation_id,
  :next_token,
  :max_results,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to use to retrieve the next page of results.

Returns:

  • (String)


45235
45236
45237
45238
45239
45240
45241
45242
# File 'lib/aws-sdk-ec2/types.rb', line 45235

class GetGroupsForCapacityReservationRequest < Struct.new(
  :capacity_reservation_id,
  :next_token,
  :max_results,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end