Class: Aws::EC2::Types::GetGroupsForCapacityReservationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetGroupsForCapacityReservationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_reservation_id ⇒ String
The ID of the Capacity Reservation.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token to use to retrieve the next page of results.
Instance Attribute Details
#capacity_reservation_id ⇒ String
The ID of the Capacity Reservation. If you specify a Capacity Reservation that is shared with you, the operation returns only Capacity Reservation groups that you own.
43384 43385 43386 43387 43388 43389 43390 43391 |
# File 'lib/aws-sdk-ec2/types.rb', line 43384 class GetGroupsForCapacityReservationRequest < Struct.new( :capacity_reservation_id, :next_token, :max_results, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
43384 43385 43386 43387 43388 43389 43390 43391 |
# File 'lib/aws-sdk-ec2/types.rb', line 43384 class GetGroupsForCapacityReservationRequest < Struct.new( :capacity_reservation_id, :next_token, :max_results, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination
43384 43385 43386 43387 43388 43389 43390 43391 |
# File 'lib/aws-sdk-ec2/types.rb', line 43384 class GetGroupsForCapacityReservationRequest < Struct.new( :capacity_reservation_id, :next_token, :max_results, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to retrieve the next page of results.
43384 43385 43386 43387 43388 43389 43390 43391 |
# File 'lib/aws-sdk-ec2/types.rb', line 43384 class GetGroupsForCapacityReservationRequest < Struct.new( :capacity_reservation_id, :next_token, :max_results, :dry_run) SENSITIVE = [] include Aws::Structure end |