Class: Aws::EC2::Types::GetImageAncestryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


45095
45096
45097
45098
45099
45100
# File 'lib/aws-sdk-ec2/types.rb', line 45095

class GetImageAncestryRequest < Struct.new(
  :image_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#image_idString

The ID of the AMI whose ancestry you want to trace.

Returns:

  • (String)


45095
45096
45097
45098
45099
45100
# File 'lib/aws-sdk-ec2/types.rb', line 45095

class GetImageAncestryRequest < Struct.new(
  :image_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end