Class: Aws::EC2::Types::GetImageAncestryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetImageAncestryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#image_id ⇒ String
The ID of the AMI whose ancestry you want to trace.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
44450 44451 44452 44453 44454 44455 |
# File 'lib/aws-sdk-ec2/types.rb', line 44450 class GetImageAncestryRequest < Struct.new( :image_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#image_id ⇒ String
The ID of the AMI whose ancestry you want to trace.
44450 44451 44452 44453 44454 44455 |
# File 'lib/aws-sdk-ec2/types.rb', line 44450 class GetImageAncestryRequest < Struct.new( :image_id, :dry_run) SENSITIVE = [] include Aws::Structure end |