Class: Aws::EC2::Types::GetImageBlockPublicAccessStateRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


45261
45262
45263
45264
45265
# File 'lib/aws-sdk-ec2/types.rb', line 45261

class GetImageBlockPublicAccessStateRequest < Struct.new(
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end