Class: Aws::EC2::Types::GetImageBlockPublicAccessStateRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


43429
43430
43431
43432
43433
# File 'lib/aws-sdk-ec2/types.rb', line 43429

class GetImageBlockPublicAccessStateRequest < Struct.new(
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end