Class: Aws::EC2::Types::GetInstanceMetadataDefaultsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


44884
44885
44886
44887
44888
# File 'lib/aws-sdk-ec2/types.rb', line 44884

class GetInstanceMetadataDefaultsRequest < Struct.new(
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end