Class: Aws::EC2::Types::GetInstanceMetadataDefaultsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetInstanceMetadataDefaultsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
44526 44527 44528 44529 44530 |
# File 'lib/aws-sdk-ec2/types.rb', line 44526 class GetInstanceMetadataDefaultsRequest < Struct.new( :dry_run) SENSITIVE = [] include Aws::Structure end |