Class: Aws::EC2::Types::GetInstanceTpmEkPubRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetInstanceTpmEkPubRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Specify this parameter to verify whether the request will succeed, without actually making the request.
-
#instance_id ⇒ String
The ID of the instance for which to get the public endorsement key.
-
#key_format ⇒ String
The required public endorsement key format.
-
#key_type ⇒ String
The required public endorsement key type.
Instance Attribute Details
#dry_run ⇒ Boolean
Specify this parameter to verify whether the request will succeed,
without actually making the request. If the request will succeed,
the response is DryRunOperation. Otherwise, the response is
UnauthorizedOperation.
45199 45200 45201 45202 45203 45204 45205 45206 |
# File 'lib/aws-sdk-ec2/types.rb', line 45199 class GetInstanceTpmEkPubRequest < Struct.new( :instance_id, :key_type, :key_format, :dry_run) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the instance for which to get the public endorsement key.
45199 45200 45201 45202 45203 45204 45205 45206 |
# File 'lib/aws-sdk-ec2/types.rb', line 45199 class GetInstanceTpmEkPubRequest < Struct.new( :instance_id, :key_type, :key_format, :dry_run) SENSITIVE = [] include Aws::Structure end |
#key_format ⇒ String
The required public endorsement key format. Specify der for a
DER-encoded public key that is compatible with OpenSSL. Specify
tpmt for a TPM 2.0 format that is compatible with tpm2-tools. The
returned key is base64 encoded.
45199 45200 45201 45202 45203 45204 45205 45206 |
# File 'lib/aws-sdk-ec2/types.rb', line 45199 class GetInstanceTpmEkPubRequest < Struct.new( :instance_id, :key_type, :key_format, :dry_run) SENSITIVE = [] include Aws::Structure end |
#key_type ⇒ String
The required public endorsement key type.
45199 45200 45201 45202 45203 45204 45205 45206 |
# File 'lib/aws-sdk-ec2/types.rb', line 45199 class GetInstanceTpmEkPubRequest < Struct.new( :instance_id, :key_type, :key_format, :dry_run) SENSITIVE = [] include Aws::Structure end |