Class: Aws::EC2::Types::GetInstanceTypesFromInstanceRequirementsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetInstanceTypesFromInstanceRequirementsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_types ⇒ Array<Types::InstanceTypeInfoFromInstanceRequirements>
The instance types with the specified instance attributes.
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
Instance Attribute Details
#instance_types ⇒ Array<Types::InstanceTypeInfoFromInstanceRequirements>
The instance types with the specified instance attributes.
46613 46614 46615 46616 46617 46618 |
# File 'lib/aws-sdk-ec2/types.rb', line 46613 class GetInstanceTypesFromInstanceRequirementsResult < Struct.new( :instance_types, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
46613 46614 46615 46616 46617 46618 |
# File 'lib/aws-sdk-ec2/types.rb', line 46613 class GetInstanceTypesFromInstanceRequirementsResult < Struct.new( :instance_types, :next_token) SENSITIVE = [] include Aws::Structure end |