Class: Aws::EC2::Types::GetInstanceTypesFromInstanceRequirementsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetInstanceTypesFromInstanceRequirementsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_types ⇒ Array<Types::InstanceTypeInfoFromInstanceRequirements>
The instance types with the specified instance attributes.
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
Instance Attribute Details
#instance_types ⇒ Array<Types::InstanceTypeInfoFromInstanceRequirements>
The instance types with the specified instance attributes.
45542 45543 45544 45545 45546 45547 |
# File 'lib/aws-sdk-ec2/types.rb', line 45542 class GetInstanceTypesFromInstanceRequirementsResult < Struct.new( :instance_types, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
45542 45543 45544 45545 45546 45547 |
# File 'lib/aws-sdk-ec2/types.rb', line 45542 class GetInstanceTypesFromInstanceRequirementsResult < Struct.new( :instance_types, :next_token) SENSITIVE = [] include Aws::Structure end |