Class: Aws::EC2::Types::GetInstanceUefiDataRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


47076
47077
47078
47079
47080
47081
# File 'lib/aws-sdk-ec2/types.rb', line 47076

class GetInstanceUefiDataRequest < Struct.new(
  :instance_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The ID of the instance from which to retrieve the UEFI data.

Returns:

  • (String)


47076
47077
47078
47079
47080
47081
# File 'lib/aws-sdk-ec2/types.rb', line 47076

class GetInstanceUefiDataRequest < Struct.new(
  :instance_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end