Class: Aws::EC2::Types::GetInstanceUefiDataRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


46633
46634
46635
46636
46637
46638
# File 'lib/aws-sdk-ec2/types.rb', line 46633

class GetInstanceUefiDataRequest < Struct.new(
  :instance_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The ID of the instance from which to retrieve the UEFI data.

Returns:

  • (String)


46633
46634
46635
46636
46637
46638
# File 'lib/aws-sdk-ec2/types.rb', line 46633

class GetInstanceUefiDataRequest < Struct.new(
  :instance_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end