Class: Aws::EC2::Types::GetInstanceUefiDataRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


45470
45471
45472
45473
45474
45475
# File 'lib/aws-sdk-ec2/types.rb', line 45470

class GetInstanceUefiDataRequest < Struct.new(
  :instance_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The ID of the instance from which to retrieve the UEFI data.

Returns:

  • (String)


45470
45471
45472
45473
45474
45475
# File 'lib/aws-sdk-ec2/types.rb', line 45470

class GetInstanceUefiDataRequest < Struct.new(
  :instance_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end