Class: Aws::EC2::Types::GetInstanceUefiDataRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetInstanceUefiDataRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#instance_id ⇒ String
The ID of the instance from which to retrieve the UEFI data.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
45058 45059 45060 45061 45062 45063 |
# File 'lib/aws-sdk-ec2/types.rb', line 45058 class GetInstanceUefiDataRequest < Struct.new( :instance_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the instance from which to retrieve the UEFI data.
45058 45059 45060 45061 45062 45063 |
# File 'lib/aws-sdk-ec2/types.rb', line 45058 class GetInstanceUefiDataRequest < Struct.new( :instance_id, :dry_run) SENSITIVE = [] include Aws::Structure end |