Class: Aws::EC2::Types::GetInstanceUefiDataResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetInstanceUefiDataResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The ID of the instance from which to retrieve the UEFI data.
-
#uefi_data ⇒ String
Base64 representation of the non-volatile UEFI variable store.
Instance Attribute Details
#instance_id ⇒ String
The ID of the instance from which to retrieve the UEFI data.
45157 45158 45159 45160 45161 45162 |
# File 'lib/aws-sdk-ec2/types.rb', line 45157 class GetInstanceUefiDataResult < Struct.new( :instance_id, :uefi_data) SENSITIVE = [] include Aws::Structure end |
#uefi_data ⇒ String
Base64 representation of the non-volatile UEFI variable store.
45157 45158 45159 45160 45161 45162 |
# File 'lib/aws-sdk-ec2/types.rb', line 45157 class GetInstanceUefiDataResult < Struct.new( :instance_id, :uefi_data) SENSITIVE = [] include Aws::Structure end |