Class: Aws::EC2::Types::GetLaunchTemplateDataRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


48333
48334
48335
48336
48337
48338
# File 'lib/aws-sdk-ec2/types.rb', line 48333

class GetLaunchTemplateDataRequest < Struct.new(
  :dry_run,
  :instance_id)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The ID of the instance.

Returns:

  • (String)


48333
48334
48335
48336
48337
48338
# File 'lib/aws-sdk-ec2/types.rb', line 48333

class GetLaunchTemplateDataRequest < Struct.new(
  :dry_run,
  :instance_id)
  SENSITIVE = []
  include Aws::Structure
end