Class: Aws::EC2::Types::GetLaunchTemplateDataRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


48321
48322
48323
48324
48325
48326
# File 'lib/aws-sdk-ec2/types.rb', line 48321

class GetLaunchTemplateDataRequest < Struct.new(
  :dry_run,
  :instance_id)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The ID of the instance.

Returns:

  • (String)


48321
48322
48323
48324
48325
48326
# File 'lib/aws-sdk-ec2/types.rb', line 48321

class GetLaunchTemplateDataRequest < Struct.new(
  :dry_run,
  :instance_id)
  SENSITIVE = []
  include Aws::Structure
end