Class: Aws::EC2::Types::GetLaunchTemplateDataRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


45892
45893
45894
45895
45896
45897
# File 'lib/aws-sdk-ec2/types.rb', line 45892

class GetLaunchTemplateDataRequest < Struct.new(
  :dry_run,
  :instance_id)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The ID of the instance.

Returns:

  • (String)


45892
45893
45894
45895
45896
45897
# File 'lib/aws-sdk-ec2/types.rb', line 45892

class GetLaunchTemplateDataRequest < Struct.new(
  :dry_run,
  :instance_id)
  SENSITIVE = []
  include Aws::Structure
end