Class: Aws::EC2::Types::GetLaunchTemplateDataRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetLaunchTemplateDataRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#instance_id ⇒ String
The ID of the instance.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
45623 45624 45625 45626 45627 45628 |
# File 'lib/aws-sdk-ec2/types.rb', line 45623 class GetLaunchTemplateDataRequest < Struct.new( :dry_run, :instance_id) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the instance.
45623 45624 45625 45626 45627 45628 |
# File 'lib/aws-sdk-ec2/types.rb', line 45623 class GetLaunchTemplateDataRequest < Struct.new( :dry_run, :instance_id) SENSITIVE = [] include Aws::Structure end |