Class: Aws::EC2::Types::GetLaunchTemplateDataRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


45510
45511
45512
45513
45514
45515
# File 'lib/aws-sdk-ec2/types.rb', line 45510

class GetLaunchTemplateDataRequest < Struct.new(
  :dry_run,
  :instance_id)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The ID of the instance.

Returns:

  • (String)


45510
45511
45512
45513
45514
45515
# File 'lib/aws-sdk-ec2/types.rb', line 45510

class GetLaunchTemplateDataRequest < Struct.new(
  :dry_run,
  :instance_id)
  SENSITIVE = []
  include Aws::Structure
end