Class: Aws::EC2::Types::GetManagedResourceVisibilityRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetManagedResourceVisibilityRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
46114 46115 46116 46117 46118 |
# File 'lib/aws-sdk-ec2/types.rb', line 46114 class GetManagedResourceVisibilityRequest < Struct.new( :dry_run) SENSITIVE = [] include Aws::Structure end |