Class: Aws::EC2::Types::GetNetworkInsightsAccessScopeAnalysisFindingsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetNetworkInsightsAccessScopeAnalysisFindingsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#network_insights_access_scope_analysis_id ⇒ String
The ID of the Network Access Scope analysis.
-
#next_token ⇒ String
The token for the next page of results.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
46479 46480 46481 46482 46483 46484 46485 46486 |
# File 'lib/aws-sdk-ec2/types.rb', line 46479 class GetNetworkInsightsAccessScopeAnalysisFindingsRequest < Struct.new( :network_insights_access_scope_analysis_id, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To
retrieve the remaining results, make another call with the returned
nextToken value.
46479 46480 46481 46482 46483 46484 46485 46486 |
# File 'lib/aws-sdk-ec2/types.rb', line 46479 class GetNetworkInsightsAccessScopeAnalysisFindingsRequest < Struct.new( :network_insights_access_scope_analysis_id, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#network_insights_access_scope_analysis_id ⇒ String
The ID of the Network Access Scope analysis.
46479 46480 46481 46482 46483 46484 46485 46486 |
# File 'lib/aws-sdk-ec2/types.rb', line 46479 class GetNetworkInsightsAccessScopeAnalysisFindingsRequest < Struct.new( :network_insights_access_scope_analysis_id, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
46479 46480 46481 46482 46483 46484 46485 46486 |
# File 'lib/aws-sdk-ec2/types.rb', line 46479 class GetNetworkInsightsAccessScopeAnalysisFindingsRequest < Struct.new( :network_insights_access_scope_analysis_id, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |