Class: Aws::EC2::Types::GetNetworkInsightsAccessScopeAnalysisFindingsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


45602
45603
45604
45605
45606
45607
45608
45609
# File 'lib/aws-sdk-ec2/types.rb', line 45602

class GetNetworkInsightsAccessScopeAnalysisFindingsRequest < Struct.new(
  :network_insights_access_scope_analysis_id,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.

Returns:

  • (Integer)


45602
45603
45604
45605
45606
45607
45608
45609
# File 'lib/aws-sdk-ec2/types.rb', line 45602

class GetNetworkInsightsAccessScopeAnalysisFindingsRequest < Struct.new(
  :network_insights_access_scope_analysis_id,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#network_insights_access_scope_analysis_idString

The ID of the Network Access Scope analysis.

Returns:

  • (String)


45602
45603
45604
45605
45606
45607
45608
45609
# File 'lib/aws-sdk-ec2/types.rb', line 45602

class GetNetworkInsightsAccessScopeAnalysisFindingsRequest < Struct.new(
  :network_insights_access_scope_analysis_id,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


45602
45603
45604
45605
45606
45607
45608
45609
# File 'lib/aws-sdk-ec2/types.rb', line 45602

class GetNetworkInsightsAccessScopeAnalysisFindingsRequest < Struct.new(
  :network_insights_access_scope_analysis_id,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end