Class: Aws::EC2::Types::GetNetworkInsightsAccessScopeAnalysisFindingsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetNetworkInsightsAccessScopeAnalysisFindingsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analysis_findings ⇒ Array<Types::AccessScopeAnalysisFinding>
The findings associated with Network Access Scope Analysis.
-
#analysis_status ⇒ String
The status of Network Access Scope Analysis.
-
#network_insights_access_scope_analysis_id ⇒ String
The ID of the Network Access Scope analysis.
-
#next_token ⇒ String
The token to use to retrieve the next page of results.
Instance Attribute Details
#analysis_findings ⇒ Array<Types::AccessScopeAnalysisFinding>
The findings associated with Network Access Scope Analysis.
46507 46508 46509 46510 46511 46512 46513 46514 |
# File 'lib/aws-sdk-ec2/types.rb', line 46507 class GetNetworkInsightsAccessScopeAnalysisFindingsResult < Struct.new( :network_insights_access_scope_analysis_id, :analysis_status, :analysis_findings, :next_token) SENSITIVE = [] include Aws::Structure end |
#analysis_status ⇒ String
The status of Network Access Scope Analysis.
46507 46508 46509 46510 46511 46512 46513 46514 |
# File 'lib/aws-sdk-ec2/types.rb', line 46507 class GetNetworkInsightsAccessScopeAnalysisFindingsResult < Struct.new( :network_insights_access_scope_analysis_id, :analysis_status, :analysis_findings, :next_token) SENSITIVE = [] include Aws::Structure end |
#network_insights_access_scope_analysis_id ⇒ String
The ID of the Network Access Scope analysis.
46507 46508 46509 46510 46511 46512 46513 46514 |
# File 'lib/aws-sdk-ec2/types.rb', line 46507 class GetNetworkInsightsAccessScopeAnalysisFindingsResult < Struct.new( :network_insights_access_scope_analysis_id, :analysis_status, :analysis_findings, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to retrieve the next page of results. This value is
null when there are no more results to return.
46507 46508 46509 46510 46511 46512 46513 46514 |
# File 'lib/aws-sdk-ec2/types.rb', line 46507 class GetNetworkInsightsAccessScopeAnalysisFindingsResult < Struct.new( :network_insights_access_scope_analysis_id, :analysis_status, :analysis_findings, :next_token) SENSITIVE = [] include Aws::Structure end |