Class: Aws::EC2::Types::GetNetworkInsightsAccessScopeContentRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


46199
46200
46201
46202
46203
46204
# File 'lib/aws-sdk-ec2/types.rb', line 46199

class GetNetworkInsightsAccessScopeContentRequest < Struct.new(
  :network_insights_access_scope_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#network_insights_access_scope_idString

The ID of the Network Access Scope.

Returns:

  • (String)


46199
46200
46201
46202
46203
46204
# File 'lib/aws-sdk-ec2/types.rb', line 46199

class GetNetworkInsightsAccessScopeContentRequest < Struct.new(
  :network_insights_access_scope_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end