Class: Aws::EC2::Types::GetNetworkInsightsAccessScopeContentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetNetworkInsightsAccessScopeContentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#network_insights_access_scope_id ⇒ String
The ID of the Network Access Scope.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
46117 46118 46119 46120 46121 46122 |
# File 'lib/aws-sdk-ec2/types.rb', line 46117 class GetNetworkInsightsAccessScopeContentRequest < Struct.new( :network_insights_access_scope_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#network_insights_access_scope_id ⇒ String
The ID of the Network Access Scope.
46117 46118 46119 46120 46121 46122 |
# File 'lib/aws-sdk-ec2/types.rb', line 46117 class GetNetworkInsightsAccessScopeContentRequest < Struct.new( :network_insights_access_scope_id, :dry_run) SENSITIVE = [] include Aws::Structure end |