Class: Aws::EC2::Types::GetPasswordDataRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


45880
45881
45882
45883
45884
45885
# File 'lib/aws-sdk-ec2/types.rb', line 45880

class GetPasswordDataRequest < Struct.new(
  :instance_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The ID of the Windows instance.

Returns:

  • (String)


45880
45881
45882
45883
45884
45885
# File 'lib/aws-sdk-ec2/types.rb', line 45880

class GetPasswordDataRequest < Struct.new(
  :instance_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end