Class: Aws::EC2::Types::GetPasswordDataRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetPasswordDataRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#instance_id ⇒ String
The ID of the Windows instance.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
45377 45378 45379 45380 45381 45382 |
# File 'lib/aws-sdk-ec2/types.rb', line 45377 class GetPasswordDataRequest < Struct.new( :instance_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the Windows instance.
45377 45378 45379 45380 45381 45382 |
# File 'lib/aws-sdk-ec2/types.rb', line 45377 class GetPasswordDataRequest < Struct.new( :instance_id, :dry_run) SENSITIVE = [] include Aws::Structure end |