Class: Aws::EC2::Types::GetReservedInstancesExchangeQuoteRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for GetReservedInstanceExchangeQuote.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


46187
46188
46189
46190
46191
46192
46193
# File 'lib/aws-sdk-ec2/types.rb', line 46187

class GetReservedInstancesExchangeQuoteRequest < Struct.new(
  :dry_run,
  :reserved_instance_ids,
  :target_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#reserved_instance_idsArray<String>

The IDs of the Convertible Reserved Instances to exchange.

Returns:

  • (Array<String>)


46187
46188
46189
46190
46191
46192
46193
# File 'lib/aws-sdk-ec2/types.rb', line 46187

class GetReservedInstancesExchangeQuoteRequest < Struct.new(
  :dry_run,
  :reserved_instance_ids,
  :target_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#target_configurationsArray<Types::TargetConfigurationRequest>

The configuration of the target Convertible Reserved Instance to exchange for your current Convertible Reserved Instances.



46187
46188
46189
46190
46191
46192
46193
# File 'lib/aws-sdk-ec2/types.rb', line 46187

class GetReservedInstancesExchangeQuoteRequest < Struct.new(
  :dry_run,
  :reserved_instance_ids,
  :target_configurations)
  SENSITIVE = []
  include Aws::Structure
end