Class: Aws::EC2::Types::GetReservedInstancesExchangeQuoteRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetReservedInstancesExchangeQuoteRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for GetReservedInstanceExchangeQuote.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#reserved_instance_ids ⇒ Array<String>
The IDs of the Convertible Reserved Instances to exchange.
-
#target_configurations ⇒ Array<Types::TargetConfigurationRequest>
The configuration of the target Convertible Reserved Instance to exchange for your current Convertible Reserved Instances.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
45817 45818 45819 45820 45821 45822 45823 |
# File 'lib/aws-sdk-ec2/types.rb', line 45817 class GetReservedInstancesExchangeQuoteRequest < Struct.new( :dry_run, :reserved_instance_ids, :target_configurations) SENSITIVE = [] include Aws::Structure end |
#reserved_instance_ids ⇒ Array<String>
The IDs of the Convertible Reserved Instances to exchange.
45817 45818 45819 45820 45821 45822 45823 |
# File 'lib/aws-sdk-ec2/types.rb', line 45817 class GetReservedInstancesExchangeQuoteRequest < Struct.new( :dry_run, :reserved_instance_ids, :target_configurations) SENSITIVE = [] include Aws::Structure end |
#target_configurations ⇒ Array<Types::TargetConfigurationRequest>
The configuration of the target Convertible Reserved Instance to exchange for your current Convertible Reserved Instances.
45817 45818 45819 45820 45821 45822 45823 |
# File 'lib/aws-sdk-ec2/types.rb', line 45817 class GetReservedInstancesExchangeQuoteRequest < Struct.new( :dry_run, :reserved_instance_ids, :target_configurations) SENSITIVE = [] include Aws::Structure end |