Class: Aws::EC2::Types::GetRouteServerAssociationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


45900
45901
45902
45903
45904
45905
# File 'lib/aws-sdk-ec2/types.rb', line 45900

class GetRouteServerAssociationsRequest < Struct.new(
  :route_server_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#route_server_idString

The ID of the route server for which to get association information.

Returns:

  • (String)


45900
45901
45902
45903
45904
45905
# File 'lib/aws-sdk-ec2/types.rb', line 45900

class GetRouteServerAssociationsRequest < Struct.new(
  :route_server_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end