Class: Aws::EC2::Types::GetRouteServerPropagationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


46723
46724
46725
46726
46727
46728
46729
# File 'lib/aws-sdk-ec2/types.rb', line 46723

class GetRouteServerPropagationsRequest < Struct.new(
  :route_server_id,
  :route_table_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#route_server_idString

The ID of the route server for which to get propagation information.

Returns:

  • (String)


46723
46724
46725
46726
46727
46728
46729
# File 'lib/aws-sdk-ec2/types.rb', line 46723

class GetRouteServerPropagationsRequest < Struct.new(
  :route_server_id,
  :route_table_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#route_table_idString

The ID of the route table for which to get propagation information.

Returns:

  • (String)


46723
46724
46725
46726
46727
46728
46729
# File 'lib/aws-sdk-ec2/types.rb', line 46723

class GetRouteServerPropagationsRequest < Struct.new(
  :route_server_id,
  :route_table_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end