Class: Aws::EC2::Types::GetRouteServerPropagationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetRouteServerPropagationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#route_server_id ⇒ String
The ID of the route server for which to get propagation information.
-
#route_table_id ⇒ String
The ID of the route table for which to get propagation information.
Instance Attribute Details
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
46393 46394 46395 46396 46397 46398 46399 |
# File 'lib/aws-sdk-ec2/types.rb', line 46393 class GetRouteServerPropagationsRequest < Struct.new( :route_server_id, :route_table_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#route_server_id ⇒ String
The ID of the route server for which to get propagation information.
46393 46394 46395 46396 46397 46398 46399 |
# File 'lib/aws-sdk-ec2/types.rb', line 46393 class GetRouteServerPropagationsRequest < Struct.new( :route_server_id, :route_table_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#route_table_id ⇒ String
The ID of the route table for which to get propagation information.
46393 46394 46395 46396 46397 46398 46399 |
# File 'lib/aws-sdk-ec2/types.rb', line 46393 class GetRouteServerPropagationsRequest < Struct.new( :route_server_id, :route_table_id, :dry_run) SENSITIVE = [] include Aws::Structure end |