Class: Aws::EC2::Types::GetRouteServerRoutingDatabaseRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


48799
48800
48801
48802
48803
48804
48805
48806
48807
# File 'lib/aws-sdk-ec2/types.rb', line 48799

class GetRouteServerRoutingDatabaseRequest < Struct.new(
  :route_server_id,
  :next_token,
  :max_results,
  :dry_run,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

Filters to apply to the routing database query.

Returns:



48799
48800
48801
48802
48803
48804
48805
48806
48807
# File 'lib/aws-sdk-ec2/types.rb', line 48799

class GetRouteServerRoutingDatabaseRequest < Struct.new(
  :route_server_id,
  :next_token,
  :max_results,
  :dry_run,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of routing database entries to return in a single response.

Returns:

  • (Integer)


48799
48800
48801
48802
48803
48804
48805
48806
48807
# File 'lib/aws-sdk-ec2/types.rb', line 48799

class GetRouteServerRoutingDatabaseRequest < Struct.new(
  :route_server_id,
  :next_token,
  :max_results,
  :dry_run,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


48799
48800
48801
48802
48803
48804
48805
48806
48807
# File 'lib/aws-sdk-ec2/types.rb', line 48799

class GetRouteServerRoutingDatabaseRequest < Struct.new(
  :route_server_id,
  :next_token,
  :max_results,
  :dry_run,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#route_server_idString

The ID of the route server for which to get the routing database.

Returns:

  • (String)


48799
48800
48801
48802
48803
48804
48805
48806
48807
# File 'lib/aws-sdk-ec2/types.rb', line 48799

class GetRouteServerRoutingDatabaseRequest < Struct.new(
  :route_server_id,
  :next_token,
  :max_results,
  :dry_run,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end