Class: Aws::EC2::Types::GetRouteServerRoutingDatabaseRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetRouteServerRoutingDatabaseRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#filters ⇒ Array<Types::Filter>
Filters to apply to the routing database query.
-
#max_results ⇒ Integer
The maximum number of routing database entries to return in a single response.
-
#next_token ⇒ String
The token for the next page of results.
-
#route_server_id ⇒ String
The ID of the route server for which to get the routing database.
Instance Attribute Details
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action
without actually making the request and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
46619 46620 46621 46622 46623 46624 46625 46626 46627 |
# File 'lib/aws-sdk-ec2/types.rb', line 46619 class GetRouteServerRoutingDatabaseRequest < Struct.new( :route_server_id, :next_token, :max_results, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
Filters to apply to the routing database query.
46619 46620 46621 46622 46623 46624 46625 46626 46627 |
# File 'lib/aws-sdk-ec2/types.rb', line 46619 class GetRouteServerRoutingDatabaseRequest < Struct.new( :route_server_id, :next_token, :max_results, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of routing database entries to return in a single response.
46619 46620 46621 46622 46623 46624 46625 46626 46627 |
# File 'lib/aws-sdk-ec2/types.rb', line 46619 class GetRouteServerRoutingDatabaseRequest < Struct.new( :route_server_id, :next_token, :max_results, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
46619 46620 46621 46622 46623 46624 46625 46626 46627 |
# File 'lib/aws-sdk-ec2/types.rb', line 46619 class GetRouteServerRoutingDatabaseRequest < Struct.new( :route_server_id, :next_token, :max_results, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |
#route_server_id ⇒ String
The ID of the route server for which to get the routing database.
46619 46620 46621 46622 46623 46624 46625 46626 46627 |
# File 'lib/aws-sdk-ec2/types.rb', line 46619 class GetRouteServerRoutingDatabaseRequest < Struct.new( :route_server_id, :next_token, :max_results, :dry_run, :filters) SENSITIVE = [] include Aws::Structure end |