Class: Aws::EC2::Types::GetRouteServerRoutingDatabaseRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


45586
45587
45588
45589
45590
45591
45592
45593
45594
# File 'lib/aws-sdk-ec2/types.rb', line 45586

class GetRouteServerRoutingDatabaseRequest < Struct.new(
  :route_server_id,
  :next_token,
  :max_results,
  :dry_run,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

Filters to apply to the routing database query.

Returns:



45586
45587
45588
45589
45590
45591
45592
45593
45594
# File 'lib/aws-sdk-ec2/types.rb', line 45586

class GetRouteServerRoutingDatabaseRequest < Struct.new(
  :route_server_id,
  :next_token,
  :max_results,
  :dry_run,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of routing database entries to return in a single response.

Returns:

  • (Integer)


45586
45587
45588
45589
45590
45591
45592
45593
45594
# File 'lib/aws-sdk-ec2/types.rb', line 45586

class GetRouteServerRoutingDatabaseRequest < Struct.new(
  :route_server_id,
  :next_token,
  :max_results,
  :dry_run,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


45586
45587
45588
45589
45590
45591
45592
45593
45594
# File 'lib/aws-sdk-ec2/types.rb', line 45586

class GetRouteServerRoutingDatabaseRequest < Struct.new(
  :route_server_id,
  :next_token,
  :max_results,
  :dry_run,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#route_server_idString

The ID of the route server for which to get the routing database.

Returns:

  • (String)


45586
45587
45588
45589
45590
45591
45592
45593
45594
# File 'lib/aws-sdk-ec2/types.rb', line 45586

class GetRouteServerRoutingDatabaseRequest < Struct.new(
  :route_server_id,
  :next_token,
  :max_results,
  :dry_run,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end