Class: Aws::EC2::Types::GetRouteServerRoutingDatabaseResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetRouteServerRoutingDatabaseResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#are_routes_persisted ⇒ Boolean
Indicates whether routes are being persisted in the routing database.
-
#next_token ⇒ String
The token to use to retrieve the next page of results.
-
#routes ⇒ Array<Types::RouteServerRoute>
The collection of routes in the route server's routing database.
Instance Attribute Details
#are_routes_persisted ⇒ Boolean
Indicates whether routes are being persisted in the routing database.
48804 48805 48806 48807 48808 48809 48810 |
# File 'lib/aws-sdk-ec2/types.rb', line 48804 class GetRouteServerRoutingDatabaseResult < Struct.new( :are_routes_persisted, :routes, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to retrieve the next page of results. This value is
null when there are no more results to return.
48804 48805 48806 48807 48808 48809 48810 |
# File 'lib/aws-sdk-ec2/types.rb', line 48804 class GetRouteServerRoutingDatabaseResult < Struct.new( :are_routes_persisted, :routes, :next_token) SENSITIVE = [] include Aws::Structure end |
#routes ⇒ Array<Types::RouteServerRoute>
The collection of routes in the route server's routing database.
48804 48805 48806 48807 48808 48809 48810 |
# File 'lib/aws-sdk-ec2/types.rb', line 48804 class GetRouteServerRoutingDatabaseResult < Struct.new( :are_routes_persisted, :routes, :next_token) SENSITIVE = [] include Aws::Structure end |