Class: Aws::EC2::Types::GetRouteServerRoutingDatabaseResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#are_routes_persistedBoolean

Indicates whether routes are being persisted in the routing database.

Returns:

  • (Boolean)


44921
44922
44923
44924
44925
44926
44927
# File 'lib/aws-sdk-ec2/types.rb', line 44921

class GetRouteServerRoutingDatabaseResult < Struct.new(
  :are_routes_persisted,
  :routes,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to use to retrieve the next page of results. This value is ‘null` when there are no more results to return.

Returns:

  • (String)


44921
44922
44923
44924
44925
44926
44927
# File 'lib/aws-sdk-ec2/types.rb', line 44921

class GetRouteServerRoutingDatabaseResult < Struct.new(
  :are_routes_persisted,
  :routes,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#routesArray<Types::RouteServerRoute>

The collection of routes in the route server’s routing database.

Returns:



44921
44922
44923
44924
44925
44926
44927
# File 'lib/aws-sdk-ec2/types.rb', line 44921

class GetRouteServerRoutingDatabaseResult < Struct.new(
  :are_routes_persisted,
  :routes,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end