Class: Aws::EC2::Types::GetSecurityGroupsForVpcRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetSecurityGroupsForVpcRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The filters.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token returned from a previous paginated request.
-
#vpc_id ⇒ String
The VPC ID where the security group can be used.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
46519 46520 46521 46522 46523 46524 46525 46526 46527 |
# File 'lib/aws-sdk-ec2/types.rb', line 46519 class GetSecurityGroupsForVpcRequest < Struct.new( :vpc_id, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters. If using multiple filters, the results include security groups which match all filters.
-
‘group-id`: The security group ID.
-
‘description`: The security group’s description.
-
‘group-name`: The security group name.
-
‘owner-id`: The security group owner ID.
-
‘primary-vpc-id`: The VPC ID in which the security group was created.
46519 46520 46521 46522 46523 46524 46525 46526 46527 |
# File 'lib/aws-sdk-ec2/types.rb', line 46519 class GetSecurityGroupsForVpcRequest < Struct.new( :vpc_id, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination
46519 46520 46521 46522 46523 46524 46525 46526 46527 |
# File 'lib/aws-sdk-ec2/types.rb', line 46519 class GetSecurityGroupsForVpcRequest < Struct.new( :vpc_id, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
46519 46520 46521 46522 46523 46524 46525 46526 46527 |
# File 'lib/aws-sdk-ec2/types.rb', line 46519 class GetSecurityGroupsForVpcRequest < Struct.new( :vpc_id, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The VPC ID where the security group can be used.
46519 46520 46521 46522 46523 46524 46525 46526 46527 |
# File 'lib/aws-sdk-ec2/types.rb', line 46519 class GetSecurityGroupsForVpcRequest < Struct.new( :vpc_id, :next_token, :max_results, :filters, :dry_run) SENSITIVE = [] include Aws::Structure end |