Class: Aws::EC2::Types::GetSecurityGroupsForVpcRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


46055
46056
46057
46058
46059
46060
46061
46062
46063
# File 'lib/aws-sdk-ec2/types.rb', line 46055

class GetSecurityGroupsForVpcRequest < Struct.new(
  :vpc_id,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters. If using multiple filters, the results include security groups which match all filters.

  • ‘group-id`: The security group ID.

  • ‘description`: The security group’s description.

  • ‘group-name`: The security group name.

  • ‘owner-id`: The security group owner ID.

  • ‘primary-vpc-id`: The VPC ID in which the security group was created.

Returns:



46055
46056
46057
46058
46059
46060
46061
46062
46063
# File 'lib/aws-sdk-ec2/types.rb', line 46055

class GetSecurityGroupsForVpcRequest < Struct.new(
  :vpc_id,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination

Returns:

  • (Integer)


46055
46056
46057
46058
46059
46060
46061
46062
46063
# File 'lib/aws-sdk-ec2/types.rb', line 46055

class GetSecurityGroupsForVpcRequest < Struct.new(
  :vpc_id,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Returns:

  • (String)


46055
46056
46057
46058
46059
46060
46061
46062
46063
# File 'lib/aws-sdk-ec2/types.rb', line 46055

class GetSecurityGroupsForVpcRequest < Struct.new(
  :vpc_id,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The VPC ID where the security group can be used.

Returns:

  • (String)


46055
46056
46057
46058
46059
46060
46061
46062
46063
# File 'lib/aws-sdk-ec2/types.rb', line 46055

class GetSecurityGroupsForVpcRequest < Struct.new(
  :vpc_id,
  :next_token,
  :max_results,
  :filters,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end