Class: Aws::EC2::Types::GetSecurityGroupsForVpcResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetSecurityGroupsForVpcResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#security_group_for_vpcs ⇒ Array<Types::SecurityGroupForVpc>
The security group that can be used by interfaces in the VPC.
Instance Attribute Details
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
48033 48034 48035 48036 48037 48038 |
# File 'lib/aws-sdk-ec2/types.rb', line 48033 class GetSecurityGroupsForVpcResult < Struct.new( :next_token, :security_group_for_vpcs) SENSITIVE = [] include Aws::Structure end |
#security_group_for_vpcs ⇒ Array<Types::SecurityGroupForVpc>
The security group that can be used by interfaces in the VPC.
48033 48034 48035 48036 48037 48038 |
# File 'lib/aws-sdk-ec2/types.rb', line 48033 class GetSecurityGroupsForVpcResult < Struct.new( :next_token, :security_group_for_vpcs) SENSITIVE = [] include Aws::Structure end |