Class: Aws::EC2::Types::GetSerialConsoleAccessStatusResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetSerialConsoleAccessStatusResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#managed_by ⇒ String
The entity that manages access to the serial console.
-
#serial_console_access_enabled ⇒ Boolean
If
true, access to the EC2 serial console of all instances is enabled for your account.
Instance Attribute Details
#managed_by ⇒ String
The entity that manages access to the serial console. Possible values include:
-
account- Access is managed by the account. -
declarative-policy- Access is managed by a declarative policy and can't be modified by the account.
47002 47003 47004 47005 47006 47007 |
# File 'lib/aws-sdk-ec2/types.rb', line 47002 class GetSerialConsoleAccessStatusResult < Struct.new( :serial_console_access_enabled, :managed_by) SENSITIVE = [] include Aws::Structure end |
#serial_console_access_enabled ⇒ Boolean
If true, access to the EC2 serial console of all instances is
enabled for your account. If false, access to the EC2 serial
console of all instances is disabled for your account.
47002 47003 47004 47005 47006 47007 |
# File 'lib/aws-sdk-ec2/types.rb', line 47002 class GetSerialConsoleAccessStatusResult < Struct.new( :serial_console_access_enabled, :managed_by) SENSITIVE = [] include Aws::Structure end |