Class: Aws::EC2::Types::GetSnapshotBlockPublicAccessStateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetSnapshotBlockPublicAccessStateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
46502 46503 46504 46505 46506 |
# File 'lib/aws-sdk-ec2/types.rb', line 46502 class GetSnapshotBlockPublicAccessStateRequest < Struct.new( :dry_run) SENSITIVE = [] include Aws::Structure end |