Class: Aws::EC2::Types::GetSubnetCidrReservationsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetSubnetCidrReservationsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to use to retrieve the next page of results.
-
#subnet_ipv_4_cidr_reservations ⇒ Array<Types::SubnetCidrReservation>
Information about the IPv4 subnet CIDR reservations.
-
#subnet_ipv_6_cidr_reservations ⇒ Array<Types::SubnetCidrReservation>
Information about the IPv6 subnet CIDR reservations.
Instance Attribute Details
#next_token ⇒ String
The token to use to retrieve the next page of results. This value is
null when there are no more results to return.
46980 46981 46982 46983 46984 46985 46986 |
# File 'lib/aws-sdk-ec2/types.rb', line 46980 class GetSubnetCidrReservationsResult < Struct.new( :subnet_ipv_4_cidr_reservations, :subnet_ipv_6_cidr_reservations, :next_token) SENSITIVE = [] include Aws::Structure end |
#subnet_ipv_4_cidr_reservations ⇒ Array<Types::SubnetCidrReservation>
Information about the IPv4 subnet CIDR reservations.
46980 46981 46982 46983 46984 46985 46986 |
# File 'lib/aws-sdk-ec2/types.rb', line 46980 class GetSubnetCidrReservationsResult < Struct.new( :subnet_ipv_4_cidr_reservations, :subnet_ipv_6_cidr_reservations, :next_token) SENSITIVE = [] include Aws::Structure end |
#subnet_ipv_6_cidr_reservations ⇒ Array<Types::SubnetCidrReservation>
Information about the IPv6 subnet CIDR reservations.
46980 46981 46982 46983 46984 46985 46986 |
# File 'lib/aws-sdk-ec2/types.rb', line 46980 class GetSubnetCidrReservationsResult < Struct.new( :subnet_ipv_4_cidr_reservations, :subnet_ipv_6_cidr_reservations, :next_token) SENSITIVE = [] include Aws::Structure end |