Class: Aws::EC2::Types::GetTransitGatewayAttachmentPropagationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetTransitGatewayAttachmentPropagationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
-
#transit_gateway_attachment_id ⇒ String
The ID of the attachment.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
49215 49216 49217 49218 49219 49220 49221 49222 49223 |
# File 'lib/aws-sdk-ec2/types.rb', line 49215 class GetTransitGatewayAttachmentPropagationsRequest < Struct.new( :transit_gateway_attachment_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters. The possible values are:
transit-gateway-route-table-id- The ID of the transit gateway route table.
^
49215 49216 49217 49218 49219 49220 49221 49222 49223 |
# File 'lib/aws-sdk-ec2/types.rb', line 49215 class GetTransitGatewayAttachmentPropagationsRequest < Struct.new( :transit_gateway_attachment_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To
retrieve the remaining results, make another call with the returned
nextToken value.
49215 49216 49217 49218 49219 49220 49221 49222 49223 |
# File 'lib/aws-sdk-ec2/types.rb', line 49215 class GetTransitGatewayAttachmentPropagationsRequest < Struct.new( :transit_gateway_attachment_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
49215 49216 49217 49218 49219 49220 49221 49222 49223 |
# File 'lib/aws-sdk-ec2/types.rb', line 49215 class GetTransitGatewayAttachmentPropagationsRequest < Struct.new( :transit_gateway_attachment_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_attachment_id ⇒ String
The ID of the attachment.
49215 49216 49217 49218 49219 49220 49221 49222 49223 |
# File 'lib/aws-sdk-ec2/types.rb', line 49215 class GetTransitGatewayAttachmentPropagationsRequest < Struct.new( :transit_gateway_attachment_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |