Class: Aws::EC2::Types::GetTransitGatewayMeteringPolicyEntriesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetTransitGatewayMeteringPolicyEntriesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters to apply when retrieving metering policy entries.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
-
#transit_gateway_metering_policy_id ⇒ String
The ID of the transit gateway metering policy to retrieve entries for.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
49272 49273 49274 49275 49276 49277 49278 49279 49280 |
# File 'lib/aws-sdk-ec2/types.rb', line 49272 class GetTransitGatewayMeteringPolicyEntriesRequest < Struct.new( :transit_gateway_metering_policy_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters to apply when retrieving metering policy entries.
49272 49273 49274 49275 49276 49277 49278 49279 49280 |
# File 'lib/aws-sdk-ec2/types.rb', line 49272 class GetTransitGatewayMeteringPolicyEntriesRequest < Struct.new( :transit_gateway_metering_policy_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To
retrieve the remaining results, make another call with the returned
nextToken value.
49272 49273 49274 49275 49276 49277 49278 49279 49280 |
# File 'lib/aws-sdk-ec2/types.rb', line 49272 class GetTransitGatewayMeteringPolicyEntriesRequest < Struct.new( :transit_gateway_metering_policy_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
49272 49273 49274 49275 49276 49277 49278 49279 49280 |
# File 'lib/aws-sdk-ec2/types.rb', line 49272 class GetTransitGatewayMeteringPolicyEntriesRequest < Struct.new( :transit_gateway_metering_policy_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_metering_policy_id ⇒ String
The ID of the transit gateway metering policy to retrieve entries for.
49272 49273 49274 49275 49276 49277 49278 49279 49280 |
# File 'lib/aws-sdk-ec2/types.rb', line 49272 class GetTransitGatewayMeteringPolicyEntriesRequest < Struct.new( :transit_gateway_metering_policy_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |