Class: Aws::EC2::Types::GetTransitGatewayMeteringPolicyEntriesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


46378
46379
46380
46381
46382
46383
46384
46385
46386
# File 'lib/aws-sdk-ec2/types.rb', line 46378

class GetTransitGatewayMeteringPolicyEntriesRequest < Struct.new(
  :transit_gateway_metering_policy_id,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters to apply when retrieving metering policy entries.

Returns:



46378
46379
46380
46381
46382
46383
46384
46385
46386
# File 'lib/aws-sdk-ec2/types.rb', line 46378

class GetTransitGatewayMeteringPolicyEntriesRequest < Struct.new(
  :transit_gateway_metering_policy_id,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.

Returns:

  • (Integer)


46378
46379
46380
46381
46382
46383
46384
46385
46386
# File 'lib/aws-sdk-ec2/types.rb', line 46378

class GetTransitGatewayMeteringPolicyEntriesRequest < Struct.new(
  :transit_gateway_metering_policy_id,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


46378
46379
46380
46381
46382
46383
46384
46385
46386
# File 'lib/aws-sdk-ec2/types.rb', line 46378

class GetTransitGatewayMeteringPolicyEntriesRequest < Struct.new(
  :transit_gateway_metering_policy_id,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_metering_policy_idString

The ID of the transit gateway metering policy to retrieve entries for.

Returns:

  • (String)


46378
46379
46380
46381
46382
46383
46384
46385
46386
# File 'lib/aws-sdk-ec2/types.rb', line 46378

class GetTransitGatewayMeteringPolicyEntriesRequest < Struct.new(
  :transit_gateway_metering_policy_id,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end