Class: Aws::EC2::Types::GetTransitGatewayMulticastDomainAssociationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetTransitGatewayMulticastDomainAssociationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
-
#transit_gateway_multicast_domain_id ⇒ String
The ID of the transit gateway multicast domain.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
46993 46994 46995 46996 46997 46998 46999 47000 47001 |
# File 'lib/aws-sdk-ec2/types.rb', line 46993 class GetTransitGatewayMulticastDomainAssociationsRequest < Struct.new( :transit_gateway_multicast_domain_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters. The possible values are:
-
‘resource-id` - The ID of the resource.
-
‘resource-type` - The type of resource. The valid value is: `vpc`.
-
‘state` - The state of the subnet association. Valid values are `associated` | `associating` | `disassociated` | `disassociating`.
-
‘subnet-id` - The ID of the subnet.
-
‘transit-gateway-attachment-id` - The id of the transit gateway attachment.
46993 46994 46995 46996 46997 46998 46999 47000 47001 |
# File 'lib/aws-sdk-ec2/types.rb', line 46993 class GetTransitGatewayMulticastDomainAssociationsRequest < Struct.new( :transit_gateway_multicast_domain_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.
46993 46994 46995 46996 46997 46998 46999 47000 47001 |
# File 'lib/aws-sdk-ec2/types.rb', line 46993 class GetTransitGatewayMulticastDomainAssociationsRequest < Struct.new( :transit_gateway_multicast_domain_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
46993 46994 46995 46996 46997 46998 46999 47000 47001 |
# File 'lib/aws-sdk-ec2/types.rb', line 46993 class GetTransitGatewayMulticastDomainAssociationsRequest < Struct.new( :transit_gateway_multicast_domain_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_multicast_domain_id ⇒ String
The ID of the transit gateway multicast domain.
46993 46994 46995 46996 46997 46998 46999 47000 47001 |
# File 'lib/aws-sdk-ec2/types.rb', line 46993 class GetTransitGatewayMulticastDomainAssociationsRequest < Struct.new( :transit_gateway_multicast_domain_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |