Class: Aws::EC2::Types::GetTransitGatewayMulticastDomainAssociationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


45448
45449
45450
45451
45452
45453
45454
45455
45456
# File 'lib/aws-sdk-ec2/types.rb', line 45448

class GetTransitGatewayMulticastDomainAssociationsRequest < Struct.new(
  :transit_gateway_multicast_domain_id,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters. The possible values are:

  • ‘resource-id` - The ID of the resource.

  • ‘resource-type` - The type of resource. The valid value is: `vpc`.

  • ‘state` - The state of the subnet association. Valid values are `associated` | `associating` | `disassociated` | `disassociating`.

  • ‘subnet-id` - The ID of the subnet.

  • ‘transit-gateway-attachment-id` - The id of the transit gateway attachment.

Returns:



45448
45449
45450
45451
45452
45453
45454
45455
45456
# File 'lib/aws-sdk-ec2/types.rb', line 45448

class GetTransitGatewayMulticastDomainAssociationsRequest < Struct.new(
  :transit_gateway_multicast_domain_id,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.

Returns:

  • (Integer)


45448
45449
45450
45451
45452
45453
45454
45455
45456
# File 'lib/aws-sdk-ec2/types.rb', line 45448

class GetTransitGatewayMulticastDomainAssociationsRequest < Struct.new(
  :transit_gateway_multicast_domain_id,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


45448
45449
45450
45451
45452
45453
45454
45455
45456
# File 'lib/aws-sdk-ec2/types.rb', line 45448

class GetTransitGatewayMulticastDomainAssociationsRequest < Struct.new(
  :transit_gateway_multicast_domain_id,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_multicast_domain_idString

The ID of the transit gateway multicast domain.

Returns:

  • (String)


45448
45449
45450
45451
45452
45453
45454
45455
45456
# File 'lib/aws-sdk-ec2/types.rb', line 45448

class GetTransitGatewayMulticastDomainAssociationsRequest < Struct.new(
  :transit_gateway_multicast_domain_id,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end