Class: Aws::EC2::Types::GetTransitGatewayPolicyTableEntriesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetTransitGatewayPolicyTableEntriesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
-
#transit_gateway_policy_table_id ⇒ String
The ID of the transit gateway policy table.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
48620 48621 48622 48623 48624 48625 48626 48627 48628 |
# File 'lib/aws-sdk-ec2/types.rb', line 48620 class GetTransitGatewayPolicyTableEntriesRequest < Struct.new( :transit_gateway_policy_table_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters. The possible values are:
-
policy-rule-number- The rule number for the transit gateway policy table entry. -
target-route-table-id- The ID of the target route table. -
policy-rule.source-ip- The source CIDR block for the policy rule. -
policy-rule.destination-ip- The destination CIDR block for the policy rule. -
policy-rule.source-port- The source port or port range for the policy rule. -
policy-rule.destination-port- The destination port or port range for the policy rule. -
policy-rule.protocol- The protocol for the policy rule. -
policy-rule.meta-data.key- The metadata key for the policy rule. -
policy-rule.meta-data.value- The metadata value for the policy rule.
48620 48621 48622 48623 48624 48625 48626 48627 48628 |
# File 'lib/aws-sdk-ec2/types.rb', line 48620 class GetTransitGatewayPolicyTableEntriesRequest < Struct.new( :transit_gateway_policy_table_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To
retrieve the remaining results, make another call with the returned
nextToken value.
48620 48621 48622 48623 48624 48625 48626 48627 48628 |
# File 'lib/aws-sdk-ec2/types.rb', line 48620 class GetTransitGatewayPolicyTableEntriesRequest < Struct.new( :transit_gateway_policy_table_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
48620 48621 48622 48623 48624 48625 48626 48627 48628 |
# File 'lib/aws-sdk-ec2/types.rb', line 48620 class GetTransitGatewayPolicyTableEntriesRequest < Struct.new( :transit_gateway_policy_table_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_policy_table_id ⇒ String
The ID of the transit gateway policy table.
48620 48621 48622 48623 48624 48625 48626 48627 48628 |
# File 'lib/aws-sdk-ec2/types.rb', line 48620 class GetTransitGatewayPolicyTableEntriesRequest < Struct.new( :transit_gateway_policy_table_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |