Class: Aws::EC2::Types::GetTransitGatewayPolicyTableEntriesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetTransitGatewayPolicyTableEntriesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
The filters associated with the transit gateway policy table.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
-
#transit_gateway_policy_table_id ⇒ String
The ID of the transit gateway policy table.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
46248 46249 46250 46251 46252 46253 46254 46255 46256 |
# File 'lib/aws-sdk-ec2/types.rb', line 46248 class GetTransitGatewayPolicyTableEntriesRequest < Struct.new( :transit_gateway_policy_table_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters associated with the transit gateway policy table.
46248 46249 46250 46251 46252 46253 46254 46255 46256 |
# File 'lib/aws-sdk-ec2/types.rb', line 46248 class GetTransitGatewayPolicyTableEntriesRequest < Struct.new( :transit_gateway_policy_table_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.
46248 46249 46250 46251 46252 46253 46254 46255 46256 |
# File 'lib/aws-sdk-ec2/types.rb', line 46248 class GetTransitGatewayPolicyTableEntriesRequest < Struct.new( :transit_gateway_policy_table_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
46248 46249 46250 46251 46252 46253 46254 46255 46256 |
# File 'lib/aws-sdk-ec2/types.rb', line 46248 class GetTransitGatewayPolicyTableEntriesRequest < Struct.new( :transit_gateway_policy_table_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_policy_table_id ⇒ String
The ID of the transit gateway policy table.
46248 46249 46250 46251 46252 46253 46254 46255 46256 |
# File 'lib/aws-sdk-ec2/types.rb', line 46248 class GetTransitGatewayPolicyTableEntriesRequest < Struct.new( :transit_gateway_policy_table_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |