Class: Aws::EC2::Types::GetTransitGatewayRouteTableAssociationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetTransitGatewayRouteTableAssociationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
-
#transit_gateway_route_table_id ⇒ String
The ID of the transit gateway route table.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
47563 47564 47565 47566 47567 47568 47569 47570 47571 |
# File 'lib/aws-sdk-ec2/types.rb', line 47563 class GetTransitGatewayRouteTableAssociationsRequest < Struct.new( :transit_gateway_route_table_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters. The possible values are:
-
resource-id- The ID of the resource. -
resource-type- The resource type. Valid values arevpc|vpn|direct-connect-gateway|peering|connect. -
transit-gateway-attachment-id- The ID of the attachment.
47563 47564 47565 47566 47567 47568 47569 47570 47571 |
# File 'lib/aws-sdk-ec2/types.rb', line 47563 class GetTransitGatewayRouteTableAssociationsRequest < Struct.new( :transit_gateway_route_table_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To
retrieve the remaining results, make another call with the returned
nextToken value.
47563 47564 47565 47566 47567 47568 47569 47570 47571 |
# File 'lib/aws-sdk-ec2/types.rb', line 47563 class GetTransitGatewayRouteTableAssociationsRequest < Struct.new( :transit_gateway_route_table_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
47563 47564 47565 47566 47567 47568 47569 47570 47571 |
# File 'lib/aws-sdk-ec2/types.rb', line 47563 class GetTransitGatewayRouteTableAssociationsRequest < Struct.new( :transit_gateway_route_table_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_route_table_id ⇒ String
The ID of the transit gateway route table.
47563 47564 47565 47566 47567 47568 47569 47570 47571 |
# File 'lib/aws-sdk-ec2/types.rb', line 47563 class GetTransitGatewayRouteTableAssociationsRequest < Struct.new( :transit_gateway_route_table_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |