Class: Aws::EC2::Types::GetTransitGatewayRouteTableAssociationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


47151
47152
47153
47154
47155
47156
47157
47158
47159
# File 'lib/aws-sdk-ec2/types.rb', line 47151

class GetTransitGatewayRouteTableAssociationsRequest < Struct.new(
  :transit_gateway_route_table_id,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

One or more filters. The possible values are:

  • ‘resource-id` - The ID of the resource.

  • ‘resource-type` - The resource type. Valid values are `vpc` | `vpn` | `direct-connect-gateway` | `peering` | `connect`.

  • ‘transit-gateway-attachment-id` - The ID of the attachment.

Returns:



47151
47152
47153
47154
47155
47156
47157
47158
47159
# File 'lib/aws-sdk-ec2/types.rb', line 47151

class GetTransitGatewayRouteTableAssociationsRequest < Struct.new(
  :transit_gateway_route_table_id,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.

Returns:

  • (Integer)


47151
47152
47153
47154
47155
47156
47157
47158
47159
# File 'lib/aws-sdk-ec2/types.rb', line 47151

class GetTransitGatewayRouteTableAssociationsRequest < Struct.new(
  :transit_gateway_route_table_id,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


47151
47152
47153
47154
47155
47156
47157
47158
47159
# File 'lib/aws-sdk-ec2/types.rb', line 47151

class GetTransitGatewayRouteTableAssociationsRequest < Struct.new(
  :transit_gateway_route_table_id,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_route_table_idString

The ID of the transit gateway route table.

Returns:

  • (String)


47151
47152
47153
47154
47155
47156
47157
47158
47159
# File 'lib/aws-sdk-ec2/types.rb', line 47151

class GetTransitGatewayRouteTableAssociationsRequest < Struct.new(
  :transit_gateway_route_table_id,
  :filters,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end