Class: Aws::EC2::Types::GetVerifiedAccessEndpointPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


47789
47790
47791
47792
47793
47794
# File 'lib/aws-sdk-ec2/types.rb', line 47789

class GetVerifiedAccessEndpointPolicyRequest < Struct.new(
  :verified_access_endpoint_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#verified_access_endpoint_idString

The ID of the Verified Access endpoint.

Returns:

  • (String)


47789
47790
47791
47792
47793
47794
# File 'lib/aws-sdk-ec2/types.rb', line 47789

class GetVerifiedAccessEndpointPolicyRequest < Struct.new(
  :verified_access_endpoint_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end