Class: Aws::EC2::Types::GetVerifiedAccessEndpointPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetVerifiedAccessEndpointPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#verified_access_endpoint_id ⇒ String
The ID of the Verified Access endpoint.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
47342 47343 47344 47345 47346 47347 |
# File 'lib/aws-sdk-ec2/types.rb', line 47342 class GetVerifiedAccessEndpointPolicyRequest < Struct.new( :verified_access_endpoint_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#verified_access_endpoint_id ⇒ String
The ID of the Verified Access endpoint.
47342 47343 47344 47345 47346 47347 |
# File 'lib/aws-sdk-ec2/types.rb', line 47342 class GetVerifiedAccessEndpointPolicyRequest < Struct.new( :verified_access_endpoint_id, :dry_run) SENSITIVE = [] include Aws::Structure end |