Class: Aws::EC2::Types::GetVerifiedAccessEndpointTargetsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


49770
49771
49772
49773
49774
49775
49776
49777
# File 'lib/aws-sdk-ec2/types.rb', line 49770

class GetVerifiedAccessEndpointTargetsRequest < Struct.new(
  :verified_access_endpoint_id,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.

Returns:

  • (Integer)


49770
49771
49772
49773
49774
49775
49776
49777
# File 'lib/aws-sdk-ec2/types.rb', line 49770

class GetVerifiedAccessEndpointTargetsRequest < Struct.new(
  :verified_access_endpoint_id,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


49770
49771
49772
49773
49774
49775
49776
49777
# File 'lib/aws-sdk-ec2/types.rb', line 49770

class GetVerifiedAccessEndpointTargetsRequest < Struct.new(
  :verified_access_endpoint_id,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#verified_access_endpoint_idString

The ID of the network CIDR endpoint.

Returns:

  • (String)


49770
49771
49772
49773
49774
49775
49776
49777
# File 'lib/aws-sdk-ec2/types.rb', line 49770

class GetVerifiedAccessEndpointTargetsRequest < Struct.new(
  :verified_access_endpoint_id,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end