Class: Aws::EC2::Types::GetVerifiedAccessEndpointTargetsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


47389
47390
47391
47392
47393
47394
47395
47396
# File 'lib/aws-sdk-ec2/types.rb', line 47389

class GetVerifiedAccessEndpointTargetsRequest < Struct.new(
  :verified_access_endpoint_id,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.

Returns:

  • (Integer)


47389
47390
47391
47392
47393
47394
47395
47396
# File 'lib/aws-sdk-ec2/types.rb', line 47389

class GetVerifiedAccessEndpointTargetsRequest < Struct.new(
  :verified_access_endpoint_id,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.

Returns:

  • (String)


47389
47390
47391
47392
47393
47394
47395
47396
# File 'lib/aws-sdk-ec2/types.rb', line 47389

class GetVerifiedAccessEndpointTargetsRequest < Struct.new(
  :verified_access_endpoint_id,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#verified_access_endpoint_idString

The ID of the network CIDR endpoint.

Returns:

  • (String)


47389
47390
47391
47392
47393
47394
47395
47396
# File 'lib/aws-sdk-ec2/types.rb', line 47389

class GetVerifiedAccessEndpointTargetsRequest < Struct.new(
  :verified_access_endpoint_id,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end