Class: Aws::EC2::Types::GetVerifiedAccessEndpointTargetsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetVerifiedAccessEndpointTargetsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
-
#verified_access_endpoint_id ⇒ String
The ID of the network CIDR endpoint.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
46836 46837 46838 46839 46840 46841 46842 46843 |
# File 'lib/aws-sdk-ec2/types.rb', line 46836 class GetVerifiedAccessEndpointTargetsRequest < Struct.new( :verified_access_endpoint_id, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.
46836 46837 46838 46839 46840 46841 46842 46843 |
# File 'lib/aws-sdk-ec2/types.rb', line 46836 class GetVerifiedAccessEndpointTargetsRequest < Struct.new( :verified_access_endpoint_id, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
46836 46837 46838 46839 46840 46841 46842 46843 |
# File 'lib/aws-sdk-ec2/types.rb', line 46836 class GetVerifiedAccessEndpointTargetsRequest < Struct.new( :verified_access_endpoint_id, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#verified_access_endpoint_id ⇒ String
The ID of the network CIDR endpoint.
46836 46837 46838 46839 46840 46841 46842 46843 |
# File 'lib/aws-sdk-ec2/types.rb', line 46836 class GetVerifiedAccessEndpointTargetsRequest < Struct.new( :verified_access_endpoint_id, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |