Class: Aws::EC2::Types::GetVerifiedAccessGroupPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


49822
49823
49824
49825
49826
49827
# File 'lib/aws-sdk-ec2/types.rb', line 49822

class GetVerifiedAccessGroupPolicyRequest < Struct.new(
  :verified_access_group_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#verified_access_group_idString

The ID of the Verified Access group.

Returns:

  • (String)


49822
49823
49824
49825
49826
49827
# File 'lib/aws-sdk-ec2/types.rb', line 49822

class GetVerifiedAccessGroupPolicyRequest < Struct.new(
  :verified_access_group_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end