Class: Aws::EC2::Types::GetVerifiedAccessGroupPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetVerifiedAccessGroupPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#verified_access_group_id ⇒ String
The ID of the Verified Access group.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
46959 46960 46961 46962 46963 46964 |
# File 'lib/aws-sdk-ec2/types.rb', line 46959 class GetVerifiedAccessGroupPolicyRequest < Struct.new( :verified_access_group_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#verified_access_group_id ⇒ String
The ID of the Verified Access group.
46959 46960 46961 46962 46963 46964 |
# File 'lib/aws-sdk-ec2/types.rb', line 46959 class GetVerifiedAccessGroupPolicyRequest < Struct.new( :verified_access_group_id, :dry_run) SENSITIVE = [] include Aws::Structure end |