Class: Aws::EC2::Types::GetVerifiedAccessGroupPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


46569
46570
46571
46572
46573
46574
# File 'lib/aws-sdk-ec2/types.rb', line 46569

class GetVerifiedAccessGroupPolicyRequest < Struct.new(
  :verified_access_group_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#verified_access_group_idString

The ID of the Verified Access group.

Returns:

  • (String)


46569
46570
46571
46572
46573
46574
# File 'lib/aws-sdk-ec2/types.rb', line 46569

class GetVerifiedAccessGroupPolicyRequest < Struct.new(
  :verified_access_group_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end