Class: Aws::EC2::Types::GetVpcResourcesBlockingEncryptionEnforcementRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


49001
49002
49003
49004
49005
49006
49007
49008
# File 'lib/aws-sdk-ec2/types.rb', line 49001

class GetVpcResourcesBlockingEncryptionEnforcementRequest < Struct.new(
  :vpc_id,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.

Returns:

  • (Integer)


49001
49002
49003
49004
49005
49006
49007
49008
# File 'lib/aws-sdk-ec2/types.rb', line 49001

class GetVpcResourcesBlockingEncryptionEnforcementRequest < Struct.new(
  :vpc_id,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Returns:

  • (String)


49001
49002
49003
49004
49005
49006
49007
49008
# File 'lib/aws-sdk-ec2/types.rb', line 49001

class GetVpcResourcesBlockingEncryptionEnforcementRequest < Struct.new(
  :vpc_id,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC to check for resources blocking encryption enforcement.

Returns:

  • (String)


49001
49002
49003
49004
49005
49006
49007
49008
# File 'lib/aws-sdk-ec2/types.rb', line 49001

class GetVpcResourcesBlockingEncryptionEnforcementRequest < Struct.new(
  :vpc_id,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end