Class: Aws::EC2::Types::GetVpcResourcesBlockingEncryptionEnforcementRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetVpcResourcesBlockingEncryptionEnforcementRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token returned from a previous paginated request.
-
#vpc_id ⇒ String
The ID of the VPC to check for resources blocking encryption enforcement.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
47383 47384 47385 47386 47387 47388 47389 47390 |
# File 'lib/aws-sdk-ec2/types.rb', line 47383 class GetVpcResourcesBlockingEncryptionEnforcementRequest < Struct.new( :vpc_id, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination
47383 47384 47385 47386 47387 47388 47389 47390 |
# File 'lib/aws-sdk-ec2/types.rb', line 47383 class GetVpcResourcesBlockingEncryptionEnforcementRequest < Struct.new( :vpc_id, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
47383 47384 47385 47386 47387 47388 47389 47390 |
# File 'lib/aws-sdk-ec2/types.rb', line 47383 class GetVpcResourcesBlockingEncryptionEnforcementRequest < Struct.new( :vpc_id, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC to check for resources blocking encryption enforcement.
47383 47384 47385 47386 47387 47388 47389 47390 |
# File 'lib/aws-sdk-ec2/types.rb', line 47383 class GetVpcResourcesBlockingEncryptionEnforcementRequest < Struct.new( :vpc_id, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |