Class: Aws::EC2::Types::GetVpcResourcesBlockingEncryptionEnforcementRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


46930
46931
46932
46933
46934
46935
46936
46937
# File 'lib/aws-sdk-ec2/types.rb', line 46930

class GetVpcResourcesBlockingEncryptionEnforcementRequest < Struct.new(
  :vpc_id,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination

Returns:

  • (Integer)


46930
46931
46932
46933
46934
46935
46936
46937
# File 'lib/aws-sdk-ec2/types.rb', line 46930

class GetVpcResourcesBlockingEncryptionEnforcementRequest < Struct.new(
  :vpc_id,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Returns:

  • (String)


46930
46931
46932
46933
46934
46935
46936
46937
# File 'lib/aws-sdk-ec2/types.rb', line 46930

class GetVpcResourcesBlockingEncryptionEnforcementRequest < Struct.new(
  :vpc_id,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC to check for resources blocking encryption enforcement.

Returns:

  • (String)


46930
46931
46932
46933
46934
46935
46936
46937
# File 'lib/aws-sdk-ec2/types.rb', line 46930

class GetVpcResourcesBlockingEncryptionEnforcementRequest < Struct.new(
  :vpc_id,
  :max_results,
  :next_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end