Class: Aws::EC2::Types::GetVpcResourcesBlockingEncryptionEnforcementResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetVpcResourcesBlockingEncryptionEnforcementResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
-
#non_compliant_resources ⇒ Array<Types::VpcEncryptionNonCompliantResource>
Information about resources that are blocking encryption enforcement.
Instance Attribute Details
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
49885 49886 49887 49888 49889 49890 |
# File 'lib/aws-sdk-ec2/types.rb', line 49885 class GetVpcResourcesBlockingEncryptionEnforcementResult < Struct.new( :non_compliant_resources, :next_token) SENSITIVE = [] include Aws::Structure end |
#non_compliant_resources ⇒ Array<Types::VpcEncryptionNonCompliantResource>
Information about resources that are blocking encryption enforcement.
49885 49886 49887 49888 49889 49890 |
# File 'lib/aws-sdk-ec2/types.rb', line 49885 class GetVpcResourcesBlockingEncryptionEnforcementResult < Struct.new( :non_compliant_resources, :next_token) SENSITIVE = [] include Aws::Structure end |