Class: Aws::EC2::Types::GetVpnConnectionDeviceSampleConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetVpnConnectionDeviceSampleConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#internet_key_exchange_version ⇒ String
The IKE version to be used in the sample configuration file for your customer gateway device.
-
#sample_type ⇒ String
The type of sample configuration to generate.
-
#vpn_connection_device_type_id ⇒ String
Device identifier provided by the ‘GetVpnConnectionDeviceTypes` API.
-
#vpn_connection_id ⇒ String
The ‘VpnConnectionId` specifies the Site-to-Site VPN connection used for the sample configuration.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
47453 47454 47455 47456 47457 47458 47459 47460 47461 |
# File 'lib/aws-sdk-ec2/types.rb', line 47453 class GetVpnConnectionDeviceSampleConfigurationRequest < Struct.new( :vpn_connection_id, :vpn_connection_device_type_id, :internet_key_exchange_version, :sample_type, :dry_run) SENSITIVE = [] include Aws::Structure end |
#internet_key_exchange_version ⇒ String
The IKE version to be used in the sample configuration file for your customer gateway device. You can specify one of the following versions: ‘ikev1` or `ikev2`.
47453 47454 47455 47456 47457 47458 47459 47460 47461 |
# File 'lib/aws-sdk-ec2/types.rb', line 47453 class GetVpnConnectionDeviceSampleConfigurationRequest < Struct.new( :vpn_connection_id, :vpn_connection_device_type_id, :internet_key_exchange_version, :sample_type, :dry_run) SENSITIVE = [] include Aws::Structure end |
#sample_type ⇒ String
The type of sample configuration to generate. Valid values are “compatibility” (includes IKEv1) or “recommended” (throws UnsupportedOperationException for IKEv1).
47453 47454 47455 47456 47457 47458 47459 47460 47461 |
# File 'lib/aws-sdk-ec2/types.rb', line 47453 class GetVpnConnectionDeviceSampleConfigurationRequest < Struct.new( :vpn_connection_id, :vpn_connection_device_type_id, :internet_key_exchange_version, :sample_type, :dry_run) SENSITIVE = [] include Aws::Structure end |
#vpn_connection_device_type_id ⇒ String
Device identifier provided by the ‘GetVpnConnectionDeviceTypes` API.
47453 47454 47455 47456 47457 47458 47459 47460 47461 |
# File 'lib/aws-sdk-ec2/types.rb', line 47453 class GetVpnConnectionDeviceSampleConfigurationRequest < Struct.new( :vpn_connection_id, :vpn_connection_device_type_id, :internet_key_exchange_version, :sample_type, :dry_run) SENSITIVE = [] include Aws::Structure end |
#vpn_connection_id ⇒ String
The ‘VpnConnectionId` specifies the Site-to-Site VPN connection used for the sample configuration.
47453 47454 47455 47456 47457 47458 47459 47460 47461 |
# File 'lib/aws-sdk-ec2/types.rb', line 47453 class GetVpnConnectionDeviceSampleConfigurationRequest < Struct.new( :vpn_connection_id, :vpn_connection_device_type_id, :internet_key_exchange_version, :sample_type, :dry_run) SENSITIVE = [] include Aws::Structure end |