Class: Aws::EC2::Types::GetVpnConnectionDeviceTypesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetVpnConnectionDeviceTypesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#max_results ⇒ Integer
The maximum number of results returned by ‘GetVpnConnectionDeviceTypes` in paginated output.
-
#next_token ⇒ String
The ‘NextToken` value returned from a previous paginated `GetVpnConnectionDeviceTypes` request where `MaxResults` was used and the results exceeded the value of that parameter.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
46042 46043 46044 46045 46046 46047 46048 |
# File 'lib/aws-sdk-ec2/types.rb', line 46042 class GetVpnConnectionDeviceTypesRequest < Struct.new( :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results returned by ‘GetVpnConnectionDeviceTypes` in paginated output. When this parameter is used, `GetVpnConnectionDeviceTypes` only returns `MaxResults` results in a single page along with a `NextToken` response element. The remaining results of the initial request can be seen by sending another `GetVpnConnectionDeviceTypes` request with the returned `NextToken` value. This value can be between 200 and 1000. If this parameter is not used, then `GetVpnConnectionDeviceTypes` returns all results.
46042 46043 46044 46045 46046 46047 46048 |
# File 'lib/aws-sdk-ec2/types.rb', line 46042 class GetVpnConnectionDeviceTypesRequest < Struct.new( :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The ‘NextToken` value returned from a previous paginated `GetVpnConnectionDeviceTypes` request where `MaxResults` was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the `NextToken` value. This value is null when there are no more results to return.
46042 46043 46044 46045 46046 46047 46048 |
# File 'lib/aws-sdk-ec2/types.rb', line 46042 class GetVpnConnectionDeviceTypesRequest < Struct.new( :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |