Class: Aws::EC2::Types::GetVpnTunnelReplacementStatusRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::GetVpnTunnelReplacementStatusRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#vpn_connection_id ⇒ String
The ID of the Site-to-Site VPN connection.
-
#vpn_tunnel_outside_ip_address ⇒ String
The external IP address of the VPN tunnel.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
47964 47965 47966 47967 47968 47969 47970 |
# File 'lib/aws-sdk-ec2/types.rb', line 47964 class GetVpnTunnelReplacementStatusRequest < Struct.new( :vpn_connection_id, :vpn_tunnel_outside_ip_address, :dry_run) SENSITIVE = [] include Aws::Structure end |
#vpn_connection_id ⇒ String
The ID of the Site-to-Site VPN connection.
47964 47965 47966 47967 47968 47969 47970 |
# File 'lib/aws-sdk-ec2/types.rb', line 47964 class GetVpnTunnelReplacementStatusRequest < Struct.new( :vpn_connection_id, :vpn_tunnel_outside_ip_address, :dry_run) SENSITIVE = [] include Aws::Structure end |
#vpn_tunnel_outside_ip_address ⇒ String
The external IP address of the VPN tunnel.
47964 47965 47966 47967 47968 47969 47970 |
# File 'lib/aws-sdk-ec2/types.rb', line 47964 class GetVpnTunnelReplacementStatusRequest < Struct.new( :vpn_connection_id, :vpn_tunnel_outside_ip_address, :dry_run) SENSITIVE = [] include Aws::Structure end |