Class: Aws::EC2::Types::GetVpnTunnelReplacementStatusRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


47087
47088
47089
47090
47091
47092
47093
# File 'lib/aws-sdk-ec2/types.rb', line 47087

class GetVpnTunnelReplacementStatusRequest < Struct.new(
  :vpn_connection_id,
  :vpn_tunnel_outside_ip_address,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpn_connection_idString

The ID of the Site-to-Site VPN connection.

Returns:

  • (String)


47087
47088
47089
47090
47091
47092
47093
# File 'lib/aws-sdk-ec2/types.rb', line 47087

class GetVpnTunnelReplacementStatusRequest < Struct.new(
  :vpn_connection_id,
  :vpn_tunnel_outside_ip_address,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpn_tunnel_outside_ip_addressString

The external IP address of the VPN tunnel.

Returns:

  • (String)


47087
47088
47089
47090
47091
47092
47093
# File 'lib/aws-sdk-ec2/types.rb', line 47087

class GetVpnTunnelReplacementStatusRequest < Struct.new(
  :vpn_connection_id,
  :vpn_tunnel_outside_ip_address,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end