Class: Aws::EC2::Types::HealthCheckPathDestinationRequestObject
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::HealthCheckPathDestinationRequestObject
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a destination for a health check path in a request. Destinations can be in a different Availability Zone than the source (cross-AZ) or in a Local Zone (AZ to Local Zone), enabling remote health validation of your application.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#security_group_id ⇒ String
The ID of the security group for the destination.
-
#subnet_id ⇒ String
The ID of the subnet for the destination.
Instance Attribute Details
#security_group_id ⇒ String
The ID of the security group for the destination.
49316 49317 49318 49319 49320 49321 |
# File 'lib/aws-sdk-ec2/types.rb', line 49316 class HealthCheckPathDestinationRequestObject < Struct.new( :subnet_id, :security_group_id) SENSITIVE = [] include Aws::Structure end |
#subnet_id ⇒ String
The ID of the subnet for the destination.
49316 49317 49318 49319 49320 49321 |
# File 'lib/aws-sdk-ec2/types.rb', line 49316 class HealthCheckPathDestinationRequestObject < Struct.new( :subnet_id, :security_group_id) SENSITIVE = [] include Aws::Structure end |