Class: Aws::EC2::Types::Host
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::Host
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the properties of the Dedicated Host.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allocation_time ⇒ Time
The time that the Dedicated Host was allocated.
-
#allows_multiple_instance_types ⇒ String
Indicates whether the Dedicated Host supports multiple instance types of the same instance family.
-
#asset_id ⇒ String
The ID of the Outpost hardware asset on which the Dedicated Host is allocated.
-
#auto_placement ⇒ String
Whether auto-placement is on or off.
-
#availability_zone ⇒ String
The Availability Zone of the Dedicated Host.
-
#availability_zone_id ⇒ String
The ID of the Availability Zone in which the Dedicated Host is allocated.
-
#available_capacity ⇒ Types::AvailableCapacity
Information about the instances running on the Dedicated Host.
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#cpu_options ⇒ Types::HostCpuOptions
The CPU options for the Dedicated Host, including AMD Secure Encrypted Virtualization-Secure Nested Paging (AMD SEV-SNP) settings.
-
#host_id ⇒ String
The ID of the Dedicated Host.
-
#host_maintenance ⇒ String
Indicates whether host maintenance is enabled or disabled for the Dedicated Host.
-
#host_properties ⇒ Types::HostProperties
The hardware specifications of the Dedicated Host.
-
#host_recovery ⇒ String
Indicates whether host recovery is enabled or disabled for the Dedicated Host.
-
#host_reservation_id ⇒ String
The reservation ID of the Dedicated Host.
-
#instances ⇒ Array<Types::HostInstance>
The IDs and instance type that are currently running on the Dedicated Host.
-
#member_of_service_linked_resource_group ⇒ Boolean
Indicates whether the Dedicated Host is in a host resource group.
-
#outpost_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Web Services Outpost on which the Dedicated Host is allocated.
-
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the Dedicated Host.
-
#release_time ⇒ Time
The time that the Dedicated Host was released.
-
#state ⇒ String
The Dedicated Host's state.
-
#tags ⇒ Array<Types::Tag>
Any tags assigned to the Dedicated Host.
Instance Attribute Details
#allocation_time ⇒ Time
The time that the Dedicated Host was allocated.
48339 48340 48341 48342 48343 48344 48345 48346 48347 48348 48349 48350 48351 48352 48353 48354 48355 48356 48357 48358 48359 48360 48361 48362 48363 |
# File 'lib/aws-sdk-ec2/types.rb', line 48339 class Host < Struct.new( :auto_placement, :availability_zone, :available_capacity, :client_token, :host_id, :host_properties, :host_reservation_id, :instances, :state, :allocation_time, :release_time, :tags, :host_recovery, :allows_multiple_instance_types, :owner_id, :availability_zone_id, :member_of_service_linked_resource_group, :outpost_arn, :host_maintenance, :asset_id, :cpu_options) SENSITIVE = [] include Aws::Structure end |
#allows_multiple_instance_types ⇒ String
Indicates whether the Dedicated Host supports multiple instance
types of the same instance family. If the value is on, the
Dedicated Host supports multiple instance types in the instance
family. If the value is off, the Dedicated Host supports a single
instance type only.
48339 48340 48341 48342 48343 48344 48345 48346 48347 48348 48349 48350 48351 48352 48353 48354 48355 48356 48357 48358 48359 48360 48361 48362 48363 |
# File 'lib/aws-sdk-ec2/types.rb', line 48339 class Host < Struct.new( :auto_placement, :availability_zone, :available_capacity, :client_token, :host_id, :host_properties, :host_reservation_id, :instances, :state, :allocation_time, :release_time, :tags, :host_recovery, :allows_multiple_instance_types, :owner_id, :availability_zone_id, :member_of_service_linked_resource_group, :outpost_arn, :host_maintenance, :asset_id, :cpu_options) SENSITIVE = [] include Aws::Structure end |
#asset_id ⇒ String
The ID of the Outpost hardware asset on which the Dedicated Host is allocated.
48339 48340 48341 48342 48343 48344 48345 48346 48347 48348 48349 48350 48351 48352 48353 48354 48355 48356 48357 48358 48359 48360 48361 48362 48363 |
# File 'lib/aws-sdk-ec2/types.rb', line 48339 class Host < Struct.new( :auto_placement, :availability_zone, :available_capacity, :client_token, :host_id, :host_properties, :host_reservation_id, :instances, :state, :allocation_time, :release_time, :tags, :host_recovery, :allows_multiple_instance_types, :owner_id, :availability_zone_id, :member_of_service_linked_resource_group, :outpost_arn, :host_maintenance, :asset_id, :cpu_options) SENSITIVE = [] include Aws::Structure end |
#auto_placement ⇒ String
Whether auto-placement is on or off.
48339 48340 48341 48342 48343 48344 48345 48346 48347 48348 48349 48350 48351 48352 48353 48354 48355 48356 48357 48358 48359 48360 48361 48362 48363 |
# File 'lib/aws-sdk-ec2/types.rb', line 48339 class Host < Struct.new( :auto_placement, :availability_zone, :available_capacity, :client_token, :host_id, :host_properties, :host_reservation_id, :instances, :state, :allocation_time, :release_time, :tags, :host_recovery, :allows_multiple_instance_types, :owner_id, :availability_zone_id, :member_of_service_linked_resource_group, :outpost_arn, :host_maintenance, :asset_id, :cpu_options) SENSITIVE = [] include Aws::Structure end |
#availability_zone ⇒ String
The Availability Zone of the Dedicated Host.
48339 48340 48341 48342 48343 48344 48345 48346 48347 48348 48349 48350 48351 48352 48353 48354 48355 48356 48357 48358 48359 48360 48361 48362 48363 |
# File 'lib/aws-sdk-ec2/types.rb', line 48339 class Host < Struct.new( :auto_placement, :availability_zone, :available_capacity, :client_token, :host_id, :host_properties, :host_reservation_id, :instances, :state, :allocation_time, :release_time, :tags, :host_recovery, :allows_multiple_instance_types, :owner_id, :availability_zone_id, :member_of_service_linked_resource_group, :outpost_arn, :host_maintenance, :asset_id, :cpu_options) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
The ID of the Availability Zone in which the Dedicated Host is allocated.
48339 48340 48341 48342 48343 48344 48345 48346 48347 48348 48349 48350 48351 48352 48353 48354 48355 48356 48357 48358 48359 48360 48361 48362 48363 |
# File 'lib/aws-sdk-ec2/types.rb', line 48339 class Host < Struct.new( :auto_placement, :availability_zone, :available_capacity, :client_token, :host_id, :host_properties, :host_reservation_id, :instances, :state, :allocation_time, :release_time, :tags, :host_recovery, :allows_multiple_instance_types, :owner_id, :availability_zone_id, :member_of_service_linked_resource_group, :outpost_arn, :host_maintenance, :asset_id, :cpu_options) SENSITIVE = [] include Aws::Structure end |
#available_capacity ⇒ Types::AvailableCapacity
Information about the instances running on the Dedicated Host.
48339 48340 48341 48342 48343 48344 48345 48346 48347 48348 48349 48350 48351 48352 48353 48354 48355 48356 48357 48358 48359 48360 48361 48362 48363 |
# File 'lib/aws-sdk-ec2/types.rb', line 48339 class Host < Struct.new( :auto_placement, :availability_zone, :available_capacity, :client_token, :host_id, :host_properties, :host_reservation_id, :instances, :state, :allocation_time, :release_time, :tags, :host_recovery, :allows_multiple_instance_types, :owner_id, :availability_zone_id, :member_of_service_linked_resource_group, :outpost_arn, :host_maintenance, :asset_id, :cpu_options) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring Idempotency.
48339 48340 48341 48342 48343 48344 48345 48346 48347 48348 48349 48350 48351 48352 48353 48354 48355 48356 48357 48358 48359 48360 48361 48362 48363 |
# File 'lib/aws-sdk-ec2/types.rb', line 48339 class Host < Struct.new( :auto_placement, :availability_zone, :available_capacity, :client_token, :host_id, :host_properties, :host_reservation_id, :instances, :state, :allocation_time, :release_time, :tags, :host_recovery, :allows_multiple_instance_types, :owner_id, :availability_zone_id, :member_of_service_linked_resource_group, :outpost_arn, :host_maintenance, :asset_id, :cpu_options) SENSITIVE = [] include Aws::Structure end |
#cpu_options ⇒ Types::HostCpuOptions
The CPU options for the Dedicated Host, including AMD Secure Encrypted Virtualization-Secure Nested Paging (AMD SEV-SNP) settings.
48339 48340 48341 48342 48343 48344 48345 48346 48347 48348 48349 48350 48351 48352 48353 48354 48355 48356 48357 48358 48359 48360 48361 48362 48363 |
# File 'lib/aws-sdk-ec2/types.rb', line 48339 class Host < Struct.new( :auto_placement, :availability_zone, :available_capacity, :client_token, :host_id, :host_properties, :host_reservation_id, :instances, :state, :allocation_time, :release_time, :tags, :host_recovery, :allows_multiple_instance_types, :owner_id, :availability_zone_id, :member_of_service_linked_resource_group, :outpost_arn, :host_maintenance, :asset_id, :cpu_options) SENSITIVE = [] include Aws::Structure end |
#host_id ⇒ String
The ID of the Dedicated Host.
48339 48340 48341 48342 48343 48344 48345 48346 48347 48348 48349 48350 48351 48352 48353 48354 48355 48356 48357 48358 48359 48360 48361 48362 48363 |
# File 'lib/aws-sdk-ec2/types.rb', line 48339 class Host < Struct.new( :auto_placement, :availability_zone, :available_capacity, :client_token, :host_id, :host_properties, :host_reservation_id, :instances, :state, :allocation_time, :release_time, :tags, :host_recovery, :allows_multiple_instance_types, :owner_id, :availability_zone_id, :member_of_service_linked_resource_group, :outpost_arn, :host_maintenance, :asset_id, :cpu_options) SENSITIVE = [] include Aws::Structure end |
#host_maintenance ⇒ String
Indicates whether host maintenance is enabled or disabled for the Dedicated Host.
48339 48340 48341 48342 48343 48344 48345 48346 48347 48348 48349 48350 48351 48352 48353 48354 48355 48356 48357 48358 48359 48360 48361 48362 48363 |
# File 'lib/aws-sdk-ec2/types.rb', line 48339 class Host < Struct.new( :auto_placement, :availability_zone, :available_capacity, :client_token, :host_id, :host_properties, :host_reservation_id, :instances, :state, :allocation_time, :release_time, :tags, :host_recovery, :allows_multiple_instance_types, :owner_id, :availability_zone_id, :member_of_service_linked_resource_group, :outpost_arn, :host_maintenance, :asset_id, :cpu_options) SENSITIVE = [] include Aws::Structure end |
#host_properties ⇒ Types::HostProperties
The hardware specifications of the Dedicated Host.
48339 48340 48341 48342 48343 48344 48345 48346 48347 48348 48349 48350 48351 48352 48353 48354 48355 48356 48357 48358 48359 48360 48361 48362 48363 |
# File 'lib/aws-sdk-ec2/types.rb', line 48339 class Host < Struct.new( :auto_placement, :availability_zone, :available_capacity, :client_token, :host_id, :host_properties, :host_reservation_id, :instances, :state, :allocation_time, :release_time, :tags, :host_recovery, :allows_multiple_instance_types, :owner_id, :availability_zone_id, :member_of_service_linked_resource_group, :outpost_arn, :host_maintenance, :asset_id, :cpu_options) SENSITIVE = [] include Aws::Structure end |
#host_recovery ⇒ String
Indicates whether host recovery is enabled or disabled for the Dedicated Host.
48339 48340 48341 48342 48343 48344 48345 48346 48347 48348 48349 48350 48351 48352 48353 48354 48355 48356 48357 48358 48359 48360 48361 48362 48363 |
# File 'lib/aws-sdk-ec2/types.rb', line 48339 class Host < Struct.new( :auto_placement, :availability_zone, :available_capacity, :client_token, :host_id, :host_properties, :host_reservation_id, :instances, :state, :allocation_time, :release_time, :tags, :host_recovery, :allows_multiple_instance_types, :owner_id, :availability_zone_id, :member_of_service_linked_resource_group, :outpost_arn, :host_maintenance, :asset_id, :cpu_options) SENSITIVE = [] include Aws::Structure end |
#host_reservation_id ⇒ String
The reservation ID of the Dedicated Host. This returns a null
response if the Dedicated Host doesn't have an associated
reservation.
48339 48340 48341 48342 48343 48344 48345 48346 48347 48348 48349 48350 48351 48352 48353 48354 48355 48356 48357 48358 48359 48360 48361 48362 48363 |
# File 'lib/aws-sdk-ec2/types.rb', line 48339 class Host < Struct.new( :auto_placement, :availability_zone, :available_capacity, :client_token, :host_id, :host_properties, :host_reservation_id, :instances, :state, :allocation_time, :release_time, :tags, :host_recovery, :allows_multiple_instance_types, :owner_id, :availability_zone_id, :member_of_service_linked_resource_group, :outpost_arn, :host_maintenance, :asset_id, :cpu_options) SENSITIVE = [] include Aws::Structure end |
#instances ⇒ Array<Types::HostInstance>
The IDs and instance type that are currently running on the Dedicated Host.
48339 48340 48341 48342 48343 48344 48345 48346 48347 48348 48349 48350 48351 48352 48353 48354 48355 48356 48357 48358 48359 48360 48361 48362 48363 |
# File 'lib/aws-sdk-ec2/types.rb', line 48339 class Host < Struct.new( :auto_placement, :availability_zone, :available_capacity, :client_token, :host_id, :host_properties, :host_reservation_id, :instances, :state, :allocation_time, :release_time, :tags, :host_recovery, :allows_multiple_instance_types, :owner_id, :availability_zone_id, :member_of_service_linked_resource_group, :outpost_arn, :host_maintenance, :asset_id, :cpu_options) SENSITIVE = [] include Aws::Structure end |
#member_of_service_linked_resource_group ⇒ Boolean
Indicates whether the Dedicated Host is in a host resource group. If
memberOfServiceLinkedResourceGroup is true, the host is in a
host resource group; otherwise, it is not.
48339 48340 48341 48342 48343 48344 48345 48346 48347 48348 48349 48350 48351 48352 48353 48354 48355 48356 48357 48358 48359 48360 48361 48362 48363 |
# File 'lib/aws-sdk-ec2/types.rb', line 48339 class Host < Struct.new( :auto_placement, :availability_zone, :available_capacity, :client_token, :host_id, :host_properties, :host_reservation_id, :instances, :state, :allocation_time, :release_time, :tags, :host_recovery, :allows_multiple_instance_types, :owner_id, :availability_zone_id, :member_of_service_linked_resource_group, :outpost_arn, :host_maintenance, :asset_id, :cpu_options) SENSITIVE = [] include Aws::Structure end |
#outpost_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Web Services Outpost on which the Dedicated Host is allocated.
48339 48340 48341 48342 48343 48344 48345 48346 48347 48348 48349 48350 48351 48352 48353 48354 48355 48356 48357 48358 48359 48360 48361 48362 48363 |
# File 'lib/aws-sdk-ec2/types.rb', line 48339 class Host < Struct.new( :auto_placement, :availability_zone, :available_capacity, :client_token, :host_id, :host_properties, :host_reservation_id, :instances, :state, :allocation_time, :release_time, :tags, :host_recovery, :allows_multiple_instance_types, :owner_id, :availability_zone_id, :member_of_service_linked_resource_group, :outpost_arn, :host_maintenance, :asset_id, :cpu_options) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the Dedicated Host.
48339 48340 48341 48342 48343 48344 48345 48346 48347 48348 48349 48350 48351 48352 48353 48354 48355 48356 48357 48358 48359 48360 48361 48362 48363 |
# File 'lib/aws-sdk-ec2/types.rb', line 48339 class Host < Struct.new( :auto_placement, :availability_zone, :available_capacity, :client_token, :host_id, :host_properties, :host_reservation_id, :instances, :state, :allocation_time, :release_time, :tags, :host_recovery, :allows_multiple_instance_types, :owner_id, :availability_zone_id, :member_of_service_linked_resource_group, :outpost_arn, :host_maintenance, :asset_id, :cpu_options) SENSITIVE = [] include Aws::Structure end |
#release_time ⇒ Time
The time that the Dedicated Host was released.
48339 48340 48341 48342 48343 48344 48345 48346 48347 48348 48349 48350 48351 48352 48353 48354 48355 48356 48357 48358 48359 48360 48361 48362 48363 |
# File 'lib/aws-sdk-ec2/types.rb', line 48339 class Host < Struct.new( :auto_placement, :availability_zone, :available_capacity, :client_token, :host_id, :host_properties, :host_reservation_id, :instances, :state, :allocation_time, :release_time, :tags, :host_recovery, :allows_multiple_instance_types, :owner_id, :availability_zone_id, :member_of_service_linked_resource_group, :outpost_arn, :host_maintenance, :asset_id, :cpu_options) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The Dedicated Host's state.
48339 48340 48341 48342 48343 48344 48345 48346 48347 48348 48349 48350 48351 48352 48353 48354 48355 48356 48357 48358 48359 48360 48361 48362 48363 |
# File 'lib/aws-sdk-ec2/types.rb', line 48339 class Host < Struct.new( :auto_placement, :availability_zone, :available_capacity, :client_token, :host_id, :host_properties, :host_reservation_id, :instances, :state, :allocation_time, :release_time, :tags, :host_recovery, :allows_multiple_instance_types, :owner_id, :availability_zone_id, :member_of_service_linked_resource_group, :outpost_arn, :host_maintenance, :asset_id, :cpu_options) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Any tags assigned to the Dedicated Host.
48339 48340 48341 48342 48343 48344 48345 48346 48347 48348 48349 48350 48351 48352 48353 48354 48355 48356 48357 48358 48359 48360 48361 48362 48363 |
# File 'lib/aws-sdk-ec2/types.rb', line 48339 class Host < Struct.new( :auto_placement, :availability_zone, :available_capacity, :client_token, :host_id, :host_properties, :host_reservation_id, :instances, :state, :allocation_time, :release_time, :tags, :host_recovery, :allows_multiple_instance_types, :owner_id, :availability_zone_id, :member_of_service_linked_resource_group, :outpost_arn, :host_maintenance, :asset_id, :cpu_options) SENSITIVE = [] include Aws::Structure end |