Class: Aws::EC2::Types::Host

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes the properties of the Dedicated Host.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allocation_timeTime

The time that the Dedicated Host was allocated.

Returns:

  • (Time)


48161
48162
48163
48164
48165
48166
48167
48168
48169
48170
48171
48172
48173
48174
48175
48176
48177
48178
48179
48180
48181
48182
48183
48184
48185
# File 'lib/aws-sdk-ec2/types.rb', line 48161

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id,
  :cpu_options)
  SENSITIVE = []
  include Aws::Structure
end

#allows_multiple_instance_typesString

Indicates whether the Dedicated Host supports multiple instance types of the same instance family. If the value is on, the Dedicated Host supports multiple instance types in the instance family. If the value is off, the Dedicated Host supports a single instance type only.

Returns:

  • (String)


48161
48162
48163
48164
48165
48166
48167
48168
48169
48170
48171
48172
48173
48174
48175
48176
48177
48178
48179
48180
48181
48182
48183
48184
48185
# File 'lib/aws-sdk-ec2/types.rb', line 48161

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id,
  :cpu_options)
  SENSITIVE = []
  include Aws::Structure
end

#asset_idString

The ID of the Outpost hardware asset on which the Dedicated Host is allocated.

Returns:

  • (String)


48161
48162
48163
48164
48165
48166
48167
48168
48169
48170
48171
48172
48173
48174
48175
48176
48177
48178
48179
48180
48181
48182
48183
48184
48185
# File 'lib/aws-sdk-ec2/types.rb', line 48161

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id,
  :cpu_options)
  SENSITIVE = []
  include Aws::Structure
end

#auto_placementString

Whether auto-placement is on or off.

Returns:

  • (String)


48161
48162
48163
48164
48165
48166
48167
48168
48169
48170
48171
48172
48173
48174
48175
48176
48177
48178
48179
48180
48181
48182
48183
48184
48185
# File 'lib/aws-sdk-ec2/types.rb', line 48161

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id,
  :cpu_options)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zoneString

The Availability Zone of the Dedicated Host.

Returns:

  • (String)


48161
48162
48163
48164
48165
48166
48167
48168
48169
48170
48171
48172
48173
48174
48175
48176
48177
48178
48179
48180
48181
48182
48183
48184
48185
# File 'lib/aws-sdk-ec2/types.rb', line 48161

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id,
  :cpu_options)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zone_idString

The ID of the Availability Zone in which the Dedicated Host is allocated.

Returns:

  • (String)


48161
48162
48163
48164
48165
48166
48167
48168
48169
48170
48171
48172
48173
48174
48175
48176
48177
48178
48179
48180
48181
48182
48183
48184
48185
# File 'lib/aws-sdk-ec2/types.rb', line 48161

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id,
  :cpu_options)
  SENSITIVE = []
  include Aws::Structure
end

#available_capacityTypes::AvailableCapacity

Information about the instances running on the Dedicated Host.



48161
48162
48163
48164
48165
48166
48167
48168
48169
48170
48171
48172
48173
48174
48175
48176
48177
48178
48179
48180
48181
48182
48183
48184
48185
# File 'lib/aws-sdk-ec2/types.rb', line 48161

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id,
  :cpu_options)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring Idempotency.

Returns:

  • (String)


48161
48162
48163
48164
48165
48166
48167
48168
48169
48170
48171
48172
48173
48174
48175
48176
48177
48178
48179
48180
48181
48182
48183
48184
48185
# File 'lib/aws-sdk-ec2/types.rb', line 48161

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id,
  :cpu_options)
  SENSITIVE = []
  include Aws::Structure
end

#cpu_optionsTypes::HostCpuOptions

The CPU options for the Dedicated Host, including AMD Secure Encrypted Virtualization-Secure Nested Paging (AMD SEV-SNP) settings.



48161
48162
48163
48164
48165
48166
48167
48168
48169
48170
48171
48172
48173
48174
48175
48176
48177
48178
48179
48180
48181
48182
48183
48184
48185
# File 'lib/aws-sdk-ec2/types.rb', line 48161

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id,
  :cpu_options)
  SENSITIVE = []
  include Aws::Structure
end

#host_idString

The ID of the Dedicated Host.

Returns:

  • (String)


48161
48162
48163
48164
48165
48166
48167
48168
48169
48170
48171
48172
48173
48174
48175
48176
48177
48178
48179
48180
48181
48182
48183
48184
48185
# File 'lib/aws-sdk-ec2/types.rb', line 48161

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id,
  :cpu_options)
  SENSITIVE = []
  include Aws::Structure
end

#host_maintenanceString

Indicates whether host maintenance is enabled or disabled for the Dedicated Host.

Returns:

  • (String)


48161
48162
48163
48164
48165
48166
48167
48168
48169
48170
48171
48172
48173
48174
48175
48176
48177
48178
48179
48180
48181
48182
48183
48184
48185
# File 'lib/aws-sdk-ec2/types.rb', line 48161

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id,
  :cpu_options)
  SENSITIVE = []
  include Aws::Structure
end

#host_propertiesTypes::HostProperties

The hardware specifications of the Dedicated Host.



48161
48162
48163
48164
48165
48166
48167
48168
48169
48170
48171
48172
48173
48174
48175
48176
48177
48178
48179
48180
48181
48182
48183
48184
48185
# File 'lib/aws-sdk-ec2/types.rb', line 48161

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id,
  :cpu_options)
  SENSITIVE = []
  include Aws::Structure
end

#host_recoveryString

Indicates whether host recovery is enabled or disabled for the Dedicated Host.

Returns:

  • (String)


48161
48162
48163
48164
48165
48166
48167
48168
48169
48170
48171
48172
48173
48174
48175
48176
48177
48178
48179
48180
48181
48182
48183
48184
48185
# File 'lib/aws-sdk-ec2/types.rb', line 48161

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id,
  :cpu_options)
  SENSITIVE = []
  include Aws::Structure
end

#host_reservation_idString

The reservation ID of the Dedicated Host. This returns a null response if the Dedicated Host doesn't have an associated reservation.

Returns:

  • (String)


48161
48162
48163
48164
48165
48166
48167
48168
48169
48170
48171
48172
48173
48174
48175
48176
48177
48178
48179
48180
48181
48182
48183
48184
48185
# File 'lib/aws-sdk-ec2/types.rb', line 48161

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id,
  :cpu_options)
  SENSITIVE = []
  include Aws::Structure
end

#instancesArray<Types::HostInstance>

The IDs and instance type that are currently running on the Dedicated Host.

Returns:



48161
48162
48163
48164
48165
48166
48167
48168
48169
48170
48171
48172
48173
48174
48175
48176
48177
48178
48179
48180
48181
48182
48183
48184
48185
# File 'lib/aws-sdk-ec2/types.rb', line 48161

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id,
  :cpu_options)
  SENSITIVE = []
  include Aws::Structure
end

#member_of_service_linked_resource_groupBoolean

Indicates whether the Dedicated Host is in a host resource group. If memberOfServiceLinkedResourceGroup is true, the host is in a host resource group; otherwise, it is not.

Returns:

  • (Boolean)


48161
48162
48163
48164
48165
48166
48167
48168
48169
48170
48171
48172
48173
48174
48175
48176
48177
48178
48179
48180
48181
48182
48183
48184
48185
# File 'lib/aws-sdk-ec2/types.rb', line 48161

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id,
  :cpu_options)
  SENSITIVE = []
  include Aws::Structure
end

#outpost_arnString

The Amazon Resource Name (ARN) of the Amazon Web Services Outpost on which the Dedicated Host is allocated.

Returns:

  • (String)


48161
48162
48163
48164
48165
48166
48167
48168
48169
48170
48171
48172
48173
48174
48175
48176
48177
48178
48179
48180
48181
48182
48183
48184
48185
# File 'lib/aws-sdk-ec2/types.rb', line 48161

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id,
  :cpu_options)
  SENSITIVE = []
  include Aws::Structure
end

#owner_idString

The ID of the Amazon Web Services account that owns the Dedicated Host.

Returns:

  • (String)


48161
48162
48163
48164
48165
48166
48167
48168
48169
48170
48171
48172
48173
48174
48175
48176
48177
48178
48179
48180
48181
48182
48183
48184
48185
# File 'lib/aws-sdk-ec2/types.rb', line 48161

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id,
  :cpu_options)
  SENSITIVE = []
  include Aws::Structure
end

#release_timeTime

The time that the Dedicated Host was released.

Returns:

  • (Time)


48161
48162
48163
48164
48165
48166
48167
48168
48169
48170
48171
48172
48173
48174
48175
48176
48177
48178
48179
48180
48181
48182
48183
48184
48185
# File 'lib/aws-sdk-ec2/types.rb', line 48161

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id,
  :cpu_options)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The Dedicated Host's state.

Returns:

  • (String)


48161
48162
48163
48164
48165
48166
48167
48168
48169
48170
48171
48172
48173
48174
48175
48176
48177
48178
48179
48180
48181
48182
48183
48184
48185
# File 'lib/aws-sdk-ec2/types.rb', line 48161

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id,
  :cpu_options)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Any tags assigned to the Dedicated Host.

Returns:



48161
48162
48163
48164
48165
48166
48167
48168
48169
48170
48171
48172
48173
48174
48175
48176
48177
48178
48179
48180
48181
48182
48183
48184
48185
# File 'lib/aws-sdk-ec2/types.rb', line 48161

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id,
  :cpu_options)
  SENSITIVE = []
  include Aws::Structure
end