Class: Aws::EC2::Types::Host

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes the properties of the Dedicated Host.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allocation_timeTime

The time that the Dedicated Host was allocated.

Returns:

  • (Time)


47149
47150
47151
47152
47153
47154
47155
47156
47157
47158
47159
47160
47161
47162
47163
47164
47165
47166
47167
47168
47169
47170
47171
47172
# File 'lib/aws-sdk-ec2/types.rb', line 47149

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id)
  SENSITIVE = []
  include Aws::Structure
end

#allows_multiple_instance_typesString

Indicates whether the Dedicated Host supports multiple instance types of the same instance family. If the value is ‘on`, the Dedicated Host supports multiple instance types in the instance family. If the value is `off`, the Dedicated Host supports a single instance type only.

Returns:

  • (String)


47149
47150
47151
47152
47153
47154
47155
47156
47157
47158
47159
47160
47161
47162
47163
47164
47165
47166
47167
47168
47169
47170
47171
47172
# File 'lib/aws-sdk-ec2/types.rb', line 47149

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id)
  SENSITIVE = []
  include Aws::Structure
end

#asset_idString

The ID of the Outpost hardware asset on which the Dedicated Host is allocated.

Returns:

  • (String)


47149
47150
47151
47152
47153
47154
47155
47156
47157
47158
47159
47160
47161
47162
47163
47164
47165
47166
47167
47168
47169
47170
47171
47172
# File 'lib/aws-sdk-ec2/types.rb', line 47149

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id)
  SENSITIVE = []
  include Aws::Structure
end

#auto_placementString

Whether auto-placement is on or off.

Returns:

  • (String)


47149
47150
47151
47152
47153
47154
47155
47156
47157
47158
47159
47160
47161
47162
47163
47164
47165
47166
47167
47168
47169
47170
47171
47172
# File 'lib/aws-sdk-ec2/types.rb', line 47149

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zoneString

The Availability Zone of the Dedicated Host.

Returns:

  • (String)


47149
47150
47151
47152
47153
47154
47155
47156
47157
47158
47159
47160
47161
47162
47163
47164
47165
47166
47167
47168
47169
47170
47171
47172
# File 'lib/aws-sdk-ec2/types.rb', line 47149

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zone_idString

The ID of the Availability Zone in which the Dedicated Host is allocated.

Returns:

  • (String)


47149
47150
47151
47152
47153
47154
47155
47156
47157
47158
47159
47160
47161
47162
47163
47164
47165
47166
47167
47168
47169
47170
47171
47172
# File 'lib/aws-sdk-ec2/types.rb', line 47149

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id)
  SENSITIVE = []
  include Aws::Structure
end

#available_capacityTypes::AvailableCapacity

Information about the instances running on the Dedicated Host.



47149
47150
47151
47152
47153
47154
47155
47156
47157
47158
47159
47160
47161
47162
47163
47164
47165
47166
47167
47168
47169
47170
47171
47172
# File 'lib/aws-sdk-ec2/types.rb', line 47149

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [Ensuring Idempotency].

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html

Returns:

  • (String)


47149
47150
47151
47152
47153
47154
47155
47156
47157
47158
47159
47160
47161
47162
47163
47164
47165
47166
47167
47168
47169
47170
47171
47172
# File 'lib/aws-sdk-ec2/types.rb', line 47149

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id)
  SENSITIVE = []
  include Aws::Structure
end

#host_idString

The ID of the Dedicated Host.

Returns:

  • (String)


47149
47150
47151
47152
47153
47154
47155
47156
47157
47158
47159
47160
47161
47162
47163
47164
47165
47166
47167
47168
47169
47170
47171
47172
# File 'lib/aws-sdk-ec2/types.rb', line 47149

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id)
  SENSITIVE = []
  include Aws::Structure
end

#host_maintenanceString

Indicates whether host maintenance is enabled or disabled for the Dedicated Host.

Returns:

  • (String)


47149
47150
47151
47152
47153
47154
47155
47156
47157
47158
47159
47160
47161
47162
47163
47164
47165
47166
47167
47168
47169
47170
47171
47172
# File 'lib/aws-sdk-ec2/types.rb', line 47149

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id)
  SENSITIVE = []
  include Aws::Structure
end

#host_propertiesTypes::HostProperties

The hardware specifications of the Dedicated Host.



47149
47150
47151
47152
47153
47154
47155
47156
47157
47158
47159
47160
47161
47162
47163
47164
47165
47166
47167
47168
47169
47170
47171
47172
# File 'lib/aws-sdk-ec2/types.rb', line 47149

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id)
  SENSITIVE = []
  include Aws::Structure
end

#host_recoveryString

Indicates whether host recovery is enabled or disabled for the Dedicated Host.

Returns:

  • (String)


47149
47150
47151
47152
47153
47154
47155
47156
47157
47158
47159
47160
47161
47162
47163
47164
47165
47166
47167
47168
47169
47170
47171
47172
# File 'lib/aws-sdk-ec2/types.rb', line 47149

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id)
  SENSITIVE = []
  include Aws::Structure
end

#host_reservation_idString

The reservation ID of the Dedicated Host. This returns a ‘null` response if the Dedicated Host doesn’t have an associated reservation.

Returns:

  • (String)


47149
47150
47151
47152
47153
47154
47155
47156
47157
47158
47159
47160
47161
47162
47163
47164
47165
47166
47167
47168
47169
47170
47171
47172
# File 'lib/aws-sdk-ec2/types.rb', line 47149

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id)
  SENSITIVE = []
  include Aws::Structure
end

#instancesArray<Types::HostInstance>

The IDs and instance type that are currently running on the Dedicated Host.

Returns:



47149
47150
47151
47152
47153
47154
47155
47156
47157
47158
47159
47160
47161
47162
47163
47164
47165
47166
47167
47168
47169
47170
47171
47172
# File 'lib/aws-sdk-ec2/types.rb', line 47149

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id)
  SENSITIVE = []
  include Aws::Structure
end

#member_of_service_linked_resource_groupBoolean

Indicates whether the Dedicated Host is in a host resource group. If memberOfServiceLinkedResourceGroup is ‘true`, the host is in a host resource group; otherwise, it is not.

Returns:

  • (Boolean)


47149
47150
47151
47152
47153
47154
47155
47156
47157
47158
47159
47160
47161
47162
47163
47164
47165
47166
47167
47168
47169
47170
47171
47172
# File 'lib/aws-sdk-ec2/types.rb', line 47149

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id)
  SENSITIVE = []
  include Aws::Structure
end

#outpost_arnString

The Amazon Resource Name (ARN) of the Amazon Web Services Outpost on which the Dedicated Host is allocated.

Returns:

  • (String)


47149
47150
47151
47152
47153
47154
47155
47156
47157
47158
47159
47160
47161
47162
47163
47164
47165
47166
47167
47168
47169
47170
47171
47172
# File 'lib/aws-sdk-ec2/types.rb', line 47149

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id)
  SENSITIVE = []
  include Aws::Structure
end

#owner_idString

The ID of the Amazon Web Services account that owns the Dedicated Host.

Returns:

  • (String)


47149
47150
47151
47152
47153
47154
47155
47156
47157
47158
47159
47160
47161
47162
47163
47164
47165
47166
47167
47168
47169
47170
47171
47172
# File 'lib/aws-sdk-ec2/types.rb', line 47149

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id)
  SENSITIVE = []
  include Aws::Structure
end

#release_timeTime

The time that the Dedicated Host was released.

Returns:

  • (Time)


47149
47150
47151
47152
47153
47154
47155
47156
47157
47158
47159
47160
47161
47162
47163
47164
47165
47166
47167
47168
47169
47170
47171
47172
# File 'lib/aws-sdk-ec2/types.rb', line 47149

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The Dedicated Host’s state.

Returns:

  • (String)


47149
47150
47151
47152
47153
47154
47155
47156
47157
47158
47159
47160
47161
47162
47163
47164
47165
47166
47167
47168
47169
47170
47171
47172
# File 'lib/aws-sdk-ec2/types.rb', line 47149

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Any tags assigned to the Dedicated Host.

Returns:



47149
47150
47151
47152
47153
47154
47155
47156
47157
47158
47159
47160
47161
47162
47163
47164
47165
47166
47167
47168
47169
47170
47171
47172
# File 'lib/aws-sdk-ec2/types.rb', line 47149

class Host < Struct.new(
  :auto_placement,
  :availability_zone,
  :available_capacity,
  :client_token,
  :host_id,
  :host_properties,
  :host_reservation_id,
  :instances,
  :state,
  :allocation_time,
  :release_time,
  :tags,
  :host_recovery,
  :allows_multiple_instance_types,
  :owner_id,
  :availability_zone_id,
  :member_of_service_linked_resource_group,
  :outpost_arn,
  :host_maintenance,
  :asset_id)
  SENSITIVE = []
  include Aws::Structure
end