Class: Aws::EC2::Types::HostReservation
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::HostReservation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Details about the Dedicated Host Reservation and associated Dedicated Hosts.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#count ⇒ Integer
The number of Dedicated Hosts the reservation is associated with.
-
#currency_code ⇒ String
The currency in which the ‘upfrontPrice` and `hourlyPrice` amounts are specified.
-
#duration ⇒ Integer
The length of the reservation’s term, specified in seconds.
-
#end ⇒ Time
The date and time that the reservation ends.
-
#host_id_set ⇒ Array<String>
The IDs of the Dedicated Hosts associated with the reservation.
-
#host_reservation_id ⇒ String
The ID of the reservation that specifies the associated Dedicated Hosts.
-
#hourly_price ⇒ String
The hourly price of the reservation.
-
#instance_family ⇒ String
The instance family of the Dedicated Host Reservation.
-
#offering_id ⇒ String
The ID of the reservation.
-
#payment_option ⇒ String
The payment option selected for this reservation.
-
#start ⇒ Time
The date and time that the reservation started.
-
#state ⇒ String
The state of the reservation.
-
#tags ⇒ Array<Types::Tag>
Any tags assigned to the Dedicated Host Reservation.
-
#upfront_price ⇒ String
The upfront price of the reservation.
Instance Attribute Details
#count ⇒ Integer
The number of Dedicated Hosts the reservation is associated with.
46734 46735 46736 46737 46738 46739 46740 46741 46742 46743 46744 46745 46746 46747 46748 46749 46750 46751 |
# File 'lib/aws-sdk-ec2/types.rb', line 46734 class HostReservation < Struct.new( :count, :currency_code, :duration, :end, :host_id_set, :host_reservation_id, :hourly_price, :instance_family, :offering_id, :payment_option, :start, :state, :upfront_price, :tags) SENSITIVE = [] include Aws::Structure end |
#currency_code ⇒ String
The currency in which the ‘upfrontPrice` and `hourlyPrice` amounts are specified. At this time, the only supported currency is `USD`.
46734 46735 46736 46737 46738 46739 46740 46741 46742 46743 46744 46745 46746 46747 46748 46749 46750 46751 |
# File 'lib/aws-sdk-ec2/types.rb', line 46734 class HostReservation < Struct.new( :count, :currency_code, :duration, :end, :host_id_set, :host_reservation_id, :hourly_price, :instance_family, :offering_id, :payment_option, :start, :state, :upfront_price, :tags) SENSITIVE = [] include Aws::Structure end |
#duration ⇒ Integer
The length of the reservation’s term, specified in seconds. Can be ‘31536000 (1 year)` | `94608000 (3 years)`.
46734 46735 46736 46737 46738 46739 46740 46741 46742 46743 46744 46745 46746 46747 46748 46749 46750 46751 |
# File 'lib/aws-sdk-ec2/types.rb', line 46734 class HostReservation < Struct.new( :count, :currency_code, :duration, :end, :host_id_set, :host_reservation_id, :hourly_price, :instance_family, :offering_id, :payment_option, :start, :state, :upfront_price, :tags) SENSITIVE = [] include Aws::Structure end |
#end ⇒ Time
The date and time that the reservation ends.
46734 46735 46736 46737 46738 46739 46740 46741 46742 46743 46744 46745 46746 46747 46748 46749 46750 46751 |
# File 'lib/aws-sdk-ec2/types.rb', line 46734 class HostReservation < Struct.new( :count, :currency_code, :duration, :end, :host_id_set, :host_reservation_id, :hourly_price, :instance_family, :offering_id, :payment_option, :start, :state, :upfront_price, :tags) SENSITIVE = [] include Aws::Structure end |
#host_id_set ⇒ Array<String>
The IDs of the Dedicated Hosts associated with the reservation.
46734 46735 46736 46737 46738 46739 46740 46741 46742 46743 46744 46745 46746 46747 46748 46749 46750 46751 |
# File 'lib/aws-sdk-ec2/types.rb', line 46734 class HostReservation < Struct.new( :count, :currency_code, :duration, :end, :host_id_set, :host_reservation_id, :hourly_price, :instance_family, :offering_id, :payment_option, :start, :state, :upfront_price, :tags) SENSITIVE = [] include Aws::Structure end |
#host_reservation_id ⇒ String
The ID of the reservation that specifies the associated Dedicated Hosts.
46734 46735 46736 46737 46738 46739 46740 46741 46742 46743 46744 46745 46746 46747 46748 46749 46750 46751 |
# File 'lib/aws-sdk-ec2/types.rb', line 46734 class HostReservation < Struct.new( :count, :currency_code, :duration, :end, :host_id_set, :host_reservation_id, :hourly_price, :instance_family, :offering_id, :payment_option, :start, :state, :upfront_price, :tags) SENSITIVE = [] include Aws::Structure end |
#hourly_price ⇒ String
The hourly price of the reservation.
46734 46735 46736 46737 46738 46739 46740 46741 46742 46743 46744 46745 46746 46747 46748 46749 46750 46751 |
# File 'lib/aws-sdk-ec2/types.rb', line 46734 class HostReservation < Struct.new( :count, :currency_code, :duration, :end, :host_id_set, :host_reservation_id, :hourly_price, :instance_family, :offering_id, :payment_option, :start, :state, :upfront_price, :tags) SENSITIVE = [] include Aws::Structure end |
#instance_family ⇒ String
The instance family of the Dedicated Host Reservation. The instance family on the Dedicated Host must be the same in order for it to benefit from the reservation.
46734 46735 46736 46737 46738 46739 46740 46741 46742 46743 46744 46745 46746 46747 46748 46749 46750 46751 |
# File 'lib/aws-sdk-ec2/types.rb', line 46734 class HostReservation < Struct.new( :count, :currency_code, :duration, :end, :host_id_set, :host_reservation_id, :hourly_price, :instance_family, :offering_id, :payment_option, :start, :state, :upfront_price, :tags) SENSITIVE = [] include Aws::Structure end |
#offering_id ⇒ String
The ID of the reservation. This remains the same regardless of which Dedicated Hosts are associated with it.
46734 46735 46736 46737 46738 46739 46740 46741 46742 46743 46744 46745 46746 46747 46748 46749 46750 46751 |
# File 'lib/aws-sdk-ec2/types.rb', line 46734 class HostReservation < Struct.new( :count, :currency_code, :duration, :end, :host_id_set, :host_reservation_id, :hourly_price, :instance_family, :offering_id, :payment_option, :start, :state, :upfront_price, :tags) SENSITIVE = [] include Aws::Structure end |
#payment_option ⇒ String
The payment option selected for this reservation.
46734 46735 46736 46737 46738 46739 46740 46741 46742 46743 46744 46745 46746 46747 46748 46749 46750 46751 |
# File 'lib/aws-sdk-ec2/types.rb', line 46734 class HostReservation < Struct.new( :count, :currency_code, :duration, :end, :host_id_set, :host_reservation_id, :hourly_price, :instance_family, :offering_id, :payment_option, :start, :state, :upfront_price, :tags) SENSITIVE = [] include Aws::Structure end |
#start ⇒ Time
The date and time that the reservation started.
46734 46735 46736 46737 46738 46739 46740 46741 46742 46743 46744 46745 46746 46747 46748 46749 46750 46751 |
# File 'lib/aws-sdk-ec2/types.rb', line 46734 class HostReservation < Struct.new( :count, :currency_code, :duration, :end, :host_id_set, :host_reservation_id, :hourly_price, :instance_family, :offering_id, :payment_option, :start, :state, :upfront_price, :tags) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the reservation.
46734 46735 46736 46737 46738 46739 46740 46741 46742 46743 46744 46745 46746 46747 46748 46749 46750 46751 |
# File 'lib/aws-sdk-ec2/types.rb', line 46734 class HostReservation < Struct.new( :count, :currency_code, :duration, :end, :host_id_set, :host_reservation_id, :hourly_price, :instance_family, :offering_id, :payment_option, :start, :state, :upfront_price, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Any tags assigned to the Dedicated Host Reservation.
46734 46735 46736 46737 46738 46739 46740 46741 46742 46743 46744 46745 46746 46747 46748 46749 46750 46751 |
# File 'lib/aws-sdk-ec2/types.rb', line 46734 class HostReservation < Struct.new( :count, :currency_code, :duration, :end, :host_id_set, :host_reservation_id, :hourly_price, :instance_family, :offering_id, :payment_option, :start, :state, :upfront_price, :tags) SENSITIVE = [] include Aws::Structure end |
#upfront_price ⇒ String
The upfront price of the reservation.
46734 46735 46736 46737 46738 46739 46740 46741 46742 46743 46744 46745 46746 46747 46748 46749 46750 46751 |
# File 'lib/aws-sdk-ec2/types.rb', line 46734 class HostReservation < Struct.new( :count, :currency_code, :duration, :end, :host_id_set, :host_reservation_id, :hourly_price, :instance_family, :offering_id, :payment_option, :start, :state, :upfront_price, :tags) SENSITIVE = [] include Aws::Structure end |