Class: Aws::EC2::Types::Image
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::Image
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes an image.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#architecture ⇒ String
The architecture of the image.
-
#block_device_mappings ⇒ Array<Types::BlockDeviceMapping>
Any block device mapping entries.
-
#boot_mode ⇒ String
The boot mode of the image.
-
#creation_date ⇒ String
The date and time the image was created.
-
#deprecation_time ⇒ String
The date and time to deprecate the AMI, in UTC, in the following format: YYYY-MM-*DD*T*HH*:MM:*SS*Z.
-
#deregistration_protection ⇒ String
Indicates whether deregistration protection is enabled for the AMI.
-
#description ⇒ String
The description of the AMI that was provided during image creation.
-
#ena_support ⇒ Boolean
Specifies whether enhanced networking with ENA is enabled.
-
#free_tier_eligible ⇒ Boolean
Indicates whether the image is eligible for Amazon Web Services Free Tier.
-
#hypervisor ⇒ String
The hypervisor type of the image.
-
#image_allowed ⇒ Boolean
If ‘true`, the AMI satisfies the criteria for Allowed AMIs and can be discovered and used in the account.
-
#image_id ⇒ String
The ID of the AMI.
-
#image_location ⇒ String
The location of the AMI.
-
#image_owner_alias ⇒ String
The owner alias (‘amazon` | `aws-backup-vault` | `aws-marketplace`).
-
#image_type ⇒ String
The type of image.
-
#imds_support ⇒ String
If ‘v2.0`, it indicates that IMDSv2 is specified in the AMI.
-
#kernel_id ⇒ String
The kernel associated with the image, if any.
-
#last_launched_time ⇒ String
The date and time, in [ISO 8601 date-time format], when the AMI was last used to launch an EC2 instance.
-
#name ⇒ String
The name of the AMI that was provided during image creation.
-
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the image.
-
#platform ⇒ String
This value is set to ‘windows` for Windows AMIs; otherwise, it is blank.
-
#platform_details ⇒ String
The platform details associated with the billing code of the AMI.
-
#product_codes ⇒ Array<Types::ProductCode>
Any product codes associated with the AMI.
-
#public ⇒ Boolean
Indicates whether the image has public launch permissions.
-
#ramdisk_id ⇒ String
The RAM disk associated with the image, if any.
-
#root_device_name ⇒ String
The device name of the root device volume (for example, ‘/dev/sda1`).
-
#root_device_type ⇒ String
The type of root device used by the AMI.
-
#source_image_id ⇒ String
The ID of the source AMI from which the AMI was created.
-
#source_image_region ⇒ String
The Region of the source AMI.
-
#source_instance_id ⇒ String
The ID of the instance that the AMI was created from if the AMI was created using [CreateImage].
-
#sriov_net_support ⇒ String
Specifies whether enhanced networking with the Intel 82599 Virtual Function interface is enabled.
-
#state ⇒ String
The current state of the AMI.
-
#state_reason ⇒ Types::StateReason
The reason for the state change.
-
#tags ⇒ Array<Types::Tag>
Any tags assigned to the image.
-
#tpm_support ⇒ String
If the image is configured for NitroTPM support, the value is ‘v2.0`.
-
#usage_operation ⇒ String
The operation of the Amazon EC2 instance and the billing code that is associated with the AMI.
-
#virtualization_type ⇒ String
The type of virtualization of the AMI.
Instance Attribute Details
#architecture ⇒ String
The architecture of the image.
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |
#block_device_mappings ⇒ Array<Types::BlockDeviceMapping>
Any block device mapping entries.
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |
#boot_mode ⇒ String
The boot mode of the image. For more information, see [Instance launch behavior with Amazon EC2 boot modes] in the *Amazon EC2 User Guide*.
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/ami-boot.html
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |
#creation_date ⇒ String
The date and time the image was created.
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |
#deprecation_time ⇒ String
The date and time to deprecate the AMI, in UTC, in the following format: YYYY-MM-*DD*T*HH*:MM:*SS*Z. If you specified a value for seconds, Amazon EC2 rounds the seconds to the nearest minute.
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |
#deregistration_protection ⇒ String
Indicates whether deregistration protection is enabled for the AMI.
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the AMI that was provided during image creation.
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |
#ena_support ⇒ Boolean
Specifies whether enhanced networking with ENA is enabled.
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |
#free_tier_eligible ⇒ Boolean
Indicates whether the image is eligible for Amazon Web Services Free Tier.
-
If ‘true`, the AMI is eligible for Free Tier and can be used to launch instances under the Free Tier limits.
-
If ‘false`, the AMI is not eligible for Free Tier.
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |
#hypervisor ⇒ String
The hypervisor type of the image. Only ‘xen` is supported. `ovm` is not supported.
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |
#image_allowed ⇒ Boolean
If ‘true`, the AMI satisfies the criteria for Allowed AMIs and can be discovered and used in the account. If `false` and Allowed AMIs is set to `enabled`, the AMI can’t be discovered or used in the account. If ‘false` and Allowed AMIs is set to `audit-mode`, the AMI can be discovered and used in the account.
For more information, see [Control the discovery and use of AMIs in Amazon EC2 with Allowed AMIs] in *Amazon EC2 User Guide*.
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-allowed-amis.html
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |
#image_id ⇒ String
The ID of the AMI.
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |
#image_location ⇒ String
The location of the AMI.
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |
#image_owner_alias ⇒ String
The owner alias (‘amazon` | `aws-backup-vault` | `aws-marketplace`).
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |
#image_type ⇒ String
The type of image.
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |
#imds_support ⇒ String
If ‘v2.0`, it indicates that IMDSv2 is specified in the AMI. Instances launched from this AMI will have `HttpTokens` automatically set to `required` so that, by default, the instance requires that IMDSv2 is used when requesting instance metadata. In addition, `HttpPutResponseHopLimit` is set to `2`. For more information, see [Configure the AMI] in the *Amazon EC2 User Guide*.
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |
#kernel_id ⇒ String
The kernel associated with the image, if any. Only applicable for machine images.
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |
#last_launched_time ⇒ String
The date and time, in [ISO 8601 date-time format], when the AMI was last used to launch an EC2 instance. When the AMI is used to launch an instance, there is a 24-hour delay before that usage is reported.
<note markdown=“1”> ‘lastLaunchedTime` data is available starting April 2017.
</note>
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the AMI that was provided during image creation.
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the image.
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |
#platform ⇒ String
This value is set to ‘windows` for Windows AMIs; otherwise, it is blank.
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |
#platform_details ⇒ String
The platform details associated with the billing code of the AMI. For more information, see [Understand AMI billing information] in the *Amazon EC2 User Guide*.
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/ami-billing-info.html
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |
#product_codes ⇒ Array<Types::ProductCode>
Any product codes associated with the AMI.
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |
#public ⇒ Boolean
Indicates whether the image has public launch permissions. The value is ‘true` if this image has public launch permissions or `false` if it has only implicit and explicit launch permissions.
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |
#ramdisk_id ⇒ String
The RAM disk associated with the image, if any. Only applicable for machine images.
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |
#root_device_name ⇒ String
The device name of the root device volume (for example, ‘/dev/sda1`).
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |
#root_device_type ⇒ String
The type of root device used by the AMI. The AMI can use an Amazon EBS volume or an instance store volume.
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |
#source_image_id ⇒ String
The ID of the source AMI from which the AMI was created.
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |
#source_image_region ⇒ String
The Region of the source AMI.
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |
#source_instance_id ⇒ String
The ID of the instance that the AMI was created from if the AMI was created using [CreateImage]. This field only appears if the AMI was created using CreateImage.
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateImage.html
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |
#sriov_net_support ⇒ String
Specifies whether enhanced networking with the Intel 82599 Virtual Function interface is enabled.
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the AMI. If the state is ‘available`, the image is successfully registered and can be used to launch an instance.
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |
#state_reason ⇒ Types::StateReason
The reason for the state change.
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Any tags assigned to the image.
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |
#tpm_support ⇒ String
If the image is configured for NitroTPM support, the value is ‘v2.0`. For more information, see [NitroTPM] in the *Amazon EC2 User Guide*.
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/nitrotpm.html
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |
#usage_operation ⇒ String
The operation of the Amazon EC2 instance and the billing code that is associated with the AMI. ‘usageOperation` corresponds to the
- lineitem/Operation][1
-
column on your Amazon Web Services Cost and
Usage Report and in the [Amazon Web Services Price List API]. You can view these fields on the Instances or AMIs pages in the Amazon EC2 console, or in the responses that are returned by the
- DescribeImages][3
-
command in the Amazon EC2 API, or the
- describe-images][4
-
command in the CLI.
[1]: docs.aws.amazon.com/cur/latest/userguide/Lineitem-columns.html#Lineitem-details-O-Operation [2]: docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/price-changes.html [3]: docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeImages.html [4]: docs.aws.amazon.com/cli/latest/reference/ec2/describe-images.html
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |
#virtualization_type ⇒ String
The type of virtualization of the AMI.
47049 47050 47051 47052 47053 47054 47055 47056 47057 47058 47059 47060 47061 47062 47063 47064 47065 47066 47067 47068 47069 47070 47071 47072 47073 47074 47075 47076 47077 47078 47079 47080 47081 47082 47083 47084 47085 47086 47087 47088 47089 |
# File 'lib/aws-sdk-ec2/types.rb', line 47049 class Image < Struct.new( :platform_details, :usage_operation, :block_device_mappings, :description, :ena_support, :hypervisor, :image_owner_alias, :name, :root_device_name, :root_device_type, :sriov_net_support, :state_reason, :tags, :virtualization_type, :boot_mode, :tpm_support, :deprecation_time, :imds_support, :source_instance_id, :deregistration_protection, :last_launched_time, :image_allowed, :source_image_id, :source_image_region, :free_tier_eligible, :image_id, :image_location, :state, :owner_id, :creation_date, :public, :product_codes, :architecture, :image_type, :kernel_id, :ramdisk_id, :platform) SENSITIVE = [] include Aws::Structure end |