Class: Aws::EC2::Types::ImageAttribute
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ImageAttribute
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes an image attribute.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#block_device_mappings ⇒ Array<Types::BlockDeviceMapping>
The block device mapping entries.
-
#boot_mode ⇒ Types::AttributeValue
The boot mode.
-
#deregistration_protection ⇒ Types::AttributeValue
Indicates whether deregistration protection is enabled for the AMI.
-
#description ⇒ Types::AttributeValue
A description for the AMI.
-
#image_id ⇒ String
The ID of the AMI.
-
#imds_support ⇒ Types::AttributeValue
If
v2.0, it indicates that IMDSv2 is specified in the AMI. -
#kernel_id ⇒ Types::AttributeValue
The kernel ID.
-
#last_launched_time ⇒ Types::AttributeValue
The date and time, in [ISO 8601 date-time format][1], when the AMI was last used to launch an EC2 instance.
-
#launch_permissions ⇒ Array<Types::LaunchPermission>
The launch permissions.
-
#product_codes ⇒ Array<Types::ProductCode>
The product codes.
-
#ramdisk_id ⇒ Types::AttributeValue
The RAM disk ID.
-
#sriov_net_support ⇒ Types::AttributeValue
Indicates whether enhanced networking with the Intel 82599 Virtual Function interface is enabled.
-
#tpm_support ⇒ Types::AttributeValue
If the image is configured for NitroTPM support, the value is
v2.0. -
#uefi_data ⇒ Types::AttributeValue
Base64 representation of the non-volatile UEFI variable store.
Instance Attribute Details
#block_device_mappings ⇒ Array<Types::BlockDeviceMapping>
The block device mapping entries.
50478 50479 50480 50481 50482 50483 50484 50485 50486 50487 50488 50489 50490 50491 50492 50493 50494 50495 |
# File 'lib/aws-sdk-ec2/types.rb', line 50478 class ImageAttribute < Struct.new( :description, :kernel_id, :ramdisk_id, :sriov_net_support, :boot_mode, :tpm_support, :uefi_data, :last_launched_time, :imds_support, :deregistration_protection, :image_id, :launch_permissions, :product_codes, :block_device_mappings) SENSITIVE = [] include Aws::Structure end |
#boot_mode ⇒ Types::AttributeValue
The boot mode.
50478 50479 50480 50481 50482 50483 50484 50485 50486 50487 50488 50489 50490 50491 50492 50493 50494 50495 |
# File 'lib/aws-sdk-ec2/types.rb', line 50478 class ImageAttribute < Struct.new( :description, :kernel_id, :ramdisk_id, :sriov_net_support, :boot_mode, :tpm_support, :uefi_data, :last_launched_time, :imds_support, :deregistration_protection, :image_id, :launch_permissions, :product_codes, :block_device_mappings) SENSITIVE = [] include Aws::Structure end |
#deregistration_protection ⇒ Types::AttributeValue
Indicates whether deregistration protection is enabled for the AMI.
50478 50479 50480 50481 50482 50483 50484 50485 50486 50487 50488 50489 50490 50491 50492 50493 50494 50495 |
# File 'lib/aws-sdk-ec2/types.rb', line 50478 class ImageAttribute < Struct.new( :description, :kernel_id, :ramdisk_id, :sriov_net_support, :boot_mode, :tpm_support, :uefi_data, :last_launched_time, :imds_support, :deregistration_protection, :image_id, :launch_permissions, :product_codes, :block_device_mappings) SENSITIVE = [] include Aws::Structure end |
#description ⇒ Types::AttributeValue
A description for the AMI.
50478 50479 50480 50481 50482 50483 50484 50485 50486 50487 50488 50489 50490 50491 50492 50493 50494 50495 |
# File 'lib/aws-sdk-ec2/types.rb', line 50478 class ImageAttribute < Struct.new( :description, :kernel_id, :ramdisk_id, :sriov_net_support, :boot_mode, :tpm_support, :uefi_data, :last_launched_time, :imds_support, :deregistration_protection, :image_id, :launch_permissions, :product_codes, :block_device_mappings) SENSITIVE = [] include Aws::Structure end |
#image_id ⇒ String
The ID of the AMI.
50478 50479 50480 50481 50482 50483 50484 50485 50486 50487 50488 50489 50490 50491 50492 50493 50494 50495 |
# File 'lib/aws-sdk-ec2/types.rb', line 50478 class ImageAttribute < Struct.new( :description, :kernel_id, :ramdisk_id, :sriov_net_support, :boot_mode, :tpm_support, :uefi_data, :last_launched_time, :imds_support, :deregistration_protection, :image_id, :launch_permissions, :product_codes, :block_device_mappings) SENSITIVE = [] include Aws::Structure end |
#imds_support ⇒ Types::AttributeValue
If v2.0, it indicates that IMDSv2 is specified in the AMI.
Instances launched from this AMI will have HttpTokens
automatically set to required so that, by default, the instance
requires that IMDSv2 is used when requesting instance metadata. In
addition, HttpPutResponseHopLimit is set to 2. For more
information, see Configure the AMI in the Amazon EC2 User
Guide.
50478 50479 50480 50481 50482 50483 50484 50485 50486 50487 50488 50489 50490 50491 50492 50493 50494 50495 |
# File 'lib/aws-sdk-ec2/types.rb', line 50478 class ImageAttribute < Struct.new( :description, :kernel_id, :ramdisk_id, :sriov_net_support, :boot_mode, :tpm_support, :uefi_data, :last_launched_time, :imds_support, :deregistration_protection, :image_id, :launch_permissions, :product_codes, :block_device_mappings) SENSITIVE = [] include Aws::Structure end |
#kernel_id ⇒ Types::AttributeValue
The kernel ID.
50478 50479 50480 50481 50482 50483 50484 50485 50486 50487 50488 50489 50490 50491 50492 50493 50494 50495 |
# File 'lib/aws-sdk-ec2/types.rb', line 50478 class ImageAttribute < Struct.new( :description, :kernel_id, :ramdisk_id, :sriov_net_support, :boot_mode, :tpm_support, :uefi_data, :last_launched_time, :imds_support, :deregistration_protection, :image_id, :launch_permissions, :product_codes, :block_device_mappings) SENSITIVE = [] include Aws::Structure end |
#last_launched_time ⇒ Types::AttributeValue
The date and time, in ISO 8601 date-time format, when the AMI was last used to launch an EC2 instance. When the AMI is used to launch an instance, there is a 24-hour delay before that usage is reported.
lastLaunchedTime data is available starting April 2017.
50478 50479 50480 50481 50482 50483 50484 50485 50486 50487 50488 50489 50490 50491 50492 50493 50494 50495 |
# File 'lib/aws-sdk-ec2/types.rb', line 50478 class ImageAttribute < Struct.new( :description, :kernel_id, :ramdisk_id, :sriov_net_support, :boot_mode, :tpm_support, :uefi_data, :last_launched_time, :imds_support, :deregistration_protection, :image_id, :launch_permissions, :product_codes, :block_device_mappings) SENSITIVE = [] include Aws::Structure end |
#launch_permissions ⇒ Array<Types::LaunchPermission>
The launch permissions.
50478 50479 50480 50481 50482 50483 50484 50485 50486 50487 50488 50489 50490 50491 50492 50493 50494 50495 |
# File 'lib/aws-sdk-ec2/types.rb', line 50478 class ImageAttribute < Struct.new( :description, :kernel_id, :ramdisk_id, :sriov_net_support, :boot_mode, :tpm_support, :uefi_data, :last_launched_time, :imds_support, :deregistration_protection, :image_id, :launch_permissions, :product_codes, :block_device_mappings) SENSITIVE = [] include Aws::Structure end |
#product_codes ⇒ Array<Types::ProductCode>
The product codes.
50478 50479 50480 50481 50482 50483 50484 50485 50486 50487 50488 50489 50490 50491 50492 50493 50494 50495 |
# File 'lib/aws-sdk-ec2/types.rb', line 50478 class ImageAttribute < Struct.new( :description, :kernel_id, :ramdisk_id, :sriov_net_support, :boot_mode, :tpm_support, :uefi_data, :last_launched_time, :imds_support, :deregistration_protection, :image_id, :launch_permissions, :product_codes, :block_device_mappings) SENSITIVE = [] include Aws::Structure end |
#ramdisk_id ⇒ Types::AttributeValue
The RAM disk ID.
50478 50479 50480 50481 50482 50483 50484 50485 50486 50487 50488 50489 50490 50491 50492 50493 50494 50495 |
# File 'lib/aws-sdk-ec2/types.rb', line 50478 class ImageAttribute < Struct.new( :description, :kernel_id, :ramdisk_id, :sriov_net_support, :boot_mode, :tpm_support, :uefi_data, :last_launched_time, :imds_support, :deregistration_protection, :image_id, :launch_permissions, :product_codes, :block_device_mappings) SENSITIVE = [] include Aws::Structure end |
#sriov_net_support ⇒ Types::AttributeValue
Indicates whether enhanced networking with the Intel 82599 Virtual Function interface is enabled.
50478 50479 50480 50481 50482 50483 50484 50485 50486 50487 50488 50489 50490 50491 50492 50493 50494 50495 |
# File 'lib/aws-sdk-ec2/types.rb', line 50478 class ImageAttribute < Struct.new( :description, :kernel_id, :ramdisk_id, :sriov_net_support, :boot_mode, :tpm_support, :uefi_data, :last_launched_time, :imds_support, :deregistration_protection, :image_id, :launch_permissions, :product_codes, :block_device_mappings) SENSITIVE = [] include Aws::Structure end |
#tpm_support ⇒ Types::AttributeValue
If the image is configured for NitroTPM support, the value is
v2.0.
50478 50479 50480 50481 50482 50483 50484 50485 50486 50487 50488 50489 50490 50491 50492 50493 50494 50495 |
# File 'lib/aws-sdk-ec2/types.rb', line 50478 class ImageAttribute < Struct.new( :description, :kernel_id, :ramdisk_id, :sriov_net_support, :boot_mode, :tpm_support, :uefi_data, :last_launched_time, :imds_support, :deregistration_protection, :image_id, :launch_permissions, :product_codes, :block_device_mappings) SENSITIVE = [] include Aws::Structure end |
#uefi_data ⇒ Types::AttributeValue
Base64 representation of the non-volatile UEFI variable store. To retrieve the UEFI data, use the GetInstanceUefiData command. You can inspect and modify the UEFI data by using the python-uefivars tool on GitHub. For more information, see UEFI Secure Boot for Amazon EC2 instances in the Amazon EC2 User Guide.
50478 50479 50480 50481 50482 50483 50484 50485 50486 50487 50488 50489 50490 50491 50492 50493 50494 50495 |
# File 'lib/aws-sdk-ec2/types.rb', line 50478 class ImageAttribute < Struct.new( :description, :kernel_id, :ramdisk_id, :sriov_net_support, :boot_mode, :tpm_support, :uefi_data, :last_launched_time, :imds_support, :deregistration_protection, :image_id, :launch_permissions, :product_codes, :block_device_mappings) SENSITIVE = [] include Aws::Structure end |