Class: Aws::EC2::Types::ImageAttribute

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes an image attribute.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#block_device_mappingsArray<Types::BlockDeviceMapping>

The block device mapping entries.

Returns:



48325
48326
48327
48328
48329
48330
48331
48332
48333
48334
48335
48336
48337
48338
48339
48340
48341
48342
# File 'lib/aws-sdk-ec2/types.rb', line 48325

class ImageAttribute < Struct.new(
  :description,
  :kernel_id,
  :ramdisk_id,
  :sriov_net_support,
  :boot_mode,
  :tpm_support,
  :uefi_data,
  :last_launched_time,
  :imds_support,
  :deregistration_protection,
  :image_id,
  :launch_permissions,
  :product_codes,
  :block_device_mappings)
  SENSITIVE = []
  include Aws::Structure
end

#boot_modeTypes::AttributeValue

The boot mode.



48325
48326
48327
48328
48329
48330
48331
48332
48333
48334
48335
48336
48337
48338
48339
48340
48341
48342
# File 'lib/aws-sdk-ec2/types.rb', line 48325

class ImageAttribute < Struct.new(
  :description,
  :kernel_id,
  :ramdisk_id,
  :sriov_net_support,
  :boot_mode,
  :tpm_support,
  :uefi_data,
  :last_launched_time,
  :imds_support,
  :deregistration_protection,
  :image_id,
  :launch_permissions,
  :product_codes,
  :block_device_mappings)
  SENSITIVE = []
  include Aws::Structure
end

#deregistration_protectionTypes::AttributeValue

Indicates whether deregistration protection is enabled for the AMI.



48325
48326
48327
48328
48329
48330
48331
48332
48333
48334
48335
48336
48337
48338
48339
48340
48341
48342
# File 'lib/aws-sdk-ec2/types.rb', line 48325

class ImageAttribute < Struct.new(
  :description,
  :kernel_id,
  :ramdisk_id,
  :sriov_net_support,
  :boot_mode,
  :tpm_support,
  :uefi_data,
  :last_launched_time,
  :imds_support,
  :deregistration_protection,
  :image_id,
  :launch_permissions,
  :product_codes,
  :block_device_mappings)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionTypes::AttributeValue

A description for the AMI.



48325
48326
48327
48328
48329
48330
48331
48332
48333
48334
48335
48336
48337
48338
48339
48340
48341
48342
# File 'lib/aws-sdk-ec2/types.rb', line 48325

class ImageAttribute < Struct.new(
  :description,
  :kernel_id,
  :ramdisk_id,
  :sriov_net_support,
  :boot_mode,
  :tpm_support,
  :uefi_data,
  :last_launched_time,
  :imds_support,
  :deregistration_protection,
  :image_id,
  :launch_permissions,
  :product_codes,
  :block_device_mappings)
  SENSITIVE = []
  include Aws::Structure
end

#image_idString

The ID of the AMI.

Returns:

  • (String)


48325
48326
48327
48328
48329
48330
48331
48332
48333
48334
48335
48336
48337
48338
48339
48340
48341
48342
# File 'lib/aws-sdk-ec2/types.rb', line 48325

class ImageAttribute < Struct.new(
  :description,
  :kernel_id,
  :ramdisk_id,
  :sriov_net_support,
  :boot_mode,
  :tpm_support,
  :uefi_data,
  :last_launched_time,
  :imds_support,
  :deregistration_protection,
  :image_id,
  :launch_permissions,
  :product_codes,
  :block_device_mappings)
  SENSITIVE = []
  include Aws::Structure
end

#imds_supportTypes::AttributeValue

If ‘v2.0`, it indicates that IMDSv2 is specified in the AMI. Instances launched from this AMI will have `HttpTokens` automatically set to `required` so that, by default, the instance requires that IMDSv2 is used when requesting instance metadata. In addition, `HttpPutResponseHopLimit` is set to `2`. For more information, see [Configure the AMI] in the *Amazon EC2 User Guide*.

[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/configuring-IMDS-new-instances.html#configure-IMDS-new-instances-ami-configuration



48325
48326
48327
48328
48329
48330
48331
48332
48333
48334
48335
48336
48337
48338
48339
48340
48341
48342
# File 'lib/aws-sdk-ec2/types.rb', line 48325

class ImageAttribute < Struct.new(
  :description,
  :kernel_id,
  :ramdisk_id,
  :sriov_net_support,
  :boot_mode,
  :tpm_support,
  :uefi_data,
  :last_launched_time,
  :imds_support,
  :deregistration_protection,
  :image_id,
  :launch_permissions,
  :product_codes,
  :block_device_mappings)
  SENSITIVE = []
  include Aws::Structure
end

#kernel_idTypes::AttributeValue

The kernel ID.



48325
48326
48327
48328
48329
48330
48331
48332
48333
48334
48335
48336
48337
48338
48339
48340
48341
48342
# File 'lib/aws-sdk-ec2/types.rb', line 48325

class ImageAttribute < Struct.new(
  :description,
  :kernel_id,
  :ramdisk_id,
  :sriov_net_support,
  :boot_mode,
  :tpm_support,
  :uefi_data,
  :last_launched_time,
  :imds_support,
  :deregistration_protection,
  :image_id,
  :launch_permissions,
  :product_codes,
  :block_device_mappings)
  SENSITIVE = []
  include Aws::Structure
end

#last_launched_timeTypes::AttributeValue

The date and time, in [ISO 8601 date-time format], when the AMI was last used to launch an EC2 instance. When the AMI is used to launch an instance, there is a 24-hour delay before that usage is reported.

<note markdown=“1”> ‘lastLaunchedTime` data is available starting April 2017.

</note>

[1]: www.iso.org/iso/iso8601



48325
48326
48327
48328
48329
48330
48331
48332
48333
48334
48335
48336
48337
48338
48339
48340
48341
48342
# File 'lib/aws-sdk-ec2/types.rb', line 48325

class ImageAttribute < Struct.new(
  :description,
  :kernel_id,
  :ramdisk_id,
  :sriov_net_support,
  :boot_mode,
  :tpm_support,
  :uefi_data,
  :last_launched_time,
  :imds_support,
  :deregistration_protection,
  :image_id,
  :launch_permissions,
  :product_codes,
  :block_device_mappings)
  SENSITIVE = []
  include Aws::Structure
end

#launch_permissionsArray<Types::LaunchPermission>

The launch permissions.

Returns:



48325
48326
48327
48328
48329
48330
48331
48332
48333
48334
48335
48336
48337
48338
48339
48340
48341
48342
# File 'lib/aws-sdk-ec2/types.rb', line 48325

class ImageAttribute < Struct.new(
  :description,
  :kernel_id,
  :ramdisk_id,
  :sriov_net_support,
  :boot_mode,
  :tpm_support,
  :uefi_data,
  :last_launched_time,
  :imds_support,
  :deregistration_protection,
  :image_id,
  :launch_permissions,
  :product_codes,
  :block_device_mappings)
  SENSITIVE = []
  include Aws::Structure
end

#product_codesArray<Types::ProductCode>

The product codes.

Returns:



48325
48326
48327
48328
48329
48330
48331
48332
48333
48334
48335
48336
48337
48338
48339
48340
48341
48342
# File 'lib/aws-sdk-ec2/types.rb', line 48325

class ImageAttribute < Struct.new(
  :description,
  :kernel_id,
  :ramdisk_id,
  :sriov_net_support,
  :boot_mode,
  :tpm_support,
  :uefi_data,
  :last_launched_time,
  :imds_support,
  :deregistration_protection,
  :image_id,
  :launch_permissions,
  :product_codes,
  :block_device_mappings)
  SENSITIVE = []
  include Aws::Structure
end

#ramdisk_idTypes::AttributeValue

The RAM disk ID.



48325
48326
48327
48328
48329
48330
48331
48332
48333
48334
48335
48336
48337
48338
48339
48340
48341
48342
# File 'lib/aws-sdk-ec2/types.rb', line 48325

class ImageAttribute < Struct.new(
  :description,
  :kernel_id,
  :ramdisk_id,
  :sriov_net_support,
  :boot_mode,
  :tpm_support,
  :uefi_data,
  :last_launched_time,
  :imds_support,
  :deregistration_protection,
  :image_id,
  :launch_permissions,
  :product_codes,
  :block_device_mappings)
  SENSITIVE = []
  include Aws::Structure
end

#sriov_net_supportTypes::AttributeValue

Indicates whether enhanced networking with the Intel 82599 Virtual Function interface is enabled.



48325
48326
48327
48328
48329
48330
48331
48332
48333
48334
48335
48336
48337
48338
48339
48340
48341
48342
# File 'lib/aws-sdk-ec2/types.rb', line 48325

class ImageAttribute < Struct.new(
  :description,
  :kernel_id,
  :ramdisk_id,
  :sriov_net_support,
  :boot_mode,
  :tpm_support,
  :uefi_data,
  :last_launched_time,
  :imds_support,
  :deregistration_protection,
  :image_id,
  :launch_permissions,
  :product_codes,
  :block_device_mappings)
  SENSITIVE = []
  include Aws::Structure
end

#tpm_supportTypes::AttributeValue

If the image is configured for NitroTPM support, the value is ‘v2.0`.



48325
48326
48327
48328
48329
48330
48331
48332
48333
48334
48335
48336
48337
48338
48339
48340
48341
48342
# File 'lib/aws-sdk-ec2/types.rb', line 48325

class ImageAttribute < Struct.new(
  :description,
  :kernel_id,
  :ramdisk_id,
  :sriov_net_support,
  :boot_mode,
  :tpm_support,
  :uefi_data,
  :last_launched_time,
  :imds_support,
  :deregistration_protection,
  :image_id,
  :launch_permissions,
  :product_codes,
  :block_device_mappings)
  SENSITIVE = []
  include Aws::Structure
end

#uefi_dataTypes::AttributeValue

Base64 representation of the non-volatile UEFI variable store. To retrieve the UEFI data, use the [GetInstanceUefiData] command. You can inspect and modify the UEFI data by using the

python-uefivars tool][2

on GitHub. For more information, see [UEFI

Secure Boot for Amazon EC2 instances] in the *Amazon EC2 User Guide*.

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetInstanceUefiData [2]: github.com/awslabs/python-uefivars [3]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/uefi-secure-boot.html



48325
48326
48327
48328
48329
48330
48331
48332
48333
48334
48335
48336
48337
48338
48339
48340
48341
48342
# File 'lib/aws-sdk-ec2/types.rb', line 48325

class ImageAttribute < Struct.new(
  :description,
  :kernel_id,
  :ramdisk_id,
  :sriov_net_support,
  :boot_mode,
  :tpm_support,
  :uefi_data,
  :last_launched_time,
  :imds_support,
  :deregistration_protection,
  :image_id,
  :launch_permissions,
  :product_codes,
  :block_device_mappings)
  SENSITIVE = []
  include Aws::Structure
end