Class: Aws::EC2::Types::ImageCriterionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ImageCriterionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
The criteria that are evaluated to determine which AMIs are discoverable and usable in your account for the specified Amazon Web Services Region.
The ImageCriteria can include up to:
- 10
ImageCriterion
^
Each ImageCriterion can include up to:
-
200 values for
ImageProviders -
50 values for
ImageNames -
50 values for
MarketplaceProductCodes -
50 values for
ImageWatermarks
For more information, see How Allowed AMIs works in the Amazon EC2 User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_date_condition ⇒ Types::CreationDateConditionRequest
The maximum age for allowed images.
-
#deprecation_time_condition ⇒ Types::DeprecationTimeConditionRequest
The maximum period since deprecation for allowed images.
-
#image_names ⇒ Array<String>
The names of allowed images.
-
#image_providers ⇒ Array<String>
The image providers whose images are allowed.
-
#image_watermarks ⇒ Array<Types::ImageWatermarkFilterRequest>
The watermark criteria that an AMI must match to be allowed.
-
#marketplace_product_codes ⇒ Array<String>
The Amazon Web Services Marketplace product codes for allowed images.
Instance Attribute Details
#creation_date_condition ⇒ Types::CreationDateConditionRequest
The maximum age for allowed images.
49004 49005 49006 49007 49008 49009 49010 49011 49012 49013 |
# File 'lib/aws-sdk-ec2/types.rb', line 49004 class ImageCriterionRequest < Struct.new( :image_providers, :marketplace_product_codes, :image_names, :deprecation_time_condition, :creation_date_condition, :image_watermarks) SENSITIVE = [] include Aws::Structure end |
#deprecation_time_condition ⇒ Types::DeprecationTimeConditionRequest
The maximum period since deprecation for allowed images.
49004 49005 49006 49007 49008 49009 49010 49011 49012 49013 |
# File 'lib/aws-sdk-ec2/types.rb', line 49004 class ImageCriterionRequest < Struct.new( :image_providers, :marketplace_product_codes, :image_names, :deprecation_time_condition, :creation_date_condition, :image_watermarks) SENSITIVE = [] include Aws::Structure end |
#image_names ⇒ Array<String>
The names of allowed images. Names can include wildcards (? and
*).
Length: 1–128 characters. With ?, the minimum is 3 characters.
Valid characters:
-
Letters:
A–Z, a–z -
Numbers:
0–9 -
Special characters:
( ) [ ] . / - ' @ _ * ? -
Spaces
Maximum: 50 values
49004 49005 49006 49007 49008 49009 49010 49011 49012 49013 |
# File 'lib/aws-sdk-ec2/types.rb', line 49004 class ImageCriterionRequest < Struct.new( :image_providers, :marketplace_product_codes, :image_names, :deprecation_time_condition, :creation_date_condition, :image_watermarks) SENSITIVE = [] include Aws::Structure end |
#image_providers ⇒ Array<String>
The image providers whose images are allowed.
Possible values:
-
amazon: Allow AMIs created by Amazon or verified providers. -
aws-marketplace: Allow AMIs created by verified providers in the Amazon Web Services Marketplace. -
aws-backup-vault: Allow AMIs created by Amazon Web Services Backup. -
12-digit account ID: Allow AMIs created by the specified accounts. One or more account IDs can be specified.
-
none: Allow AMIs created by your own account only. Whennoneis specified, no other values can be specified.
Maximum: 200 values
49004 49005 49006 49007 49008 49009 49010 49011 49012 49013 |
# File 'lib/aws-sdk-ec2/types.rb', line 49004 class ImageCriterionRequest < Struct.new( :image_providers, :marketplace_product_codes, :image_names, :deprecation_time_condition, :creation_date_condition, :image_watermarks) SENSITIVE = [] include Aws::Structure end |
#image_watermarks ⇒ Array<Types::ImageWatermarkFilterRequest>
The watermark criteria that an AMI must match to be allowed. An AMI is allowed if it carries at least one watermark that satisfies an ImageWatermarkFilter. A watermark satisfies a filter when all specified fields in the ImageWatermarkFilter match the corresponding values on the watermark of the AMI.
Maximum: 50 values
49004 49005 49006 49007 49008 49009 49010 49011 49012 49013 |
# File 'lib/aws-sdk-ec2/types.rb', line 49004 class ImageCriterionRequest < Struct.new( :image_providers, :marketplace_product_codes, :image_names, :deprecation_time_condition, :creation_date_condition, :image_watermarks) SENSITIVE = [] include Aws::Structure end |
#marketplace_product_codes ⇒ Array<String>
The Amazon Web Services Marketplace product codes for allowed images.
Length: 1-25 characters
Valid characters: Letters (A–Z, a–z) and numbers (0–9)
Maximum: 50 values
49004 49005 49006 49007 49008 49009 49010 49011 49012 49013 |
# File 'lib/aws-sdk-ec2/types.rb', line 49004 class ImageCriterionRequest < Struct.new( :image_providers, :marketplace_product_codes, :image_names, :deprecation_time_condition, :creation_date_condition, :image_watermarks) SENSITIVE = [] include Aws::Structure end |