Class: Aws::EC2::Types::ImageMetadata

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Information about the AMI.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_dateString

The date and time the AMI was created.

Returns:

  • (String)


49352
49353
49354
49355
49356
49357
49358
49359
49360
49361
49362
49363
49364
49365
# File 'lib/aws-sdk-ec2/types.rb', line 49352

class ImageMetadata < Struct.new(
  :image_id,
  :name,
  :owner_id,
  :state,
  :image_owner_alias,
  :creation_date,
  :deprecation_time,
  :image_allowed,
  :is_public,
  :image_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#deprecation_timeString

The deprecation date and time of the AMI, in UTC, in the following format: YYYY-MM-DDTHH:MM:SSZ.

Returns:

  • (String)


49352
49353
49354
49355
49356
49357
49358
49359
49360
49361
49362
49363
49364
49365
# File 'lib/aws-sdk-ec2/types.rb', line 49352

class ImageMetadata < Struct.new(
  :image_id,
  :name,
  :owner_id,
  :state,
  :image_owner_alias,
  :creation_date,
  :deprecation_time,
  :image_allowed,
  :is_public,
  :image_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#image_allowedBoolean

If true, the AMI satisfies the criteria for Allowed AMIs and can be discovered and used in the account. If false, the AMI can't be discovered or used in the account.

For more information, see Control the discovery and use of AMIs in Amazon EC2 with Allowed AMIs in Amazon EC2 User Guide.

Returns:

  • (Boolean)


49352
49353
49354
49355
49356
49357
49358
49359
49360
49361
49362
49363
49364
49365
# File 'lib/aws-sdk-ec2/types.rb', line 49352

class ImageMetadata < Struct.new(
  :image_id,
  :name,
  :owner_id,
  :state,
  :image_owner_alias,
  :creation_date,
  :deprecation_time,
  :image_allowed,
  :is_public,
  :image_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#image_idString

The ID of the AMI.

Returns:

  • (String)


49352
49353
49354
49355
49356
49357
49358
49359
49360
49361
49362
49363
49364
49365
# File 'lib/aws-sdk-ec2/types.rb', line 49352

class ImageMetadata < Struct.new(
  :image_id,
  :name,
  :owner_id,
  :state,
  :image_owner_alias,
  :creation_date,
  :deprecation_time,
  :image_allowed,
  :is_public,
  :image_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#image_owner_aliasString

The alias of the AMI owner.

Valid values: amazon | aws-backup-vault | aws-marketplace

Returns:

  • (String)


49352
49353
49354
49355
49356
49357
49358
49359
49360
49361
49362
49363
49364
49365
# File 'lib/aws-sdk-ec2/types.rb', line 49352

class ImageMetadata < Struct.new(
  :image_id,
  :name,
  :owner_id,
  :state,
  :image_owner_alias,
  :creation_date,
  :deprecation_time,
  :image_allowed,
  :is_public,
  :image_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#image_watermarksArray<Types::ImageWatermark>

The watermarks attached to the AMI.

Returns:



49352
49353
49354
49355
49356
49357
49358
49359
49360
49361
49362
49363
49364
49365
# File 'lib/aws-sdk-ec2/types.rb', line 49352

class ImageMetadata < Struct.new(
  :image_id,
  :name,
  :owner_id,
  :state,
  :image_owner_alias,
  :creation_date,
  :deprecation_time,
  :image_allowed,
  :is_public,
  :image_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#is_publicBoolean

Indicates whether the AMI has public launch permissions. A value of true means this AMI has public launch permissions, while false means it has only implicit (AMI owner) or explicit (shared with your account) launch permissions.

Returns:

  • (Boolean)


49352
49353
49354
49355
49356
49357
49358
49359
49360
49361
49362
49363
49364
49365
# File 'lib/aws-sdk-ec2/types.rb', line 49352

class ImageMetadata < Struct.new(
  :image_id,
  :name,
  :owner_id,
  :state,
  :image_owner_alias,
  :creation_date,
  :deprecation_time,
  :image_allowed,
  :is_public,
  :image_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the AMI.

Returns:

  • (String)


49352
49353
49354
49355
49356
49357
49358
49359
49360
49361
49362
49363
49364
49365
# File 'lib/aws-sdk-ec2/types.rb', line 49352

class ImageMetadata < Struct.new(
  :image_id,
  :name,
  :owner_id,
  :state,
  :image_owner_alias,
  :creation_date,
  :deprecation_time,
  :image_allowed,
  :is_public,
  :image_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#owner_idString

The ID of the Amazon Web Services account that owns the AMI.

Returns:

  • (String)


49352
49353
49354
49355
49356
49357
49358
49359
49360
49361
49362
49363
49364
49365
# File 'lib/aws-sdk-ec2/types.rb', line 49352

class ImageMetadata < Struct.new(
  :image_id,
  :name,
  :owner_id,
  :state,
  :image_owner_alias,
  :creation_date,
  :deprecation_time,
  :image_allowed,
  :is_public,
  :image_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The current state of the AMI. If the state is available, the AMI is successfully registered and can be used to launch an instance.

Returns:

  • (String)


49352
49353
49354
49355
49356
49357
49358
49359
49360
49361
49362
49363
49364
49365
# File 'lib/aws-sdk-ec2/types.rb', line 49352

class ImageMetadata < Struct.new(
  :image_id,
  :name,
  :owner_id,
  :state,
  :image_owner_alias,
  :creation_date,
  :deprecation_time,
  :image_allowed,
  :is_public,
  :image_watermarks)
  SENSITIVE = []
  include Aws::Structure
end