Class: Aws::EC2::Types::ImageMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ImageMetadata
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Information about the AMI.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_date ⇒ String
The date and time the AMI was created.
-
#deprecation_time ⇒ String
The deprecation date and time of the AMI, in UTC, in the following format: YYYY-MM-DDTHH:MM:SSZ.
-
#image_allowed ⇒ Boolean
If
true, the AMI satisfies the criteria for Allowed AMIs and can be discovered and used in the account. -
#image_id ⇒ String
The ID of the AMI.
-
#image_owner_alias ⇒ String
The alias of the AMI owner.
-
#image_watermarks ⇒ Array<Types::ImageWatermark>
The watermarks attached to the AMI.
-
#is_public ⇒ Boolean
Indicates whether the AMI has public launch permissions.
-
#name ⇒ String
The name of the AMI.
-
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the AMI.
-
#state ⇒ String
The current state of the AMI.
Instance Attribute Details
#creation_date ⇒ String
The date and time the AMI was created.
49117 49118 49119 49120 49121 49122 49123 49124 49125 49126 49127 49128 49129 49130 |
# File 'lib/aws-sdk-ec2/types.rb', line 49117 class ImageMetadata < Struct.new( :image_id, :name, :owner_id, :state, :image_owner_alias, :creation_date, :deprecation_time, :image_allowed, :is_public, :image_watermarks) SENSITIVE = [] include Aws::Structure end |
#deprecation_time ⇒ String
The deprecation date and time of the AMI, in UTC, in the following format: YYYY-MM-DDTHH:MM:SSZ.
49117 49118 49119 49120 49121 49122 49123 49124 49125 49126 49127 49128 49129 49130 |
# File 'lib/aws-sdk-ec2/types.rb', line 49117 class ImageMetadata < Struct.new( :image_id, :name, :owner_id, :state, :image_owner_alias, :creation_date, :deprecation_time, :image_allowed, :is_public, :image_watermarks) SENSITIVE = [] include Aws::Structure end |
#image_allowed ⇒ Boolean
If true, the AMI satisfies the criteria for Allowed AMIs and can
be discovered and used in the account. If false, the AMI can't be
discovered or used in the account.
For more information, see Control the discovery and use of AMIs in Amazon EC2 with Allowed AMIs in Amazon EC2 User Guide.
49117 49118 49119 49120 49121 49122 49123 49124 49125 49126 49127 49128 49129 49130 |
# File 'lib/aws-sdk-ec2/types.rb', line 49117 class ImageMetadata < Struct.new( :image_id, :name, :owner_id, :state, :image_owner_alias, :creation_date, :deprecation_time, :image_allowed, :is_public, :image_watermarks) SENSITIVE = [] include Aws::Structure end |
#image_id ⇒ String
The ID of the AMI.
49117 49118 49119 49120 49121 49122 49123 49124 49125 49126 49127 49128 49129 49130 |
# File 'lib/aws-sdk-ec2/types.rb', line 49117 class ImageMetadata < Struct.new( :image_id, :name, :owner_id, :state, :image_owner_alias, :creation_date, :deprecation_time, :image_allowed, :is_public, :image_watermarks) SENSITIVE = [] include Aws::Structure end |
#image_owner_alias ⇒ String
The alias of the AMI owner.
Valid values: amazon | aws-backup-vault | aws-marketplace
49117 49118 49119 49120 49121 49122 49123 49124 49125 49126 49127 49128 49129 49130 |
# File 'lib/aws-sdk-ec2/types.rb', line 49117 class ImageMetadata < Struct.new( :image_id, :name, :owner_id, :state, :image_owner_alias, :creation_date, :deprecation_time, :image_allowed, :is_public, :image_watermarks) SENSITIVE = [] include Aws::Structure end |
#image_watermarks ⇒ Array<Types::ImageWatermark>
The watermarks attached to the AMI.
49117 49118 49119 49120 49121 49122 49123 49124 49125 49126 49127 49128 49129 49130 |
# File 'lib/aws-sdk-ec2/types.rb', line 49117 class ImageMetadata < Struct.new( :image_id, :name, :owner_id, :state, :image_owner_alias, :creation_date, :deprecation_time, :image_allowed, :is_public, :image_watermarks) SENSITIVE = [] include Aws::Structure end |
#is_public ⇒ Boolean
Indicates whether the AMI has public launch permissions. A value of
true means this AMI has public launch permissions, while false
means it has only implicit (AMI owner) or explicit (shared with your
account) launch permissions.
49117 49118 49119 49120 49121 49122 49123 49124 49125 49126 49127 49128 49129 49130 |
# File 'lib/aws-sdk-ec2/types.rb', line 49117 class ImageMetadata < Struct.new( :image_id, :name, :owner_id, :state, :image_owner_alias, :creation_date, :deprecation_time, :image_allowed, :is_public, :image_watermarks) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the AMI.
49117 49118 49119 49120 49121 49122 49123 49124 49125 49126 49127 49128 49129 49130 |
# File 'lib/aws-sdk-ec2/types.rb', line 49117 class ImageMetadata < Struct.new( :image_id, :name, :owner_id, :state, :image_owner_alias, :creation_date, :deprecation_time, :image_allowed, :is_public, :image_watermarks) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the AMI.
49117 49118 49119 49120 49121 49122 49123 49124 49125 49126 49127 49128 49129 49130 |
# File 'lib/aws-sdk-ec2/types.rb', line 49117 class ImageMetadata < Struct.new( :image_id, :name, :owner_id, :state, :image_owner_alias, :creation_date, :deprecation_time, :image_allowed, :is_public, :image_watermarks) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the AMI. If the state is available, the AMI
is successfully registered and can be used to launch an instance.
49117 49118 49119 49120 49121 49122 49123 49124 49125 49126 49127 49128 49129 49130 |
# File 'lib/aws-sdk-ec2/types.rb', line 49117 class ImageMetadata < Struct.new( :image_id, :name, :owner_id, :state, :image_owner_alias, :creation_date, :deprecation_time, :image_allowed, :is_public, :image_watermarks) SENSITIVE = [] include Aws::Structure end |