Class: Aws::EC2::Types::ImageUsageReport
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ImageUsageReport
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
The configuration and status of an image usage report.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_ids ⇒ Array<String>
The IDs of the Amazon Web Services accounts that were specified when the report was created.
-
#creation_time ⇒ Time
The date and time when the report was created.
-
#expiration_time ⇒ Time
The date and time when Amazon EC2 will delete the report (30 days after the report was created).
-
#image_id ⇒ String
The ID of the image that was specified when the report was created.
-
#report_id ⇒ String
The ID of the report.
-
#resource_types ⇒ Array<Types::ImageUsageResourceType>
The resource types that were specified when the report was created.
-
#state ⇒ String
The current state of the report.
-
#state_reason ⇒ String
Provides additional details when the report is in an ‘error` state.
-
#tags ⇒ Array<Types::Tag>
Any tags assigned to the report.
Instance Attribute Details
#account_ids ⇒ Array<String>
The IDs of the Amazon Web Services accounts that were specified when the report was created.
49118 49119 49120 49121 49122 49123 49124 49125 49126 49127 49128 49129 49130 |
# File 'lib/aws-sdk-ec2/types.rb', line 49118 class ImageUsageReport < Struct.new( :image_id, :report_id, :resource_types, :account_ids, :state, :state_reason, :creation_time, :expiration_time, :tags) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The date and time when the report was created.
49118 49119 49120 49121 49122 49123 49124 49125 49126 49127 49128 49129 49130 |
# File 'lib/aws-sdk-ec2/types.rb', line 49118 class ImageUsageReport < Struct.new( :image_id, :report_id, :resource_types, :account_ids, :state, :state_reason, :creation_time, :expiration_time, :tags) SENSITIVE = [] include Aws::Structure end |
#expiration_time ⇒ Time
The date and time when Amazon EC2 will delete the report (30 days after the report was created).
49118 49119 49120 49121 49122 49123 49124 49125 49126 49127 49128 49129 49130 |
# File 'lib/aws-sdk-ec2/types.rb', line 49118 class ImageUsageReport < Struct.new( :image_id, :report_id, :resource_types, :account_ids, :state, :state_reason, :creation_time, :expiration_time, :tags) SENSITIVE = [] include Aws::Structure end |
#image_id ⇒ String
The ID of the image that was specified when the report was created.
49118 49119 49120 49121 49122 49123 49124 49125 49126 49127 49128 49129 49130 |
# File 'lib/aws-sdk-ec2/types.rb', line 49118 class ImageUsageReport < Struct.new( :image_id, :report_id, :resource_types, :account_ids, :state, :state_reason, :creation_time, :expiration_time, :tags) SENSITIVE = [] include Aws::Structure end |
#report_id ⇒ String
The ID of the report.
49118 49119 49120 49121 49122 49123 49124 49125 49126 49127 49128 49129 49130 |
# File 'lib/aws-sdk-ec2/types.rb', line 49118 class ImageUsageReport < Struct.new( :image_id, :report_id, :resource_types, :account_ids, :state, :state_reason, :creation_time, :expiration_time, :tags) SENSITIVE = [] include Aws::Structure end |
#resource_types ⇒ Array<Types::ImageUsageResourceType>
The resource types that were specified when the report was created.
49118 49119 49120 49121 49122 49123 49124 49125 49126 49127 49128 49129 49130 |
# File 'lib/aws-sdk-ec2/types.rb', line 49118 class ImageUsageReport < Struct.new( :image_id, :report_id, :resource_types, :account_ids, :state, :state_reason, :creation_time, :expiration_time, :tags) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the report. Possible values:
-
‘available` - The report is available to view.
-
‘pending` - The report is being created and not available to view.
-
‘error` - The report could not be created.
49118 49119 49120 49121 49122 49123 49124 49125 49126 49127 49128 49129 49130 |
# File 'lib/aws-sdk-ec2/types.rb', line 49118 class ImageUsageReport < Struct.new( :image_id, :report_id, :resource_types, :account_ids, :state, :state_reason, :creation_time, :expiration_time, :tags) SENSITIVE = [] include Aws::Structure end |
#state_reason ⇒ String
Provides additional details when the report is in an ‘error` state.
49118 49119 49120 49121 49122 49123 49124 49125 49126 49127 49128 49129 49130 |
# File 'lib/aws-sdk-ec2/types.rb', line 49118 class ImageUsageReport < Struct.new( :image_id, :report_id, :resource_types, :account_ids, :state, :state_reason, :creation_time, :expiration_time, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Any tags assigned to the report.
49118 49119 49120 49121 49122 49123 49124 49125 49126 49127 49128 49129 49130 |
# File 'lib/aws-sdk-ec2/types.rb', line 49118 class ImageUsageReport < Struct.new( :image_id, :report_id, :resource_types, :account_ids, :state, :state_reason, :creation_time, :expiration_time, :tags) SENSITIVE = [] include Aws::Structure end |