Class: Aws::EC2::Types::ImageUsageReport

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

The configuration and status of an image usage report.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idsArray<String>

The IDs of the Amazon Web Services accounts that were specified when the report was created.

Returns:

  • (Array<String>)


47639
47640
47641
47642
47643
47644
47645
47646
47647
47648
47649
47650
47651
# File 'lib/aws-sdk-ec2/types.rb', line 47639

class ImageUsageReport < Struct.new(
  :image_id,
  :report_id,
  :resource_types,
  :account_ids,
  :state,
  :state_reason,
  :creation_time,
  :expiration_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The date and time when the report was created.

Returns:

  • (Time)


47639
47640
47641
47642
47643
47644
47645
47646
47647
47648
47649
47650
47651
# File 'lib/aws-sdk-ec2/types.rb', line 47639

class ImageUsageReport < Struct.new(
  :image_id,
  :report_id,
  :resource_types,
  :account_ids,
  :state,
  :state_reason,
  :creation_time,
  :expiration_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#expiration_timeTime

The date and time when Amazon EC2 will delete the report (30 days after the report was created).

Returns:

  • (Time)


47639
47640
47641
47642
47643
47644
47645
47646
47647
47648
47649
47650
47651
# File 'lib/aws-sdk-ec2/types.rb', line 47639

class ImageUsageReport < Struct.new(
  :image_id,
  :report_id,
  :resource_types,
  :account_ids,
  :state,
  :state_reason,
  :creation_time,
  :expiration_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#image_idString

The ID of the image that was specified when the report was created.

Returns:

  • (String)


47639
47640
47641
47642
47643
47644
47645
47646
47647
47648
47649
47650
47651
# File 'lib/aws-sdk-ec2/types.rb', line 47639

class ImageUsageReport < Struct.new(
  :image_id,
  :report_id,
  :resource_types,
  :account_ids,
  :state,
  :state_reason,
  :creation_time,
  :expiration_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#report_idString

The ID of the report.

Returns:

  • (String)


47639
47640
47641
47642
47643
47644
47645
47646
47647
47648
47649
47650
47651
# File 'lib/aws-sdk-ec2/types.rb', line 47639

class ImageUsageReport < Struct.new(
  :image_id,
  :report_id,
  :resource_types,
  :account_ids,
  :state,
  :state_reason,
  :creation_time,
  :expiration_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typesArray<Types::ImageUsageResourceType>

The resource types that were specified when the report was created.

Returns:



47639
47640
47641
47642
47643
47644
47645
47646
47647
47648
47649
47650
47651
# File 'lib/aws-sdk-ec2/types.rb', line 47639

class ImageUsageReport < Struct.new(
  :image_id,
  :report_id,
  :resource_types,
  :account_ids,
  :state,
  :state_reason,
  :creation_time,
  :expiration_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The current state of the report. Possible values:

  • ‘available` - The report is available to view.

  • ‘pending` - The report is being created and not available to view.

  • ‘error` - The report could not be created.

Returns:

  • (String)


47639
47640
47641
47642
47643
47644
47645
47646
47647
47648
47649
47650
47651
# File 'lib/aws-sdk-ec2/types.rb', line 47639

class ImageUsageReport < Struct.new(
  :image_id,
  :report_id,
  :resource_types,
  :account_ids,
  :state,
  :state_reason,
  :creation_time,
  :expiration_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#state_reasonString

Provides additional details when the report is in an ‘error` state.

Returns:

  • (String)


47639
47640
47641
47642
47643
47644
47645
47646
47647
47648
47649
47650
47651
# File 'lib/aws-sdk-ec2/types.rb', line 47639

class ImageUsageReport < Struct.new(
  :image_id,
  :report_id,
  :resource_types,
  :account_ids,
  :state,
  :state_reason,
  :creation_time,
  :expiration_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Any tags assigned to the report.

Returns:



47639
47640
47641
47642
47643
47644
47645
47646
47647
47648
47649
47650
47651
# File 'lib/aws-sdk-ec2/types.rb', line 47639

class ImageUsageReport < Struct.new(
  :image_id,
  :report_id,
  :resource_types,
  :account_ids,
  :state,
  :state_reason,
  :creation_time,
  :expiration_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end