Class: Aws::EC2::Types::ImportImageResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ImportImageResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#architecture ⇒ String
The architecture of the virtual machine.
-
#description ⇒ String
A description of the import task.
-
#encrypted ⇒ Boolean
Indicates whether the AMI is encrypted.
-
#hypervisor ⇒ String
The target hypervisor of the import task.
-
#image_id ⇒ String
The ID of the Amazon Machine Image (AMI) created by the import task.
-
#import_task_id ⇒ String
The task ID of the import image task.
-
#kms_key_id ⇒ String
The identifier for the symmetric KMS key that was used to create the encrypted AMI.
-
#license_specifications ⇒ Array<Types::ImportImageLicenseConfigurationResponse>
The ARNs of the license configurations.
-
#license_type ⇒ String
The license type of the virtual machine.
-
#platform ⇒ String
The operating system of the virtual machine.
-
#progress ⇒ String
The progress of the task.
-
#snapshot_details ⇒ Array<Types::SnapshotDetail>
Information about the snapshots.
-
#status ⇒ String
A brief status of the task.
-
#status_message ⇒ String
A detailed status message of the import task.
-
#tags ⇒ Array<Types::Tag>
Any tags assigned to the import image task.
-
#usage_operation ⇒ String
The usage operation value.
Instance Attribute Details
#architecture ⇒ String
The architecture of the virtual machine.
49708 49709 49710 49711 49712 49713 49714 49715 49716 49717 49718 49719 49720 49721 49722 49723 49724 49725 49726 49727 |
# File 'lib/aws-sdk-ec2/types.rb', line 49708 class ImportImageResult < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :license_specifications, :tags, :usage_operation) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the import task.
49708 49709 49710 49711 49712 49713 49714 49715 49716 49717 49718 49719 49720 49721 49722 49723 49724 49725 49726 49727 |
# File 'lib/aws-sdk-ec2/types.rb', line 49708 class ImportImageResult < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :license_specifications, :tags, :usage_operation) SENSITIVE = [] include Aws::Structure end |
#encrypted ⇒ Boolean
Indicates whether the AMI is encrypted.
49708 49709 49710 49711 49712 49713 49714 49715 49716 49717 49718 49719 49720 49721 49722 49723 49724 49725 49726 49727 |
# File 'lib/aws-sdk-ec2/types.rb', line 49708 class ImportImageResult < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :license_specifications, :tags, :usage_operation) SENSITIVE = [] include Aws::Structure end |
#hypervisor ⇒ String
The target hypervisor of the import task.
49708 49709 49710 49711 49712 49713 49714 49715 49716 49717 49718 49719 49720 49721 49722 49723 49724 49725 49726 49727 |
# File 'lib/aws-sdk-ec2/types.rb', line 49708 class ImportImageResult < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :license_specifications, :tags, :usage_operation) SENSITIVE = [] include Aws::Structure end |
#image_id ⇒ String
The ID of the Amazon Machine Image (AMI) created by the import task.
49708 49709 49710 49711 49712 49713 49714 49715 49716 49717 49718 49719 49720 49721 49722 49723 49724 49725 49726 49727 |
# File 'lib/aws-sdk-ec2/types.rb', line 49708 class ImportImageResult < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :license_specifications, :tags, :usage_operation) SENSITIVE = [] include Aws::Structure end |
#import_task_id ⇒ String
The task ID of the import image task.
49708 49709 49710 49711 49712 49713 49714 49715 49716 49717 49718 49719 49720 49721 49722 49723 49724 49725 49726 49727 |
# File 'lib/aws-sdk-ec2/types.rb', line 49708 class ImportImageResult < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :license_specifications, :tags, :usage_operation) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The identifier for the symmetric KMS key that was used to create the encrypted AMI.
49708 49709 49710 49711 49712 49713 49714 49715 49716 49717 49718 49719 49720 49721 49722 49723 49724 49725 49726 49727 |
# File 'lib/aws-sdk-ec2/types.rb', line 49708 class ImportImageResult < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :license_specifications, :tags, :usage_operation) SENSITIVE = [] include Aws::Structure end |
#license_specifications ⇒ Array<Types::ImportImageLicenseConfigurationResponse>
The ARNs of the license configurations.
49708 49709 49710 49711 49712 49713 49714 49715 49716 49717 49718 49719 49720 49721 49722 49723 49724 49725 49726 49727 |
# File 'lib/aws-sdk-ec2/types.rb', line 49708 class ImportImageResult < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :license_specifications, :tags, :usage_operation) SENSITIVE = [] include Aws::Structure end |
#license_type ⇒ String
The license type of the virtual machine.
49708 49709 49710 49711 49712 49713 49714 49715 49716 49717 49718 49719 49720 49721 49722 49723 49724 49725 49726 49727 |
# File 'lib/aws-sdk-ec2/types.rb', line 49708 class ImportImageResult < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :license_specifications, :tags, :usage_operation) SENSITIVE = [] include Aws::Structure end |
#platform ⇒ String
The operating system of the virtual machine.
49708 49709 49710 49711 49712 49713 49714 49715 49716 49717 49718 49719 49720 49721 49722 49723 49724 49725 49726 49727 |
# File 'lib/aws-sdk-ec2/types.rb', line 49708 class ImportImageResult < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :license_specifications, :tags, :usage_operation) SENSITIVE = [] include Aws::Structure end |
#progress ⇒ String
The progress of the task.
49708 49709 49710 49711 49712 49713 49714 49715 49716 49717 49718 49719 49720 49721 49722 49723 49724 49725 49726 49727 |
# File 'lib/aws-sdk-ec2/types.rb', line 49708 class ImportImageResult < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :license_specifications, :tags, :usage_operation) SENSITIVE = [] include Aws::Structure end |
#snapshot_details ⇒ Array<Types::SnapshotDetail>
Information about the snapshots.
49708 49709 49710 49711 49712 49713 49714 49715 49716 49717 49718 49719 49720 49721 49722 49723 49724 49725 49726 49727 |
# File 'lib/aws-sdk-ec2/types.rb', line 49708 class ImportImageResult < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :license_specifications, :tags, :usage_operation) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
A brief status of the task.
49708 49709 49710 49711 49712 49713 49714 49715 49716 49717 49718 49719 49720 49721 49722 49723 49724 49725 49726 49727 |
# File 'lib/aws-sdk-ec2/types.rb', line 49708 class ImportImageResult < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :license_specifications, :tags, :usage_operation) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
A detailed status message of the import task.
49708 49709 49710 49711 49712 49713 49714 49715 49716 49717 49718 49719 49720 49721 49722 49723 49724 49725 49726 49727 |
# File 'lib/aws-sdk-ec2/types.rb', line 49708 class ImportImageResult < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :license_specifications, :tags, :usage_operation) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Any tags assigned to the import image task.
49708 49709 49710 49711 49712 49713 49714 49715 49716 49717 49718 49719 49720 49721 49722 49723 49724 49725 49726 49727 |
# File 'lib/aws-sdk-ec2/types.rb', line 49708 class ImportImageResult < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :license_specifications, :tags, :usage_operation) SENSITIVE = [] include Aws::Structure end |
#usage_operation ⇒ String
The usage operation value.
49708 49709 49710 49711 49712 49713 49714 49715 49716 49717 49718 49719 49720 49721 49722 49723 49724 49725 49726 49727 |
# File 'lib/aws-sdk-ec2/types.rb', line 49708 class ImportImageResult < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :license_specifications, :tags, :usage_operation) SENSITIVE = [] include Aws::Structure end |