Class: Aws::EC2::Types::ImportImageResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ImportImageResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#architecture ⇒ String
The architecture of the virtual machine.
-
#description ⇒ String
A description of the import task.
-
#encrypted ⇒ Boolean
Indicates whether the AMI is encrypted.
-
#hypervisor ⇒ String
The target hypervisor of the import task.
-
#image_id ⇒ String
The ID of the Amazon Machine Image (AMI) created by the import task.
-
#import_task_id ⇒ String
The task ID of the import image task.
-
#kms_key_id ⇒ String
The identifier for the symmetric KMS key that was used to create the encrypted AMI.
-
#license_specifications ⇒ Array<Types::ImportImageLicenseConfigurationResponse>
The ARNs of the license configurations.
-
#license_type ⇒ String
The license type of the virtual machine.
-
#platform ⇒ String
The operating system of the virtual machine.
-
#progress ⇒ String
The progress of the task.
-
#snapshot_details ⇒ Array<Types::SnapshotDetail>
Information about the snapshots.
-
#status ⇒ String
A brief status of the task.
-
#status_message ⇒ String
A detailed status message of the import task.
-
#tags ⇒ Array<Types::Tag>
Any tags assigned to the import image task.
-
#usage_operation ⇒ String
The usage operation value.
Instance Attribute Details
#architecture ⇒ String
The architecture of the virtual machine.
49564 49565 49566 49567 49568 49569 49570 49571 49572 49573 49574 49575 49576 49577 49578 49579 49580 49581 49582 49583 |
# File 'lib/aws-sdk-ec2/types.rb', line 49564 class ImportImageResult < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :license_specifications, :tags, :usage_operation) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the import task.
49564 49565 49566 49567 49568 49569 49570 49571 49572 49573 49574 49575 49576 49577 49578 49579 49580 49581 49582 49583 |
# File 'lib/aws-sdk-ec2/types.rb', line 49564 class ImportImageResult < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :license_specifications, :tags, :usage_operation) SENSITIVE = [] include Aws::Structure end |
#encrypted ⇒ Boolean
Indicates whether the AMI is encrypted.
49564 49565 49566 49567 49568 49569 49570 49571 49572 49573 49574 49575 49576 49577 49578 49579 49580 49581 49582 49583 |
# File 'lib/aws-sdk-ec2/types.rb', line 49564 class ImportImageResult < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :license_specifications, :tags, :usage_operation) SENSITIVE = [] include Aws::Structure end |
#hypervisor ⇒ String
The target hypervisor of the import task.
49564 49565 49566 49567 49568 49569 49570 49571 49572 49573 49574 49575 49576 49577 49578 49579 49580 49581 49582 49583 |
# File 'lib/aws-sdk-ec2/types.rb', line 49564 class ImportImageResult < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :license_specifications, :tags, :usage_operation) SENSITIVE = [] include Aws::Structure end |
#image_id ⇒ String
The ID of the Amazon Machine Image (AMI) created by the import task.
49564 49565 49566 49567 49568 49569 49570 49571 49572 49573 49574 49575 49576 49577 49578 49579 49580 49581 49582 49583 |
# File 'lib/aws-sdk-ec2/types.rb', line 49564 class ImportImageResult < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :license_specifications, :tags, :usage_operation) SENSITIVE = [] include Aws::Structure end |
#import_task_id ⇒ String
The task ID of the import image task.
49564 49565 49566 49567 49568 49569 49570 49571 49572 49573 49574 49575 49576 49577 49578 49579 49580 49581 49582 49583 |
# File 'lib/aws-sdk-ec2/types.rb', line 49564 class ImportImageResult < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :license_specifications, :tags, :usage_operation) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The identifier for the symmetric KMS key that was used to create the encrypted AMI.
49564 49565 49566 49567 49568 49569 49570 49571 49572 49573 49574 49575 49576 49577 49578 49579 49580 49581 49582 49583 |
# File 'lib/aws-sdk-ec2/types.rb', line 49564 class ImportImageResult < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :license_specifications, :tags, :usage_operation) SENSITIVE = [] include Aws::Structure end |
#license_specifications ⇒ Array<Types::ImportImageLicenseConfigurationResponse>
The ARNs of the license configurations.
49564 49565 49566 49567 49568 49569 49570 49571 49572 49573 49574 49575 49576 49577 49578 49579 49580 49581 49582 49583 |
# File 'lib/aws-sdk-ec2/types.rb', line 49564 class ImportImageResult < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :license_specifications, :tags, :usage_operation) SENSITIVE = [] include Aws::Structure end |
#license_type ⇒ String
The license type of the virtual machine.
49564 49565 49566 49567 49568 49569 49570 49571 49572 49573 49574 49575 49576 49577 49578 49579 49580 49581 49582 49583 |
# File 'lib/aws-sdk-ec2/types.rb', line 49564 class ImportImageResult < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :license_specifications, :tags, :usage_operation) SENSITIVE = [] include Aws::Structure end |
#platform ⇒ String
The operating system of the virtual machine.
49564 49565 49566 49567 49568 49569 49570 49571 49572 49573 49574 49575 49576 49577 49578 49579 49580 49581 49582 49583 |
# File 'lib/aws-sdk-ec2/types.rb', line 49564 class ImportImageResult < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :license_specifications, :tags, :usage_operation) SENSITIVE = [] include Aws::Structure end |
#progress ⇒ String
The progress of the task.
49564 49565 49566 49567 49568 49569 49570 49571 49572 49573 49574 49575 49576 49577 49578 49579 49580 49581 49582 49583 |
# File 'lib/aws-sdk-ec2/types.rb', line 49564 class ImportImageResult < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :license_specifications, :tags, :usage_operation) SENSITIVE = [] include Aws::Structure end |
#snapshot_details ⇒ Array<Types::SnapshotDetail>
Information about the snapshots.
49564 49565 49566 49567 49568 49569 49570 49571 49572 49573 49574 49575 49576 49577 49578 49579 49580 49581 49582 49583 |
# File 'lib/aws-sdk-ec2/types.rb', line 49564 class ImportImageResult < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :license_specifications, :tags, :usage_operation) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
A brief status of the task.
49564 49565 49566 49567 49568 49569 49570 49571 49572 49573 49574 49575 49576 49577 49578 49579 49580 49581 49582 49583 |
# File 'lib/aws-sdk-ec2/types.rb', line 49564 class ImportImageResult < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :license_specifications, :tags, :usage_operation) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
A detailed status message of the import task.
49564 49565 49566 49567 49568 49569 49570 49571 49572 49573 49574 49575 49576 49577 49578 49579 49580 49581 49582 49583 |
# File 'lib/aws-sdk-ec2/types.rb', line 49564 class ImportImageResult < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :license_specifications, :tags, :usage_operation) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Any tags assigned to the import image task.
49564 49565 49566 49567 49568 49569 49570 49571 49572 49573 49574 49575 49576 49577 49578 49579 49580 49581 49582 49583 |
# File 'lib/aws-sdk-ec2/types.rb', line 49564 class ImportImageResult < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :license_specifications, :tags, :usage_operation) SENSITIVE = [] include Aws::Structure end |
#usage_operation ⇒ String
The usage operation value.
49564 49565 49566 49567 49568 49569 49570 49571 49572 49573 49574 49575 49576 49577 49578 49579 49580 49581 49582 49583 |
# File 'lib/aws-sdk-ec2/types.rb', line 49564 class ImportImageResult < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :license_specifications, :tags, :usage_operation) SENSITIVE = [] include Aws::Structure end |