Class: Aws::EC2::Types::ImportImageTask
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ImportImageTask
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes an import image task.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#architecture ⇒ String
The architecture of the virtual machine.
-
#boot_mode ⇒ String
The boot mode of the virtual machine.
-
#description ⇒ String
A description of the import task.
-
#encrypted ⇒ Boolean
Indicates whether the image is encrypted.
-
#hypervisor ⇒ String
The target hypervisor for the import task.
-
#image_id ⇒ String
The ID of the Amazon Machine Image (AMI) of the imported virtual machine.
-
#import_task_id ⇒ String
The ID of the import image task.
-
#kms_key_id ⇒ String
The identifier for the KMS key that was used to create the encrypted image.
-
#license_specifications ⇒ Array<Types::ImportImageLicenseConfigurationResponse>
The ARNs of the license configurations that are associated with the import image task.
-
#license_type ⇒ String
The license type of the virtual machine.
-
#platform ⇒ String
The description string for the import image task.
-
#progress ⇒ String
The percentage of progress of the import image task.
-
#snapshot_details ⇒ Array<Types::SnapshotDetail>
Information about the snapshots.
-
#status ⇒ String
A brief status for the import image task.
-
#status_message ⇒ String
A descriptive status message for the import image task.
-
#tags ⇒ Array<Types::Tag>
The tags for the import image task.
-
#usage_operation ⇒ String
The usage operation value.
Instance Attribute Details
#architecture ⇒ String
The architecture of the virtual machine.
Valid values: i386 | x86_64 | arm64
50151 50152 50153 50154 50155 50156 50157 50158 50159 50160 50161 50162 50163 50164 50165 50166 50167 50168 50169 50170 50171 |
# File 'lib/aws-sdk-ec2/types.rb', line 50151 class ImportImageTask < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :tags, :license_specifications, :usage_operation, :boot_mode) SENSITIVE = [] include Aws::Structure end |
#boot_mode ⇒ String
The boot mode of the virtual machine.
50151 50152 50153 50154 50155 50156 50157 50158 50159 50160 50161 50162 50163 50164 50165 50166 50167 50168 50169 50170 50171 |
# File 'lib/aws-sdk-ec2/types.rb', line 50151 class ImportImageTask < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :tags, :license_specifications, :usage_operation, :boot_mode) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the import task.
50151 50152 50153 50154 50155 50156 50157 50158 50159 50160 50161 50162 50163 50164 50165 50166 50167 50168 50169 50170 50171 |
# File 'lib/aws-sdk-ec2/types.rb', line 50151 class ImportImageTask < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :tags, :license_specifications, :usage_operation, :boot_mode) SENSITIVE = [] include Aws::Structure end |
#encrypted ⇒ Boolean
Indicates whether the image is encrypted.
50151 50152 50153 50154 50155 50156 50157 50158 50159 50160 50161 50162 50163 50164 50165 50166 50167 50168 50169 50170 50171 |
# File 'lib/aws-sdk-ec2/types.rb', line 50151 class ImportImageTask < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :tags, :license_specifications, :usage_operation, :boot_mode) SENSITIVE = [] include Aws::Structure end |
#hypervisor ⇒ String
The target hypervisor for the import task.
Valid values: xen
50151 50152 50153 50154 50155 50156 50157 50158 50159 50160 50161 50162 50163 50164 50165 50166 50167 50168 50169 50170 50171 |
# File 'lib/aws-sdk-ec2/types.rb', line 50151 class ImportImageTask < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :tags, :license_specifications, :usage_operation, :boot_mode) SENSITIVE = [] include Aws::Structure end |
#image_id ⇒ String
The ID of the Amazon Machine Image (AMI) of the imported virtual machine.
50151 50152 50153 50154 50155 50156 50157 50158 50159 50160 50161 50162 50163 50164 50165 50166 50167 50168 50169 50170 50171 |
# File 'lib/aws-sdk-ec2/types.rb', line 50151 class ImportImageTask < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :tags, :license_specifications, :usage_operation, :boot_mode) SENSITIVE = [] include Aws::Structure end |
#import_task_id ⇒ String
The ID of the import image task.
50151 50152 50153 50154 50155 50156 50157 50158 50159 50160 50161 50162 50163 50164 50165 50166 50167 50168 50169 50170 50171 |
# File 'lib/aws-sdk-ec2/types.rb', line 50151 class ImportImageTask < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :tags, :license_specifications, :usage_operation, :boot_mode) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The identifier for the KMS key that was used to create the encrypted image.
50151 50152 50153 50154 50155 50156 50157 50158 50159 50160 50161 50162 50163 50164 50165 50166 50167 50168 50169 50170 50171 |
# File 'lib/aws-sdk-ec2/types.rb', line 50151 class ImportImageTask < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :tags, :license_specifications, :usage_operation, :boot_mode) SENSITIVE = [] include Aws::Structure end |
#license_specifications ⇒ Array<Types::ImportImageLicenseConfigurationResponse>
The ARNs of the license configurations that are associated with the import image task.
50151 50152 50153 50154 50155 50156 50157 50158 50159 50160 50161 50162 50163 50164 50165 50166 50167 50168 50169 50170 50171 |
# File 'lib/aws-sdk-ec2/types.rb', line 50151 class ImportImageTask < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :tags, :license_specifications, :usage_operation, :boot_mode) SENSITIVE = [] include Aws::Structure end |
#license_type ⇒ String
The license type of the virtual machine.
50151 50152 50153 50154 50155 50156 50157 50158 50159 50160 50161 50162 50163 50164 50165 50166 50167 50168 50169 50170 50171 |
# File 'lib/aws-sdk-ec2/types.rb', line 50151 class ImportImageTask < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :tags, :license_specifications, :usage_operation, :boot_mode) SENSITIVE = [] include Aws::Structure end |
#platform ⇒ String
The description string for the import image task.
50151 50152 50153 50154 50155 50156 50157 50158 50159 50160 50161 50162 50163 50164 50165 50166 50167 50168 50169 50170 50171 |
# File 'lib/aws-sdk-ec2/types.rb', line 50151 class ImportImageTask < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :tags, :license_specifications, :usage_operation, :boot_mode) SENSITIVE = [] include Aws::Structure end |
#progress ⇒ String
The percentage of progress of the import image task.
50151 50152 50153 50154 50155 50156 50157 50158 50159 50160 50161 50162 50163 50164 50165 50166 50167 50168 50169 50170 50171 |
# File 'lib/aws-sdk-ec2/types.rb', line 50151 class ImportImageTask < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :tags, :license_specifications, :usage_operation, :boot_mode) SENSITIVE = [] include Aws::Structure end |
#snapshot_details ⇒ Array<Types::SnapshotDetail>
Information about the snapshots.
50151 50152 50153 50154 50155 50156 50157 50158 50159 50160 50161 50162 50163 50164 50165 50166 50167 50168 50169 50170 50171 |
# File 'lib/aws-sdk-ec2/types.rb', line 50151 class ImportImageTask < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :tags, :license_specifications, :usage_operation, :boot_mode) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
A brief status for the import image task.
50151 50152 50153 50154 50155 50156 50157 50158 50159 50160 50161 50162 50163 50164 50165 50166 50167 50168 50169 50170 50171 |
# File 'lib/aws-sdk-ec2/types.rb', line 50151 class ImportImageTask < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :tags, :license_specifications, :usage_operation, :boot_mode) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
A descriptive status message for the import image task.
50151 50152 50153 50154 50155 50156 50157 50158 50159 50160 50161 50162 50163 50164 50165 50166 50167 50168 50169 50170 50171 |
# File 'lib/aws-sdk-ec2/types.rb', line 50151 class ImportImageTask < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :tags, :license_specifications, :usage_operation, :boot_mode) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags for the import image task.
50151 50152 50153 50154 50155 50156 50157 50158 50159 50160 50161 50162 50163 50164 50165 50166 50167 50168 50169 50170 50171 |
# File 'lib/aws-sdk-ec2/types.rb', line 50151 class ImportImageTask < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :tags, :license_specifications, :usage_operation, :boot_mode) SENSITIVE = [] include Aws::Structure end |
#usage_operation ⇒ String
The usage operation value.
50151 50152 50153 50154 50155 50156 50157 50158 50159 50160 50161 50162 50163 50164 50165 50166 50167 50168 50169 50170 50171 |
# File 'lib/aws-sdk-ec2/types.rb', line 50151 class ImportImageTask < Struct.new( :architecture, :description, :encrypted, :hypervisor, :image_id, :import_task_id, :kms_key_id, :license_type, :platform, :progress, :snapshot_details, :status, :status_message, :tags, :license_specifications, :usage_operation, :boot_mode) SENSITIVE = [] include Aws::Structure end |