Class: Aws::EC2::Types::ImportImageTask

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes an import image task.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#architectureString

The architecture of the virtual machine.

Valid values: ‘i386` | `x86_64` | `arm64`

Returns:

  • (String)


48904
48905
48906
48907
48908
48909
48910
48911
48912
48913
48914
48915
48916
48917
48918
48919
48920
48921
48922
48923
48924
# File 'lib/aws-sdk-ec2/types.rb', line 48904

class ImportImageTask < Struct.new(
  :architecture,
  :description,
  :encrypted,
  :hypervisor,
  :image_id,
  :import_task_id,
  :kms_key_id,
  :license_type,
  :platform,
  :progress,
  :snapshot_details,
  :status,
  :status_message,
  :tags,
  :license_specifications,
  :usage_operation,
  :boot_mode)
  SENSITIVE = []
  include Aws::Structure
end

#boot_modeString

The boot mode of the virtual machine.

Returns:

  • (String)


48904
48905
48906
48907
48908
48909
48910
48911
48912
48913
48914
48915
48916
48917
48918
48919
48920
48921
48922
48923
48924
# File 'lib/aws-sdk-ec2/types.rb', line 48904

class ImportImageTask < Struct.new(
  :architecture,
  :description,
  :encrypted,
  :hypervisor,
  :image_id,
  :import_task_id,
  :kms_key_id,
  :license_type,
  :platform,
  :progress,
  :snapshot_details,
  :status,
  :status_message,
  :tags,
  :license_specifications,
  :usage_operation,
  :boot_mode)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the import task.

Returns:

  • (String)


48904
48905
48906
48907
48908
48909
48910
48911
48912
48913
48914
48915
48916
48917
48918
48919
48920
48921
48922
48923
48924
# File 'lib/aws-sdk-ec2/types.rb', line 48904

class ImportImageTask < Struct.new(
  :architecture,
  :description,
  :encrypted,
  :hypervisor,
  :image_id,
  :import_task_id,
  :kms_key_id,
  :license_type,
  :platform,
  :progress,
  :snapshot_details,
  :status,
  :status_message,
  :tags,
  :license_specifications,
  :usage_operation,
  :boot_mode)
  SENSITIVE = []
  include Aws::Structure
end

#encryptedBoolean

Indicates whether the image is encrypted.

Returns:

  • (Boolean)


48904
48905
48906
48907
48908
48909
48910
48911
48912
48913
48914
48915
48916
48917
48918
48919
48920
48921
48922
48923
48924
# File 'lib/aws-sdk-ec2/types.rb', line 48904

class ImportImageTask < Struct.new(
  :architecture,
  :description,
  :encrypted,
  :hypervisor,
  :image_id,
  :import_task_id,
  :kms_key_id,
  :license_type,
  :platform,
  :progress,
  :snapshot_details,
  :status,
  :status_message,
  :tags,
  :license_specifications,
  :usage_operation,
  :boot_mode)
  SENSITIVE = []
  include Aws::Structure
end

#hypervisorString

The target hypervisor for the import task.

Valid values: ‘xen`

Returns:

  • (String)


48904
48905
48906
48907
48908
48909
48910
48911
48912
48913
48914
48915
48916
48917
48918
48919
48920
48921
48922
48923
48924
# File 'lib/aws-sdk-ec2/types.rb', line 48904

class ImportImageTask < Struct.new(
  :architecture,
  :description,
  :encrypted,
  :hypervisor,
  :image_id,
  :import_task_id,
  :kms_key_id,
  :license_type,
  :platform,
  :progress,
  :snapshot_details,
  :status,
  :status_message,
  :tags,
  :license_specifications,
  :usage_operation,
  :boot_mode)
  SENSITIVE = []
  include Aws::Structure
end

#image_idString

The ID of the Amazon Machine Image (AMI) of the imported virtual machine.

Returns:

  • (String)


48904
48905
48906
48907
48908
48909
48910
48911
48912
48913
48914
48915
48916
48917
48918
48919
48920
48921
48922
48923
48924
# File 'lib/aws-sdk-ec2/types.rb', line 48904

class ImportImageTask < Struct.new(
  :architecture,
  :description,
  :encrypted,
  :hypervisor,
  :image_id,
  :import_task_id,
  :kms_key_id,
  :license_type,
  :platform,
  :progress,
  :snapshot_details,
  :status,
  :status_message,
  :tags,
  :license_specifications,
  :usage_operation,
  :boot_mode)
  SENSITIVE = []
  include Aws::Structure
end

#import_task_idString

The ID of the import image task.

Returns:

  • (String)


48904
48905
48906
48907
48908
48909
48910
48911
48912
48913
48914
48915
48916
48917
48918
48919
48920
48921
48922
48923
48924
# File 'lib/aws-sdk-ec2/types.rb', line 48904

class ImportImageTask < Struct.new(
  :architecture,
  :description,
  :encrypted,
  :hypervisor,
  :image_id,
  :import_task_id,
  :kms_key_id,
  :license_type,
  :platform,
  :progress,
  :snapshot_details,
  :status,
  :status_message,
  :tags,
  :license_specifications,
  :usage_operation,
  :boot_mode)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

The identifier for the KMS key that was used to create the encrypted image.

Returns:

  • (String)


48904
48905
48906
48907
48908
48909
48910
48911
48912
48913
48914
48915
48916
48917
48918
48919
48920
48921
48922
48923
48924
# File 'lib/aws-sdk-ec2/types.rb', line 48904

class ImportImageTask < Struct.new(
  :architecture,
  :description,
  :encrypted,
  :hypervisor,
  :image_id,
  :import_task_id,
  :kms_key_id,
  :license_type,
  :platform,
  :progress,
  :snapshot_details,
  :status,
  :status_message,
  :tags,
  :license_specifications,
  :usage_operation,
  :boot_mode)
  SENSITIVE = []
  include Aws::Structure
end

#license_specificationsArray<Types::ImportImageLicenseConfigurationResponse>

The ARNs of the license configurations that are associated with the import image task.



48904
48905
48906
48907
48908
48909
48910
48911
48912
48913
48914
48915
48916
48917
48918
48919
48920
48921
48922
48923
48924
# File 'lib/aws-sdk-ec2/types.rb', line 48904

class ImportImageTask < Struct.new(
  :architecture,
  :description,
  :encrypted,
  :hypervisor,
  :image_id,
  :import_task_id,
  :kms_key_id,
  :license_type,
  :platform,
  :progress,
  :snapshot_details,
  :status,
  :status_message,
  :tags,
  :license_specifications,
  :usage_operation,
  :boot_mode)
  SENSITIVE = []
  include Aws::Structure
end

#license_typeString

The license type of the virtual machine.

Returns:

  • (String)


48904
48905
48906
48907
48908
48909
48910
48911
48912
48913
48914
48915
48916
48917
48918
48919
48920
48921
48922
48923
48924
# File 'lib/aws-sdk-ec2/types.rb', line 48904

class ImportImageTask < Struct.new(
  :architecture,
  :description,
  :encrypted,
  :hypervisor,
  :image_id,
  :import_task_id,
  :kms_key_id,
  :license_type,
  :platform,
  :progress,
  :snapshot_details,
  :status,
  :status_message,
  :tags,
  :license_specifications,
  :usage_operation,
  :boot_mode)
  SENSITIVE = []
  include Aws::Structure
end

#platformString

The description string for the import image task.

Returns:

  • (String)


48904
48905
48906
48907
48908
48909
48910
48911
48912
48913
48914
48915
48916
48917
48918
48919
48920
48921
48922
48923
48924
# File 'lib/aws-sdk-ec2/types.rb', line 48904

class ImportImageTask < Struct.new(
  :architecture,
  :description,
  :encrypted,
  :hypervisor,
  :image_id,
  :import_task_id,
  :kms_key_id,
  :license_type,
  :platform,
  :progress,
  :snapshot_details,
  :status,
  :status_message,
  :tags,
  :license_specifications,
  :usage_operation,
  :boot_mode)
  SENSITIVE = []
  include Aws::Structure
end

#progressString

The percentage of progress of the import image task.

Returns:

  • (String)


48904
48905
48906
48907
48908
48909
48910
48911
48912
48913
48914
48915
48916
48917
48918
48919
48920
48921
48922
48923
48924
# File 'lib/aws-sdk-ec2/types.rb', line 48904

class ImportImageTask < Struct.new(
  :architecture,
  :description,
  :encrypted,
  :hypervisor,
  :image_id,
  :import_task_id,
  :kms_key_id,
  :license_type,
  :platform,
  :progress,
  :snapshot_details,
  :status,
  :status_message,
  :tags,
  :license_specifications,
  :usage_operation,
  :boot_mode)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_detailsArray<Types::SnapshotDetail>

Information about the snapshots.

Returns:



48904
48905
48906
48907
48908
48909
48910
48911
48912
48913
48914
48915
48916
48917
48918
48919
48920
48921
48922
48923
48924
# File 'lib/aws-sdk-ec2/types.rb', line 48904

class ImportImageTask < Struct.new(
  :architecture,
  :description,
  :encrypted,
  :hypervisor,
  :image_id,
  :import_task_id,
  :kms_key_id,
  :license_type,
  :platform,
  :progress,
  :snapshot_details,
  :status,
  :status_message,
  :tags,
  :license_specifications,
  :usage_operation,
  :boot_mode)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

A brief status for the import image task.

Returns:

  • (String)


48904
48905
48906
48907
48908
48909
48910
48911
48912
48913
48914
48915
48916
48917
48918
48919
48920
48921
48922
48923
48924
# File 'lib/aws-sdk-ec2/types.rb', line 48904

class ImportImageTask < Struct.new(
  :architecture,
  :description,
  :encrypted,
  :hypervisor,
  :image_id,
  :import_task_id,
  :kms_key_id,
  :license_type,
  :platform,
  :progress,
  :snapshot_details,
  :status,
  :status_message,
  :tags,
  :license_specifications,
  :usage_operation,
  :boot_mode)
  SENSITIVE = []
  include Aws::Structure
end

#status_messageString

A descriptive status message for the import image task.

Returns:

  • (String)


48904
48905
48906
48907
48908
48909
48910
48911
48912
48913
48914
48915
48916
48917
48918
48919
48920
48921
48922
48923
48924
# File 'lib/aws-sdk-ec2/types.rb', line 48904

class ImportImageTask < Struct.new(
  :architecture,
  :description,
  :encrypted,
  :hypervisor,
  :image_id,
  :import_task_id,
  :kms_key_id,
  :license_type,
  :platform,
  :progress,
  :snapshot_details,
  :status,
  :status_message,
  :tags,
  :license_specifications,
  :usage_operation,
  :boot_mode)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The tags for the import image task.

Returns:



48904
48905
48906
48907
48908
48909
48910
48911
48912
48913
48914
48915
48916
48917
48918
48919
48920
48921
48922
48923
48924
# File 'lib/aws-sdk-ec2/types.rb', line 48904

class ImportImageTask < Struct.new(
  :architecture,
  :description,
  :encrypted,
  :hypervisor,
  :image_id,
  :import_task_id,
  :kms_key_id,
  :license_type,
  :platform,
  :progress,
  :snapshot_details,
  :status,
  :status_message,
  :tags,
  :license_specifications,
  :usage_operation,
  :boot_mode)
  SENSITIVE = []
  include Aws::Structure
end

#usage_operationString

The usage operation value.

Returns:

  • (String)


48904
48905
48906
48907
48908
48909
48910
48911
48912
48913
48914
48915
48916
48917
48918
48919
48920
48921
48922
48923
48924
# File 'lib/aws-sdk-ec2/types.rb', line 48904

class ImportImageTask < Struct.new(
  :architecture,
  :description,
  :encrypted,
  :hypervisor,
  :image_id,
  :import_task_id,
  :kms_key_id,
  :license_type,
  :platform,
  :progress,
  :snapshot_details,
  :status,
  :status_message,
  :tags,
  :license_specifications,
  :usage_operation,
  :boot_mode)
  SENSITIVE = []
  include Aws::Structure
end