Class: Aws::EC2::Types::ImportInstanceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description for the instance being imported.

Returns:

  • (String)


50271
50272
50273
50274
50275
50276
50277
50278
50279
# File 'lib/aws-sdk-ec2/types.rb', line 50271

class ImportInstanceRequest < Struct.new(
  :dry_run,
  :description,
  :launch_specification,
  :disk_images,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#disk_imagesArray<Types::DiskImage>

The disk image.

Returns:



50271
50272
50273
50274
50275
50276
50277
50278
50279
# File 'lib/aws-sdk-ec2/types.rb', line 50271

class ImportInstanceRequest < Struct.new(
  :dry_run,
  :description,
  :launch_specification,
  :disk_images,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


50271
50272
50273
50274
50275
50276
50277
50278
50279
# File 'lib/aws-sdk-ec2/types.rb', line 50271

class ImportInstanceRequest < Struct.new(
  :dry_run,
  :description,
  :launch_specification,
  :disk_images,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#launch_specificationTypes::ImportInstanceLaunchSpecification

The launch specification.



50271
50272
50273
50274
50275
50276
50277
50278
50279
# File 'lib/aws-sdk-ec2/types.rb', line 50271

class ImportInstanceRequest < Struct.new(
  :dry_run,
  :description,
  :launch_specification,
  :disk_images,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#platformString

The instance operating system.

Returns:

  • (String)


50271
50272
50273
50274
50275
50276
50277
50278
50279
# File 'lib/aws-sdk-ec2/types.rb', line 50271

class ImportInstanceRequest < Struct.new(
  :dry_run,
  :description,
  :launch_specification,
  :disk_images,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end