Class: Aws::EC2::Types::ImportInstanceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description for the instance being imported.

Returns:

  • (String)


49414
49415
49416
49417
49418
49419
49420
49421
49422
# File 'lib/aws-sdk-ec2/types.rb', line 49414

class ImportInstanceRequest < Struct.new(
  :dry_run,
  :description,
  :launch_specification,
  :disk_images,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#disk_imagesArray<Types::DiskImage>

The disk image.

Returns:



49414
49415
49416
49417
49418
49419
49420
49421
49422
# File 'lib/aws-sdk-ec2/types.rb', line 49414

class ImportInstanceRequest < Struct.new(
  :dry_run,
  :description,
  :launch_specification,
  :disk_images,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


49414
49415
49416
49417
49418
49419
49420
49421
49422
# File 'lib/aws-sdk-ec2/types.rb', line 49414

class ImportInstanceRequest < Struct.new(
  :dry_run,
  :description,
  :launch_specification,
  :disk_images,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#launch_specificationTypes::ImportInstanceLaunchSpecification

The launch specification.



49414
49415
49416
49417
49418
49419
49420
49421
49422
# File 'lib/aws-sdk-ec2/types.rb', line 49414

class ImportInstanceRequest < Struct.new(
  :dry_run,
  :description,
  :launch_specification,
  :disk_images,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end

#platformString

The instance operating system.

Returns:

  • (String)


49414
49415
49416
49417
49418
49419
49420
49421
49422
# File 'lib/aws-sdk-ec2/types.rb', line 49414

class ImportInstanceRequest < Struct.new(
  :dry_run,
  :description,
  :launch_specification,
  :disk_images,
  :platform)
  SENSITIVE = []
  include Aws::Structure
end