Class: Aws::EC2::Types::ImportInstanceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ImportInstanceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description for the instance being imported.
-
#disk_images ⇒ Array<Types::DiskImage>
The disk image.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#launch_specification ⇒ Types::ImportInstanceLaunchSpecification
The launch specification.
-
#platform ⇒ String
The instance operating system.
Instance Attribute Details
#description ⇒ String
A description for the instance being imported.
49024 49025 49026 49027 49028 49029 49030 49031 49032 |
# File 'lib/aws-sdk-ec2/types.rb', line 49024 class ImportInstanceRequest < Struct.new( :dry_run, :description, :launch_specification, :disk_images, :platform) SENSITIVE = [] include Aws::Structure end |
#disk_images ⇒ Array<Types::DiskImage>
The disk image.
49024 49025 49026 49027 49028 49029 49030 49031 49032 |
# File 'lib/aws-sdk-ec2/types.rb', line 49024 class ImportInstanceRequest < Struct.new( :dry_run, :description, :launch_specification, :disk_images, :platform) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
49024 49025 49026 49027 49028 49029 49030 49031 49032 |
# File 'lib/aws-sdk-ec2/types.rb', line 49024 class ImportInstanceRequest < Struct.new( :dry_run, :description, :launch_specification, :disk_images, :platform) SENSITIVE = [] include Aws::Structure end |
#launch_specification ⇒ Types::ImportInstanceLaunchSpecification
The launch specification.
49024 49025 49026 49027 49028 49029 49030 49031 49032 |
# File 'lib/aws-sdk-ec2/types.rb', line 49024 class ImportInstanceRequest < Struct.new( :dry_run, :description, :launch_specification, :disk_images, :platform) SENSITIVE = [] include Aws::Structure end |
#platform ⇒ String
The instance operating system.
49024 49025 49026 49027 49028 49029 49030 49031 49032 |
# File 'lib/aws-sdk-ec2/types.rb', line 49024 class ImportInstanceRequest < Struct.new( :dry_run, :description, :launch_specification, :disk_images, :platform) SENSITIVE = [] include Aws::Structure end |