Class: Aws::EC2::Types::ImportKeyPairRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


51843
51844
51845
51846
51847
51848
51849
51850
# File 'lib/aws-sdk-ec2/types.rb', line 51843

class ImportKeyPairRequest < Struct.new(
  :tag_specifications,
  :dry_run,
  :key_name,
  :public_key_material)
  SENSITIVE = []
  include Aws::Structure
end

#key_nameString

A unique name for the key pair.

Returns:

  • (String)


51843
51844
51845
51846
51847
51848
51849
51850
# File 'lib/aws-sdk-ec2/types.rb', line 51843

class ImportKeyPairRequest < Struct.new(
  :tag_specifications,
  :dry_run,
  :key_name,
  :public_key_material)
  SENSITIVE = []
  include Aws::Structure
end

#public_key_materialString

The public key.

Returns:

  • (String)


51843
51844
51845
51846
51847
51848
51849
51850
# File 'lib/aws-sdk-ec2/types.rb', line 51843

class ImportKeyPairRequest < Struct.new(
  :tag_specifications,
  :dry_run,
  :key_name,
  :public_key_material)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the imported key pair.

Returns:



51843
51844
51845
51846
51847
51848
51849
51850
# File 'lib/aws-sdk-ec2/types.rb', line 51843

class ImportKeyPairRequest < Struct.new(
  :tag_specifications,
  :dry_run,
  :key_name,
  :public_key_material)
  SENSITIVE = []
  include Aws::Structure
end