Class: Aws::EC2::Types::ImportKeyPairRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


49649
49650
49651
49652
49653
49654
49655
49656
# File 'lib/aws-sdk-ec2/types.rb', line 49649

class ImportKeyPairRequest < Struct.new(
  :tag_specifications,
  :dry_run,
  :key_name,
  :public_key_material)
  SENSITIVE = []
  include Aws::Structure
end

#key_nameString

A unique name for the key pair.

Returns:

  • (String)


49649
49650
49651
49652
49653
49654
49655
49656
# File 'lib/aws-sdk-ec2/types.rb', line 49649

class ImportKeyPairRequest < Struct.new(
  :tag_specifications,
  :dry_run,
  :key_name,
  :public_key_material)
  SENSITIVE = []
  include Aws::Structure
end

#public_key_materialString

The public key.

Returns:

  • (String)


49649
49650
49651
49652
49653
49654
49655
49656
# File 'lib/aws-sdk-ec2/types.rb', line 49649

class ImportKeyPairRequest < Struct.new(
  :tag_specifications,
  :dry_run,
  :key_name,
  :public_key_material)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the imported key pair.

Returns:



49649
49650
49651
49652
49653
49654
49655
49656
# File 'lib/aws-sdk-ec2/types.rb', line 49649

class ImportKeyPairRequest < Struct.new(
  :tag_specifications,
  :dry_run,
  :key_name,
  :public_key_material)
  SENSITIVE = []
  include Aws::Structure
end