Class: Aws::EC2::Types::ImportVolumeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_zoneString

The Availability Zone for the resulting EBS volume.

Either AvailabilityZone or AvailabilityZoneId must be specified, but not both.

Returns:

  • (String)


50762
50763
50764
50765
50766
50767
50768
50769
50770
50771
# File 'lib/aws-sdk-ec2/types.rb', line 50762

class ImportVolumeRequest < Struct.new(
  :availability_zone_id,
  :dry_run,
  :availability_zone,
  :image,
  :description,
  :volume)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zone_idString

The ID of the Availability Zone for the resulting EBS volume.

Either AvailabilityZone or AvailabilityZoneId must be specified, but not both.

Returns:

  • (String)


50762
50763
50764
50765
50766
50767
50768
50769
50770
50771
# File 'lib/aws-sdk-ec2/types.rb', line 50762

class ImportVolumeRequest < Struct.new(
  :availability_zone_id,
  :dry_run,
  :availability_zone,
  :image,
  :description,
  :volume)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the volume.

Returns:

  • (String)


50762
50763
50764
50765
50766
50767
50768
50769
50770
50771
# File 'lib/aws-sdk-ec2/types.rb', line 50762

class ImportVolumeRequest < Struct.new(
  :availability_zone_id,
  :dry_run,
  :availability_zone,
  :image,
  :description,
  :volume)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


50762
50763
50764
50765
50766
50767
50768
50769
50770
50771
# File 'lib/aws-sdk-ec2/types.rb', line 50762

class ImportVolumeRequest < Struct.new(
  :availability_zone_id,
  :dry_run,
  :availability_zone,
  :image,
  :description,
  :volume)
  SENSITIVE = []
  include Aws::Structure
end

#imageTypes::DiskImageDetail

The disk image.



50762
50763
50764
50765
50766
50767
50768
50769
50770
50771
# File 'lib/aws-sdk-ec2/types.rb', line 50762

class ImportVolumeRequest < Struct.new(
  :availability_zone_id,
  :dry_run,
  :availability_zone,
  :image,
  :description,
  :volume)
  SENSITIVE = []
  include Aws::Structure
end

#volumeTypes::VolumeDetail

The volume size.

Returns:



50762
50763
50764
50765
50766
50767
50768
50769
50770
50771
# File 'lib/aws-sdk-ec2/types.rb', line 50762

class ImportVolumeRequest < Struct.new(
  :availability_zone_id,
  :dry_run,
  :availability_zone,
  :image,
  :description,
  :volume)
  SENSITIVE = []
  include Aws::Structure
end