Class: Aws::EC2::Types::ImportVolumeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_zoneString

The Availability Zone for the resulting EBS volume.

Either ‘AvailabilityZone` or `AvailabilityZoneId` must be specified, but not both.

Returns:

  • (String)


49685
49686
49687
49688
49689
49690
49691
49692
49693
49694
# File 'lib/aws-sdk-ec2/types.rb', line 49685

class ImportVolumeRequest < Struct.new(
  :availability_zone_id,
  :dry_run,
  :availability_zone,
  :image,
  :description,
  :volume)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zone_idString

The ID of the Availability Zone for the resulting EBS volume.

Either ‘AvailabilityZone` or `AvailabilityZoneId` must be specified, but not both.

Returns:

  • (String)


49685
49686
49687
49688
49689
49690
49691
49692
49693
49694
# File 'lib/aws-sdk-ec2/types.rb', line 49685

class ImportVolumeRequest < Struct.new(
  :availability_zone_id,
  :dry_run,
  :availability_zone,
  :image,
  :description,
  :volume)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the volume.

Returns:

  • (String)


49685
49686
49687
49688
49689
49690
49691
49692
49693
49694
# File 'lib/aws-sdk-ec2/types.rb', line 49685

class ImportVolumeRequest < Struct.new(
  :availability_zone_id,
  :dry_run,
  :availability_zone,
  :image,
  :description,
  :volume)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


49685
49686
49687
49688
49689
49690
49691
49692
49693
49694
# File 'lib/aws-sdk-ec2/types.rb', line 49685

class ImportVolumeRequest < Struct.new(
  :availability_zone_id,
  :dry_run,
  :availability_zone,
  :image,
  :description,
  :volume)
  SENSITIVE = []
  include Aws::Structure
end

#imageTypes::DiskImageDetail

The disk image.



49685
49686
49687
49688
49689
49690
49691
49692
49693
49694
# File 'lib/aws-sdk-ec2/types.rb', line 49685

class ImportVolumeRequest < Struct.new(
  :availability_zone_id,
  :dry_run,
  :availability_zone,
  :image,
  :description,
  :volume)
  SENSITIVE = []
  include Aws::Structure
end

#volumeTypes::VolumeDetail

The volume size.

Returns:



49685
49686
49687
49688
49689
49690
49691
49692
49693
49694
# File 'lib/aws-sdk-ec2/types.rb', line 49685

class ImportVolumeRequest < Struct.new(
  :availability_zone_id,
  :dry_run,
  :availability_zone,
  :image,
  :description,
  :volume)
  SENSITIVE = []
  include Aws::Structure
end