Class: Aws::EC2::Types::ImportVolumeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ImportVolumeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone ⇒ String
The Availability Zone for the resulting EBS volume.
-
#availability_zone_id ⇒ String
The ID of the Availability Zone for the resulting EBS volume.
-
#description ⇒ String
A description of the volume.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#image ⇒ Types::DiskImageDetail
The disk image.
-
#volume ⇒ Types::VolumeDetail
The volume size.
Instance Attribute Details
#availability_zone ⇒ String
The Availability Zone for the resulting EBS volume.
Either ‘AvailabilityZone` or `AvailabilityZoneId` must be specified, but not both.
48764 48765 48766 48767 48768 48769 48770 48771 48772 48773 |
# File 'lib/aws-sdk-ec2/types.rb', line 48764 class ImportVolumeRequest < Struct.new( :availability_zone_id, :dry_run, :availability_zone, :image, :description, :volume) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
The ID of the Availability Zone for the resulting EBS volume.
Either ‘AvailabilityZone` or `AvailabilityZoneId` must be specified, but not both.
48764 48765 48766 48767 48768 48769 48770 48771 48772 48773 |
# File 'lib/aws-sdk-ec2/types.rb', line 48764 class ImportVolumeRequest < Struct.new( :availability_zone_id, :dry_run, :availability_zone, :image, :description, :volume) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the volume.
48764 48765 48766 48767 48768 48769 48770 48771 48772 48773 |
# File 'lib/aws-sdk-ec2/types.rb', line 48764 class ImportVolumeRequest < Struct.new( :availability_zone_id, :dry_run, :availability_zone, :image, :description, :volume) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
48764 48765 48766 48767 48768 48769 48770 48771 48772 48773 |
# File 'lib/aws-sdk-ec2/types.rb', line 48764 class ImportVolumeRequest < Struct.new( :availability_zone_id, :dry_run, :availability_zone, :image, :description, :volume) SENSITIVE = [] include Aws::Structure end |
#image ⇒ Types::DiskImageDetail
The disk image.
48764 48765 48766 48767 48768 48769 48770 48771 48772 48773 |
# File 'lib/aws-sdk-ec2/types.rb', line 48764 class ImportVolumeRequest < Struct.new( :availability_zone_id, :dry_run, :availability_zone, :image, :description, :volume) SENSITIVE = [] include Aws::Structure end |
#volume ⇒ Types::VolumeDetail
The volume size.
48764 48765 48766 48767 48768 48769 48770 48771 48772 48773 |
# File 'lib/aws-sdk-ec2/types.rb', line 48764 class ImportVolumeRequest < Struct.new( :availability_zone_id, :dry_run, :availability_zone, :image, :description, :volume) SENSITIVE = [] include Aws::Structure end |