Class: Aws::EC2::Types::InstanceAttribute

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes an instance attribute.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#block_device_mappingsArray<Types::InstanceBlockDeviceMapping>

The block device mapping of the instance.



51344
51345
51346
51347
51348
51349
51350
51351
51352
51353
51354
51355
51356
51357
51358
51359
51360
51361
51362
51363
51364
# File 'lib/aws-sdk-ec2/types.rb', line 51344

class InstanceAttribute < Struct.new(
  :block_device_mappings,
  :disable_api_termination,
  :ena_support,
  :enclave_options,
  :ebs_optimized,
  :instance_id,
  :instance_initiated_shutdown_behavior,
  :instance_type,
  :kernel_id,
  :product_codes,
  :ramdisk_id,
  :root_device_name,
  :source_dest_check,
  :sriov_net_support,
  :user_data,
  :disable_api_stop,
  :groups)
  SENSITIVE = []
  include Aws::Structure
end

#disable_api_stopTypes::AttributeBooleanValue

Indicates whether stop protection is enabled for the instance.



51344
51345
51346
51347
51348
51349
51350
51351
51352
51353
51354
51355
51356
51357
51358
51359
51360
51361
51362
51363
51364
# File 'lib/aws-sdk-ec2/types.rb', line 51344

class InstanceAttribute < Struct.new(
  :block_device_mappings,
  :disable_api_termination,
  :ena_support,
  :enclave_options,
  :ebs_optimized,
  :instance_id,
  :instance_initiated_shutdown_behavior,
  :instance_type,
  :kernel_id,
  :product_codes,
  :ramdisk_id,
  :root_device_name,
  :source_dest_check,
  :sriov_net_support,
  :user_data,
  :disable_api_stop,
  :groups)
  SENSITIVE = []
  include Aws::Structure
end

#disable_api_terminationTypes::AttributeBooleanValue

Indicates whether termination protection is enabled. If the value is true, you can't terminate the instance using the Amazon EC2 console, command line tools, or API.



51344
51345
51346
51347
51348
51349
51350
51351
51352
51353
51354
51355
51356
51357
51358
51359
51360
51361
51362
51363
51364
# File 'lib/aws-sdk-ec2/types.rb', line 51344

class InstanceAttribute < Struct.new(
  :block_device_mappings,
  :disable_api_termination,
  :ena_support,
  :enclave_options,
  :ebs_optimized,
  :instance_id,
  :instance_initiated_shutdown_behavior,
  :instance_type,
  :kernel_id,
  :product_codes,
  :ramdisk_id,
  :root_device_name,
  :source_dest_check,
  :sriov_net_support,
  :user_data,
  :disable_api_stop,
  :groups)
  SENSITIVE = []
  include Aws::Structure
end

#ebs_optimizedTypes::AttributeBooleanValue

Indicates whether the instance is optimized for Amazon EBS I/O.



51344
51345
51346
51347
51348
51349
51350
51351
51352
51353
51354
51355
51356
51357
51358
51359
51360
51361
51362
51363
51364
# File 'lib/aws-sdk-ec2/types.rb', line 51344

class InstanceAttribute < Struct.new(
  :block_device_mappings,
  :disable_api_termination,
  :ena_support,
  :enclave_options,
  :ebs_optimized,
  :instance_id,
  :instance_initiated_shutdown_behavior,
  :instance_type,
  :kernel_id,
  :product_codes,
  :ramdisk_id,
  :root_device_name,
  :source_dest_check,
  :sriov_net_support,
  :user_data,
  :disable_api_stop,
  :groups)
  SENSITIVE = []
  include Aws::Structure
end

#ena_supportTypes::AttributeBooleanValue

Indicates whether enhanced networking with ENA is enabled.



51344
51345
51346
51347
51348
51349
51350
51351
51352
51353
51354
51355
51356
51357
51358
51359
51360
51361
51362
51363
51364
# File 'lib/aws-sdk-ec2/types.rb', line 51344

class InstanceAttribute < Struct.new(
  :block_device_mappings,
  :disable_api_termination,
  :ena_support,
  :enclave_options,
  :ebs_optimized,
  :instance_id,
  :instance_initiated_shutdown_behavior,
  :instance_type,
  :kernel_id,
  :product_codes,
  :ramdisk_id,
  :root_device_name,
  :source_dest_check,
  :sriov_net_support,
  :user_data,
  :disable_api_stop,
  :groups)
  SENSITIVE = []
  include Aws::Structure
end

#enclave_optionsTypes::EnclaveOptions

Indicates whether the instance is enabled for Amazon Web Services Nitro Enclaves.



51344
51345
51346
51347
51348
51349
51350
51351
51352
51353
51354
51355
51356
51357
51358
51359
51360
51361
51362
51363
51364
# File 'lib/aws-sdk-ec2/types.rb', line 51344

class InstanceAttribute < Struct.new(
  :block_device_mappings,
  :disable_api_termination,
  :ena_support,
  :enclave_options,
  :ebs_optimized,
  :instance_id,
  :instance_initiated_shutdown_behavior,
  :instance_type,
  :kernel_id,
  :product_codes,
  :ramdisk_id,
  :root_device_name,
  :source_dest_check,
  :sriov_net_support,
  :user_data,
  :disable_api_stop,
  :groups)
  SENSITIVE = []
  include Aws::Structure
end

#groupsArray<Types::GroupIdentifier>

The security groups associated with the instance.

Returns:



51344
51345
51346
51347
51348
51349
51350
51351
51352
51353
51354
51355
51356
51357
51358
51359
51360
51361
51362
51363
51364
# File 'lib/aws-sdk-ec2/types.rb', line 51344

class InstanceAttribute < Struct.new(
  :block_device_mappings,
  :disable_api_termination,
  :ena_support,
  :enclave_options,
  :ebs_optimized,
  :instance_id,
  :instance_initiated_shutdown_behavior,
  :instance_type,
  :kernel_id,
  :product_codes,
  :ramdisk_id,
  :root_device_name,
  :source_dest_check,
  :sriov_net_support,
  :user_data,
  :disable_api_stop,
  :groups)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The ID of the instance.

Returns:

  • (String)


51344
51345
51346
51347
51348
51349
51350
51351
51352
51353
51354
51355
51356
51357
51358
51359
51360
51361
51362
51363
51364
# File 'lib/aws-sdk-ec2/types.rb', line 51344

class InstanceAttribute < Struct.new(
  :block_device_mappings,
  :disable_api_termination,
  :ena_support,
  :enclave_options,
  :ebs_optimized,
  :instance_id,
  :instance_initiated_shutdown_behavior,
  :instance_type,
  :kernel_id,
  :product_codes,
  :ramdisk_id,
  :root_device_name,
  :source_dest_check,
  :sriov_net_support,
  :user_data,
  :disable_api_stop,
  :groups)
  SENSITIVE = []
  include Aws::Structure
end

#instance_initiated_shutdown_behaviorTypes::AttributeValue

Indicates whether an instance stops or terminates when you initiate shutdown from the instance (using the operating system command for system shutdown).



51344
51345
51346
51347
51348
51349
51350
51351
51352
51353
51354
51355
51356
51357
51358
51359
51360
51361
51362
51363
51364
# File 'lib/aws-sdk-ec2/types.rb', line 51344

class InstanceAttribute < Struct.new(
  :block_device_mappings,
  :disable_api_termination,
  :ena_support,
  :enclave_options,
  :ebs_optimized,
  :instance_id,
  :instance_initiated_shutdown_behavior,
  :instance_type,
  :kernel_id,
  :product_codes,
  :ramdisk_id,
  :root_device_name,
  :source_dest_check,
  :sriov_net_support,
  :user_data,
  :disable_api_stop,
  :groups)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeTypes::AttributeValue

The instance type.



51344
51345
51346
51347
51348
51349
51350
51351
51352
51353
51354
51355
51356
51357
51358
51359
51360
51361
51362
51363
51364
# File 'lib/aws-sdk-ec2/types.rb', line 51344

class InstanceAttribute < Struct.new(
  :block_device_mappings,
  :disable_api_termination,
  :ena_support,
  :enclave_options,
  :ebs_optimized,
  :instance_id,
  :instance_initiated_shutdown_behavior,
  :instance_type,
  :kernel_id,
  :product_codes,
  :ramdisk_id,
  :root_device_name,
  :source_dest_check,
  :sriov_net_support,
  :user_data,
  :disable_api_stop,
  :groups)
  SENSITIVE = []
  include Aws::Structure
end

#kernel_idTypes::AttributeValue

The kernel ID.



51344
51345
51346
51347
51348
51349
51350
51351
51352
51353
51354
51355
51356
51357
51358
51359
51360
51361
51362
51363
51364
# File 'lib/aws-sdk-ec2/types.rb', line 51344

class InstanceAttribute < Struct.new(
  :block_device_mappings,
  :disable_api_termination,
  :ena_support,
  :enclave_options,
  :ebs_optimized,
  :instance_id,
  :instance_initiated_shutdown_behavior,
  :instance_type,
  :kernel_id,
  :product_codes,
  :ramdisk_id,
  :root_device_name,
  :source_dest_check,
  :sriov_net_support,
  :user_data,
  :disable_api_stop,
  :groups)
  SENSITIVE = []
  include Aws::Structure
end

#product_codesArray<Types::ProductCode>

The product codes.

Returns:



51344
51345
51346
51347
51348
51349
51350
51351
51352
51353
51354
51355
51356
51357
51358
51359
51360
51361
51362
51363
51364
# File 'lib/aws-sdk-ec2/types.rb', line 51344

class InstanceAttribute < Struct.new(
  :block_device_mappings,
  :disable_api_termination,
  :ena_support,
  :enclave_options,
  :ebs_optimized,
  :instance_id,
  :instance_initiated_shutdown_behavior,
  :instance_type,
  :kernel_id,
  :product_codes,
  :ramdisk_id,
  :root_device_name,
  :source_dest_check,
  :sriov_net_support,
  :user_data,
  :disable_api_stop,
  :groups)
  SENSITIVE = []
  include Aws::Structure
end

#ramdisk_idTypes::AttributeValue

The RAM disk ID.



51344
51345
51346
51347
51348
51349
51350
51351
51352
51353
51354
51355
51356
51357
51358
51359
51360
51361
51362
51363
51364
# File 'lib/aws-sdk-ec2/types.rb', line 51344

class InstanceAttribute < Struct.new(
  :block_device_mappings,
  :disable_api_termination,
  :ena_support,
  :enclave_options,
  :ebs_optimized,
  :instance_id,
  :instance_initiated_shutdown_behavior,
  :instance_type,
  :kernel_id,
  :product_codes,
  :ramdisk_id,
  :root_device_name,
  :source_dest_check,
  :sriov_net_support,
  :user_data,
  :disable_api_stop,
  :groups)
  SENSITIVE = []
  include Aws::Structure
end

#root_device_nameTypes::AttributeValue

The device name of the root device volume (for example, /dev/sda1).



51344
51345
51346
51347
51348
51349
51350
51351
51352
51353
51354
51355
51356
51357
51358
51359
51360
51361
51362
51363
51364
# File 'lib/aws-sdk-ec2/types.rb', line 51344

class InstanceAttribute < Struct.new(
  :block_device_mappings,
  :disable_api_termination,
  :ena_support,
  :enclave_options,
  :ebs_optimized,
  :instance_id,
  :instance_initiated_shutdown_behavior,
  :instance_type,
  :kernel_id,
  :product_codes,
  :ramdisk_id,
  :root_device_name,
  :source_dest_check,
  :sriov_net_support,
  :user_data,
  :disable_api_stop,
  :groups)
  SENSITIVE = []
  include Aws::Structure
end

#source_dest_checkTypes::AttributeBooleanValue

Indicates whether source/destination checks are enabled.



51344
51345
51346
51347
51348
51349
51350
51351
51352
51353
51354
51355
51356
51357
51358
51359
51360
51361
51362
51363
51364
# File 'lib/aws-sdk-ec2/types.rb', line 51344

class InstanceAttribute < Struct.new(
  :block_device_mappings,
  :disable_api_termination,
  :ena_support,
  :enclave_options,
  :ebs_optimized,
  :instance_id,
  :instance_initiated_shutdown_behavior,
  :instance_type,
  :kernel_id,
  :product_codes,
  :ramdisk_id,
  :root_device_name,
  :source_dest_check,
  :sriov_net_support,
  :user_data,
  :disable_api_stop,
  :groups)
  SENSITIVE = []
  include Aws::Structure
end

#sriov_net_supportTypes::AttributeValue

Indicates whether enhanced networking with the Intel 82599 Virtual Function interface is enabled.



51344
51345
51346
51347
51348
51349
51350
51351
51352
51353
51354
51355
51356
51357
51358
51359
51360
51361
51362
51363
51364
# File 'lib/aws-sdk-ec2/types.rb', line 51344

class InstanceAttribute < Struct.new(
  :block_device_mappings,
  :disable_api_termination,
  :ena_support,
  :enclave_options,
  :ebs_optimized,
  :instance_id,
  :instance_initiated_shutdown_behavior,
  :instance_type,
  :kernel_id,
  :product_codes,
  :ramdisk_id,
  :root_device_name,
  :source_dest_check,
  :sriov_net_support,
  :user_data,
  :disable_api_stop,
  :groups)
  SENSITIVE = []
  include Aws::Structure
end

#user_dataTypes::AttributeValue

The user data.



51344
51345
51346
51347
51348
51349
51350
51351
51352
51353
51354
51355
51356
51357
51358
51359
51360
51361
51362
51363
51364
# File 'lib/aws-sdk-ec2/types.rb', line 51344

class InstanceAttribute < Struct.new(
  :block_device_mappings,
  :disable_api_termination,
  :ena_support,
  :enclave_options,
  :ebs_optimized,
  :instance_id,
  :instance_initiated_shutdown_behavior,
  :instance_type,
  :kernel_id,
  :product_codes,
  :ramdisk_id,
  :root_device_name,
  :source_dest_check,
  :sriov_net_support,
  :user_data,
  :disable_api_stop,
  :groups)
  SENSITIVE = []
  include Aws::Structure
end