Class: Aws::EC2::Types::InstanceAttribute
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::InstanceAttribute
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes an instance attribute.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#block_device_mappings ⇒ Array<Types::InstanceBlockDeviceMapping>
The block device mapping of the instance.
-
#disable_api_stop ⇒ Types::AttributeBooleanValue
Indicates whether stop protection is enabled for the instance.
-
#disable_api_termination ⇒ Types::AttributeBooleanValue
Indicates whether termination protection is enabled.
-
#ebs_optimized ⇒ Types::AttributeBooleanValue
Indicates whether the instance is optimized for Amazon EBS I/O.
-
#ena_support ⇒ Types::AttributeBooleanValue
Indicates whether enhanced networking with ENA is enabled.
-
#enclave_options ⇒ Types::EnclaveOptions
Indicates whether the instance is enabled for Amazon Web Services Nitro Enclaves.
-
#groups ⇒ Array<Types::GroupIdentifier>
The security groups associated with the instance.
-
#instance_id ⇒ String
The ID of the instance.
-
#instance_initiated_shutdown_behavior ⇒ Types::AttributeValue
Indicates whether an instance stops or terminates when you initiate shutdown from the instance (using the operating system command for system shutdown).
-
#instance_type ⇒ Types::AttributeValue
The instance type.
-
#kernel_id ⇒ Types::AttributeValue
The kernel ID.
-
#product_codes ⇒ Array<Types::ProductCode>
The product codes.
-
#ramdisk_id ⇒ Types::AttributeValue
The RAM disk ID.
-
#root_device_name ⇒ Types::AttributeValue
The device name of the root device volume (for example, ‘/dev/sda1`).
-
#source_dest_check ⇒ Types::AttributeBooleanValue
Indicates whether source/destination checks are enabled.
-
#sriov_net_support ⇒ Types::AttributeValue
Indicates whether enhanced networking with the Intel 82599 Virtual Function interface is enabled.
-
#user_data ⇒ Types::AttributeValue
The user data.
Instance Attribute Details
#block_device_mappings ⇒ Array<Types::InstanceBlockDeviceMapping>
The block device mapping of the instance.
50097 50098 50099 50100 50101 50102 50103 50104 50105 50106 50107 50108 50109 50110 50111 50112 50113 50114 50115 50116 50117 |
# File 'lib/aws-sdk-ec2/types.rb', line 50097 class InstanceAttribute < Struct.new( :block_device_mappings, :disable_api_termination, :ena_support, :enclave_options, :ebs_optimized, :instance_id, :instance_initiated_shutdown_behavior, :instance_type, :kernel_id, :product_codes, :ramdisk_id, :root_device_name, :source_dest_check, :sriov_net_support, :user_data, :disable_api_stop, :groups) SENSITIVE = [] include Aws::Structure end |
#disable_api_stop ⇒ Types::AttributeBooleanValue
Indicates whether stop protection is enabled for the instance.
50097 50098 50099 50100 50101 50102 50103 50104 50105 50106 50107 50108 50109 50110 50111 50112 50113 50114 50115 50116 50117 |
# File 'lib/aws-sdk-ec2/types.rb', line 50097 class InstanceAttribute < Struct.new( :block_device_mappings, :disable_api_termination, :ena_support, :enclave_options, :ebs_optimized, :instance_id, :instance_initiated_shutdown_behavior, :instance_type, :kernel_id, :product_codes, :ramdisk_id, :root_device_name, :source_dest_check, :sriov_net_support, :user_data, :disable_api_stop, :groups) SENSITIVE = [] include Aws::Structure end |
#disable_api_termination ⇒ Types::AttributeBooleanValue
Indicates whether termination protection is enabled. If the value is ‘true`, you can’t terminate the instance using the Amazon EC2 console, command line tools, or API.
50097 50098 50099 50100 50101 50102 50103 50104 50105 50106 50107 50108 50109 50110 50111 50112 50113 50114 50115 50116 50117 |
# File 'lib/aws-sdk-ec2/types.rb', line 50097 class InstanceAttribute < Struct.new( :block_device_mappings, :disable_api_termination, :ena_support, :enclave_options, :ebs_optimized, :instance_id, :instance_initiated_shutdown_behavior, :instance_type, :kernel_id, :product_codes, :ramdisk_id, :root_device_name, :source_dest_check, :sriov_net_support, :user_data, :disable_api_stop, :groups) SENSITIVE = [] include Aws::Structure end |
#ebs_optimized ⇒ Types::AttributeBooleanValue
Indicates whether the instance is optimized for Amazon EBS I/O.
50097 50098 50099 50100 50101 50102 50103 50104 50105 50106 50107 50108 50109 50110 50111 50112 50113 50114 50115 50116 50117 |
# File 'lib/aws-sdk-ec2/types.rb', line 50097 class InstanceAttribute < Struct.new( :block_device_mappings, :disable_api_termination, :ena_support, :enclave_options, :ebs_optimized, :instance_id, :instance_initiated_shutdown_behavior, :instance_type, :kernel_id, :product_codes, :ramdisk_id, :root_device_name, :source_dest_check, :sriov_net_support, :user_data, :disable_api_stop, :groups) SENSITIVE = [] include Aws::Structure end |
#ena_support ⇒ Types::AttributeBooleanValue
Indicates whether enhanced networking with ENA is enabled.
50097 50098 50099 50100 50101 50102 50103 50104 50105 50106 50107 50108 50109 50110 50111 50112 50113 50114 50115 50116 50117 |
# File 'lib/aws-sdk-ec2/types.rb', line 50097 class InstanceAttribute < Struct.new( :block_device_mappings, :disable_api_termination, :ena_support, :enclave_options, :ebs_optimized, :instance_id, :instance_initiated_shutdown_behavior, :instance_type, :kernel_id, :product_codes, :ramdisk_id, :root_device_name, :source_dest_check, :sriov_net_support, :user_data, :disable_api_stop, :groups) SENSITIVE = [] include Aws::Structure end |
#enclave_options ⇒ Types::EnclaveOptions
Indicates whether the instance is enabled for Amazon Web Services Nitro Enclaves.
50097 50098 50099 50100 50101 50102 50103 50104 50105 50106 50107 50108 50109 50110 50111 50112 50113 50114 50115 50116 50117 |
# File 'lib/aws-sdk-ec2/types.rb', line 50097 class InstanceAttribute < Struct.new( :block_device_mappings, :disable_api_termination, :ena_support, :enclave_options, :ebs_optimized, :instance_id, :instance_initiated_shutdown_behavior, :instance_type, :kernel_id, :product_codes, :ramdisk_id, :root_device_name, :source_dest_check, :sriov_net_support, :user_data, :disable_api_stop, :groups) SENSITIVE = [] include Aws::Structure end |
#groups ⇒ Array<Types::GroupIdentifier>
The security groups associated with the instance.
50097 50098 50099 50100 50101 50102 50103 50104 50105 50106 50107 50108 50109 50110 50111 50112 50113 50114 50115 50116 50117 |
# File 'lib/aws-sdk-ec2/types.rb', line 50097 class InstanceAttribute < Struct.new( :block_device_mappings, :disable_api_termination, :ena_support, :enclave_options, :ebs_optimized, :instance_id, :instance_initiated_shutdown_behavior, :instance_type, :kernel_id, :product_codes, :ramdisk_id, :root_device_name, :source_dest_check, :sriov_net_support, :user_data, :disable_api_stop, :groups) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the instance.
50097 50098 50099 50100 50101 50102 50103 50104 50105 50106 50107 50108 50109 50110 50111 50112 50113 50114 50115 50116 50117 |
# File 'lib/aws-sdk-ec2/types.rb', line 50097 class InstanceAttribute < Struct.new( :block_device_mappings, :disable_api_termination, :ena_support, :enclave_options, :ebs_optimized, :instance_id, :instance_initiated_shutdown_behavior, :instance_type, :kernel_id, :product_codes, :ramdisk_id, :root_device_name, :source_dest_check, :sriov_net_support, :user_data, :disable_api_stop, :groups) SENSITIVE = [] include Aws::Structure end |
#instance_initiated_shutdown_behavior ⇒ Types::AttributeValue
Indicates whether an instance stops or terminates when you initiate shutdown from the instance (using the operating system command for system shutdown).
50097 50098 50099 50100 50101 50102 50103 50104 50105 50106 50107 50108 50109 50110 50111 50112 50113 50114 50115 50116 50117 |
# File 'lib/aws-sdk-ec2/types.rb', line 50097 class InstanceAttribute < Struct.new( :block_device_mappings, :disable_api_termination, :ena_support, :enclave_options, :ebs_optimized, :instance_id, :instance_initiated_shutdown_behavior, :instance_type, :kernel_id, :product_codes, :ramdisk_id, :root_device_name, :source_dest_check, :sriov_net_support, :user_data, :disable_api_stop, :groups) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ Types::AttributeValue
The instance type.
50097 50098 50099 50100 50101 50102 50103 50104 50105 50106 50107 50108 50109 50110 50111 50112 50113 50114 50115 50116 50117 |
# File 'lib/aws-sdk-ec2/types.rb', line 50097 class InstanceAttribute < Struct.new( :block_device_mappings, :disable_api_termination, :ena_support, :enclave_options, :ebs_optimized, :instance_id, :instance_initiated_shutdown_behavior, :instance_type, :kernel_id, :product_codes, :ramdisk_id, :root_device_name, :source_dest_check, :sriov_net_support, :user_data, :disable_api_stop, :groups) SENSITIVE = [] include Aws::Structure end |
#kernel_id ⇒ Types::AttributeValue
The kernel ID.
50097 50098 50099 50100 50101 50102 50103 50104 50105 50106 50107 50108 50109 50110 50111 50112 50113 50114 50115 50116 50117 |
# File 'lib/aws-sdk-ec2/types.rb', line 50097 class InstanceAttribute < Struct.new( :block_device_mappings, :disable_api_termination, :ena_support, :enclave_options, :ebs_optimized, :instance_id, :instance_initiated_shutdown_behavior, :instance_type, :kernel_id, :product_codes, :ramdisk_id, :root_device_name, :source_dest_check, :sriov_net_support, :user_data, :disable_api_stop, :groups) SENSITIVE = [] include Aws::Structure end |
#product_codes ⇒ Array<Types::ProductCode>
The product codes.
50097 50098 50099 50100 50101 50102 50103 50104 50105 50106 50107 50108 50109 50110 50111 50112 50113 50114 50115 50116 50117 |
# File 'lib/aws-sdk-ec2/types.rb', line 50097 class InstanceAttribute < Struct.new( :block_device_mappings, :disable_api_termination, :ena_support, :enclave_options, :ebs_optimized, :instance_id, :instance_initiated_shutdown_behavior, :instance_type, :kernel_id, :product_codes, :ramdisk_id, :root_device_name, :source_dest_check, :sriov_net_support, :user_data, :disable_api_stop, :groups) SENSITIVE = [] include Aws::Structure end |
#ramdisk_id ⇒ Types::AttributeValue
The RAM disk ID.
50097 50098 50099 50100 50101 50102 50103 50104 50105 50106 50107 50108 50109 50110 50111 50112 50113 50114 50115 50116 50117 |
# File 'lib/aws-sdk-ec2/types.rb', line 50097 class InstanceAttribute < Struct.new( :block_device_mappings, :disable_api_termination, :ena_support, :enclave_options, :ebs_optimized, :instance_id, :instance_initiated_shutdown_behavior, :instance_type, :kernel_id, :product_codes, :ramdisk_id, :root_device_name, :source_dest_check, :sriov_net_support, :user_data, :disable_api_stop, :groups) SENSITIVE = [] include Aws::Structure end |
#root_device_name ⇒ Types::AttributeValue
The device name of the root device volume (for example, ‘/dev/sda1`).
50097 50098 50099 50100 50101 50102 50103 50104 50105 50106 50107 50108 50109 50110 50111 50112 50113 50114 50115 50116 50117 |
# File 'lib/aws-sdk-ec2/types.rb', line 50097 class InstanceAttribute < Struct.new( :block_device_mappings, :disable_api_termination, :ena_support, :enclave_options, :ebs_optimized, :instance_id, :instance_initiated_shutdown_behavior, :instance_type, :kernel_id, :product_codes, :ramdisk_id, :root_device_name, :source_dest_check, :sriov_net_support, :user_data, :disable_api_stop, :groups) SENSITIVE = [] include Aws::Structure end |
#source_dest_check ⇒ Types::AttributeBooleanValue
Indicates whether source/destination checks are enabled.
50097 50098 50099 50100 50101 50102 50103 50104 50105 50106 50107 50108 50109 50110 50111 50112 50113 50114 50115 50116 50117 |
# File 'lib/aws-sdk-ec2/types.rb', line 50097 class InstanceAttribute < Struct.new( :block_device_mappings, :disable_api_termination, :ena_support, :enclave_options, :ebs_optimized, :instance_id, :instance_initiated_shutdown_behavior, :instance_type, :kernel_id, :product_codes, :ramdisk_id, :root_device_name, :source_dest_check, :sriov_net_support, :user_data, :disable_api_stop, :groups) SENSITIVE = [] include Aws::Structure end |
#sriov_net_support ⇒ Types::AttributeValue
Indicates whether enhanced networking with the Intel 82599 Virtual Function interface is enabled.
50097 50098 50099 50100 50101 50102 50103 50104 50105 50106 50107 50108 50109 50110 50111 50112 50113 50114 50115 50116 50117 |
# File 'lib/aws-sdk-ec2/types.rb', line 50097 class InstanceAttribute < Struct.new( :block_device_mappings, :disable_api_termination, :ena_support, :enclave_options, :ebs_optimized, :instance_id, :instance_initiated_shutdown_behavior, :instance_type, :kernel_id, :product_codes, :ramdisk_id, :root_device_name, :source_dest_check, :sriov_net_support, :user_data, :disable_api_stop, :groups) SENSITIVE = [] include Aws::Structure end |
#user_data ⇒ Types::AttributeValue
The user data.
50097 50098 50099 50100 50101 50102 50103 50104 50105 50106 50107 50108 50109 50110 50111 50112 50113 50114 50115 50116 50117 |
# File 'lib/aws-sdk-ec2/types.rb', line 50097 class InstanceAttribute < Struct.new( :block_device_mappings, :disable_api_termination, :ena_support, :enclave_options, :ebs_optimized, :instance_id, :instance_initiated_shutdown_behavior, :instance_type, :kernel_id, :product_codes, :ramdisk_id, :root_device_name, :source_dest_check, :sriov_net_support, :user_data, :disable_api_stop, :groups) SENSITIVE = [] include Aws::Structure end |