Class: Aws::EC2::Types::InstanceEventWindowAssociationTarget
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::InstanceEventWindowAssociationTarget
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
One or more targets associated with the event window.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dedicated_host_ids ⇒ Array<String>
The IDs of the Dedicated Hosts associated with the event window.
-
#instance_ids ⇒ Array<String>
The IDs of the instances associated with the event window.
-
#tags ⇒ Array<Types::Tag>
The instance tags associated with the event window.
Instance Attribute Details
#dedicated_host_ids ⇒ Array<String>
The IDs of the Dedicated Hosts associated with the event window.
53142 53143 53144 53145 53146 53147 53148 |
# File 'lib/aws-sdk-ec2/types.rb', line 53142 class InstanceEventWindowAssociationTarget < Struct.new( :instance_ids, :tags, :dedicated_host_ids) SENSITIVE = [] include Aws::Structure end |
#instance_ids ⇒ Array<String>
The IDs of the instances associated with the event window.
53142 53143 53144 53145 53146 53147 53148 |
# File 'lib/aws-sdk-ec2/types.rb', line 53142 class InstanceEventWindowAssociationTarget < Struct.new( :instance_ids, :tags, :dedicated_host_ids) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The instance tags associated with the event window. Any instances associated with the tags will be associated with the event window.
Note that while you can't create tag keys beginning with aws:,
you can specify existing Amazon Web Services managed tag keys (with
the aws: prefix) when specifying them as targets to associate with
the event window.
53142 53143 53144 53145 53146 53147 53148 |
# File 'lib/aws-sdk-ec2/types.rb', line 53142 class InstanceEventWindowAssociationTarget < Struct.new( :instance_ids, :tags, :dedicated_host_ids) SENSITIVE = [] include Aws::Structure end |