Class: Aws::EC2::Types::InstanceEventWindowAssociationTarget

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

One or more targets associated with the event window.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dedicated_host_idsArray<String>

The IDs of the Dedicated Hosts associated with the event window.

Returns:

  • (Array<String>)


51423
51424
51425
51426
51427
51428
51429
# File 'lib/aws-sdk-ec2/types.rb', line 51423

class InstanceEventWindowAssociationTarget < Struct.new(
  :instance_ids,
  :tags,
  :dedicated_host_ids)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idsArray<String>

The IDs of the instances associated with the event window.

Returns:

  • (Array<String>)


51423
51424
51425
51426
51427
51428
51429
# File 'lib/aws-sdk-ec2/types.rb', line 51423

class InstanceEventWindowAssociationTarget < Struct.new(
  :instance_ids,
  :tags,
  :dedicated_host_ids)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The instance tags associated with the event window. Any instances associated with the tags will be associated with the event window.

Note that while you can't create tag keys beginning with aws:, you can specify existing Amazon Web Services managed tag keys (with the aws: prefix) when specifying them as targets to associate with the event window.

Returns:



51423
51424
51425
51426
51427
51428
51429
# File 'lib/aws-sdk-ec2/types.rb', line 51423

class InstanceEventWindowAssociationTarget < Struct.new(
  :instance_ids,
  :tags,
  :dedicated_host_ids)
  SENSITIVE = []
  include Aws::Structure
end