Class: Aws::EC2::Types::InstanceEventWindowDisassociationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

The targets to disassociate from the specified event window.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dedicated_host_idsArray<String>

The IDs of the Dedicated Hosts to disassociate from the event window.

Returns:

  • (Array<String>)


50835
50836
50837
50838
50839
50840
50841
# File 'lib/aws-sdk-ec2/types.rb', line 50835

class InstanceEventWindowDisassociationRequest < Struct.new(
  :instance_ids,
  :instance_tags,
  :dedicated_host_ids)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idsArray<String>

The IDs of the instances to disassociate from the event window.

Returns:

  • (Array<String>)


50835
50836
50837
50838
50839
50840
50841
# File 'lib/aws-sdk-ec2/types.rb', line 50835

class InstanceEventWindowDisassociationRequest < Struct.new(
  :instance_ids,
  :instance_tags,
  :dedicated_host_ids)
  SENSITIVE = []
  include Aws::Structure
end

#instance_tagsArray<Types::Tag>

The instance tags to disassociate from the event window. Any instances associated with the tags will be disassociated from the event window.

Returns:



50835
50836
50837
50838
50839
50840
50841
# File 'lib/aws-sdk-ec2/types.rb', line 50835

class InstanceEventWindowDisassociationRequest < Struct.new(
  :instance_ids,
  :instance_tags,
  :dedicated_host_ids)
  SENSITIVE = []
  include Aws::Structure
end