Class: Aws::EC2::Types::InstanceNetworkInterface
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::InstanceNetworkInterface
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a network interface.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#association ⇒ Types::InstanceNetworkInterfaceAssociation
The association information for an Elastic IPv4 associated with the network interface.
-
#attachment ⇒ Types::InstanceNetworkInterfaceAttachment
The network interface attachment.
-
#connection_tracking_configuration ⇒ Types::ConnectionTrackingSpecificationResponse
A security group connection tracking configuration that enables you to set the timeout for connection tracking on an Elastic network interface.
-
#description ⇒ String
The description.
-
#groups ⇒ Array<Types::GroupIdentifier>
The security groups.
-
#interface_type ⇒ String
The type of network interface.
-
#ipv_4_prefixes ⇒ Array<Types::InstanceIpv4Prefix>
The IPv4 delegated prefixes that are assigned to the network interface.
-
#ipv_6_addresses ⇒ Array<Types::InstanceIpv6Address>
The IPv6 addresses associated with the network interface.
-
#ipv_6_prefixes ⇒ Array<Types::InstanceIpv6Prefix>
The IPv6 delegated prefixes that are assigned to the network interface.
-
#mac_address ⇒ String
The MAC address.
-
#network_interface_id ⇒ String
The ID of the network interface.
-
#operator ⇒ Types::OperatorResponse
The service provider that manages the network interface.
-
#owner_id ⇒ String
The ID of the Amazon Web Services account that created the network interface.
-
#private_dns_name ⇒ String
The private DNS name.
-
#private_ip_address ⇒ String
The IPv4 address of the network interface within the subnet.
-
#private_ip_addresses ⇒ Array<Types::InstancePrivateIpAddress>
The private IPv4 addresses associated with the network interface.
-
#source_dest_check ⇒ Boolean
Indicates whether source/destination checking is enabled.
-
#status ⇒ String
The status of the network interface.
-
#subnet_id ⇒ String
The ID of the subnet.
-
#vpc_id ⇒ String
The ID of the VPC.
Instance Attribute Details
#association ⇒ Types::InstanceNetworkInterfaceAssociation
The association information for an Elastic IPv4 associated with the network interface.
52483 52484 52485 52486 52487 52488 52489 52490 52491 52492 52493 52494 52495 52496 52497 52498 52499 52500 52501 52502 52503 52504 52505 52506 |
# File 'lib/aws-sdk-ec2/types.rb', line 52483 class InstanceNetworkInterface < Struct.new( :association, :attachment, :description, :groups, :ipv_6_addresses, :mac_address, :network_interface_id, :owner_id, :private_dns_name, :private_ip_address, :private_ip_addresses, :source_dest_check, :status, :subnet_id, :vpc_id, :interface_type, :ipv_4_prefixes, :ipv_6_prefixes, :connection_tracking_configuration, :operator) SENSITIVE = [] include Aws::Structure end |
#attachment ⇒ Types::InstanceNetworkInterfaceAttachment
The network interface attachment.
52483 52484 52485 52486 52487 52488 52489 52490 52491 52492 52493 52494 52495 52496 52497 52498 52499 52500 52501 52502 52503 52504 52505 52506 |
# File 'lib/aws-sdk-ec2/types.rb', line 52483 class InstanceNetworkInterface < Struct.new( :association, :attachment, :description, :groups, :ipv_6_addresses, :mac_address, :network_interface_id, :owner_id, :private_dns_name, :private_ip_address, :private_ip_addresses, :source_dest_check, :status, :subnet_id, :vpc_id, :interface_type, :ipv_4_prefixes, :ipv_6_prefixes, :connection_tracking_configuration, :operator) SENSITIVE = [] include Aws::Structure end |
#connection_tracking_configuration ⇒ Types::ConnectionTrackingSpecificationResponse
A security group connection tracking configuration that enables you to set the timeout for connection tracking on an Elastic network interface. For more information, see Connection tracking timeouts in the Amazon EC2 User Guide.
52483 52484 52485 52486 52487 52488 52489 52490 52491 52492 52493 52494 52495 52496 52497 52498 52499 52500 52501 52502 52503 52504 52505 52506 |
# File 'lib/aws-sdk-ec2/types.rb', line 52483 class InstanceNetworkInterface < Struct.new( :association, :attachment, :description, :groups, :ipv_6_addresses, :mac_address, :network_interface_id, :owner_id, :private_dns_name, :private_ip_address, :private_ip_addresses, :source_dest_check, :status, :subnet_id, :vpc_id, :interface_type, :ipv_4_prefixes, :ipv_6_prefixes, :connection_tracking_configuration, :operator) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description.
52483 52484 52485 52486 52487 52488 52489 52490 52491 52492 52493 52494 52495 52496 52497 52498 52499 52500 52501 52502 52503 52504 52505 52506 |
# File 'lib/aws-sdk-ec2/types.rb', line 52483 class InstanceNetworkInterface < Struct.new( :association, :attachment, :description, :groups, :ipv_6_addresses, :mac_address, :network_interface_id, :owner_id, :private_dns_name, :private_ip_address, :private_ip_addresses, :source_dest_check, :status, :subnet_id, :vpc_id, :interface_type, :ipv_4_prefixes, :ipv_6_prefixes, :connection_tracking_configuration, :operator) SENSITIVE = [] include Aws::Structure end |
#groups ⇒ Array<Types::GroupIdentifier>
The security groups.
52483 52484 52485 52486 52487 52488 52489 52490 52491 52492 52493 52494 52495 52496 52497 52498 52499 52500 52501 52502 52503 52504 52505 52506 |
# File 'lib/aws-sdk-ec2/types.rb', line 52483 class InstanceNetworkInterface < Struct.new( :association, :attachment, :description, :groups, :ipv_6_addresses, :mac_address, :network_interface_id, :owner_id, :private_dns_name, :private_ip_address, :private_ip_addresses, :source_dest_check, :status, :subnet_id, :vpc_id, :interface_type, :ipv_4_prefixes, :ipv_6_prefixes, :connection_tracking_configuration, :operator) SENSITIVE = [] include Aws::Structure end |
#interface_type ⇒ String
The type of network interface.
Valid values: interface | efa | efa-only | evs | trunk
52483 52484 52485 52486 52487 52488 52489 52490 52491 52492 52493 52494 52495 52496 52497 52498 52499 52500 52501 52502 52503 52504 52505 52506 |
# File 'lib/aws-sdk-ec2/types.rb', line 52483 class InstanceNetworkInterface < Struct.new( :association, :attachment, :description, :groups, :ipv_6_addresses, :mac_address, :network_interface_id, :owner_id, :private_dns_name, :private_ip_address, :private_ip_addresses, :source_dest_check, :status, :subnet_id, :vpc_id, :interface_type, :ipv_4_prefixes, :ipv_6_prefixes, :connection_tracking_configuration, :operator) SENSITIVE = [] include Aws::Structure end |
#ipv_4_prefixes ⇒ Array<Types::InstanceIpv4Prefix>
The IPv4 delegated prefixes that are assigned to the network interface.
52483 52484 52485 52486 52487 52488 52489 52490 52491 52492 52493 52494 52495 52496 52497 52498 52499 52500 52501 52502 52503 52504 52505 52506 |
# File 'lib/aws-sdk-ec2/types.rb', line 52483 class InstanceNetworkInterface < Struct.new( :association, :attachment, :description, :groups, :ipv_6_addresses, :mac_address, :network_interface_id, :owner_id, :private_dns_name, :private_ip_address, :private_ip_addresses, :source_dest_check, :status, :subnet_id, :vpc_id, :interface_type, :ipv_4_prefixes, :ipv_6_prefixes, :connection_tracking_configuration, :operator) SENSITIVE = [] include Aws::Structure end |
#ipv_6_addresses ⇒ Array<Types::InstanceIpv6Address>
The IPv6 addresses associated with the network interface.
52483 52484 52485 52486 52487 52488 52489 52490 52491 52492 52493 52494 52495 52496 52497 52498 52499 52500 52501 52502 52503 52504 52505 52506 |
# File 'lib/aws-sdk-ec2/types.rb', line 52483 class InstanceNetworkInterface < Struct.new( :association, :attachment, :description, :groups, :ipv_6_addresses, :mac_address, :network_interface_id, :owner_id, :private_dns_name, :private_ip_address, :private_ip_addresses, :source_dest_check, :status, :subnet_id, :vpc_id, :interface_type, :ipv_4_prefixes, :ipv_6_prefixes, :connection_tracking_configuration, :operator) SENSITIVE = [] include Aws::Structure end |
#ipv_6_prefixes ⇒ Array<Types::InstanceIpv6Prefix>
The IPv6 delegated prefixes that are assigned to the network interface.
52483 52484 52485 52486 52487 52488 52489 52490 52491 52492 52493 52494 52495 52496 52497 52498 52499 52500 52501 52502 52503 52504 52505 52506 |
# File 'lib/aws-sdk-ec2/types.rb', line 52483 class InstanceNetworkInterface < Struct.new( :association, :attachment, :description, :groups, :ipv_6_addresses, :mac_address, :network_interface_id, :owner_id, :private_dns_name, :private_ip_address, :private_ip_addresses, :source_dest_check, :status, :subnet_id, :vpc_id, :interface_type, :ipv_4_prefixes, :ipv_6_prefixes, :connection_tracking_configuration, :operator) SENSITIVE = [] include Aws::Structure end |
#mac_address ⇒ String
The MAC address.
52483 52484 52485 52486 52487 52488 52489 52490 52491 52492 52493 52494 52495 52496 52497 52498 52499 52500 52501 52502 52503 52504 52505 52506 |
# File 'lib/aws-sdk-ec2/types.rb', line 52483 class InstanceNetworkInterface < Struct.new( :association, :attachment, :description, :groups, :ipv_6_addresses, :mac_address, :network_interface_id, :owner_id, :private_dns_name, :private_ip_address, :private_ip_addresses, :source_dest_check, :status, :subnet_id, :vpc_id, :interface_type, :ipv_4_prefixes, :ipv_6_prefixes, :connection_tracking_configuration, :operator) SENSITIVE = [] include Aws::Structure end |
#network_interface_id ⇒ String
The ID of the network interface.
52483 52484 52485 52486 52487 52488 52489 52490 52491 52492 52493 52494 52495 52496 52497 52498 52499 52500 52501 52502 52503 52504 52505 52506 |
# File 'lib/aws-sdk-ec2/types.rb', line 52483 class InstanceNetworkInterface < Struct.new( :association, :attachment, :description, :groups, :ipv_6_addresses, :mac_address, :network_interface_id, :owner_id, :private_dns_name, :private_ip_address, :private_ip_addresses, :source_dest_check, :status, :subnet_id, :vpc_id, :interface_type, :ipv_4_prefixes, :ipv_6_prefixes, :connection_tracking_configuration, :operator) SENSITIVE = [] include Aws::Structure end |
#operator ⇒ Types::OperatorResponse
The service provider that manages the network interface.
52483 52484 52485 52486 52487 52488 52489 52490 52491 52492 52493 52494 52495 52496 52497 52498 52499 52500 52501 52502 52503 52504 52505 52506 |
# File 'lib/aws-sdk-ec2/types.rb', line 52483 class InstanceNetworkInterface < Struct.new( :association, :attachment, :description, :groups, :ipv_6_addresses, :mac_address, :network_interface_id, :owner_id, :private_dns_name, :private_ip_address, :private_ip_addresses, :source_dest_check, :status, :subnet_id, :vpc_id, :interface_type, :ipv_4_prefixes, :ipv_6_prefixes, :connection_tracking_configuration, :operator) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
The ID of the Amazon Web Services account that created the network interface.
52483 52484 52485 52486 52487 52488 52489 52490 52491 52492 52493 52494 52495 52496 52497 52498 52499 52500 52501 52502 52503 52504 52505 52506 |
# File 'lib/aws-sdk-ec2/types.rb', line 52483 class InstanceNetworkInterface < Struct.new( :association, :attachment, :description, :groups, :ipv_6_addresses, :mac_address, :network_interface_id, :owner_id, :private_dns_name, :private_ip_address, :private_ip_addresses, :source_dest_check, :status, :subnet_id, :vpc_id, :interface_type, :ipv_4_prefixes, :ipv_6_prefixes, :connection_tracking_configuration, :operator) SENSITIVE = [] include Aws::Structure end |
#private_dns_name ⇒ String
The private DNS name.
52483 52484 52485 52486 52487 52488 52489 52490 52491 52492 52493 52494 52495 52496 52497 52498 52499 52500 52501 52502 52503 52504 52505 52506 |
# File 'lib/aws-sdk-ec2/types.rb', line 52483 class InstanceNetworkInterface < Struct.new( :association, :attachment, :description, :groups, :ipv_6_addresses, :mac_address, :network_interface_id, :owner_id, :private_dns_name, :private_ip_address, :private_ip_addresses, :source_dest_check, :status, :subnet_id, :vpc_id, :interface_type, :ipv_4_prefixes, :ipv_6_prefixes, :connection_tracking_configuration, :operator) SENSITIVE = [] include Aws::Structure end |
#private_ip_address ⇒ String
The IPv4 address of the network interface within the subnet.
52483 52484 52485 52486 52487 52488 52489 52490 52491 52492 52493 52494 52495 52496 52497 52498 52499 52500 52501 52502 52503 52504 52505 52506 |
# File 'lib/aws-sdk-ec2/types.rb', line 52483 class InstanceNetworkInterface < Struct.new( :association, :attachment, :description, :groups, :ipv_6_addresses, :mac_address, :network_interface_id, :owner_id, :private_dns_name, :private_ip_address, :private_ip_addresses, :source_dest_check, :status, :subnet_id, :vpc_id, :interface_type, :ipv_4_prefixes, :ipv_6_prefixes, :connection_tracking_configuration, :operator) SENSITIVE = [] include Aws::Structure end |
#private_ip_addresses ⇒ Array<Types::InstancePrivateIpAddress>
The private IPv4 addresses associated with the network interface.
52483 52484 52485 52486 52487 52488 52489 52490 52491 52492 52493 52494 52495 52496 52497 52498 52499 52500 52501 52502 52503 52504 52505 52506 |
# File 'lib/aws-sdk-ec2/types.rb', line 52483 class InstanceNetworkInterface < Struct.new( :association, :attachment, :description, :groups, :ipv_6_addresses, :mac_address, :network_interface_id, :owner_id, :private_dns_name, :private_ip_address, :private_ip_addresses, :source_dest_check, :status, :subnet_id, :vpc_id, :interface_type, :ipv_4_prefixes, :ipv_6_prefixes, :connection_tracking_configuration, :operator) SENSITIVE = [] include Aws::Structure end |
#source_dest_check ⇒ Boolean
Indicates whether source/destination checking is enabled.
52483 52484 52485 52486 52487 52488 52489 52490 52491 52492 52493 52494 52495 52496 52497 52498 52499 52500 52501 52502 52503 52504 52505 52506 |
# File 'lib/aws-sdk-ec2/types.rb', line 52483 class InstanceNetworkInterface < Struct.new( :association, :attachment, :description, :groups, :ipv_6_addresses, :mac_address, :network_interface_id, :owner_id, :private_dns_name, :private_ip_address, :private_ip_addresses, :source_dest_check, :status, :subnet_id, :vpc_id, :interface_type, :ipv_4_prefixes, :ipv_6_prefixes, :connection_tracking_configuration, :operator) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the network interface.
52483 52484 52485 52486 52487 52488 52489 52490 52491 52492 52493 52494 52495 52496 52497 52498 52499 52500 52501 52502 52503 52504 52505 52506 |
# File 'lib/aws-sdk-ec2/types.rb', line 52483 class InstanceNetworkInterface < Struct.new( :association, :attachment, :description, :groups, :ipv_6_addresses, :mac_address, :network_interface_id, :owner_id, :private_dns_name, :private_ip_address, :private_ip_addresses, :source_dest_check, :status, :subnet_id, :vpc_id, :interface_type, :ipv_4_prefixes, :ipv_6_prefixes, :connection_tracking_configuration, :operator) SENSITIVE = [] include Aws::Structure end |
#subnet_id ⇒ String
The ID of the subnet.
52483 52484 52485 52486 52487 52488 52489 52490 52491 52492 52493 52494 52495 52496 52497 52498 52499 52500 52501 52502 52503 52504 52505 52506 |
# File 'lib/aws-sdk-ec2/types.rb', line 52483 class InstanceNetworkInterface < Struct.new( :association, :attachment, :description, :groups, :ipv_6_addresses, :mac_address, :network_interface_id, :owner_id, :private_dns_name, :private_ip_address, :private_ip_addresses, :source_dest_check, :status, :subnet_id, :vpc_id, :interface_type, :ipv_4_prefixes, :ipv_6_prefixes, :connection_tracking_configuration, :operator) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC.
52483 52484 52485 52486 52487 52488 52489 52490 52491 52492 52493 52494 52495 52496 52497 52498 52499 52500 52501 52502 52503 52504 52505 52506 |
# File 'lib/aws-sdk-ec2/types.rb', line 52483 class InstanceNetworkInterface < Struct.new( :association, :attachment, :description, :groups, :ipv_6_addresses, :mac_address, :network_interface_id, :owner_id, :private_dns_name, :private_ip_address, :private_ip_addresses, :source_dest_check, :status, :subnet_id, :vpc_id, :interface_type, :ipv_4_prefixes, :ipv_6_prefixes, :connection_tracking_configuration, :operator) SENSITIVE = [] include Aws::Structure end |