Class: Aws::EC2::Types::InstanceNetworkInterface

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes a network interface.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#associationTypes::InstanceNetworkInterfaceAssociation

The association information for an Elastic IPv4 associated with the network interface.



50472
50473
50474
50475
50476
50477
50478
50479
50480
50481
50482
50483
50484
50485
50486
50487
50488
50489
50490
50491
50492
50493
50494
50495
# File 'lib/aws-sdk-ec2/types.rb', line 50472

class InstanceNetworkInterface < Struct.new(
  :association,
  :attachment,
  :description,
  :groups,
  :ipv_6_addresses,
  :mac_address,
  :network_interface_id,
  :owner_id,
  :private_dns_name,
  :private_ip_address,
  :private_ip_addresses,
  :source_dest_check,
  :status,
  :subnet_id,
  :vpc_id,
  :interface_type,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :connection_tracking_configuration,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end

#attachmentTypes::InstanceNetworkInterfaceAttachment

The network interface attachment.



50472
50473
50474
50475
50476
50477
50478
50479
50480
50481
50482
50483
50484
50485
50486
50487
50488
50489
50490
50491
50492
50493
50494
50495
# File 'lib/aws-sdk-ec2/types.rb', line 50472

class InstanceNetworkInterface < Struct.new(
  :association,
  :attachment,
  :description,
  :groups,
  :ipv_6_addresses,
  :mac_address,
  :network_interface_id,
  :owner_id,
  :private_dns_name,
  :private_ip_address,
  :private_ip_addresses,
  :source_dest_check,
  :status,
  :subnet_id,
  :vpc_id,
  :interface_type,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :connection_tracking_configuration,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end

#connection_tracking_configurationTypes::ConnectionTrackingSpecificationResponse

A security group connection tracking configuration that enables you to set the timeout for connection tracking on an Elastic network interface. For more information, see [Connection tracking timeouts] in the *Amazon EC2 User Guide*.

[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/security-group-connection-tracking.html#connection-tracking-timeouts



50472
50473
50474
50475
50476
50477
50478
50479
50480
50481
50482
50483
50484
50485
50486
50487
50488
50489
50490
50491
50492
50493
50494
50495
# File 'lib/aws-sdk-ec2/types.rb', line 50472

class InstanceNetworkInterface < Struct.new(
  :association,
  :attachment,
  :description,
  :groups,
  :ipv_6_addresses,
  :mac_address,
  :network_interface_id,
  :owner_id,
  :private_dns_name,
  :private_ip_address,
  :private_ip_addresses,
  :source_dest_check,
  :status,
  :subnet_id,
  :vpc_id,
  :interface_type,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :connection_tracking_configuration,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description.

Returns:

  • (String)


50472
50473
50474
50475
50476
50477
50478
50479
50480
50481
50482
50483
50484
50485
50486
50487
50488
50489
50490
50491
50492
50493
50494
50495
# File 'lib/aws-sdk-ec2/types.rb', line 50472

class InstanceNetworkInterface < Struct.new(
  :association,
  :attachment,
  :description,
  :groups,
  :ipv_6_addresses,
  :mac_address,
  :network_interface_id,
  :owner_id,
  :private_dns_name,
  :private_ip_address,
  :private_ip_addresses,
  :source_dest_check,
  :status,
  :subnet_id,
  :vpc_id,
  :interface_type,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :connection_tracking_configuration,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end

#groupsArray<Types::GroupIdentifier>

The security groups.

Returns:



50472
50473
50474
50475
50476
50477
50478
50479
50480
50481
50482
50483
50484
50485
50486
50487
50488
50489
50490
50491
50492
50493
50494
50495
# File 'lib/aws-sdk-ec2/types.rb', line 50472

class InstanceNetworkInterface < Struct.new(
  :association,
  :attachment,
  :description,
  :groups,
  :ipv_6_addresses,
  :mac_address,
  :network_interface_id,
  :owner_id,
  :private_dns_name,
  :private_ip_address,
  :private_ip_addresses,
  :source_dest_check,
  :status,
  :subnet_id,
  :vpc_id,
  :interface_type,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :connection_tracking_configuration,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end

#interface_typeString

The type of network interface.

Valid values: ‘interface` | `efa` | `efa-only` | `evs` | `trunk`

Returns:

  • (String)


50472
50473
50474
50475
50476
50477
50478
50479
50480
50481
50482
50483
50484
50485
50486
50487
50488
50489
50490
50491
50492
50493
50494
50495
# File 'lib/aws-sdk-ec2/types.rb', line 50472

class InstanceNetworkInterface < Struct.new(
  :association,
  :attachment,
  :description,
  :groups,
  :ipv_6_addresses,
  :mac_address,
  :network_interface_id,
  :owner_id,
  :private_dns_name,
  :private_ip_address,
  :private_ip_addresses,
  :source_dest_check,
  :status,
  :subnet_id,
  :vpc_id,
  :interface_type,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :connection_tracking_configuration,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end

#ipv_4_prefixesArray<Types::InstanceIpv4Prefix>

The IPv4 delegated prefixes that are assigned to the network interface.

Returns:



50472
50473
50474
50475
50476
50477
50478
50479
50480
50481
50482
50483
50484
50485
50486
50487
50488
50489
50490
50491
50492
50493
50494
50495
# File 'lib/aws-sdk-ec2/types.rb', line 50472

class InstanceNetworkInterface < Struct.new(
  :association,
  :attachment,
  :description,
  :groups,
  :ipv_6_addresses,
  :mac_address,
  :network_interface_id,
  :owner_id,
  :private_dns_name,
  :private_ip_address,
  :private_ip_addresses,
  :source_dest_check,
  :status,
  :subnet_id,
  :vpc_id,
  :interface_type,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :connection_tracking_configuration,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end

#ipv_6_addressesArray<Types::InstanceIpv6Address>

The IPv6 addresses associated with the network interface.

Returns:



50472
50473
50474
50475
50476
50477
50478
50479
50480
50481
50482
50483
50484
50485
50486
50487
50488
50489
50490
50491
50492
50493
50494
50495
# File 'lib/aws-sdk-ec2/types.rb', line 50472

class InstanceNetworkInterface < Struct.new(
  :association,
  :attachment,
  :description,
  :groups,
  :ipv_6_addresses,
  :mac_address,
  :network_interface_id,
  :owner_id,
  :private_dns_name,
  :private_ip_address,
  :private_ip_addresses,
  :source_dest_check,
  :status,
  :subnet_id,
  :vpc_id,
  :interface_type,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :connection_tracking_configuration,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end

#ipv_6_prefixesArray<Types::InstanceIpv6Prefix>

The IPv6 delegated prefixes that are assigned to the network interface.

Returns:



50472
50473
50474
50475
50476
50477
50478
50479
50480
50481
50482
50483
50484
50485
50486
50487
50488
50489
50490
50491
50492
50493
50494
50495
# File 'lib/aws-sdk-ec2/types.rb', line 50472

class InstanceNetworkInterface < Struct.new(
  :association,
  :attachment,
  :description,
  :groups,
  :ipv_6_addresses,
  :mac_address,
  :network_interface_id,
  :owner_id,
  :private_dns_name,
  :private_ip_address,
  :private_ip_addresses,
  :source_dest_check,
  :status,
  :subnet_id,
  :vpc_id,
  :interface_type,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :connection_tracking_configuration,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end

#mac_addressString

The MAC address.

Returns:

  • (String)


50472
50473
50474
50475
50476
50477
50478
50479
50480
50481
50482
50483
50484
50485
50486
50487
50488
50489
50490
50491
50492
50493
50494
50495
# File 'lib/aws-sdk-ec2/types.rb', line 50472

class InstanceNetworkInterface < Struct.new(
  :association,
  :attachment,
  :description,
  :groups,
  :ipv_6_addresses,
  :mac_address,
  :network_interface_id,
  :owner_id,
  :private_dns_name,
  :private_ip_address,
  :private_ip_addresses,
  :source_dest_check,
  :status,
  :subnet_id,
  :vpc_id,
  :interface_type,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :connection_tracking_configuration,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end

#network_interface_idString

The ID of the network interface.

Returns:

  • (String)


50472
50473
50474
50475
50476
50477
50478
50479
50480
50481
50482
50483
50484
50485
50486
50487
50488
50489
50490
50491
50492
50493
50494
50495
# File 'lib/aws-sdk-ec2/types.rb', line 50472

class InstanceNetworkInterface < Struct.new(
  :association,
  :attachment,
  :description,
  :groups,
  :ipv_6_addresses,
  :mac_address,
  :network_interface_id,
  :owner_id,
  :private_dns_name,
  :private_ip_address,
  :private_ip_addresses,
  :source_dest_check,
  :status,
  :subnet_id,
  :vpc_id,
  :interface_type,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :connection_tracking_configuration,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end

#operatorTypes::OperatorResponse

The service provider that manages the network interface.



50472
50473
50474
50475
50476
50477
50478
50479
50480
50481
50482
50483
50484
50485
50486
50487
50488
50489
50490
50491
50492
50493
50494
50495
# File 'lib/aws-sdk-ec2/types.rb', line 50472

class InstanceNetworkInterface < Struct.new(
  :association,
  :attachment,
  :description,
  :groups,
  :ipv_6_addresses,
  :mac_address,
  :network_interface_id,
  :owner_id,
  :private_dns_name,
  :private_ip_address,
  :private_ip_addresses,
  :source_dest_check,
  :status,
  :subnet_id,
  :vpc_id,
  :interface_type,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :connection_tracking_configuration,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end

#owner_idString

The ID of the Amazon Web Services account that created the network interface.

Returns:

  • (String)


50472
50473
50474
50475
50476
50477
50478
50479
50480
50481
50482
50483
50484
50485
50486
50487
50488
50489
50490
50491
50492
50493
50494
50495
# File 'lib/aws-sdk-ec2/types.rb', line 50472

class InstanceNetworkInterface < Struct.new(
  :association,
  :attachment,
  :description,
  :groups,
  :ipv_6_addresses,
  :mac_address,
  :network_interface_id,
  :owner_id,
  :private_dns_name,
  :private_ip_address,
  :private_ip_addresses,
  :source_dest_check,
  :status,
  :subnet_id,
  :vpc_id,
  :interface_type,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :connection_tracking_configuration,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end

#private_dns_nameString

The private DNS name.

Returns:

  • (String)


50472
50473
50474
50475
50476
50477
50478
50479
50480
50481
50482
50483
50484
50485
50486
50487
50488
50489
50490
50491
50492
50493
50494
50495
# File 'lib/aws-sdk-ec2/types.rb', line 50472

class InstanceNetworkInterface < Struct.new(
  :association,
  :attachment,
  :description,
  :groups,
  :ipv_6_addresses,
  :mac_address,
  :network_interface_id,
  :owner_id,
  :private_dns_name,
  :private_ip_address,
  :private_ip_addresses,
  :source_dest_check,
  :status,
  :subnet_id,
  :vpc_id,
  :interface_type,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :connection_tracking_configuration,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end

#private_ip_addressString

The IPv4 address of the network interface within the subnet.

Returns:

  • (String)


50472
50473
50474
50475
50476
50477
50478
50479
50480
50481
50482
50483
50484
50485
50486
50487
50488
50489
50490
50491
50492
50493
50494
50495
# File 'lib/aws-sdk-ec2/types.rb', line 50472

class InstanceNetworkInterface < Struct.new(
  :association,
  :attachment,
  :description,
  :groups,
  :ipv_6_addresses,
  :mac_address,
  :network_interface_id,
  :owner_id,
  :private_dns_name,
  :private_ip_address,
  :private_ip_addresses,
  :source_dest_check,
  :status,
  :subnet_id,
  :vpc_id,
  :interface_type,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :connection_tracking_configuration,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end

#private_ip_addressesArray<Types::InstancePrivateIpAddress>

The private IPv4 addresses associated with the network interface.



50472
50473
50474
50475
50476
50477
50478
50479
50480
50481
50482
50483
50484
50485
50486
50487
50488
50489
50490
50491
50492
50493
50494
50495
# File 'lib/aws-sdk-ec2/types.rb', line 50472

class InstanceNetworkInterface < Struct.new(
  :association,
  :attachment,
  :description,
  :groups,
  :ipv_6_addresses,
  :mac_address,
  :network_interface_id,
  :owner_id,
  :private_dns_name,
  :private_ip_address,
  :private_ip_addresses,
  :source_dest_check,
  :status,
  :subnet_id,
  :vpc_id,
  :interface_type,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :connection_tracking_configuration,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end

#source_dest_checkBoolean

Indicates whether source/destination checking is enabled.

Returns:

  • (Boolean)


50472
50473
50474
50475
50476
50477
50478
50479
50480
50481
50482
50483
50484
50485
50486
50487
50488
50489
50490
50491
50492
50493
50494
50495
# File 'lib/aws-sdk-ec2/types.rb', line 50472

class InstanceNetworkInterface < Struct.new(
  :association,
  :attachment,
  :description,
  :groups,
  :ipv_6_addresses,
  :mac_address,
  :network_interface_id,
  :owner_id,
  :private_dns_name,
  :private_ip_address,
  :private_ip_addresses,
  :source_dest_check,
  :status,
  :subnet_id,
  :vpc_id,
  :interface_type,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :connection_tracking_configuration,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the network interface.

Returns:

  • (String)


50472
50473
50474
50475
50476
50477
50478
50479
50480
50481
50482
50483
50484
50485
50486
50487
50488
50489
50490
50491
50492
50493
50494
50495
# File 'lib/aws-sdk-ec2/types.rb', line 50472

class InstanceNetworkInterface < Struct.new(
  :association,
  :attachment,
  :description,
  :groups,
  :ipv_6_addresses,
  :mac_address,
  :network_interface_id,
  :owner_id,
  :private_dns_name,
  :private_ip_address,
  :private_ip_addresses,
  :source_dest_check,
  :status,
  :subnet_id,
  :vpc_id,
  :interface_type,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :connection_tracking_configuration,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idString

The ID of the subnet.

Returns:

  • (String)


50472
50473
50474
50475
50476
50477
50478
50479
50480
50481
50482
50483
50484
50485
50486
50487
50488
50489
50490
50491
50492
50493
50494
50495
# File 'lib/aws-sdk-ec2/types.rb', line 50472

class InstanceNetworkInterface < Struct.new(
  :association,
  :attachment,
  :description,
  :groups,
  :ipv_6_addresses,
  :mac_address,
  :network_interface_id,
  :owner_id,
  :private_dns_name,
  :private_ip_address,
  :private_ip_addresses,
  :source_dest_check,
  :status,
  :subnet_id,
  :vpc_id,
  :interface_type,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :connection_tracking_configuration,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC.

Returns:

  • (String)


50472
50473
50474
50475
50476
50477
50478
50479
50480
50481
50482
50483
50484
50485
50486
50487
50488
50489
50490
50491
50492
50493
50494
50495
# File 'lib/aws-sdk-ec2/types.rb', line 50472

class InstanceNetworkInterface < Struct.new(
  :association,
  :attachment,
  :description,
  :groups,
  :ipv_6_addresses,
  :mac_address,
  :network_interface_id,
  :owner_id,
  :private_dns_name,
  :private_ip_address,
  :private_ip_addresses,
  :source_dest_check,
  :status,
  :subnet_id,
  :vpc_id,
  :interface_type,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :connection_tracking_configuration,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end