Class: Aws::EC2::Types::InstanceSecondaryInterfaceAttachment
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::InstanceSecondaryInterfaceAttachment
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the attachment of a secondary interface to an instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attach_time ⇒ Time
The timestamp when the attachment was created.
-
#attachment_id ⇒ String
The ID of the attachment.
-
#delete_on_termination ⇒ Boolean
Indicates whether the secondary interface is deleted when the instance is terminated.
-
#device_index ⇒ Integer
The device index of the secondary interface.
-
#network_card_index ⇒ Integer
The index of the network card.
-
#status ⇒ String
The attachment state.
Instance Attribute Details
#attach_time ⇒ Time
The timestamp when the attachment was created.
55416 55417 55418 55419 55420 55421 55422 55423 55424 55425 |
# File 'lib/aws-sdk-ec2/types.rb', line 55416 class InstanceSecondaryInterfaceAttachment < Struct.new( :attach_time, :attachment_id, :delete_on_termination, :device_index, :status, :network_card_index) SENSITIVE = [] include Aws::Structure end |
#attachment_id ⇒ String
The ID of the attachment.
55416 55417 55418 55419 55420 55421 55422 55423 55424 55425 |
# File 'lib/aws-sdk-ec2/types.rb', line 55416 class InstanceSecondaryInterfaceAttachment < Struct.new( :attach_time, :attachment_id, :delete_on_termination, :device_index, :status, :network_card_index) SENSITIVE = [] include Aws::Structure end |
#delete_on_termination ⇒ Boolean
Indicates whether the secondary interface is deleted when the instance is terminated.
The only supported value for this field is true.
55416 55417 55418 55419 55420 55421 55422 55423 55424 55425 |
# File 'lib/aws-sdk-ec2/types.rb', line 55416 class InstanceSecondaryInterfaceAttachment < Struct.new( :attach_time, :attachment_id, :delete_on_termination, :device_index, :status, :network_card_index) SENSITIVE = [] include Aws::Structure end |
#device_index ⇒ Integer
The device index of the secondary interface.
55416 55417 55418 55419 55420 55421 55422 55423 55424 55425 |
# File 'lib/aws-sdk-ec2/types.rb', line 55416 class InstanceSecondaryInterfaceAttachment < Struct.new( :attach_time, :attachment_id, :delete_on_termination, :device_index, :status, :network_card_index) SENSITIVE = [] include Aws::Structure end |
#network_card_index ⇒ Integer
The index of the network card.
55416 55417 55418 55419 55420 55421 55422 55423 55424 55425 |
# File 'lib/aws-sdk-ec2/types.rb', line 55416 class InstanceSecondaryInterfaceAttachment < Struct.new( :attach_time, :attachment_id, :delete_on_termination, :device_index, :status, :network_card_index) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The attachment state.
55416 55417 55418 55419 55420 55421 55422 55423 55424 55425 |
# File 'lib/aws-sdk-ec2/types.rb', line 55416 class InstanceSecondaryInterfaceAttachment < Struct.new( :attach_time, :attachment_id, :delete_on_termination, :device_index, :status, :network_card_index) SENSITIVE = [] include Aws::Structure end |