Class: Aws::EC2::Types::InstanceSecondaryInterfaceAttachment
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::InstanceSecondaryInterfaceAttachment
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the attachment of a secondary interface to an instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attach_time ⇒ Time
The timestamp when the attachment was created.
-
#attachment_id ⇒ String
The ID of the attachment.
-
#delete_on_termination ⇒ Boolean
Indicates whether the secondary interface is deleted when the instance is terminated.
-
#device_index ⇒ Integer
The device index of the secondary interface.
-
#network_card_index ⇒ Integer
The index of the network card.
-
#status ⇒ String
The attachment state.
Instance Attribute Details
#attach_time ⇒ Time
The timestamp when the attachment was created.
53188 53189 53190 53191 53192 53193 53194 53195 53196 53197 |
# File 'lib/aws-sdk-ec2/types.rb', line 53188 class InstanceSecondaryInterfaceAttachment < Struct.new( :attach_time, :attachment_id, :delete_on_termination, :device_index, :status, :network_card_index) SENSITIVE = [] include Aws::Structure end |
#attachment_id ⇒ String
The ID of the attachment.
53188 53189 53190 53191 53192 53193 53194 53195 53196 53197 |
# File 'lib/aws-sdk-ec2/types.rb', line 53188 class InstanceSecondaryInterfaceAttachment < Struct.new( :attach_time, :attachment_id, :delete_on_termination, :device_index, :status, :network_card_index) SENSITIVE = [] include Aws::Structure end |
#delete_on_termination ⇒ Boolean
Indicates whether the secondary interface is deleted when the instance is terminated.
The only supported value for this field is ‘true`.
53188 53189 53190 53191 53192 53193 53194 53195 53196 53197 |
# File 'lib/aws-sdk-ec2/types.rb', line 53188 class InstanceSecondaryInterfaceAttachment < Struct.new( :attach_time, :attachment_id, :delete_on_termination, :device_index, :status, :network_card_index) SENSITIVE = [] include Aws::Structure end |
#device_index ⇒ Integer
The device index of the secondary interface.
53188 53189 53190 53191 53192 53193 53194 53195 53196 53197 |
# File 'lib/aws-sdk-ec2/types.rb', line 53188 class InstanceSecondaryInterfaceAttachment < Struct.new( :attach_time, :attachment_id, :delete_on_termination, :device_index, :status, :network_card_index) SENSITIVE = [] include Aws::Structure end |
#network_card_index ⇒ Integer
The index of the network card.
53188 53189 53190 53191 53192 53193 53194 53195 53196 53197 |
# File 'lib/aws-sdk-ec2/types.rb', line 53188 class InstanceSecondaryInterfaceAttachment < Struct.new( :attach_time, :attachment_id, :delete_on_termination, :device_index, :status, :network_card_index) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The attachment state.
53188 53189 53190 53191 53192 53193 53194 53195 53196 53197 |
# File 'lib/aws-sdk-ec2/types.rb', line 53188 class InstanceSecondaryInterfaceAttachment < Struct.new( :attach_time, :attachment_id, :delete_on_termination, :device_index, :status, :network_card_index) SENSITIVE = [] include Aws::Structure end |