Class: Aws::EC2::Types::InstanceSecondaryInterfaceAttachment

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes the attachment of a secondary interface to an instance.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attach_timeTime

The timestamp when the attachment was created.

Returns:

  • (Time)


52685
52686
52687
52688
52689
52690
52691
52692
52693
52694
# File 'lib/aws-sdk-ec2/types.rb', line 52685

class InstanceSecondaryInterfaceAttachment < Struct.new(
  :attach_time,
  :attachment_id,
  :delete_on_termination,
  :device_index,
  :status,
  :network_card_index)
  SENSITIVE = []
  include Aws::Structure
end

#attachment_idString

The ID of the attachment.

Returns:

  • (String)


52685
52686
52687
52688
52689
52690
52691
52692
52693
52694
# File 'lib/aws-sdk-ec2/types.rb', line 52685

class InstanceSecondaryInterfaceAttachment < Struct.new(
  :attach_time,
  :attachment_id,
  :delete_on_termination,
  :device_index,
  :status,
  :network_card_index)
  SENSITIVE = []
  include Aws::Structure
end

#delete_on_terminationBoolean

Indicates whether the secondary interface is deleted when the instance is terminated.

The only supported value for this field is ‘true`.

Returns:

  • (Boolean)


52685
52686
52687
52688
52689
52690
52691
52692
52693
52694
# File 'lib/aws-sdk-ec2/types.rb', line 52685

class InstanceSecondaryInterfaceAttachment < Struct.new(
  :attach_time,
  :attachment_id,
  :delete_on_termination,
  :device_index,
  :status,
  :network_card_index)
  SENSITIVE = []
  include Aws::Structure
end

#device_indexInteger

The device index of the secondary interface.

Returns:

  • (Integer)


52685
52686
52687
52688
52689
52690
52691
52692
52693
52694
# File 'lib/aws-sdk-ec2/types.rb', line 52685

class InstanceSecondaryInterfaceAttachment < Struct.new(
  :attach_time,
  :attachment_id,
  :delete_on_termination,
  :device_index,
  :status,
  :network_card_index)
  SENSITIVE = []
  include Aws::Structure
end

#network_card_indexInteger

The index of the network card.

Returns:

  • (Integer)


52685
52686
52687
52688
52689
52690
52691
52692
52693
52694
# File 'lib/aws-sdk-ec2/types.rb', line 52685

class InstanceSecondaryInterfaceAttachment < Struct.new(
  :attach_time,
  :attachment_id,
  :delete_on_termination,
  :device_index,
  :status,
  :network_card_index)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The attachment state.

Returns:

  • (String)


52685
52686
52687
52688
52689
52690
52691
52692
52693
52694
# File 'lib/aws-sdk-ec2/types.rb', line 52685

class InstanceSecondaryInterfaceAttachment < Struct.new(
  :attach_time,
  :attachment_id,
  :delete_on_termination,
  :device_index,
  :status,
  :network_card_index)
  SENSITIVE = []
  include Aws::Structure
end