Class: Aws::EC2::Types::InstanceSecondaryInterfaceSpecificationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::InstanceSecondaryInterfaceSpecificationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a secondary interface specification for launching an instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#delete_on_termination ⇒ Boolean
Indicates whether the secondary interface is deleted when the instance is terminated.
-
#device_index ⇒ Integer
The device index for the secondary interface attachment.
-
#interface_type ⇒ String
The type of secondary interface.
-
#network_card_index ⇒ Integer
The index of the network card.
-
#private_ip_address_count ⇒ Integer
The number of private IPv4 addresses to assign to the secondary interface.
-
#private_ip_addresses ⇒ Array<Types::InstanceSecondaryInterfacePrivateIpAddressRequest>
The private IPv4 addresses to assign to the secondary interface.
-
#secondary_subnet_id ⇒ String
The ID of the secondary subnet.
Instance Attribute Details
#delete_on_termination ⇒ Boolean
Indicates whether the secondary interface is deleted when the instance is terminated.
The only supported value for this field is true.
56356 56357 56358 56359 56360 56361 56362 56363 56364 56365 56366 |
# File 'lib/aws-sdk-ec2/types.rb', line 56356 class InstanceSecondaryInterfaceSpecificationRequest < Struct.new( :delete_on_termination, :device_index, :private_ip_addresses, :private_ip_address_count, :secondary_subnet_id, :interface_type, :network_card_index) SENSITIVE = [] include Aws::Structure end |
#device_index ⇒ Integer
The device index for the secondary interface attachment.
56356 56357 56358 56359 56360 56361 56362 56363 56364 56365 56366 |
# File 'lib/aws-sdk-ec2/types.rb', line 56356 class InstanceSecondaryInterfaceSpecificationRequest < Struct.new( :delete_on_termination, :device_index, :private_ip_addresses, :private_ip_address_count, :secondary_subnet_id, :interface_type, :network_card_index) SENSITIVE = [] include Aws::Structure end |
#interface_type ⇒ String
The type of secondary interface.
56356 56357 56358 56359 56360 56361 56362 56363 56364 56365 56366 |
# File 'lib/aws-sdk-ec2/types.rb', line 56356 class InstanceSecondaryInterfaceSpecificationRequest < Struct.new( :delete_on_termination, :device_index, :private_ip_addresses, :private_ip_address_count, :secondary_subnet_id, :interface_type, :network_card_index) SENSITIVE = [] include Aws::Structure end |
#network_card_index ⇒ Integer
The index of the network card. The network card must support secondary interfaces.
56356 56357 56358 56359 56360 56361 56362 56363 56364 56365 56366 |
# File 'lib/aws-sdk-ec2/types.rb', line 56356 class InstanceSecondaryInterfaceSpecificationRequest < Struct.new( :delete_on_termination, :device_index, :private_ip_addresses, :private_ip_address_count, :secondary_subnet_id, :interface_type, :network_card_index) SENSITIVE = [] include Aws::Structure end |
#private_ip_address_count ⇒ Integer
The number of private IPv4 addresses to assign to the secondary interface.
56356 56357 56358 56359 56360 56361 56362 56363 56364 56365 56366 |
# File 'lib/aws-sdk-ec2/types.rb', line 56356 class InstanceSecondaryInterfaceSpecificationRequest < Struct.new( :delete_on_termination, :device_index, :private_ip_addresses, :private_ip_address_count, :secondary_subnet_id, :interface_type, :network_card_index) SENSITIVE = [] include Aws::Structure end |
#private_ip_addresses ⇒ Array<Types::InstanceSecondaryInterfacePrivateIpAddressRequest>
The private IPv4 addresses to assign to the secondary interface.
56356 56357 56358 56359 56360 56361 56362 56363 56364 56365 56366 |
# File 'lib/aws-sdk-ec2/types.rb', line 56356 class InstanceSecondaryInterfaceSpecificationRequest < Struct.new( :delete_on_termination, :device_index, :private_ip_addresses, :private_ip_address_count, :secondary_subnet_id, :interface_type, :network_card_index) SENSITIVE = [] include Aws::Structure end |
#secondary_subnet_id ⇒ String
The ID of the secondary subnet.
56356 56357 56358 56359 56360 56361 56362 56363 56364 56365 56366 |
# File 'lib/aws-sdk-ec2/types.rb', line 56356 class InstanceSecondaryInterfaceSpecificationRequest < Struct.new( :delete_on_termination, :device_index, :private_ip_addresses, :private_ip_address_count, :secondary_subnet_id, :interface_type, :network_card_index) SENSITIVE = [] include Aws::Structure end |