Class: Aws::EC2::Types::InstanceSpecification

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

The instance details to specify which volumes should be snapshotted.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#exclude_boot_volumeBoolean

Excludes the root volume from being snapshotted.

Returns:

  • (Boolean)


54179
54180
54181
54182
54183
54184
54185
# File 'lib/aws-sdk-ec2/types.rb', line 54179

class InstanceSpecification < Struct.new(
  :instance_id,
  :exclude_boot_volume,
  :exclude_data_volume_ids)
  SENSITIVE = []
  include Aws::Structure
end

#exclude_data_volume_idsArray<String>

The IDs of the data (non-root) volumes to exclude from the multi-volume snapshot set. If you specify the ID of the root volume, the request fails. To exclude the root volume, use ExcludeBootVolume.

You can specify up to 40 volume IDs per request.

Returns:

  • (Array<String>)


54179
54180
54181
54182
54183
54184
54185
# File 'lib/aws-sdk-ec2/types.rb', line 54179

class InstanceSpecification < Struct.new(
  :instance_id,
  :exclude_boot_volume,
  :exclude_data_volume_ids)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The instance to specify which volumes should be snapshotted.

Returns:

  • (String)


54179
54180
54181
54182
54183
54184
54185
# File 'lib/aws-sdk-ec2/types.rb', line 54179

class InstanceSpecification < Struct.new(
  :instance_id,
  :exclude_boot_volume,
  :exclude_data_volume_ids)
  SENSITIVE = []
  include Aws::Structure
end