Class: Aws::EC2::Types::InstanceSpecification
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::InstanceSpecification
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
The instance details to specify which volumes should be snapshotted.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#exclude_boot_volume ⇒ Boolean
Excludes the root volume from being snapshotted.
-
#exclude_data_volume_ids ⇒ Array<String>
The IDs of the data (non-root) volumes to exclude from the multi-volume snapshot set.
-
#instance_id ⇒ String
The instance to specify which volumes should be snapshotted.
Instance Attribute Details
#exclude_boot_volume ⇒ Boolean
Excludes the root volume from being snapshotted.
53192 53193 53194 53195 53196 53197 53198 |
# File 'lib/aws-sdk-ec2/types.rb', line 53192 class InstanceSpecification < Struct.new( :instance_id, :exclude_boot_volume, :exclude_data_volume_ids) SENSITIVE = [] include Aws::Structure end |
#exclude_data_volume_ids ⇒ Array<String>
The IDs of the data (non-root) volumes to exclude from the multi-volume snapshot set. If you specify the ID of the root volume, the request fails. To exclude the root volume, use ExcludeBootVolume.
You can specify up to 40 volume IDs per request.
53192 53193 53194 53195 53196 53197 53198 |
# File 'lib/aws-sdk-ec2/types.rb', line 53192 class InstanceSpecification < Struct.new( :instance_id, :exclude_boot_volume, :exclude_data_volume_ids) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The instance to specify which volumes should be snapshotted.
53192 53193 53194 53195 53196 53197 53198 |
# File 'lib/aws-sdk-ec2/types.rb', line 53192 class InstanceSpecification < Struct.new( :instance_id, :exclude_boot_volume, :exclude_data_volume_ids) SENSITIVE = [] include Aws::Structure end |