Class: Aws::EC2::Types::InstanceTopology
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::InstanceTopology
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Information about the instance topology.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone ⇒ String
The name of the Availability Zone or Local Zone that the instance is in.
-
#capacity_block_id ⇒ String
The ID of the Capacity Block.
-
#group_name ⇒ String
The name of the placement group that the instance is in.
-
#instance_id ⇒ String
The instance ID.
-
#instance_type ⇒ String
The instance type.
-
#network_nodes ⇒ Array<String>
The network nodes.
-
#zone_id ⇒ String
The ID of the Availability Zone or Local Zone that the instance is in.
Instance Attribute Details
#availability_zone ⇒ String
The name of the Availability Zone or Local Zone that the instance is in.
52312 52313 52314 52315 52316 52317 52318 52319 52320 52321 52322 |
# File 'lib/aws-sdk-ec2/types.rb', line 52312 class InstanceTopology < Struct.new( :instance_id, :instance_type, :group_name, :network_nodes, :availability_zone, :zone_id, :capacity_block_id) SENSITIVE = [] include Aws::Structure end |
#capacity_block_id ⇒ String
The ID of the Capacity Block. This parameter is only supported for UltraServer instances and identifies instances within the UltraServer domain.
52312 52313 52314 52315 52316 52317 52318 52319 52320 52321 52322 |
# File 'lib/aws-sdk-ec2/types.rb', line 52312 class InstanceTopology < Struct.new( :instance_id, :instance_type, :group_name, :network_nodes, :availability_zone, :zone_id, :capacity_block_id) SENSITIVE = [] include Aws::Structure end |
#group_name ⇒ String
The name of the placement group that the instance is in.
52312 52313 52314 52315 52316 52317 52318 52319 52320 52321 52322 |
# File 'lib/aws-sdk-ec2/types.rb', line 52312 class InstanceTopology < Struct.new( :instance_id, :instance_type, :group_name, :network_nodes, :availability_zone, :zone_id, :capacity_block_id) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The instance ID.
52312 52313 52314 52315 52316 52317 52318 52319 52320 52321 52322 |
# File 'lib/aws-sdk-ec2/types.rb', line 52312 class InstanceTopology < Struct.new( :instance_id, :instance_type, :group_name, :network_nodes, :availability_zone, :zone_id, :capacity_block_id) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The instance type.
52312 52313 52314 52315 52316 52317 52318 52319 52320 52321 52322 |
# File 'lib/aws-sdk-ec2/types.rb', line 52312 class InstanceTopology < Struct.new( :instance_id, :instance_type, :group_name, :network_nodes, :availability_zone, :zone_id, :capacity_block_id) SENSITIVE = [] include Aws::Structure end |
#network_nodes ⇒ Array<String>
The network nodes. The nodes are hashed based on your account. Instances from different accounts running under the same server will return a different hashed list of strings.
The value is ‘null` or empty if:
-
The instance type is not supported.
-
The instance is in a state other than ‘running`.
52312 52313 52314 52315 52316 52317 52318 52319 52320 52321 52322 |
# File 'lib/aws-sdk-ec2/types.rb', line 52312 class InstanceTopology < Struct.new( :instance_id, :instance_type, :group_name, :network_nodes, :availability_zone, :zone_id, :capacity_block_id) SENSITIVE = [] include Aws::Structure end |
#zone_id ⇒ String
The ID of the Availability Zone or Local Zone that the instance is in.
52312 52313 52314 52315 52316 52317 52318 52319 52320 52321 52322 |
# File 'lib/aws-sdk-ec2/types.rb', line 52312 class InstanceTopology < Struct.new( :instance_id, :instance_type, :group_name, :network_nodes, :availability_zone, :zone_id, :capacity_block_id) SENSITIVE = [] include Aws::Structure end |