Class: Aws::EC2::Types::InstanceTypeInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::InstanceTypeInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the instance type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_recovery_supported ⇒ Boolean
Indicates whether Amazon CloudWatch action based recovery is supported.
-
#bare_metal ⇒ Boolean
Indicates whether the instance is a bare metal instance type.
-
#burstable_performance_supported ⇒ Boolean
Indicates whether the instance type is a burstable performance T instance type.
-
#current_generation ⇒ Boolean
Indicates whether the instance type is current generation.
-
#dedicated_hosts_supported ⇒ Boolean
Indicates whether Dedicated Hosts are supported on the instance type.
-
#ebs_info ⇒ Types::EbsInfo
Describes the Amazon EBS settings for the instance type.
-
#fpga_info ⇒ Types::FpgaInfo
Describes the FPGA accelerator settings for the instance type.
-
#free_tier_eligible ⇒ Boolean
Indicates whether the instance type is eligible for the free tier.
-
#gpu_info ⇒ Types::GpuInfo
Describes the GPU accelerator settings for the instance type.
-
#hibernation_supported ⇒ Boolean
Indicates whether On-Demand hibernation is supported.
-
#hypervisor ⇒ String
The hypervisor for the instance type.
-
#inference_accelerator_info ⇒ Types::InferenceAcceleratorInfo
Describes the Inference accelerator settings for the instance type.
-
#instance_storage_info ⇒ Types::InstanceStorageInfo
Describes the instance storage for the instance type.
-
#instance_storage_supported ⇒ Boolean
Indicates whether instance storage is supported.
-
#instance_type ⇒ String
The instance type.
-
#media_accelerator_info ⇒ Types::MediaAcceleratorInfo
Describes the media accelerator settings for the instance type.
-
#memory_info ⇒ Types::MemoryInfo
Describes the memory for the instance type.
-
#network_info ⇒ Types::NetworkInfo
Describes the network settings for the instance type.
-
#neuron_info ⇒ Types::NeuronInfo
Describes the Neuron accelerator settings for the instance type.
-
#nitro_enclaves_support ⇒ String
Indicates whether Nitro Enclaves is supported.
-
#nitro_tpm_info ⇒ Types::NitroTpmInfo
Describes the supported NitroTPM versions for the instance type.
-
#nitro_tpm_support ⇒ String
Indicates whether NitroTPM is supported.
-
#phc_support ⇒ String
Indicates whether a local Precision Time Protocol (PTP) hardware clock (PHC) is supported.
-
#placement_group_info ⇒ Types::PlacementGroupInfo
Describes the placement group settings for the instance type.
-
#processor_info ⇒ Types::ProcessorInfo
Describes the processor.
-
#reboot_migration_support ⇒ String
Indicates whether reboot migration during a user-initiated reboot is supported for instances that have a scheduled ‘system-reboot` event.
-
#supported_boot_modes ⇒ Array<String>
The supported boot modes.
-
#supported_in_region ⇒ Boolean
Indicates whether the instance type is supported in the current Region.
-
#supported_root_device_types ⇒ Array<String>
The supported root device types.
-
#supported_usage_classes ⇒ Array<String>
Indicates whether the instance type is offered for spot, On-Demand, or Capacity Blocks.
-
#supported_virtualization_types ⇒ Array<String>
The supported virtualization types.
-
#v_cpu_info ⇒ Types::VCpuInfo
Describes the vCPU configurations for the instance type.
Instance Attribute Details
#auto_recovery_supported ⇒ Boolean
Indicates whether Amazon CloudWatch action based recovery is supported.
54297 54298 54299 54300 54301 54302 54303 54304 54305 54306 54307 54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 54321 54322 54323 54324 54325 54326 54327 54328 54329 54330 54331 54332 |
# File 'lib/aws-sdk-ec2/types.rb', line 54297 class InstanceTypeInfo < Struct.new( :instance_type, :current_generation, :free_tier_eligible, :supported_usage_classes, :supported_root_device_types, :supported_virtualization_types, :bare_metal, :hypervisor, :processor_info, :v_cpu_info, :memory_info, :instance_storage_supported, :instance_storage_info, :ebs_info, :network_info, :gpu_info, :fpga_info, :placement_group_info, :inference_accelerator_info, :hibernation_supported, :burstable_performance_supported, :dedicated_hosts_supported, :auto_recovery_supported, :supported_boot_modes, :nitro_enclaves_support, :nitro_tpm_support, :nitro_tpm_info, :media_accelerator_info, :neuron_info, :phc_support, :reboot_migration_support, :supported_in_region) SENSITIVE = [] include Aws::Structure end |
#bare_metal ⇒ Boolean
Indicates whether the instance is a bare metal instance type.
54297 54298 54299 54300 54301 54302 54303 54304 54305 54306 54307 54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 54321 54322 54323 54324 54325 54326 54327 54328 54329 54330 54331 54332 |
# File 'lib/aws-sdk-ec2/types.rb', line 54297 class InstanceTypeInfo < Struct.new( :instance_type, :current_generation, :free_tier_eligible, :supported_usage_classes, :supported_root_device_types, :supported_virtualization_types, :bare_metal, :hypervisor, :processor_info, :v_cpu_info, :memory_info, :instance_storage_supported, :instance_storage_info, :ebs_info, :network_info, :gpu_info, :fpga_info, :placement_group_info, :inference_accelerator_info, :hibernation_supported, :burstable_performance_supported, :dedicated_hosts_supported, :auto_recovery_supported, :supported_boot_modes, :nitro_enclaves_support, :nitro_tpm_support, :nitro_tpm_info, :media_accelerator_info, :neuron_info, :phc_support, :reboot_migration_support, :supported_in_region) SENSITIVE = [] include Aws::Structure end |
#burstable_performance_supported ⇒ Boolean
Indicates whether the instance type is a burstable performance T instance type. For more information, see [Burstable performance instances].
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/burstable-performance-instances.html
54297 54298 54299 54300 54301 54302 54303 54304 54305 54306 54307 54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 54321 54322 54323 54324 54325 54326 54327 54328 54329 54330 54331 54332 |
# File 'lib/aws-sdk-ec2/types.rb', line 54297 class InstanceTypeInfo < Struct.new( :instance_type, :current_generation, :free_tier_eligible, :supported_usage_classes, :supported_root_device_types, :supported_virtualization_types, :bare_metal, :hypervisor, :processor_info, :v_cpu_info, :memory_info, :instance_storage_supported, :instance_storage_info, :ebs_info, :network_info, :gpu_info, :fpga_info, :placement_group_info, :inference_accelerator_info, :hibernation_supported, :burstable_performance_supported, :dedicated_hosts_supported, :auto_recovery_supported, :supported_boot_modes, :nitro_enclaves_support, :nitro_tpm_support, :nitro_tpm_info, :media_accelerator_info, :neuron_info, :phc_support, :reboot_migration_support, :supported_in_region) SENSITIVE = [] include Aws::Structure end |
#current_generation ⇒ Boolean
Indicates whether the instance type is current generation.
54297 54298 54299 54300 54301 54302 54303 54304 54305 54306 54307 54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 54321 54322 54323 54324 54325 54326 54327 54328 54329 54330 54331 54332 |
# File 'lib/aws-sdk-ec2/types.rb', line 54297 class InstanceTypeInfo < Struct.new( :instance_type, :current_generation, :free_tier_eligible, :supported_usage_classes, :supported_root_device_types, :supported_virtualization_types, :bare_metal, :hypervisor, :processor_info, :v_cpu_info, :memory_info, :instance_storage_supported, :instance_storage_info, :ebs_info, :network_info, :gpu_info, :fpga_info, :placement_group_info, :inference_accelerator_info, :hibernation_supported, :burstable_performance_supported, :dedicated_hosts_supported, :auto_recovery_supported, :supported_boot_modes, :nitro_enclaves_support, :nitro_tpm_support, :nitro_tpm_info, :media_accelerator_info, :neuron_info, :phc_support, :reboot_migration_support, :supported_in_region) SENSITIVE = [] include Aws::Structure end |
#dedicated_hosts_supported ⇒ Boolean
Indicates whether Dedicated Hosts are supported on the instance type.
54297 54298 54299 54300 54301 54302 54303 54304 54305 54306 54307 54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 54321 54322 54323 54324 54325 54326 54327 54328 54329 54330 54331 54332 |
# File 'lib/aws-sdk-ec2/types.rb', line 54297 class InstanceTypeInfo < Struct.new( :instance_type, :current_generation, :free_tier_eligible, :supported_usage_classes, :supported_root_device_types, :supported_virtualization_types, :bare_metal, :hypervisor, :processor_info, :v_cpu_info, :memory_info, :instance_storage_supported, :instance_storage_info, :ebs_info, :network_info, :gpu_info, :fpga_info, :placement_group_info, :inference_accelerator_info, :hibernation_supported, :burstable_performance_supported, :dedicated_hosts_supported, :auto_recovery_supported, :supported_boot_modes, :nitro_enclaves_support, :nitro_tpm_support, :nitro_tpm_info, :media_accelerator_info, :neuron_info, :phc_support, :reboot_migration_support, :supported_in_region) SENSITIVE = [] include Aws::Structure end |
#ebs_info ⇒ Types::EbsInfo
Describes the Amazon EBS settings for the instance type.
54297 54298 54299 54300 54301 54302 54303 54304 54305 54306 54307 54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 54321 54322 54323 54324 54325 54326 54327 54328 54329 54330 54331 54332 |
# File 'lib/aws-sdk-ec2/types.rb', line 54297 class InstanceTypeInfo < Struct.new( :instance_type, :current_generation, :free_tier_eligible, :supported_usage_classes, :supported_root_device_types, :supported_virtualization_types, :bare_metal, :hypervisor, :processor_info, :v_cpu_info, :memory_info, :instance_storage_supported, :instance_storage_info, :ebs_info, :network_info, :gpu_info, :fpga_info, :placement_group_info, :inference_accelerator_info, :hibernation_supported, :burstable_performance_supported, :dedicated_hosts_supported, :auto_recovery_supported, :supported_boot_modes, :nitro_enclaves_support, :nitro_tpm_support, :nitro_tpm_info, :media_accelerator_info, :neuron_info, :phc_support, :reboot_migration_support, :supported_in_region) SENSITIVE = [] include Aws::Structure end |
#fpga_info ⇒ Types::FpgaInfo
Describes the FPGA accelerator settings for the instance type.
54297 54298 54299 54300 54301 54302 54303 54304 54305 54306 54307 54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 54321 54322 54323 54324 54325 54326 54327 54328 54329 54330 54331 54332 |
# File 'lib/aws-sdk-ec2/types.rb', line 54297 class InstanceTypeInfo < Struct.new( :instance_type, :current_generation, :free_tier_eligible, :supported_usage_classes, :supported_root_device_types, :supported_virtualization_types, :bare_metal, :hypervisor, :processor_info, :v_cpu_info, :memory_info, :instance_storage_supported, :instance_storage_info, :ebs_info, :network_info, :gpu_info, :fpga_info, :placement_group_info, :inference_accelerator_info, :hibernation_supported, :burstable_performance_supported, :dedicated_hosts_supported, :auto_recovery_supported, :supported_boot_modes, :nitro_enclaves_support, :nitro_tpm_support, :nitro_tpm_info, :media_accelerator_info, :neuron_info, :phc_support, :reboot_migration_support, :supported_in_region) SENSITIVE = [] include Aws::Structure end |
#free_tier_eligible ⇒ Boolean
Indicates whether the instance type is eligible for the free tier.
54297 54298 54299 54300 54301 54302 54303 54304 54305 54306 54307 54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 54321 54322 54323 54324 54325 54326 54327 54328 54329 54330 54331 54332 |
# File 'lib/aws-sdk-ec2/types.rb', line 54297 class InstanceTypeInfo < Struct.new( :instance_type, :current_generation, :free_tier_eligible, :supported_usage_classes, :supported_root_device_types, :supported_virtualization_types, :bare_metal, :hypervisor, :processor_info, :v_cpu_info, :memory_info, :instance_storage_supported, :instance_storage_info, :ebs_info, :network_info, :gpu_info, :fpga_info, :placement_group_info, :inference_accelerator_info, :hibernation_supported, :burstable_performance_supported, :dedicated_hosts_supported, :auto_recovery_supported, :supported_boot_modes, :nitro_enclaves_support, :nitro_tpm_support, :nitro_tpm_info, :media_accelerator_info, :neuron_info, :phc_support, :reboot_migration_support, :supported_in_region) SENSITIVE = [] include Aws::Structure end |
#gpu_info ⇒ Types::GpuInfo
Describes the GPU accelerator settings for the instance type.
54297 54298 54299 54300 54301 54302 54303 54304 54305 54306 54307 54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 54321 54322 54323 54324 54325 54326 54327 54328 54329 54330 54331 54332 |
# File 'lib/aws-sdk-ec2/types.rb', line 54297 class InstanceTypeInfo < Struct.new( :instance_type, :current_generation, :free_tier_eligible, :supported_usage_classes, :supported_root_device_types, :supported_virtualization_types, :bare_metal, :hypervisor, :processor_info, :v_cpu_info, :memory_info, :instance_storage_supported, :instance_storage_info, :ebs_info, :network_info, :gpu_info, :fpga_info, :placement_group_info, :inference_accelerator_info, :hibernation_supported, :burstable_performance_supported, :dedicated_hosts_supported, :auto_recovery_supported, :supported_boot_modes, :nitro_enclaves_support, :nitro_tpm_support, :nitro_tpm_info, :media_accelerator_info, :neuron_info, :phc_support, :reboot_migration_support, :supported_in_region) SENSITIVE = [] include Aws::Structure end |
#hibernation_supported ⇒ Boolean
Indicates whether On-Demand hibernation is supported.
54297 54298 54299 54300 54301 54302 54303 54304 54305 54306 54307 54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 54321 54322 54323 54324 54325 54326 54327 54328 54329 54330 54331 54332 |
# File 'lib/aws-sdk-ec2/types.rb', line 54297 class InstanceTypeInfo < Struct.new( :instance_type, :current_generation, :free_tier_eligible, :supported_usage_classes, :supported_root_device_types, :supported_virtualization_types, :bare_metal, :hypervisor, :processor_info, :v_cpu_info, :memory_info, :instance_storage_supported, :instance_storage_info, :ebs_info, :network_info, :gpu_info, :fpga_info, :placement_group_info, :inference_accelerator_info, :hibernation_supported, :burstable_performance_supported, :dedicated_hosts_supported, :auto_recovery_supported, :supported_boot_modes, :nitro_enclaves_support, :nitro_tpm_support, :nitro_tpm_info, :media_accelerator_info, :neuron_info, :phc_support, :reboot_migration_support, :supported_in_region) SENSITIVE = [] include Aws::Structure end |
#hypervisor ⇒ String
The hypervisor for the instance type.
54297 54298 54299 54300 54301 54302 54303 54304 54305 54306 54307 54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 54321 54322 54323 54324 54325 54326 54327 54328 54329 54330 54331 54332 |
# File 'lib/aws-sdk-ec2/types.rb', line 54297 class InstanceTypeInfo < Struct.new( :instance_type, :current_generation, :free_tier_eligible, :supported_usage_classes, :supported_root_device_types, :supported_virtualization_types, :bare_metal, :hypervisor, :processor_info, :v_cpu_info, :memory_info, :instance_storage_supported, :instance_storage_info, :ebs_info, :network_info, :gpu_info, :fpga_info, :placement_group_info, :inference_accelerator_info, :hibernation_supported, :burstable_performance_supported, :dedicated_hosts_supported, :auto_recovery_supported, :supported_boot_modes, :nitro_enclaves_support, :nitro_tpm_support, :nitro_tpm_info, :media_accelerator_info, :neuron_info, :phc_support, :reboot_migration_support, :supported_in_region) SENSITIVE = [] include Aws::Structure end |
#inference_accelerator_info ⇒ Types::InferenceAcceleratorInfo
Describes the Inference accelerator settings for the instance type.
54297 54298 54299 54300 54301 54302 54303 54304 54305 54306 54307 54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 54321 54322 54323 54324 54325 54326 54327 54328 54329 54330 54331 54332 |
# File 'lib/aws-sdk-ec2/types.rb', line 54297 class InstanceTypeInfo < Struct.new( :instance_type, :current_generation, :free_tier_eligible, :supported_usage_classes, :supported_root_device_types, :supported_virtualization_types, :bare_metal, :hypervisor, :processor_info, :v_cpu_info, :memory_info, :instance_storage_supported, :instance_storage_info, :ebs_info, :network_info, :gpu_info, :fpga_info, :placement_group_info, :inference_accelerator_info, :hibernation_supported, :burstable_performance_supported, :dedicated_hosts_supported, :auto_recovery_supported, :supported_boot_modes, :nitro_enclaves_support, :nitro_tpm_support, :nitro_tpm_info, :media_accelerator_info, :neuron_info, :phc_support, :reboot_migration_support, :supported_in_region) SENSITIVE = [] include Aws::Structure end |
#instance_storage_info ⇒ Types::InstanceStorageInfo
Describes the instance storage for the instance type.
54297 54298 54299 54300 54301 54302 54303 54304 54305 54306 54307 54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 54321 54322 54323 54324 54325 54326 54327 54328 54329 54330 54331 54332 |
# File 'lib/aws-sdk-ec2/types.rb', line 54297 class InstanceTypeInfo < Struct.new( :instance_type, :current_generation, :free_tier_eligible, :supported_usage_classes, :supported_root_device_types, :supported_virtualization_types, :bare_metal, :hypervisor, :processor_info, :v_cpu_info, :memory_info, :instance_storage_supported, :instance_storage_info, :ebs_info, :network_info, :gpu_info, :fpga_info, :placement_group_info, :inference_accelerator_info, :hibernation_supported, :burstable_performance_supported, :dedicated_hosts_supported, :auto_recovery_supported, :supported_boot_modes, :nitro_enclaves_support, :nitro_tpm_support, :nitro_tpm_info, :media_accelerator_info, :neuron_info, :phc_support, :reboot_migration_support, :supported_in_region) SENSITIVE = [] include Aws::Structure end |
#instance_storage_supported ⇒ Boolean
Indicates whether instance storage is supported.
54297 54298 54299 54300 54301 54302 54303 54304 54305 54306 54307 54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 54321 54322 54323 54324 54325 54326 54327 54328 54329 54330 54331 54332 |
# File 'lib/aws-sdk-ec2/types.rb', line 54297 class InstanceTypeInfo < Struct.new( :instance_type, :current_generation, :free_tier_eligible, :supported_usage_classes, :supported_root_device_types, :supported_virtualization_types, :bare_metal, :hypervisor, :processor_info, :v_cpu_info, :memory_info, :instance_storage_supported, :instance_storage_info, :ebs_info, :network_info, :gpu_info, :fpga_info, :placement_group_info, :inference_accelerator_info, :hibernation_supported, :burstable_performance_supported, :dedicated_hosts_supported, :auto_recovery_supported, :supported_boot_modes, :nitro_enclaves_support, :nitro_tpm_support, :nitro_tpm_info, :media_accelerator_info, :neuron_info, :phc_support, :reboot_migration_support, :supported_in_region) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The instance type. For more information, see [Instance types] in the *Amazon EC2 User Guide*.
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html
54297 54298 54299 54300 54301 54302 54303 54304 54305 54306 54307 54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 54321 54322 54323 54324 54325 54326 54327 54328 54329 54330 54331 54332 |
# File 'lib/aws-sdk-ec2/types.rb', line 54297 class InstanceTypeInfo < Struct.new( :instance_type, :current_generation, :free_tier_eligible, :supported_usage_classes, :supported_root_device_types, :supported_virtualization_types, :bare_metal, :hypervisor, :processor_info, :v_cpu_info, :memory_info, :instance_storage_supported, :instance_storage_info, :ebs_info, :network_info, :gpu_info, :fpga_info, :placement_group_info, :inference_accelerator_info, :hibernation_supported, :burstable_performance_supported, :dedicated_hosts_supported, :auto_recovery_supported, :supported_boot_modes, :nitro_enclaves_support, :nitro_tpm_support, :nitro_tpm_info, :media_accelerator_info, :neuron_info, :phc_support, :reboot_migration_support, :supported_in_region) SENSITIVE = [] include Aws::Structure end |
#media_accelerator_info ⇒ Types::MediaAcceleratorInfo
Describes the media accelerator settings for the instance type.
54297 54298 54299 54300 54301 54302 54303 54304 54305 54306 54307 54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 54321 54322 54323 54324 54325 54326 54327 54328 54329 54330 54331 54332 |
# File 'lib/aws-sdk-ec2/types.rb', line 54297 class InstanceTypeInfo < Struct.new( :instance_type, :current_generation, :free_tier_eligible, :supported_usage_classes, :supported_root_device_types, :supported_virtualization_types, :bare_metal, :hypervisor, :processor_info, :v_cpu_info, :memory_info, :instance_storage_supported, :instance_storage_info, :ebs_info, :network_info, :gpu_info, :fpga_info, :placement_group_info, :inference_accelerator_info, :hibernation_supported, :burstable_performance_supported, :dedicated_hosts_supported, :auto_recovery_supported, :supported_boot_modes, :nitro_enclaves_support, :nitro_tpm_support, :nitro_tpm_info, :media_accelerator_info, :neuron_info, :phc_support, :reboot_migration_support, :supported_in_region) SENSITIVE = [] include Aws::Structure end |
#memory_info ⇒ Types::MemoryInfo
Describes the memory for the instance type.
54297 54298 54299 54300 54301 54302 54303 54304 54305 54306 54307 54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 54321 54322 54323 54324 54325 54326 54327 54328 54329 54330 54331 54332 |
# File 'lib/aws-sdk-ec2/types.rb', line 54297 class InstanceTypeInfo < Struct.new( :instance_type, :current_generation, :free_tier_eligible, :supported_usage_classes, :supported_root_device_types, :supported_virtualization_types, :bare_metal, :hypervisor, :processor_info, :v_cpu_info, :memory_info, :instance_storage_supported, :instance_storage_info, :ebs_info, :network_info, :gpu_info, :fpga_info, :placement_group_info, :inference_accelerator_info, :hibernation_supported, :burstable_performance_supported, :dedicated_hosts_supported, :auto_recovery_supported, :supported_boot_modes, :nitro_enclaves_support, :nitro_tpm_support, :nitro_tpm_info, :media_accelerator_info, :neuron_info, :phc_support, :reboot_migration_support, :supported_in_region) SENSITIVE = [] include Aws::Structure end |
#network_info ⇒ Types::NetworkInfo
Describes the network settings for the instance type.
54297 54298 54299 54300 54301 54302 54303 54304 54305 54306 54307 54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 54321 54322 54323 54324 54325 54326 54327 54328 54329 54330 54331 54332 |
# File 'lib/aws-sdk-ec2/types.rb', line 54297 class InstanceTypeInfo < Struct.new( :instance_type, :current_generation, :free_tier_eligible, :supported_usage_classes, :supported_root_device_types, :supported_virtualization_types, :bare_metal, :hypervisor, :processor_info, :v_cpu_info, :memory_info, :instance_storage_supported, :instance_storage_info, :ebs_info, :network_info, :gpu_info, :fpga_info, :placement_group_info, :inference_accelerator_info, :hibernation_supported, :burstable_performance_supported, :dedicated_hosts_supported, :auto_recovery_supported, :supported_boot_modes, :nitro_enclaves_support, :nitro_tpm_support, :nitro_tpm_info, :media_accelerator_info, :neuron_info, :phc_support, :reboot_migration_support, :supported_in_region) SENSITIVE = [] include Aws::Structure end |
#neuron_info ⇒ Types::NeuronInfo
Describes the Neuron accelerator settings for the instance type.
54297 54298 54299 54300 54301 54302 54303 54304 54305 54306 54307 54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 54321 54322 54323 54324 54325 54326 54327 54328 54329 54330 54331 54332 |
# File 'lib/aws-sdk-ec2/types.rb', line 54297 class InstanceTypeInfo < Struct.new( :instance_type, :current_generation, :free_tier_eligible, :supported_usage_classes, :supported_root_device_types, :supported_virtualization_types, :bare_metal, :hypervisor, :processor_info, :v_cpu_info, :memory_info, :instance_storage_supported, :instance_storage_info, :ebs_info, :network_info, :gpu_info, :fpga_info, :placement_group_info, :inference_accelerator_info, :hibernation_supported, :burstable_performance_supported, :dedicated_hosts_supported, :auto_recovery_supported, :supported_boot_modes, :nitro_enclaves_support, :nitro_tpm_support, :nitro_tpm_info, :media_accelerator_info, :neuron_info, :phc_support, :reboot_migration_support, :supported_in_region) SENSITIVE = [] include Aws::Structure end |
#nitro_enclaves_support ⇒ String
Indicates whether Nitro Enclaves is supported.
54297 54298 54299 54300 54301 54302 54303 54304 54305 54306 54307 54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 54321 54322 54323 54324 54325 54326 54327 54328 54329 54330 54331 54332 |
# File 'lib/aws-sdk-ec2/types.rb', line 54297 class InstanceTypeInfo < Struct.new( :instance_type, :current_generation, :free_tier_eligible, :supported_usage_classes, :supported_root_device_types, :supported_virtualization_types, :bare_metal, :hypervisor, :processor_info, :v_cpu_info, :memory_info, :instance_storage_supported, :instance_storage_info, :ebs_info, :network_info, :gpu_info, :fpga_info, :placement_group_info, :inference_accelerator_info, :hibernation_supported, :burstable_performance_supported, :dedicated_hosts_supported, :auto_recovery_supported, :supported_boot_modes, :nitro_enclaves_support, :nitro_tpm_support, :nitro_tpm_info, :media_accelerator_info, :neuron_info, :phc_support, :reboot_migration_support, :supported_in_region) SENSITIVE = [] include Aws::Structure end |
#nitro_tpm_info ⇒ Types::NitroTpmInfo
Describes the supported NitroTPM versions for the instance type.
54297 54298 54299 54300 54301 54302 54303 54304 54305 54306 54307 54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 54321 54322 54323 54324 54325 54326 54327 54328 54329 54330 54331 54332 |
# File 'lib/aws-sdk-ec2/types.rb', line 54297 class InstanceTypeInfo < Struct.new( :instance_type, :current_generation, :free_tier_eligible, :supported_usage_classes, :supported_root_device_types, :supported_virtualization_types, :bare_metal, :hypervisor, :processor_info, :v_cpu_info, :memory_info, :instance_storage_supported, :instance_storage_info, :ebs_info, :network_info, :gpu_info, :fpga_info, :placement_group_info, :inference_accelerator_info, :hibernation_supported, :burstable_performance_supported, :dedicated_hosts_supported, :auto_recovery_supported, :supported_boot_modes, :nitro_enclaves_support, :nitro_tpm_support, :nitro_tpm_info, :media_accelerator_info, :neuron_info, :phc_support, :reboot_migration_support, :supported_in_region) SENSITIVE = [] include Aws::Structure end |
#nitro_tpm_support ⇒ String
Indicates whether NitroTPM is supported.
54297 54298 54299 54300 54301 54302 54303 54304 54305 54306 54307 54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 54321 54322 54323 54324 54325 54326 54327 54328 54329 54330 54331 54332 |
# File 'lib/aws-sdk-ec2/types.rb', line 54297 class InstanceTypeInfo < Struct.new( :instance_type, :current_generation, :free_tier_eligible, :supported_usage_classes, :supported_root_device_types, :supported_virtualization_types, :bare_metal, :hypervisor, :processor_info, :v_cpu_info, :memory_info, :instance_storage_supported, :instance_storage_info, :ebs_info, :network_info, :gpu_info, :fpga_info, :placement_group_info, :inference_accelerator_info, :hibernation_supported, :burstable_performance_supported, :dedicated_hosts_supported, :auto_recovery_supported, :supported_boot_modes, :nitro_enclaves_support, :nitro_tpm_support, :nitro_tpm_info, :media_accelerator_info, :neuron_info, :phc_support, :reboot_migration_support, :supported_in_region) SENSITIVE = [] include Aws::Structure end |
#phc_support ⇒ String
Indicates whether a local Precision Time Protocol (PTP) hardware clock (PHC) is supported.
54297 54298 54299 54300 54301 54302 54303 54304 54305 54306 54307 54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 54321 54322 54323 54324 54325 54326 54327 54328 54329 54330 54331 54332 |
# File 'lib/aws-sdk-ec2/types.rb', line 54297 class InstanceTypeInfo < Struct.new( :instance_type, :current_generation, :free_tier_eligible, :supported_usage_classes, :supported_root_device_types, :supported_virtualization_types, :bare_metal, :hypervisor, :processor_info, :v_cpu_info, :memory_info, :instance_storage_supported, :instance_storage_info, :ebs_info, :network_info, :gpu_info, :fpga_info, :placement_group_info, :inference_accelerator_info, :hibernation_supported, :burstable_performance_supported, :dedicated_hosts_supported, :auto_recovery_supported, :supported_boot_modes, :nitro_enclaves_support, :nitro_tpm_support, :nitro_tpm_info, :media_accelerator_info, :neuron_info, :phc_support, :reboot_migration_support, :supported_in_region) SENSITIVE = [] include Aws::Structure end |
#placement_group_info ⇒ Types::PlacementGroupInfo
Describes the placement group settings for the instance type.
54297 54298 54299 54300 54301 54302 54303 54304 54305 54306 54307 54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 54321 54322 54323 54324 54325 54326 54327 54328 54329 54330 54331 54332 |
# File 'lib/aws-sdk-ec2/types.rb', line 54297 class InstanceTypeInfo < Struct.new( :instance_type, :current_generation, :free_tier_eligible, :supported_usage_classes, :supported_root_device_types, :supported_virtualization_types, :bare_metal, :hypervisor, :processor_info, :v_cpu_info, :memory_info, :instance_storage_supported, :instance_storage_info, :ebs_info, :network_info, :gpu_info, :fpga_info, :placement_group_info, :inference_accelerator_info, :hibernation_supported, :burstable_performance_supported, :dedicated_hosts_supported, :auto_recovery_supported, :supported_boot_modes, :nitro_enclaves_support, :nitro_tpm_support, :nitro_tpm_info, :media_accelerator_info, :neuron_info, :phc_support, :reboot_migration_support, :supported_in_region) SENSITIVE = [] include Aws::Structure end |
#processor_info ⇒ Types::ProcessorInfo
Describes the processor.
54297 54298 54299 54300 54301 54302 54303 54304 54305 54306 54307 54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 54321 54322 54323 54324 54325 54326 54327 54328 54329 54330 54331 54332 |
# File 'lib/aws-sdk-ec2/types.rb', line 54297 class InstanceTypeInfo < Struct.new( :instance_type, :current_generation, :free_tier_eligible, :supported_usage_classes, :supported_root_device_types, :supported_virtualization_types, :bare_metal, :hypervisor, :processor_info, :v_cpu_info, :memory_info, :instance_storage_supported, :instance_storage_info, :ebs_info, :network_info, :gpu_info, :fpga_info, :placement_group_info, :inference_accelerator_info, :hibernation_supported, :burstable_performance_supported, :dedicated_hosts_supported, :auto_recovery_supported, :supported_boot_modes, :nitro_enclaves_support, :nitro_tpm_support, :nitro_tpm_info, :media_accelerator_info, :neuron_info, :phc_support, :reboot_migration_support, :supported_in_region) SENSITIVE = [] include Aws::Structure end |
#reboot_migration_support ⇒ String
Indicates whether reboot migration during a user-initiated reboot is supported for instances that have a scheduled ‘system-reboot` event. For more information, see [Enable or disable reboot migration] in the *Amazon EC2 User Guide*.
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/schedevents_actions_reboot.html#reboot-migration
54297 54298 54299 54300 54301 54302 54303 54304 54305 54306 54307 54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 54321 54322 54323 54324 54325 54326 54327 54328 54329 54330 54331 54332 |
# File 'lib/aws-sdk-ec2/types.rb', line 54297 class InstanceTypeInfo < Struct.new( :instance_type, :current_generation, :free_tier_eligible, :supported_usage_classes, :supported_root_device_types, :supported_virtualization_types, :bare_metal, :hypervisor, :processor_info, :v_cpu_info, :memory_info, :instance_storage_supported, :instance_storage_info, :ebs_info, :network_info, :gpu_info, :fpga_info, :placement_group_info, :inference_accelerator_info, :hibernation_supported, :burstable_performance_supported, :dedicated_hosts_supported, :auto_recovery_supported, :supported_boot_modes, :nitro_enclaves_support, :nitro_tpm_support, :nitro_tpm_info, :media_accelerator_info, :neuron_info, :phc_support, :reboot_migration_support, :supported_in_region) SENSITIVE = [] include Aws::Structure end |
#supported_boot_modes ⇒ Array<String>
The supported boot modes. For more information, see [Boot modes] in the *Amazon EC2 User Guide*.
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/ami-boot.html
54297 54298 54299 54300 54301 54302 54303 54304 54305 54306 54307 54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 54321 54322 54323 54324 54325 54326 54327 54328 54329 54330 54331 54332 |
# File 'lib/aws-sdk-ec2/types.rb', line 54297 class InstanceTypeInfo < Struct.new( :instance_type, :current_generation, :free_tier_eligible, :supported_usage_classes, :supported_root_device_types, :supported_virtualization_types, :bare_metal, :hypervisor, :processor_info, :v_cpu_info, :memory_info, :instance_storage_supported, :instance_storage_info, :ebs_info, :network_info, :gpu_info, :fpga_info, :placement_group_info, :inference_accelerator_info, :hibernation_supported, :burstable_performance_supported, :dedicated_hosts_supported, :auto_recovery_supported, :supported_boot_modes, :nitro_enclaves_support, :nitro_tpm_support, :nitro_tpm_info, :media_accelerator_info, :neuron_info, :phc_support, :reboot_migration_support, :supported_in_region) SENSITIVE = [] include Aws::Structure end |
#supported_in_region ⇒ Boolean
Indicates whether the instance type is supported in the current Region.
54297 54298 54299 54300 54301 54302 54303 54304 54305 54306 54307 54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 54321 54322 54323 54324 54325 54326 54327 54328 54329 54330 54331 54332 |
# File 'lib/aws-sdk-ec2/types.rb', line 54297 class InstanceTypeInfo < Struct.new( :instance_type, :current_generation, :free_tier_eligible, :supported_usage_classes, :supported_root_device_types, :supported_virtualization_types, :bare_metal, :hypervisor, :processor_info, :v_cpu_info, :memory_info, :instance_storage_supported, :instance_storage_info, :ebs_info, :network_info, :gpu_info, :fpga_info, :placement_group_info, :inference_accelerator_info, :hibernation_supported, :burstable_performance_supported, :dedicated_hosts_supported, :auto_recovery_supported, :supported_boot_modes, :nitro_enclaves_support, :nitro_tpm_support, :nitro_tpm_info, :media_accelerator_info, :neuron_info, :phc_support, :reboot_migration_support, :supported_in_region) SENSITIVE = [] include Aws::Structure end |
#supported_root_device_types ⇒ Array<String>
The supported root device types.
54297 54298 54299 54300 54301 54302 54303 54304 54305 54306 54307 54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 54321 54322 54323 54324 54325 54326 54327 54328 54329 54330 54331 54332 |
# File 'lib/aws-sdk-ec2/types.rb', line 54297 class InstanceTypeInfo < Struct.new( :instance_type, :current_generation, :free_tier_eligible, :supported_usage_classes, :supported_root_device_types, :supported_virtualization_types, :bare_metal, :hypervisor, :processor_info, :v_cpu_info, :memory_info, :instance_storage_supported, :instance_storage_info, :ebs_info, :network_info, :gpu_info, :fpga_info, :placement_group_info, :inference_accelerator_info, :hibernation_supported, :burstable_performance_supported, :dedicated_hosts_supported, :auto_recovery_supported, :supported_boot_modes, :nitro_enclaves_support, :nitro_tpm_support, :nitro_tpm_info, :media_accelerator_info, :neuron_info, :phc_support, :reboot_migration_support, :supported_in_region) SENSITIVE = [] include Aws::Structure end |
#supported_usage_classes ⇒ Array<String>
Indicates whether the instance type is offered for spot, On-Demand, or Capacity Blocks.
54297 54298 54299 54300 54301 54302 54303 54304 54305 54306 54307 54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 54321 54322 54323 54324 54325 54326 54327 54328 54329 54330 54331 54332 |
# File 'lib/aws-sdk-ec2/types.rb', line 54297 class InstanceTypeInfo < Struct.new( :instance_type, :current_generation, :free_tier_eligible, :supported_usage_classes, :supported_root_device_types, :supported_virtualization_types, :bare_metal, :hypervisor, :processor_info, :v_cpu_info, :memory_info, :instance_storage_supported, :instance_storage_info, :ebs_info, :network_info, :gpu_info, :fpga_info, :placement_group_info, :inference_accelerator_info, :hibernation_supported, :burstable_performance_supported, :dedicated_hosts_supported, :auto_recovery_supported, :supported_boot_modes, :nitro_enclaves_support, :nitro_tpm_support, :nitro_tpm_info, :media_accelerator_info, :neuron_info, :phc_support, :reboot_migration_support, :supported_in_region) SENSITIVE = [] include Aws::Structure end |
#supported_virtualization_types ⇒ Array<String>
The supported virtualization types.
54297 54298 54299 54300 54301 54302 54303 54304 54305 54306 54307 54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 54321 54322 54323 54324 54325 54326 54327 54328 54329 54330 54331 54332 |
# File 'lib/aws-sdk-ec2/types.rb', line 54297 class InstanceTypeInfo < Struct.new( :instance_type, :current_generation, :free_tier_eligible, :supported_usage_classes, :supported_root_device_types, :supported_virtualization_types, :bare_metal, :hypervisor, :processor_info, :v_cpu_info, :memory_info, :instance_storage_supported, :instance_storage_info, :ebs_info, :network_info, :gpu_info, :fpga_info, :placement_group_info, :inference_accelerator_info, :hibernation_supported, :burstable_performance_supported, :dedicated_hosts_supported, :auto_recovery_supported, :supported_boot_modes, :nitro_enclaves_support, :nitro_tpm_support, :nitro_tpm_info, :media_accelerator_info, :neuron_info, :phc_support, :reboot_migration_support, :supported_in_region) SENSITIVE = [] include Aws::Structure end |
#v_cpu_info ⇒ Types::VCpuInfo
Describes the vCPU configurations for the instance type.
54297 54298 54299 54300 54301 54302 54303 54304 54305 54306 54307 54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 54321 54322 54323 54324 54325 54326 54327 54328 54329 54330 54331 54332 |
# File 'lib/aws-sdk-ec2/types.rb', line 54297 class InstanceTypeInfo < Struct.new( :instance_type, :current_generation, :free_tier_eligible, :supported_usage_classes, :supported_root_device_types, :supported_virtualization_types, :bare_metal, :hypervisor, :processor_info, :v_cpu_info, :memory_info, :instance_storage_supported, :instance_storage_info, :ebs_info, :network_info, :gpu_info, :fpga_info, :placement_group_info, :inference_accelerator_info, :hibernation_supported, :burstable_performance_supported, :dedicated_hosts_supported, :auto_recovery_supported, :supported_boot_modes, :nitro_enclaves_support, :nitro_tpm_support, :nitro_tpm_info, :media_accelerator_info, :neuron_info, :phc_support, :reboot_migration_support, :supported_in_region) SENSITIVE = [] include Aws::Structure end |