Class: Aws::EC2::Types::InstanceTypeInfo

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes the instance type.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_recovery_supportedBoolean

Indicates whether Amazon CloudWatch action based recovery is supported.

Returns:

  • (Boolean)


53676
53677
53678
53679
53680
53681
53682
53683
53684
53685
53686
53687
53688
53689
53690
53691
53692
53693
53694
53695
53696
53697
53698
53699
53700
53701
53702
53703
53704
53705
53706
53707
53708
53709
53710
# File 'lib/aws-sdk-ec2/types.rb', line 53676

class InstanceTypeInfo < Struct.new(
  :instance_type,
  :current_generation,
  :free_tier_eligible,
  :supported_usage_classes,
  :supported_root_device_types,
  :supported_virtualization_types,
  :bare_metal,
  :hypervisor,
  :processor_info,
  :v_cpu_info,
  :memory_info,
  :instance_storage_supported,
  :instance_storage_info,
  :ebs_info,
  :network_info,
  :gpu_info,
  :fpga_info,
  :placement_group_info,
  :inference_accelerator_info,
  :hibernation_supported,
  :burstable_performance_supported,
  :dedicated_hosts_supported,
  :auto_recovery_supported,
  :supported_boot_modes,
  :nitro_enclaves_support,
  :nitro_tpm_support,
  :nitro_tpm_info,
  :media_accelerator_info,
  :neuron_info,
  :phc_support,
  :reboot_migration_support)
  SENSITIVE = []
  include Aws::Structure
end

#bare_metalBoolean

Indicates whether the instance is a bare metal instance type.

Returns:

  • (Boolean)


53676
53677
53678
53679
53680
53681
53682
53683
53684
53685
53686
53687
53688
53689
53690
53691
53692
53693
53694
53695
53696
53697
53698
53699
53700
53701
53702
53703
53704
53705
53706
53707
53708
53709
53710
# File 'lib/aws-sdk-ec2/types.rb', line 53676

class InstanceTypeInfo < Struct.new(
  :instance_type,
  :current_generation,
  :free_tier_eligible,
  :supported_usage_classes,
  :supported_root_device_types,
  :supported_virtualization_types,
  :bare_metal,
  :hypervisor,
  :processor_info,
  :v_cpu_info,
  :memory_info,
  :instance_storage_supported,
  :instance_storage_info,
  :ebs_info,
  :network_info,
  :gpu_info,
  :fpga_info,
  :placement_group_info,
  :inference_accelerator_info,
  :hibernation_supported,
  :burstable_performance_supported,
  :dedicated_hosts_supported,
  :auto_recovery_supported,
  :supported_boot_modes,
  :nitro_enclaves_support,
  :nitro_tpm_support,
  :nitro_tpm_info,
  :media_accelerator_info,
  :neuron_info,
  :phc_support,
  :reboot_migration_support)
  SENSITIVE = []
  include Aws::Structure
end

#burstable_performance_supportedBoolean

Indicates whether the instance type is a burstable performance T instance type. For more information, see [Burstable performance instances].

[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/burstable-performance-instances.html

Returns:

  • (Boolean)


53676
53677
53678
53679
53680
53681
53682
53683
53684
53685
53686
53687
53688
53689
53690
53691
53692
53693
53694
53695
53696
53697
53698
53699
53700
53701
53702
53703
53704
53705
53706
53707
53708
53709
53710
# File 'lib/aws-sdk-ec2/types.rb', line 53676

class InstanceTypeInfo < Struct.new(
  :instance_type,
  :current_generation,
  :free_tier_eligible,
  :supported_usage_classes,
  :supported_root_device_types,
  :supported_virtualization_types,
  :bare_metal,
  :hypervisor,
  :processor_info,
  :v_cpu_info,
  :memory_info,
  :instance_storage_supported,
  :instance_storage_info,
  :ebs_info,
  :network_info,
  :gpu_info,
  :fpga_info,
  :placement_group_info,
  :inference_accelerator_info,
  :hibernation_supported,
  :burstable_performance_supported,
  :dedicated_hosts_supported,
  :auto_recovery_supported,
  :supported_boot_modes,
  :nitro_enclaves_support,
  :nitro_tpm_support,
  :nitro_tpm_info,
  :media_accelerator_info,
  :neuron_info,
  :phc_support,
  :reboot_migration_support)
  SENSITIVE = []
  include Aws::Structure
end

#current_generationBoolean

Indicates whether the instance type is current generation.

Returns:

  • (Boolean)


53676
53677
53678
53679
53680
53681
53682
53683
53684
53685
53686
53687
53688
53689
53690
53691
53692
53693
53694
53695
53696
53697
53698
53699
53700
53701
53702
53703
53704
53705
53706
53707
53708
53709
53710
# File 'lib/aws-sdk-ec2/types.rb', line 53676

class InstanceTypeInfo < Struct.new(
  :instance_type,
  :current_generation,
  :free_tier_eligible,
  :supported_usage_classes,
  :supported_root_device_types,
  :supported_virtualization_types,
  :bare_metal,
  :hypervisor,
  :processor_info,
  :v_cpu_info,
  :memory_info,
  :instance_storage_supported,
  :instance_storage_info,
  :ebs_info,
  :network_info,
  :gpu_info,
  :fpga_info,
  :placement_group_info,
  :inference_accelerator_info,
  :hibernation_supported,
  :burstable_performance_supported,
  :dedicated_hosts_supported,
  :auto_recovery_supported,
  :supported_boot_modes,
  :nitro_enclaves_support,
  :nitro_tpm_support,
  :nitro_tpm_info,
  :media_accelerator_info,
  :neuron_info,
  :phc_support,
  :reboot_migration_support)
  SENSITIVE = []
  include Aws::Structure
end

#dedicated_hosts_supportedBoolean

Indicates whether Dedicated Hosts are supported on the instance type.

Returns:

  • (Boolean)


53676
53677
53678
53679
53680
53681
53682
53683
53684
53685
53686
53687
53688
53689
53690
53691
53692
53693
53694
53695
53696
53697
53698
53699
53700
53701
53702
53703
53704
53705
53706
53707
53708
53709
53710
# File 'lib/aws-sdk-ec2/types.rb', line 53676

class InstanceTypeInfo < Struct.new(
  :instance_type,
  :current_generation,
  :free_tier_eligible,
  :supported_usage_classes,
  :supported_root_device_types,
  :supported_virtualization_types,
  :bare_metal,
  :hypervisor,
  :processor_info,
  :v_cpu_info,
  :memory_info,
  :instance_storage_supported,
  :instance_storage_info,
  :ebs_info,
  :network_info,
  :gpu_info,
  :fpga_info,
  :placement_group_info,
  :inference_accelerator_info,
  :hibernation_supported,
  :burstable_performance_supported,
  :dedicated_hosts_supported,
  :auto_recovery_supported,
  :supported_boot_modes,
  :nitro_enclaves_support,
  :nitro_tpm_support,
  :nitro_tpm_info,
  :media_accelerator_info,
  :neuron_info,
  :phc_support,
  :reboot_migration_support)
  SENSITIVE = []
  include Aws::Structure
end

#ebs_infoTypes::EbsInfo

Describes the Amazon EBS settings for the instance type.

Returns:



53676
53677
53678
53679
53680
53681
53682
53683
53684
53685
53686
53687
53688
53689
53690
53691
53692
53693
53694
53695
53696
53697
53698
53699
53700
53701
53702
53703
53704
53705
53706
53707
53708
53709
53710
# File 'lib/aws-sdk-ec2/types.rb', line 53676

class InstanceTypeInfo < Struct.new(
  :instance_type,
  :current_generation,
  :free_tier_eligible,
  :supported_usage_classes,
  :supported_root_device_types,
  :supported_virtualization_types,
  :bare_metal,
  :hypervisor,
  :processor_info,
  :v_cpu_info,
  :memory_info,
  :instance_storage_supported,
  :instance_storage_info,
  :ebs_info,
  :network_info,
  :gpu_info,
  :fpga_info,
  :placement_group_info,
  :inference_accelerator_info,
  :hibernation_supported,
  :burstable_performance_supported,
  :dedicated_hosts_supported,
  :auto_recovery_supported,
  :supported_boot_modes,
  :nitro_enclaves_support,
  :nitro_tpm_support,
  :nitro_tpm_info,
  :media_accelerator_info,
  :neuron_info,
  :phc_support,
  :reboot_migration_support)
  SENSITIVE = []
  include Aws::Structure
end

#fpga_infoTypes::FpgaInfo

Describes the FPGA accelerator settings for the instance type.

Returns:



53676
53677
53678
53679
53680
53681
53682
53683
53684
53685
53686
53687
53688
53689
53690
53691
53692
53693
53694
53695
53696
53697
53698
53699
53700
53701
53702
53703
53704
53705
53706
53707
53708
53709
53710
# File 'lib/aws-sdk-ec2/types.rb', line 53676

class InstanceTypeInfo < Struct.new(
  :instance_type,
  :current_generation,
  :free_tier_eligible,
  :supported_usage_classes,
  :supported_root_device_types,
  :supported_virtualization_types,
  :bare_metal,
  :hypervisor,
  :processor_info,
  :v_cpu_info,
  :memory_info,
  :instance_storage_supported,
  :instance_storage_info,
  :ebs_info,
  :network_info,
  :gpu_info,
  :fpga_info,
  :placement_group_info,
  :inference_accelerator_info,
  :hibernation_supported,
  :burstable_performance_supported,
  :dedicated_hosts_supported,
  :auto_recovery_supported,
  :supported_boot_modes,
  :nitro_enclaves_support,
  :nitro_tpm_support,
  :nitro_tpm_info,
  :media_accelerator_info,
  :neuron_info,
  :phc_support,
  :reboot_migration_support)
  SENSITIVE = []
  include Aws::Structure
end

#free_tier_eligibleBoolean

Indicates whether the instance type is eligible for the free tier.

Returns:

  • (Boolean)


53676
53677
53678
53679
53680
53681
53682
53683
53684
53685
53686
53687
53688
53689
53690
53691
53692
53693
53694
53695
53696
53697
53698
53699
53700
53701
53702
53703
53704
53705
53706
53707
53708
53709
53710
# File 'lib/aws-sdk-ec2/types.rb', line 53676

class InstanceTypeInfo < Struct.new(
  :instance_type,
  :current_generation,
  :free_tier_eligible,
  :supported_usage_classes,
  :supported_root_device_types,
  :supported_virtualization_types,
  :bare_metal,
  :hypervisor,
  :processor_info,
  :v_cpu_info,
  :memory_info,
  :instance_storage_supported,
  :instance_storage_info,
  :ebs_info,
  :network_info,
  :gpu_info,
  :fpga_info,
  :placement_group_info,
  :inference_accelerator_info,
  :hibernation_supported,
  :burstable_performance_supported,
  :dedicated_hosts_supported,
  :auto_recovery_supported,
  :supported_boot_modes,
  :nitro_enclaves_support,
  :nitro_tpm_support,
  :nitro_tpm_info,
  :media_accelerator_info,
  :neuron_info,
  :phc_support,
  :reboot_migration_support)
  SENSITIVE = []
  include Aws::Structure
end

#gpu_infoTypes::GpuInfo

Describes the GPU accelerator settings for the instance type.

Returns:



53676
53677
53678
53679
53680
53681
53682
53683
53684
53685
53686
53687
53688
53689
53690
53691
53692
53693
53694
53695
53696
53697
53698
53699
53700
53701
53702
53703
53704
53705
53706
53707
53708
53709
53710
# File 'lib/aws-sdk-ec2/types.rb', line 53676

class InstanceTypeInfo < Struct.new(
  :instance_type,
  :current_generation,
  :free_tier_eligible,
  :supported_usage_classes,
  :supported_root_device_types,
  :supported_virtualization_types,
  :bare_metal,
  :hypervisor,
  :processor_info,
  :v_cpu_info,
  :memory_info,
  :instance_storage_supported,
  :instance_storage_info,
  :ebs_info,
  :network_info,
  :gpu_info,
  :fpga_info,
  :placement_group_info,
  :inference_accelerator_info,
  :hibernation_supported,
  :burstable_performance_supported,
  :dedicated_hosts_supported,
  :auto_recovery_supported,
  :supported_boot_modes,
  :nitro_enclaves_support,
  :nitro_tpm_support,
  :nitro_tpm_info,
  :media_accelerator_info,
  :neuron_info,
  :phc_support,
  :reboot_migration_support)
  SENSITIVE = []
  include Aws::Structure
end

#hibernation_supportedBoolean

Indicates whether On-Demand hibernation is supported.

Returns:

  • (Boolean)


53676
53677
53678
53679
53680
53681
53682
53683
53684
53685
53686
53687
53688
53689
53690
53691
53692
53693
53694
53695
53696
53697
53698
53699
53700
53701
53702
53703
53704
53705
53706
53707
53708
53709
53710
# File 'lib/aws-sdk-ec2/types.rb', line 53676

class InstanceTypeInfo < Struct.new(
  :instance_type,
  :current_generation,
  :free_tier_eligible,
  :supported_usage_classes,
  :supported_root_device_types,
  :supported_virtualization_types,
  :bare_metal,
  :hypervisor,
  :processor_info,
  :v_cpu_info,
  :memory_info,
  :instance_storage_supported,
  :instance_storage_info,
  :ebs_info,
  :network_info,
  :gpu_info,
  :fpga_info,
  :placement_group_info,
  :inference_accelerator_info,
  :hibernation_supported,
  :burstable_performance_supported,
  :dedicated_hosts_supported,
  :auto_recovery_supported,
  :supported_boot_modes,
  :nitro_enclaves_support,
  :nitro_tpm_support,
  :nitro_tpm_info,
  :media_accelerator_info,
  :neuron_info,
  :phc_support,
  :reboot_migration_support)
  SENSITIVE = []
  include Aws::Structure
end

#hypervisorString

The hypervisor for the instance type.

Returns:

  • (String)


53676
53677
53678
53679
53680
53681
53682
53683
53684
53685
53686
53687
53688
53689
53690
53691
53692
53693
53694
53695
53696
53697
53698
53699
53700
53701
53702
53703
53704
53705
53706
53707
53708
53709
53710
# File 'lib/aws-sdk-ec2/types.rb', line 53676

class InstanceTypeInfo < Struct.new(
  :instance_type,
  :current_generation,
  :free_tier_eligible,
  :supported_usage_classes,
  :supported_root_device_types,
  :supported_virtualization_types,
  :bare_metal,
  :hypervisor,
  :processor_info,
  :v_cpu_info,
  :memory_info,
  :instance_storage_supported,
  :instance_storage_info,
  :ebs_info,
  :network_info,
  :gpu_info,
  :fpga_info,
  :placement_group_info,
  :inference_accelerator_info,
  :hibernation_supported,
  :burstable_performance_supported,
  :dedicated_hosts_supported,
  :auto_recovery_supported,
  :supported_boot_modes,
  :nitro_enclaves_support,
  :nitro_tpm_support,
  :nitro_tpm_info,
  :media_accelerator_info,
  :neuron_info,
  :phc_support,
  :reboot_migration_support)
  SENSITIVE = []
  include Aws::Structure
end

#inference_accelerator_infoTypes::InferenceAcceleratorInfo

Describes the Inference accelerator settings for the instance type.



53676
53677
53678
53679
53680
53681
53682
53683
53684
53685
53686
53687
53688
53689
53690
53691
53692
53693
53694
53695
53696
53697
53698
53699
53700
53701
53702
53703
53704
53705
53706
53707
53708
53709
53710
# File 'lib/aws-sdk-ec2/types.rb', line 53676

class InstanceTypeInfo < Struct.new(
  :instance_type,
  :current_generation,
  :free_tier_eligible,
  :supported_usage_classes,
  :supported_root_device_types,
  :supported_virtualization_types,
  :bare_metal,
  :hypervisor,
  :processor_info,
  :v_cpu_info,
  :memory_info,
  :instance_storage_supported,
  :instance_storage_info,
  :ebs_info,
  :network_info,
  :gpu_info,
  :fpga_info,
  :placement_group_info,
  :inference_accelerator_info,
  :hibernation_supported,
  :burstable_performance_supported,
  :dedicated_hosts_supported,
  :auto_recovery_supported,
  :supported_boot_modes,
  :nitro_enclaves_support,
  :nitro_tpm_support,
  :nitro_tpm_info,
  :media_accelerator_info,
  :neuron_info,
  :phc_support,
  :reboot_migration_support)
  SENSITIVE = []
  include Aws::Structure
end

#instance_storage_infoTypes::InstanceStorageInfo

Describes the instance storage for the instance type.



53676
53677
53678
53679
53680
53681
53682
53683
53684
53685
53686
53687
53688
53689
53690
53691
53692
53693
53694
53695
53696
53697
53698
53699
53700
53701
53702
53703
53704
53705
53706
53707
53708
53709
53710
# File 'lib/aws-sdk-ec2/types.rb', line 53676

class InstanceTypeInfo < Struct.new(
  :instance_type,
  :current_generation,
  :free_tier_eligible,
  :supported_usage_classes,
  :supported_root_device_types,
  :supported_virtualization_types,
  :bare_metal,
  :hypervisor,
  :processor_info,
  :v_cpu_info,
  :memory_info,
  :instance_storage_supported,
  :instance_storage_info,
  :ebs_info,
  :network_info,
  :gpu_info,
  :fpga_info,
  :placement_group_info,
  :inference_accelerator_info,
  :hibernation_supported,
  :burstable_performance_supported,
  :dedicated_hosts_supported,
  :auto_recovery_supported,
  :supported_boot_modes,
  :nitro_enclaves_support,
  :nitro_tpm_support,
  :nitro_tpm_info,
  :media_accelerator_info,
  :neuron_info,
  :phc_support,
  :reboot_migration_support)
  SENSITIVE = []
  include Aws::Structure
end

#instance_storage_supportedBoolean

Indicates whether instance storage is supported.

Returns:

  • (Boolean)


53676
53677
53678
53679
53680
53681
53682
53683
53684
53685
53686
53687
53688
53689
53690
53691
53692
53693
53694
53695
53696
53697
53698
53699
53700
53701
53702
53703
53704
53705
53706
53707
53708
53709
53710
# File 'lib/aws-sdk-ec2/types.rb', line 53676

class InstanceTypeInfo < Struct.new(
  :instance_type,
  :current_generation,
  :free_tier_eligible,
  :supported_usage_classes,
  :supported_root_device_types,
  :supported_virtualization_types,
  :bare_metal,
  :hypervisor,
  :processor_info,
  :v_cpu_info,
  :memory_info,
  :instance_storage_supported,
  :instance_storage_info,
  :ebs_info,
  :network_info,
  :gpu_info,
  :fpga_info,
  :placement_group_info,
  :inference_accelerator_info,
  :hibernation_supported,
  :burstable_performance_supported,
  :dedicated_hosts_supported,
  :auto_recovery_supported,
  :supported_boot_modes,
  :nitro_enclaves_support,
  :nitro_tpm_support,
  :nitro_tpm_info,
  :media_accelerator_info,
  :neuron_info,
  :phc_support,
  :reboot_migration_support)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

The instance type. For more information, see [Instance types] in the *Amazon EC2 User Guide*.

[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html

Returns:

  • (String)


53676
53677
53678
53679
53680
53681
53682
53683
53684
53685
53686
53687
53688
53689
53690
53691
53692
53693
53694
53695
53696
53697
53698
53699
53700
53701
53702
53703
53704
53705
53706
53707
53708
53709
53710
# File 'lib/aws-sdk-ec2/types.rb', line 53676

class InstanceTypeInfo < Struct.new(
  :instance_type,
  :current_generation,
  :free_tier_eligible,
  :supported_usage_classes,
  :supported_root_device_types,
  :supported_virtualization_types,
  :bare_metal,
  :hypervisor,
  :processor_info,
  :v_cpu_info,
  :memory_info,
  :instance_storage_supported,
  :instance_storage_info,
  :ebs_info,
  :network_info,
  :gpu_info,
  :fpga_info,
  :placement_group_info,
  :inference_accelerator_info,
  :hibernation_supported,
  :burstable_performance_supported,
  :dedicated_hosts_supported,
  :auto_recovery_supported,
  :supported_boot_modes,
  :nitro_enclaves_support,
  :nitro_tpm_support,
  :nitro_tpm_info,
  :media_accelerator_info,
  :neuron_info,
  :phc_support,
  :reboot_migration_support)
  SENSITIVE = []
  include Aws::Structure
end

#media_accelerator_infoTypes::MediaAcceleratorInfo

Describes the media accelerator settings for the instance type.



53676
53677
53678
53679
53680
53681
53682
53683
53684
53685
53686
53687
53688
53689
53690
53691
53692
53693
53694
53695
53696
53697
53698
53699
53700
53701
53702
53703
53704
53705
53706
53707
53708
53709
53710
# File 'lib/aws-sdk-ec2/types.rb', line 53676

class InstanceTypeInfo < Struct.new(
  :instance_type,
  :current_generation,
  :free_tier_eligible,
  :supported_usage_classes,
  :supported_root_device_types,
  :supported_virtualization_types,
  :bare_metal,
  :hypervisor,
  :processor_info,
  :v_cpu_info,
  :memory_info,
  :instance_storage_supported,
  :instance_storage_info,
  :ebs_info,
  :network_info,
  :gpu_info,
  :fpga_info,
  :placement_group_info,
  :inference_accelerator_info,
  :hibernation_supported,
  :burstable_performance_supported,
  :dedicated_hosts_supported,
  :auto_recovery_supported,
  :supported_boot_modes,
  :nitro_enclaves_support,
  :nitro_tpm_support,
  :nitro_tpm_info,
  :media_accelerator_info,
  :neuron_info,
  :phc_support,
  :reboot_migration_support)
  SENSITIVE = []
  include Aws::Structure
end

#memory_infoTypes::MemoryInfo

Describes the memory for the instance type.

Returns:



53676
53677
53678
53679
53680
53681
53682
53683
53684
53685
53686
53687
53688
53689
53690
53691
53692
53693
53694
53695
53696
53697
53698
53699
53700
53701
53702
53703
53704
53705
53706
53707
53708
53709
53710
# File 'lib/aws-sdk-ec2/types.rb', line 53676

class InstanceTypeInfo < Struct.new(
  :instance_type,
  :current_generation,
  :free_tier_eligible,
  :supported_usage_classes,
  :supported_root_device_types,
  :supported_virtualization_types,
  :bare_metal,
  :hypervisor,
  :processor_info,
  :v_cpu_info,
  :memory_info,
  :instance_storage_supported,
  :instance_storage_info,
  :ebs_info,
  :network_info,
  :gpu_info,
  :fpga_info,
  :placement_group_info,
  :inference_accelerator_info,
  :hibernation_supported,
  :burstable_performance_supported,
  :dedicated_hosts_supported,
  :auto_recovery_supported,
  :supported_boot_modes,
  :nitro_enclaves_support,
  :nitro_tpm_support,
  :nitro_tpm_info,
  :media_accelerator_info,
  :neuron_info,
  :phc_support,
  :reboot_migration_support)
  SENSITIVE = []
  include Aws::Structure
end

#network_infoTypes::NetworkInfo

Describes the network settings for the instance type.

Returns:



53676
53677
53678
53679
53680
53681
53682
53683
53684
53685
53686
53687
53688
53689
53690
53691
53692
53693
53694
53695
53696
53697
53698
53699
53700
53701
53702
53703
53704
53705
53706
53707
53708
53709
53710
# File 'lib/aws-sdk-ec2/types.rb', line 53676

class InstanceTypeInfo < Struct.new(
  :instance_type,
  :current_generation,
  :free_tier_eligible,
  :supported_usage_classes,
  :supported_root_device_types,
  :supported_virtualization_types,
  :bare_metal,
  :hypervisor,
  :processor_info,
  :v_cpu_info,
  :memory_info,
  :instance_storage_supported,
  :instance_storage_info,
  :ebs_info,
  :network_info,
  :gpu_info,
  :fpga_info,
  :placement_group_info,
  :inference_accelerator_info,
  :hibernation_supported,
  :burstable_performance_supported,
  :dedicated_hosts_supported,
  :auto_recovery_supported,
  :supported_boot_modes,
  :nitro_enclaves_support,
  :nitro_tpm_support,
  :nitro_tpm_info,
  :media_accelerator_info,
  :neuron_info,
  :phc_support,
  :reboot_migration_support)
  SENSITIVE = []
  include Aws::Structure
end

#neuron_infoTypes::NeuronInfo

Describes the Neuron accelerator settings for the instance type.

Returns:



53676
53677
53678
53679
53680
53681
53682
53683
53684
53685
53686
53687
53688
53689
53690
53691
53692
53693
53694
53695
53696
53697
53698
53699
53700
53701
53702
53703
53704
53705
53706
53707
53708
53709
53710
# File 'lib/aws-sdk-ec2/types.rb', line 53676

class InstanceTypeInfo < Struct.new(
  :instance_type,
  :current_generation,
  :free_tier_eligible,
  :supported_usage_classes,
  :supported_root_device_types,
  :supported_virtualization_types,
  :bare_metal,
  :hypervisor,
  :processor_info,
  :v_cpu_info,
  :memory_info,
  :instance_storage_supported,
  :instance_storage_info,
  :ebs_info,
  :network_info,
  :gpu_info,
  :fpga_info,
  :placement_group_info,
  :inference_accelerator_info,
  :hibernation_supported,
  :burstable_performance_supported,
  :dedicated_hosts_supported,
  :auto_recovery_supported,
  :supported_boot_modes,
  :nitro_enclaves_support,
  :nitro_tpm_support,
  :nitro_tpm_info,
  :media_accelerator_info,
  :neuron_info,
  :phc_support,
  :reboot_migration_support)
  SENSITIVE = []
  include Aws::Structure
end

#nitro_enclaves_supportString

Indicates whether Nitro Enclaves is supported.

Returns:

  • (String)


53676
53677
53678
53679
53680
53681
53682
53683
53684
53685
53686
53687
53688
53689
53690
53691
53692
53693
53694
53695
53696
53697
53698
53699
53700
53701
53702
53703
53704
53705
53706
53707
53708
53709
53710
# File 'lib/aws-sdk-ec2/types.rb', line 53676

class InstanceTypeInfo < Struct.new(
  :instance_type,
  :current_generation,
  :free_tier_eligible,
  :supported_usage_classes,
  :supported_root_device_types,
  :supported_virtualization_types,
  :bare_metal,
  :hypervisor,
  :processor_info,
  :v_cpu_info,
  :memory_info,
  :instance_storage_supported,
  :instance_storage_info,
  :ebs_info,
  :network_info,
  :gpu_info,
  :fpga_info,
  :placement_group_info,
  :inference_accelerator_info,
  :hibernation_supported,
  :burstable_performance_supported,
  :dedicated_hosts_supported,
  :auto_recovery_supported,
  :supported_boot_modes,
  :nitro_enclaves_support,
  :nitro_tpm_support,
  :nitro_tpm_info,
  :media_accelerator_info,
  :neuron_info,
  :phc_support,
  :reboot_migration_support)
  SENSITIVE = []
  include Aws::Structure
end

#nitro_tpm_infoTypes::NitroTpmInfo

Describes the supported NitroTPM versions for the instance type.

Returns:



53676
53677
53678
53679
53680
53681
53682
53683
53684
53685
53686
53687
53688
53689
53690
53691
53692
53693
53694
53695
53696
53697
53698
53699
53700
53701
53702
53703
53704
53705
53706
53707
53708
53709
53710
# File 'lib/aws-sdk-ec2/types.rb', line 53676

class InstanceTypeInfo < Struct.new(
  :instance_type,
  :current_generation,
  :free_tier_eligible,
  :supported_usage_classes,
  :supported_root_device_types,
  :supported_virtualization_types,
  :bare_metal,
  :hypervisor,
  :processor_info,
  :v_cpu_info,
  :memory_info,
  :instance_storage_supported,
  :instance_storage_info,
  :ebs_info,
  :network_info,
  :gpu_info,
  :fpga_info,
  :placement_group_info,
  :inference_accelerator_info,
  :hibernation_supported,
  :burstable_performance_supported,
  :dedicated_hosts_supported,
  :auto_recovery_supported,
  :supported_boot_modes,
  :nitro_enclaves_support,
  :nitro_tpm_support,
  :nitro_tpm_info,
  :media_accelerator_info,
  :neuron_info,
  :phc_support,
  :reboot_migration_support)
  SENSITIVE = []
  include Aws::Structure
end

#nitro_tpm_supportString

Indicates whether NitroTPM is supported.

Returns:

  • (String)


53676
53677
53678
53679
53680
53681
53682
53683
53684
53685
53686
53687
53688
53689
53690
53691
53692
53693
53694
53695
53696
53697
53698
53699
53700
53701
53702
53703
53704
53705
53706
53707
53708
53709
53710
# File 'lib/aws-sdk-ec2/types.rb', line 53676

class InstanceTypeInfo < Struct.new(
  :instance_type,
  :current_generation,
  :free_tier_eligible,
  :supported_usage_classes,
  :supported_root_device_types,
  :supported_virtualization_types,
  :bare_metal,
  :hypervisor,
  :processor_info,
  :v_cpu_info,
  :memory_info,
  :instance_storage_supported,
  :instance_storage_info,
  :ebs_info,
  :network_info,
  :gpu_info,
  :fpga_info,
  :placement_group_info,
  :inference_accelerator_info,
  :hibernation_supported,
  :burstable_performance_supported,
  :dedicated_hosts_supported,
  :auto_recovery_supported,
  :supported_boot_modes,
  :nitro_enclaves_support,
  :nitro_tpm_support,
  :nitro_tpm_info,
  :media_accelerator_info,
  :neuron_info,
  :phc_support,
  :reboot_migration_support)
  SENSITIVE = []
  include Aws::Structure
end

#phc_supportString

Indicates whether a local Precision Time Protocol (PTP) hardware clock (PHC) is supported.

Returns:

  • (String)


53676
53677
53678
53679
53680
53681
53682
53683
53684
53685
53686
53687
53688
53689
53690
53691
53692
53693
53694
53695
53696
53697
53698
53699
53700
53701
53702
53703
53704
53705
53706
53707
53708
53709
53710
# File 'lib/aws-sdk-ec2/types.rb', line 53676

class InstanceTypeInfo < Struct.new(
  :instance_type,
  :current_generation,
  :free_tier_eligible,
  :supported_usage_classes,
  :supported_root_device_types,
  :supported_virtualization_types,
  :bare_metal,
  :hypervisor,
  :processor_info,
  :v_cpu_info,
  :memory_info,
  :instance_storage_supported,
  :instance_storage_info,
  :ebs_info,
  :network_info,
  :gpu_info,
  :fpga_info,
  :placement_group_info,
  :inference_accelerator_info,
  :hibernation_supported,
  :burstable_performance_supported,
  :dedicated_hosts_supported,
  :auto_recovery_supported,
  :supported_boot_modes,
  :nitro_enclaves_support,
  :nitro_tpm_support,
  :nitro_tpm_info,
  :media_accelerator_info,
  :neuron_info,
  :phc_support,
  :reboot_migration_support)
  SENSITIVE = []
  include Aws::Structure
end

#placement_group_infoTypes::PlacementGroupInfo

Describes the placement group settings for the instance type.



53676
53677
53678
53679
53680
53681
53682
53683
53684
53685
53686
53687
53688
53689
53690
53691
53692
53693
53694
53695
53696
53697
53698
53699
53700
53701
53702
53703
53704
53705
53706
53707
53708
53709
53710
# File 'lib/aws-sdk-ec2/types.rb', line 53676

class InstanceTypeInfo < Struct.new(
  :instance_type,
  :current_generation,
  :free_tier_eligible,
  :supported_usage_classes,
  :supported_root_device_types,
  :supported_virtualization_types,
  :bare_metal,
  :hypervisor,
  :processor_info,
  :v_cpu_info,
  :memory_info,
  :instance_storage_supported,
  :instance_storage_info,
  :ebs_info,
  :network_info,
  :gpu_info,
  :fpga_info,
  :placement_group_info,
  :inference_accelerator_info,
  :hibernation_supported,
  :burstable_performance_supported,
  :dedicated_hosts_supported,
  :auto_recovery_supported,
  :supported_boot_modes,
  :nitro_enclaves_support,
  :nitro_tpm_support,
  :nitro_tpm_info,
  :media_accelerator_info,
  :neuron_info,
  :phc_support,
  :reboot_migration_support)
  SENSITIVE = []
  include Aws::Structure
end

#processor_infoTypes::ProcessorInfo

Describes the processor.



53676
53677
53678
53679
53680
53681
53682
53683
53684
53685
53686
53687
53688
53689
53690
53691
53692
53693
53694
53695
53696
53697
53698
53699
53700
53701
53702
53703
53704
53705
53706
53707
53708
53709
53710
# File 'lib/aws-sdk-ec2/types.rb', line 53676

class InstanceTypeInfo < Struct.new(
  :instance_type,
  :current_generation,
  :free_tier_eligible,
  :supported_usage_classes,
  :supported_root_device_types,
  :supported_virtualization_types,
  :bare_metal,
  :hypervisor,
  :processor_info,
  :v_cpu_info,
  :memory_info,
  :instance_storage_supported,
  :instance_storage_info,
  :ebs_info,
  :network_info,
  :gpu_info,
  :fpga_info,
  :placement_group_info,
  :inference_accelerator_info,
  :hibernation_supported,
  :burstable_performance_supported,
  :dedicated_hosts_supported,
  :auto_recovery_supported,
  :supported_boot_modes,
  :nitro_enclaves_support,
  :nitro_tpm_support,
  :nitro_tpm_info,
  :media_accelerator_info,
  :neuron_info,
  :phc_support,
  :reboot_migration_support)
  SENSITIVE = []
  include Aws::Structure
end

#reboot_migration_supportString

Indicates whether reboot migration during a user-initiated reboot is supported for instances that have a scheduled ‘system-reboot` event. For more information, see [Enable or disable reboot migration] in the *Amazon EC2 User Guide*.

[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/schedevents_actions_reboot.html#reboot-migration

Returns:

  • (String)


53676
53677
53678
53679
53680
53681
53682
53683
53684
53685
53686
53687
53688
53689
53690
53691
53692
53693
53694
53695
53696
53697
53698
53699
53700
53701
53702
53703
53704
53705
53706
53707
53708
53709
53710
# File 'lib/aws-sdk-ec2/types.rb', line 53676

class InstanceTypeInfo < Struct.new(
  :instance_type,
  :current_generation,
  :free_tier_eligible,
  :supported_usage_classes,
  :supported_root_device_types,
  :supported_virtualization_types,
  :bare_metal,
  :hypervisor,
  :processor_info,
  :v_cpu_info,
  :memory_info,
  :instance_storage_supported,
  :instance_storage_info,
  :ebs_info,
  :network_info,
  :gpu_info,
  :fpga_info,
  :placement_group_info,
  :inference_accelerator_info,
  :hibernation_supported,
  :burstable_performance_supported,
  :dedicated_hosts_supported,
  :auto_recovery_supported,
  :supported_boot_modes,
  :nitro_enclaves_support,
  :nitro_tpm_support,
  :nitro_tpm_info,
  :media_accelerator_info,
  :neuron_info,
  :phc_support,
  :reboot_migration_support)
  SENSITIVE = []
  include Aws::Structure
end

#supported_boot_modesArray<String>

The supported boot modes. For more information, see [Boot modes] in the *Amazon EC2 User Guide*.

[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/ami-boot.html

Returns:

  • (Array<String>)


53676
53677
53678
53679
53680
53681
53682
53683
53684
53685
53686
53687
53688
53689
53690
53691
53692
53693
53694
53695
53696
53697
53698
53699
53700
53701
53702
53703
53704
53705
53706
53707
53708
53709
53710
# File 'lib/aws-sdk-ec2/types.rb', line 53676

class InstanceTypeInfo < Struct.new(
  :instance_type,
  :current_generation,
  :free_tier_eligible,
  :supported_usage_classes,
  :supported_root_device_types,
  :supported_virtualization_types,
  :bare_metal,
  :hypervisor,
  :processor_info,
  :v_cpu_info,
  :memory_info,
  :instance_storage_supported,
  :instance_storage_info,
  :ebs_info,
  :network_info,
  :gpu_info,
  :fpga_info,
  :placement_group_info,
  :inference_accelerator_info,
  :hibernation_supported,
  :burstable_performance_supported,
  :dedicated_hosts_supported,
  :auto_recovery_supported,
  :supported_boot_modes,
  :nitro_enclaves_support,
  :nitro_tpm_support,
  :nitro_tpm_info,
  :media_accelerator_info,
  :neuron_info,
  :phc_support,
  :reboot_migration_support)
  SENSITIVE = []
  include Aws::Structure
end

#supported_root_device_typesArray<String>

The supported root device types.

Returns:

  • (Array<String>)


53676
53677
53678
53679
53680
53681
53682
53683
53684
53685
53686
53687
53688
53689
53690
53691
53692
53693
53694
53695
53696
53697
53698
53699
53700
53701
53702
53703
53704
53705
53706
53707
53708
53709
53710
# File 'lib/aws-sdk-ec2/types.rb', line 53676

class InstanceTypeInfo < Struct.new(
  :instance_type,
  :current_generation,
  :free_tier_eligible,
  :supported_usage_classes,
  :supported_root_device_types,
  :supported_virtualization_types,
  :bare_metal,
  :hypervisor,
  :processor_info,
  :v_cpu_info,
  :memory_info,
  :instance_storage_supported,
  :instance_storage_info,
  :ebs_info,
  :network_info,
  :gpu_info,
  :fpga_info,
  :placement_group_info,
  :inference_accelerator_info,
  :hibernation_supported,
  :burstable_performance_supported,
  :dedicated_hosts_supported,
  :auto_recovery_supported,
  :supported_boot_modes,
  :nitro_enclaves_support,
  :nitro_tpm_support,
  :nitro_tpm_info,
  :media_accelerator_info,
  :neuron_info,
  :phc_support,
  :reboot_migration_support)
  SENSITIVE = []
  include Aws::Structure
end

#supported_usage_classesArray<String>

Indicates whether the instance type is offered for spot, On-Demand, or Capacity Blocks.

Returns:

  • (Array<String>)


53676
53677
53678
53679
53680
53681
53682
53683
53684
53685
53686
53687
53688
53689
53690
53691
53692
53693
53694
53695
53696
53697
53698
53699
53700
53701
53702
53703
53704
53705
53706
53707
53708
53709
53710
# File 'lib/aws-sdk-ec2/types.rb', line 53676

class InstanceTypeInfo < Struct.new(
  :instance_type,
  :current_generation,
  :free_tier_eligible,
  :supported_usage_classes,
  :supported_root_device_types,
  :supported_virtualization_types,
  :bare_metal,
  :hypervisor,
  :processor_info,
  :v_cpu_info,
  :memory_info,
  :instance_storage_supported,
  :instance_storage_info,
  :ebs_info,
  :network_info,
  :gpu_info,
  :fpga_info,
  :placement_group_info,
  :inference_accelerator_info,
  :hibernation_supported,
  :burstable_performance_supported,
  :dedicated_hosts_supported,
  :auto_recovery_supported,
  :supported_boot_modes,
  :nitro_enclaves_support,
  :nitro_tpm_support,
  :nitro_tpm_info,
  :media_accelerator_info,
  :neuron_info,
  :phc_support,
  :reboot_migration_support)
  SENSITIVE = []
  include Aws::Structure
end

#supported_virtualization_typesArray<String>

The supported virtualization types.

Returns:

  • (Array<String>)


53676
53677
53678
53679
53680
53681
53682
53683
53684
53685
53686
53687
53688
53689
53690
53691
53692
53693
53694
53695
53696
53697
53698
53699
53700
53701
53702
53703
53704
53705
53706
53707
53708
53709
53710
# File 'lib/aws-sdk-ec2/types.rb', line 53676

class InstanceTypeInfo < Struct.new(
  :instance_type,
  :current_generation,
  :free_tier_eligible,
  :supported_usage_classes,
  :supported_root_device_types,
  :supported_virtualization_types,
  :bare_metal,
  :hypervisor,
  :processor_info,
  :v_cpu_info,
  :memory_info,
  :instance_storage_supported,
  :instance_storage_info,
  :ebs_info,
  :network_info,
  :gpu_info,
  :fpga_info,
  :placement_group_info,
  :inference_accelerator_info,
  :hibernation_supported,
  :burstable_performance_supported,
  :dedicated_hosts_supported,
  :auto_recovery_supported,
  :supported_boot_modes,
  :nitro_enclaves_support,
  :nitro_tpm_support,
  :nitro_tpm_info,
  :media_accelerator_info,
  :neuron_info,
  :phc_support,
  :reboot_migration_support)
  SENSITIVE = []
  include Aws::Structure
end

#v_cpu_infoTypes::VCpuInfo

Describes the vCPU configurations for the instance type.

Returns:



53676
53677
53678
53679
53680
53681
53682
53683
53684
53685
53686
53687
53688
53689
53690
53691
53692
53693
53694
53695
53696
53697
53698
53699
53700
53701
53702
53703
53704
53705
53706
53707
53708
53709
53710
# File 'lib/aws-sdk-ec2/types.rb', line 53676

class InstanceTypeInfo < Struct.new(
  :instance_type,
  :current_generation,
  :free_tier_eligible,
  :supported_usage_classes,
  :supported_root_device_types,
  :supported_virtualization_types,
  :bare_metal,
  :hypervisor,
  :processor_info,
  :v_cpu_info,
  :memory_info,
  :instance_storage_supported,
  :instance_storage_info,
  :ebs_info,
  :network_info,
  :gpu_info,
  :fpga_info,
  :placement_group_info,
  :inference_accelerator_info,
  :hibernation_supported,
  :burstable_performance_supported,
  :dedicated_hosts_supported,
  :auto_recovery_supported,
  :supported_boot_modes,
  :nitro_enclaves_support,
  :nitro_tpm_support,
  :nitro_tpm_info,
  :media_accelerator_info,
  :neuron_info,
  :phc_support,
  :reboot_migration_support)
  SENSITIVE = []
  include Aws::Structure
end