Class: Aws::EC2::Types::Ipam

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

IPAM is a VPC feature that you can use to automate your IP address management workflows including assigning, tracking, troubleshooting, and auditing IP addresses across Amazon Web Services Regions and accounts throughout your Amazon Web Services Organization. For more information, see [What is IPAM?] in the *Amazon VPC IPAM User Guide*.

[1]: docs.aws.amazon.com/vpc/latest/ipam/what-is-it-ipam.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#default_resource_discovery_association_idString

The IPAM’s default resource discovery association ID.

Returns:

  • (String)


54053
54054
54055
54056
54057
54058
54059
54060
54061
54062
54063
54064
54065
54066
54067
54068
54069
54070
54071
54072
54073
54074
# File 'lib/aws-sdk-ec2/types.rb', line 54053

class Ipam < Struct.new(
  :owner_id,
  :ipam_id,
  :ipam_arn,
  :ipam_region,
  :public_default_scope_id,
  :private_default_scope_id,
  :scope_count,
  :description,
  :operating_regions,
  :state,
  :tags,
  :default_resource_discovery_id,
  :default_resource_discovery_association_id,
  :resource_discovery_association_count,
  :state_message,
  :tier,
  :enable_private_gua,
  :metered_account)
  SENSITIVE = []
  include Aws::Structure
end

#default_resource_discovery_idString

The IPAM’s default resource discovery ID.

Returns:

  • (String)


54053
54054
54055
54056
54057
54058
54059
54060
54061
54062
54063
54064
54065
54066
54067
54068
54069
54070
54071
54072
54073
54074
# File 'lib/aws-sdk-ec2/types.rb', line 54053

class Ipam < Struct.new(
  :owner_id,
  :ipam_id,
  :ipam_arn,
  :ipam_region,
  :public_default_scope_id,
  :private_default_scope_id,
  :scope_count,
  :description,
  :operating_regions,
  :state,
  :tags,
  :default_resource_discovery_id,
  :default_resource_discovery_association_id,
  :resource_discovery_association_count,
  :state_message,
  :tier,
  :enable_private_gua,
  :metered_account)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description for the IPAM.

Returns:

  • (String)


54053
54054
54055
54056
54057
54058
54059
54060
54061
54062
54063
54064
54065
54066
54067
54068
54069
54070
54071
54072
54073
54074
# File 'lib/aws-sdk-ec2/types.rb', line 54053

class Ipam < Struct.new(
  :owner_id,
  :ipam_id,
  :ipam_arn,
  :ipam_region,
  :public_default_scope_id,
  :private_default_scope_id,
  :scope_count,
  :description,
  :operating_regions,
  :state,
  :tags,
  :default_resource_discovery_id,
  :default_resource_discovery_association_id,
  :resource_discovery_association_count,
  :state_message,
  :tier,
  :enable_private_gua,
  :metered_account)
  SENSITIVE = []
  include Aws::Structure
end

#enable_private_guaBoolean

Enable this option to use your own GUA ranges as private IPv6 addresses. This option is disabled by default.

Returns:

  • (Boolean)


54053
54054
54055
54056
54057
54058
54059
54060
54061
54062
54063
54064
54065
54066
54067
54068
54069
54070
54071
54072
54073
54074
# File 'lib/aws-sdk-ec2/types.rb', line 54053

class Ipam < Struct.new(
  :owner_id,
  :ipam_id,
  :ipam_arn,
  :ipam_region,
  :public_default_scope_id,
  :private_default_scope_id,
  :scope_count,
  :description,
  :operating_regions,
  :state,
  :tags,
  :default_resource_discovery_id,
  :default_resource_discovery_association_id,
  :resource_discovery_association_count,
  :state_message,
  :tier,
  :enable_private_gua,
  :metered_account)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_arnString

The Amazon Resource Name (ARN) of the IPAM.

Returns:

  • (String)


54053
54054
54055
54056
54057
54058
54059
54060
54061
54062
54063
54064
54065
54066
54067
54068
54069
54070
54071
54072
54073
54074
# File 'lib/aws-sdk-ec2/types.rb', line 54053

class Ipam < Struct.new(
  :owner_id,
  :ipam_id,
  :ipam_arn,
  :ipam_region,
  :public_default_scope_id,
  :private_default_scope_id,
  :scope_count,
  :description,
  :operating_regions,
  :state,
  :tags,
  :default_resource_discovery_id,
  :default_resource_discovery_association_id,
  :resource_discovery_association_count,
  :state_message,
  :tier,
  :enable_private_gua,
  :metered_account)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_idString

The ID of the IPAM.

Returns:

  • (String)


54053
54054
54055
54056
54057
54058
54059
54060
54061
54062
54063
54064
54065
54066
54067
54068
54069
54070
54071
54072
54073
54074
# File 'lib/aws-sdk-ec2/types.rb', line 54053

class Ipam < Struct.new(
  :owner_id,
  :ipam_id,
  :ipam_arn,
  :ipam_region,
  :public_default_scope_id,
  :private_default_scope_id,
  :scope_count,
  :description,
  :operating_regions,
  :state,
  :tags,
  :default_resource_discovery_id,
  :default_resource_discovery_association_id,
  :resource_discovery_association_count,
  :state_message,
  :tier,
  :enable_private_gua,
  :metered_account)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_regionString

The Amazon Web Services Region of the IPAM.

Returns:

  • (String)


54053
54054
54055
54056
54057
54058
54059
54060
54061
54062
54063
54064
54065
54066
54067
54068
54069
54070
54071
54072
54073
54074
# File 'lib/aws-sdk-ec2/types.rb', line 54053

class Ipam < Struct.new(
  :owner_id,
  :ipam_id,
  :ipam_arn,
  :ipam_region,
  :public_default_scope_id,
  :private_default_scope_id,
  :scope_count,
  :description,
  :operating_regions,
  :state,
  :tags,
  :default_resource_discovery_id,
  :default_resource_discovery_association_id,
  :resource_discovery_association_count,
  :state_message,
  :tier,
  :enable_private_gua,
  :metered_account)
  SENSITIVE = []
  include Aws::Structure
end

#metered_accountString

A metered account is an Amazon Web Services account that is charged for active IP addresses managed in IPAM. For more information, see

Enable cost distribution][1

in the *Amazon VPC IPAM User Guide*.

Possible values:

  • ‘ipam-owner` (default): The Amazon Web Services account which owns the IPAM is charged for all active IP addresses managed in IPAM.

  • ‘resource-owner`: The Amazon Web Services account that owns the IP address is charged for the active IP address.

[1]: docs.aws.amazon.com/vpc/latest/ipam/ipam-enable-cost-distro.html

Returns:

  • (String)


54053
54054
54055
54056
54057
54058
54059
54060
54061
54062
54063
54064
54065
54066
54067
54068
54069
54070
54071
54072
54073
54074
# File 'lib/aws-sdk-ec2/types.rb', line 54053

class Ipam < Struct.new(
  :owner_id,
  :ipam_id,
  :ipam_arn,
  :ipam_region,
  :public_default_scope_id,
  :private_default_scope_id,
  :scope_count,
  :description,
  :operating_regions,
  :state,
  :tags,
  :default_resource_discovery_id,
  :default_resource_discovery_association_id,
  :resource_discovery_association_count,
  :state_message,
  :tier,
  :enable_private_gua,
  :metered_account)
  SENSITIVE = []
  include Aws::Structure
end

#operating_regionsArray<Types::IpamOperatingRegion>

The operating Regions for an IPAM. Operating Regions are Amazon Web Services Regions where the IPAM is allowed to manage IP address CIDRs. IPAM only discovers and monitors resources in the Amazon Web Services Regions you select as operating Regions.

For more information about operating Regions, see [Create an IPAM] in the *Amazon VPC IPAM User Guide*.

[1]: docs.aws.amazon.com/vpc/latest/ipam/create-ipam.html

Returns:



54053
54054
54055
54056
54057
54058
54059
54060
54061
54062
54063
54064
54065
54066
54067
54068
54069
54070
54071
54072
54073
54074
# File 'lib/aws-sdk-ec2/types.rb', line 54053

class Ipam < Struct.new(
  :owner_id,
  :ipam_id,
  :ipam_arn,
  :ipam_region,
  :public_default_scope_id,
  :private_default_scope_id,
  :scope_count,
  :description,
  :operating_regions,
  :state,
  :tags,
  :default_resource_discovery_id,
  :default_resource_discovery_association_id,
  :resource_discovery_association_count,
  :state_message,
  :tier,
  :enable_private_gua,
  :metered_account)
  SENSITIVE = []
  include Aws::Structure
end

#owner_idString

The Amazon Web Services account ID of the owner of the IPAM.

Returns:

  • (String)


54053
54054
54055
54056
54057
54058
54059
54060
54061
54062
54063
54064
54065
54066
54067
54068
54069
54070
54071
54072
54073
54074
# File 'lib/aws-sdk-ec2/types.rb', line 54053

class Ipam < Struct.new(
  :owner_id,
  :ipam_id,
  :ipam_arn,
  :ipam_region,
  :public_default_scope_id,
  :private_default_scope_id,
  :scope_count,
  :description,
  :operating_regions,
  :state,
  :tags,
  :default_resource_discovery_id,
  :default_resource_discovery_association_id,
  :resource_discovery_association_count,
  :state_message,
  :tier,
  :enable_private_gua,
  :metered_account)
  SENSITIVE = []
  include Aws::Structure
end

#private_default_scope_idString

The ID of the IPAM’s default private scope.

Returns:

  • (String)


54053
54054
54055
54056
54057
54058
54059
54060
54061
54062
54063
54064
54065
54066
54067
54068
54069
54070
54071
54072
54073
54074
# File 'lib/aws-sdk-ec2/types.rb', line 54053

class Ipam < Struct.new(
  :owner_id,
  :ipam_id,
  :ipam_arn,
  :ipam_region,
  :public_default_scope_id,
  :private_default_scope_id,
  :scope_count,
  :description,
  :operating_regions,
  :state,
  :tags,
  :default_resource_discovery_id,
  :default_resource_discovery_association_id,
  :resource_discovery_association_count,
  :state_message,
  :tier,
  :enable_private_gua,
  :metered_account)
  SENSITIVE = []
  include Aws::Structure
end

#public_default_scope_idString

The ID of the IPAM’s default public scope.

Returns:

  • (String)


54053
54054
54055
54056
54057
54058
54059
54060
54061
54062
54063
54064
54065
54066
54067
54068
54069
54070
54071
54072
54073
54074
# File 'lib/aws-sdk-ec2/types.rb', line 54053

class Ipam < Struct.new(
  :owner_id,
  :ipam_id,
  :ipam_arn,
  :ipam_region,
  :public_default_scope_id,
  :private_default_scope_id,
  :scope_count,
  :description,
  :operating_regions,
  :state,
  :tags,
  :default_resource_discovery_id,
  :default_resource_discovery_association_id,
  :resource_discovery_association_count,
  :state_message,
  :tier,
  :enable_private_gua,
  :metered_account)
  SENSITIVE = []
  include Aws::Structure
end

#resource_discovery_association_countInteger

The IPAM’s resource discovery association count.

Returns:

  • (Integer)


54053
54054
54055
54056
54057
54058
54059
54060
54061
54062
54063
54064
54065
54066
54067
54068
54069
54070
54071
54072
54073
54074
# File 'lib/aws-sdk-ec2/types.rb', line 54053

class Ipam < Struct.new(
  :owner_id,
  :ipam_id,
  :ipam_arn,
  :ipam_region,
  :public_default_scope_id,
  :private_default_scope_id,
  :scope_count,
  :description,
  :operating_regions,
  :state,
  :tags,
  :default_resource_discovery_id,
  :default_resource_discovery_association_id,
  :resource_discovery_association_count,
  :state_message,
  :tier,
  :enable_private_gua,
  :metered_account)
  SENSITIVE = []
  include Aws::Structure
end

#scope_countInteger

The number of scopes in the IPAM. The scope quota is 5. For more information on quotas, see [Quotas in IPAM] in the *Amazon VPC IPAM User Guide*.

[1]: docs.aws.amazon.com/vpc/latest/ipam/quotas-ipam.html

Returns:

  • (Integer)


54053
54054
54055
54056
54057
54058
54059
54060
54061
54062
54063
54064
54065
54066
54067
54068
54069
54070
54071
54072
54073
54074
# File 'lib/aws-sdk-ec2/types.rb', line 54053

class Ipam < Struct.new(
  :owner_id,
  :ipam_id,
  :ipam_arn,
  :ipam_region,
  :public_default_scope_id,
  :private_default_scope_id,
  :scope_count,
  :description,
  :operating_regions,
  :state,
  :tags,
  :default_resource_discovery_id,
  :default_resource_discovery_association_id,
  :resource_discovery_association_count,
  :state_message,
  :tier,
  :enable_private_gua,
  :metered_account)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of the IPAM.

Returns:

  • (String)


54053
54054
54055
54056
54057
54058
54059
54060
54061
54062
54063
54064
54065
54066
54067
54068
54069
54070
54071
54072
54073
54074
# File 'lib/aws-sdk-ec2/types.rb', line 54053

class Ipam < Struct.new(
  :owner_id,
  :ipam_id,
  :ipam_arn,
  :ipam_region,
  :public_default_scope_id,
  :private_default_scope_id,
  :scope_count,
  :description,
  :operating_regions,
  :state,
  :tags,
  :default_resource_discovery_id,
  :default_resource_discovery_association_id,
  :resource_discovery_association_count,
  :state_message,
  :tier,
  :enable_private_gua,
  :metered_account)
  SENSITIVE = []
  include Aws::Structure
end

#state_messageString

The state message.

Returns:

  • (String)


54053
54054
54055
54056
54057
54058
54059
54060
54061
54062
54063
54064
54065
54066
54067
54068
54069
54070
54071
54072
54073
54074
# File 'lib/aws-sdk-ec2/types.rb', line 54053

class Ipam < Struct.new(
  :owner_id,
  :ipam_id,
  :ipam_arn,
  :ipam_region,
  :public_default_scope_id,
  :private_default_scope_id,
  :scope_count,
  :description,
  :operating_regions,
  :state,
  :tags,
  :default_resource_discovery_id,
  :default_resource_discovery_association_id,
  :resource_discovery_association_count,
  :state_message,
  :tier,
  :enable_private_gua,
  :metered_account)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key ‘Owner` and the value `TeamA`, specify `tag:Owner` for the filter name and `TeamA` for the filter value.

Returns:



54053
54054
54055
54056
54057
54058
54059
54060
54061
54062
54063
54064
54065
54066
54067
54068
54069
54070
54071
54072
54073
54074
# File 'lib/aws-sdk-ec2/types.rb', line 54053

class Ipam < Struct.new(
  :owner_id,
  :ipam_id,
  :ipam_arn,
  :ipam_region,
  :public_default_scope_id,
  :private_default_scope_id,
  :scope_count,
  :description,
  :operating_regions,
  :state,
  :tags,
  :default_resource_discovery_id,
  :default_resource_discovery_association_id,
  :resource_discovery_association_count,
  :state_message,
  :tier,
  :enable_private_gua,
  :metered_account)
  SENSITIVE = []
  include Aws::Structure
end

#tierString

IPAM is offered in a Free Tier and an Advanced Tier. For more information about the features available in each tier and the costs associated with the tiers, see [Amazon VPC pricing &gt; IPAM tab].

[1]: aws.amazon.com/vpc/pricing/

Returns:

  • (String)


54053
54054
54055
54056
54057
54058
54059
54060
54061
54062
54063
54064
54065
54066
54067
54068
54069
54070
54071
54072
54073
54074
# File 'lib/aws-sdk-ec2/types.rb', line 54053

class Ipam < Struct.new(
  :owner_id,
  :ipam_id,
  :ipam_arn,
  :ipam_region,
  :public_default_scope_id,
  :private_default_scope_id,
  :scope_count,
  :description,
  :operating_regions,
  :state,
  :tags,
  :default_resource_discovery_id,
  :default_resource_discovery_association_id,
  :resource_discovery_association_count,
  :state_message,
  :tier,
  :enable_private_gua,
  :metered_account)
  SENSITIVE = []
  include Aws::Structure
end