Class: Aws::EC2::Types::IpamDiscoveredPublicAddress
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::IpamDiscoveredPublicAddress
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
A public IP Address discovered by IPAM.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#address ⇒ String
The IP address.
-
#address_allocation_id ⇒ String
The allocation ID of the resource the IP address is assigned to.
-
#address_owner_id ⇒ String
The ID of the owner of the resource the IP address is assigned to.
-
#address_region ⇒ String
The Region of the resource the IP address is assigned to.
-
#address_type ⇒ String
The IP address type.
-
#association_status ⇒ String
The association status.
-
#instance_id ⇒ String
The instance ID of the instance the assigned IP address is assigned to.
-
#ipam_resource_discovery_id ⇒ String
The resource discovery ID.
-
#network_border_group ⇒ String
The Availability Zone (AZ) or Local Zone (LZ) network border group that the resource that the IP address is assigned to is in.
-
#network_interface_description ⇒ String
The description of the network interface that IP address is assigned to.
-
#network_interface_id ⇒ String
The network interface ID of the resource with the assigned IP address.
-
#public_ipv_4_pool_id ⇒ String
The ID of the public IPv4 pool that the resource with the assigned IP address is from.
-
#sample_time ⇒ Time
The last successful resource discovery time.
-
#security_groups ⇒ Array<Types::IpamPublicAddressSecurityGroup>
Security groups associated with the resource that the IP address is assigned to.
-
#service ⇒ String
The Amazon Web Services service associated with the IP address.
-
#service_resource ⇒ String
The resource ARN or ID.
-
#subnet_id ⇒ String
The ID of the subnet that the resource with the assigned IP address is in.
-
#tags ⇒ Types::IpamPublicAddressTags
Tags associated with the IP address.
-
#vpc_id ⇒ String
The ID of the VPC that the resource with the assigned IP address is in.
Instance Attribute Details
#address ⇒ String
The IP address.
55222 55223 55224 55225 55226 55227 55228 55229 55230 55231 55232 55233 55234 55235 55236 55237 55238 55239 55240 55241 55242 55243 55244 |
# File 'lib/aws-sdk-ec2/types.rb', line 55222 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |
#address_allocation_id ⇒ String
The allocation ID of the resource the IP address is assigned to.
55222 55223 55224 55225 55226 55227 55228 55229 55230 55231 55232 55233 55234 55235 55236 55237 55238 55239 55240 55241 55242 55243 55244 |
# File 'lib/aws-sdk-ec2/types.rb', line 55222 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |
#address_owner_id ⇒ String
The ID of the owner of the resource the IP address is assigned to.
55222 55223 55224 55225 55226 55227 55228 55229 55230 55231 55232 55233 55234 55235 55236 55237 55238 55239 55240 55241 55242 55243 55244 |
# File 'lib/aws-sdk-ec2/types.rb', line 55222 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |
#address_region ⇒ String
The Region of the resource the IP address is assigned to.
55222 55223 55224 55225 55226 55227 55228 55229 55230 55231 55232 55233 55234 55235 55236 55237 55238 55239 55240 55241 55242 55243 55244 |
# File 'lib/aws-sdk-ec2/types.rb', line 55222 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |
#address_type ⇒ String
The IP address type.
55222 55223 55224 55225 55226 55227 55228 55229 55230 55231 55232 55233 55234 55235 55236 55237 55238 55239 55240 55241 55242 55243 55244 |
# File 'lib/aws-sdk-ec2/types.rb', line 55222 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |
#association_status ⇒ String
The association status.
55222 55223 55224 55225 55226 55227 55228 55229 55230 55231 55232 55233 55234 55235 55236 55237 55238 55239 55240 55241 55242 55243 55244 |
# File 'lib/aws-sdk-ec2/types.rb', line 55222 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The instance ID of the instance the assigned IP address is assigned to.
55222 55223 55224 55225 55226 55227 55228 55229 55230 55231 55232 55233 55234 55235 55236 55237 55238 55239 55240 55241 55242 55243 55244 |
# File 'lib/aws-sdk-ec2/types.rb', line 55222 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |
#ipam_resource_discovery_id ⇒ String
The resource discovery ID.
55222 55223 55224 55225 55226 55227 55228 55229 55230 55231 55232 55233 55234 55235 55236 55237 55238 55239 55240 55241 55242 55243 55244 |
# File 'lib/aws-sdk-ec2/types.rb', line 55222 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |
#network_border_group ⇒ String
The Availability Zone (AZ) or Local Zone (LZ) network border group that the resource that the IP address is assigned to is in. Defaults to an AZ network border group. For more information on available Local Zones, see Local Zone availability in the Amazon EC2 User Guide.
55222 55223 55224 55225 55226 55227 55228 55229 55230 55231 55232 55233 55234 55235 55236 55237 55238 55239 55240 55241 55242 55243 55244 |
# File 'lib/aws-sdk-ec2/types.rb', line 55222 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |
#network_interface_description ⇒ String
The description of the network interface that IP address is assigned to.
55222 55223 55224 55225 55226 55227 55228 55229 55230 55231 55232 55233 55234 55235 55236 55237 55238 55239 55240 55241 55242 55243 55244 |
# File 'lib/aws-sdk-ec2/types.rb', line 55222 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |
#network_interface_id ⇒ String
The network interface ID of the resource with the assigned IP address.
55222 55223 55224 55225 55226 55227 55228 55229 55230 55231 55232 55233 55234 55235 55236 55237 55238 55239 55240 55241 55242 55243 55244 |
# File 'lib/aws-sdk-ec2/types.rb', line 55222 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |
#public_ipv_4_pool_id ⇒ String
The ID of the public IPv4 pool that the resource with the assigned IP address is from.
55222 55223 55224 55225 55226 55227 55228 55229 55230 55231 55232 55233 55234 55235 55236 55237 55238 55239 55240 55241 55242 55243 55244 |
# File 'lib/aws-sdk-ec2/types.rb', line 55222 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |
#sample_time ⇒ Time
The last successful resource discovery time.
55222 55223 55224 55225 55226 55227 55228 55229 55230 55231 55232 55233 55234 55235 55236 55237 55238 55239 55240 55241 55242 55243 55244 |
# File 'lib/aws-sdk-ec2/types.rb', line 55222 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |
#security_groups ⇒ Array<Types::IpamPublicAddressSecurityGroup>
Security groups associated with the resource that the IP address is assigned to.
55222 55223 55224 55225 55226 55227 55228 55229 55230 55231 55232 55233 55234 55235 55236 55237 55238 55239 55240 55241 55242 55243 55244 |
# File 'lib/aws-sdk-ec2/types.rb', line 55222 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |
#service ⇒ String
The Amazon Web Services service associated with the IP address.
55222 55223 55224 55225 55226 55227 55228 55229 55230 55231 55232 55233 55234 55235 55236 55237 55238 55239 55240 55241 55242 55243 55244 |
# File 'lib/aws-sdk-ec2/types.rb', line 55222 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |
#service_resource ⇒ String
The resource ARN or ID.
55222 55223 55224 55225 55226 55227 55228 55229 55230 55231 55232 55233 55234 55235 55236 55237 55238 55239 55240 55241 55242 55243 55244 |
# File 'lib/aws-sdk-ec2/types.rb', line 55222 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |
#subnet_id ⇒ String
The ID of the subnet that the resource with the assigned IP address is in.
55222 55223 55224 55225 55226 55227 55228 55229 55230 55231 55232 55233 55234 55235 55236 55237 55238 55239 55240 55241 55242 55243 55244 |
# File 'lib/aws-sdk-ec2/types.rb', line 55222 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Types::IpamPublicAddressTags
Tags associated with the IP address.
55222 55223 55224 55225 55226 55227 55228 55229 55230 55231 55232 55233 55234 55235 55236 55237 55238 55239 55240 55241 55242 55243 55244 |
# File 'lib/aws-sdk-ec2/types.rb', line 55222 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC that the resource with the assigned IP address is in.
55222 55223 55224 55225 55226 55227 55228 55229 55230 55231 55232 55233 55234 55235 55236 55237 55238 55239 55240 55241 55242 55243 55244 |
# File 'lib/aws-sdk-ec2/types.rb', line 55222 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |