Class: Aws::EC2::Types::IpamDiscoveredPublicAddress

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

A public IP Address discovered by IPAM.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#addressString

The IP address.

Returns:

  • (String)


55028
55029
55030
55031
55032
55033
55034
55035
55036
55037
55038
55039
55040
55041
55042
55043
55044
55045
55046
55047
55048
55049
55050
# File 'lib/aws-sdk-ec2/types.rb', line 55028

class IpamDiscoveredPublicAddress < Struct.new(
  :ipam_resource_discovery_id,
  :address_region,
  :address,
  :address_owner_id,
  :address_allocation_id,
  :association_status,
  :address_type,
  :service,
  :service_resource,
  :vpc_id,
  :subnet_id,
  :public_ipv_4_pool_id,
  :network_interface_id,
  :network_interface_description,
  :instance_id,
  :tags,
  :network_border_group,
  :security_groups,
  :sample_time)
  SENSITIVE = []
  include Aws::Structure
end

#address_allocation_idString

The allocation ID of the resource the IP address is assigned to.

Returns:

  • (String)


55028
55029
55030
55031
55032
55033
55034
55035
55036
55037
55038
55039
55040
55041
55042
55043
55044
55045
55046
55047
55048
55049
55050
# File 'lib/aws-sdk-ec2/types.rb', line 55028

class IpamDiscoveredPublicAddress < Struct.new(
  :ipam_resource_discovery_id,
  :address_region,
  :address,
  :address_owner_id,
  :address_allocation_id,
  :association_status,
  :address_type,
  :service,
  :service_resource,
  :vpc_id,
  :subnet_id,
  :public_ipv_4_pool_id,
  :network_interface_id,
  :network_interface_description,
  :instance_id,
  :tags,
  :network_border_group,
  :security_groups,
  :sample_time)
  SENSITIVE = []
  include Aws::Structure
end

#address_owner_idString

The ID of the owner of the resource the IP address is assigned to.

Returns:

  • (String)


55028
55029
55030
55031
55032
55033
55034
55035
55036
55037
55038
55039
55040
55041
55042
55043
55044
55045
55046
55047
55048
55049
55050
# File 'lib/aws-sdk-ec2/types.rb', line 55028

class IpamDiscoveredPublicAddress < Struct.new(
  :ipam_resource_discovery_id,
  :address_region,
  :address,
  :address_owner_id,
  :address_allocation_id,
  :association_status,
  :address_type,
  :service,
  :service_resource,
  :vpc_id,
  :subnet_id,
  :public_ipv_4_pool_id,
  :network_interface_id,
  :network_interface_description,
  :instance_id,
  :tags,
  :network_border_group,
  :security_groups,
  :sample_time)
  SENSITIVE = []
  include Aws::Structure
end

#address_regionString

The Region of the resource the IP address is assigned to.

Returns:

  • (String)


55028
55029
55030
55031
55032
55033
55034
55035
55036
55037
55038
55039
55040
55041
55042
55043
55044
55045
55046
55047
55048
55049
55050
# File 'lib/aws-sdk-ec2/types.rb', line 55028

class IpamDiscoveredPublicAddress < Struct.new(
  :ipam_resource_discovery_id,
  :address_region,
  :address,
  :address_owner_id,
  :address_allocation_id,
  :association_status,
  :address_type,
  :service,
  :service_resource,
  :vpc_id,
  :subnet_id,
  :public_ipv_4_pool_id,
  :network_interface_id,
  :network_interface_description,
  :instance_id,
  :tags,
  :network_border_group,
  :security_groups,
  :sample_time)
  SENSITIVE = []
  include Aws::Structure
end

#address_typeString

The IP address type.

Returns:

  • (String)


55028
55029
55030
55031
55032
55033
55034
55035
55036
55037
55038
55039
55040
55041
55042
55043
55044
55045
55046
55047
55048
55049
55050
# File 'lib/aws-sdk-ec2/types.rb', line 55028

class IpamDiscoveredPublicAddress < Struct.new(
  :ipam_resource_discovery_id,
  :address_region,
  :address,
  :address_owner_id,
  :address_allocation_id,
  :association_status,
  :address_type,
  :service,
  :service_resource,
  :vpc_id,
  :subnet_id,
  :public_ipv_4_pool_id,
  :network_interface_id,
  :network_interface_description,
  :instance_id,
  :tags,
  :network_border_group,
  :security_groups,
  :sample_time)
  SENSITIVE = []
  include Aws::Structure
end

#association_statusString

The association status.

Returns:

  • (String)


55028
55029
55030
55031
55032
55033
55034
55035
55036
55037
55038
55039
55040
55041
55042
55043
55044
55045
55046
55047
55048
55049
55050
# File 'lib/aws-sdk-ec2/types.rb', line 55028

class IpamDiscoveredPublicAddress < Struct.new(
  :ipam_resource_discovery_id,
  :address_region,
  :address,
  :address_owner_id,
  :address_allocation_id,
  :association_status,
  :address_type,
  :service,
  :service_resource,
  :vpc_id,
  :subnet_id,
  :public_ipv_4_pool_id,
  :network_interface_id,
  :network_interface_description,
  :instance_id,
  :tags,
  :network_border_group,
  :security_groups,
  :sample_time)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The instance ID of the instance the assigned IP address is assigned to.

Returns:

  • (String)


55028
55029
55030
55031
55032
55033
55034
55035
55036
55037
55038
55039
55040
55041
55042
55043
55044
55045
55046
55047
55048
55049
55050
# File 'lib/aws-sdk-ec2/types.rb', line 55028

class IpamDiscoveredPublicAddress < Struct.new(
  :ipam_resource_discovery_id,
  :address_region,
  :address,
  :address_owner_id,
  :address_allocation_id,
  :association_status,
  :address_type,
  :service,
  :service_resource,
  :vpc_id,
  :subnet_id,
  :public_ipv_4_pool_id,
  :network_interface_id,
  :network_interface_description,
  :instance_id,
  :tags,
  :network_border_group,
  :security_groups,
  :sample_time)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_resource_discovery_idString

The resource discovery ID.

Returns:

  • (String)


55028
55029
55030
55031
55032
55033
55034
55035
55036
55037
55038
55039
55040
55041
55042
55043
55044
55045
55046
55047
55048
55049
55050
# File 'lib/aws-sdk-ec2/types.rb', line 55028

class IpamDiscoveredPublicAddress < Struct.new(
  :ipam_resource_discovery_id,
  :address_region,
  :address,
  :address_owner_id,
  :address_allocation_id,
  :association_status,
  :address_type,
  :service,
  :service_resource,
  :vpc_id,
  :subnet_id,
  :public_ipv_4_pool_id,
  :network_interface_id,
  :network_interface_description,
  :instance_id,
  :tags,
  :network_border_group,
  :security_groups,
  :sample_time)
  SENSITIVE = []
  include Aws::Structure
end

#network_border_groupString

The Availability Zone (AZ) or Local Zone (LZ) network border group that the resource that the IP address is assigned to is in. Defaults to an AZ network border group. For more information on available Local Zones, see [Local Zone availability] in the *Amazon EC2 User Guide*.

[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-byoip.html#byoip-zone-avail

Returns:

  • (String)


55028
55029
55030
55031
55032
55033
55034
55035
55036
55037
55038
55039
55040
55041
55042
55043
55044
55045
55046
55047
55048
55049
55050
# File 'lib/aws-sdk-ec2/types.rb', line 55028

class IpamDiscoveredPublicAddress < Struct.new(
  :ipam_resource_discovery_id,
  :address_region,
  :address,
  :address_owner_id,
  :address_allocation_id,
  :association_status,
  :address_type,
  :service,
  :service_resource,
  :vpc_id,
  :subnet_id,
  :public_ipv_4_pool_id,
  :network_interface_id,
  :network_interface_description,
  :instance_id,
  :tags,
  :network_border_group,
  :security_groups,
  :sample_time)
  SENSITIVE = []
  include Aws::Structure
end

#network_interface_descriptionString

The description of the network interface that IP address is assigned to.

Returns:

  • (String)


55028
55029
55030
55031
55032
55033
55034
55035
55036
55037
55038
55039
55040
55041
55042
55043
55044
55045
55046
55047
55048
55049
55050
# File 'lib/aws-sdk-ec2/types.rb', line 55028

class IpamDiscoveredPublicAddress < Struct.new(
  :ipam_resource_discovery_id,
  :address_region,
  :address,
  :address_owner_id,
  :address_allocation_id,
  :association_status,
  :address_type,
  :service,
  :service_resource,
  :vpc_id,
  :subnet_id,
  :public_ipv_4_pool_id,
  :network_interface_id,
  :network_interface_description,
  :instance_id,
  :tags,
  :network_border_group,
  :security_groups,
  :sample_time)
  SENSITIVE = []
  include Aws::Structure
end

#network_interface_idString

The network interface ID of the resource with the assigned IP address.

Returns:

  • (String)


55028
55029
55030
55031
55032
55033
55034
55035
55036
55037
55038
55039
55040
55041
55042
55043
55044
55045
55046
55047
55048
55049
55050
# File 'lib/aws-sdk-ec2/types.rb', line 55028

class IpamDiscoveredPublicAddress < Struct.new(
  :ipam_resource_discovery_id,
  :address_region,
  :address,
  :address_owner_id,
  :address_allocation_id,
  :association_status,
  :address_type,
  :service,
  :service_resource,
  :vpc_id,
  :subnet_id,
  :public_ipv_4_pool_id,
  :network_interface_id,
  :network_interface_description,
  :instance_id,
  :tags,
  :network_border_group,
  :security_groups,
  :sample_time)
  SENSITIVE = []
  include Aws::Structure
end

#public_ipv_4_pool_idString

The ID of the public IPv4 pool that the resource with the assigned IP address is from.

Returns:

  • (String)


55028
55029
55030
55031
55032
55033
55034
55035
55036
55037
55038
55039
55040
55041
55042
55043
55044
55045
55046
55047
55048
55049
55050
# File 'lib/aws-sdk-ec2/types.rb', line 55028

class IpamDiscoveredPublicAddress < Struct.new(
  :ipam_resource_discovery_id,
  :address_region,
  :address,
  :address_owner_id,
  :address_allocation_id,
  :association_status,
  :address_type,
  :service,
  :service_resource,
  :vpc_id,
  :subnet_id,
  :public_ipv_4_pool_id,
  :network_interface_id,
  :network_interface_description,
  :instance_id,
  :tags,
  :network_border_group,
  :security_groups,
  :sample_time)
  SENSITIVE = []
  include Aws::Structure
end

#sample_timeTime

The last successful resource discovery time.

Returns:

  • (Time)


55028
55029
55030
55031
55032
55033
55034
55035
55036
55037
55038
55039
55040
55041
55042
55043
55044
55045
55046
55047
55048
55049
55050
# File 'lib/aws-sdk-ec2/types.rb', line 55028

class IpamDiscoveredPublicAddress < Struct.new(
  :ipam_resource_discovery_id,
  :address_region,
  :address,
  :address_owner_id,
  :address_allocation_id,
  :association_status,
  :address_type,
  :service,
  :service_resource,
  :vpc_id,
  :subnet_id,
  :public_ipv_4_pool_id,
  :network_interface_id,
  :network_interface_description,
  :instance_id,
  :tags,
  :network_border_group,
  :security_groups,
  :sample_time)
  SENSITIVE = []
  include Aws::Structure
end

#security_groupsArray<Types::IpamPublicAddressSecurityGroup>

Security groups associated with the resource that the IP address is assigned to.



55028
55029
55030
55031
55032
55033
55034
55035
55036
55037
55038
55039
55040
55041
55042
55043
55044
55045
55046
55047
55048
55049
55050
# File 'lib/aws-sdk-ec2/types.rb', line 55028

class IpamDiscoveredPublicAddress < Struct.new(
  :ipam_resource_discovery_id,
  :address_region,
  :address,
  :address_owner_id,
  :address_allocation_id,
  :association_status,
  :address_type,
  :service,
  :service_resource,
  :vpc_id,
  :subnet_id,
  :public_ipv_4_pool_id,
  :network_interface_id,
  :network_interface_description,
  :instance_id,
  :tags,
  :network_border_group,
  :security_groups,
  :sample_time)
  SENSITIVE = []
  include Aws::Structure
end

#serviceString

The Amazon Web Services service associated with the IP address.

Returns:

  • (String)


55028
55029
55030
55031
55032
55033
55034
55035
55036
55037
55038
55039
55040
55041
55042
55043
55044
55045
55046
55047
55048
55049
55050
# File 'lib/aws-sdk-ec2/types.rb', line 55028

class IpamDiscoveredPublicAddress < Struct.new(
  :ipam_resource_discovery_id,
  :address_region,
  :address,
  :address_owner_id,
  :address_allocation_id,
  :association_status,
  :address_type,
  :service,
  :service_resource,
  :vpc_id,
  :subnet_id,
  :public_ipv_4_pool_id,
  :network_interface_id,
  :network_interface_description,
  :instance_id,
  :tags,
  :network_border_group,
  :security_groups,
  :sample_time)
  SENSITIVE = []
  include Aws::Structure
end

#service_resourceString

The resource ARN or ID.

Returns:

  • (String)


55028
55029
55030
55031
55032
55033
55034
55035
55036
55037
55038
55039
55040
55041
55042
55043
55044
55045
55046
55047
55048
55049
55050
# File 'lib/aws-sdk-ec2/types.rb', line 55028

class IpamDiscoveredPublicAddress < Struct.new(
  :ipam_resource_discovery_id,
  :address_region,
  :address,
  :address_owner_id,
  :address_allocation_id,
  :association_status,
  :address_type,
  :service,
  :service_resource,
  :vpc_id,
  :subnet_id,
  :public_ipv_4_pool_id,
  :network_interface_id,
  :network_interface_description,
  :instance_id,
  :tags,
  :network_border_group,
  :security_groups,
  :sample_time)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idString

The ID of the subnet that the resource with the assigned IP address is in.

Returns:

  • (String)


55028
55029
55030
55031
55032
55033
55034
55035
55036
55037
55038
55039
55040
55041
55042
55043
55044
55045
55046
55047
55048
55049
55050
# File 'lib/aws-sdk-ec2/types.rb', line 55028

class IpamDiscoveredPublicAddress < Struct.new(
  :ipam_resource_discovery_id,
  :address_region,
  :address,
  :address_owner_id,
  :address_allocation_id,
  :association_status,
  :address_type,
  :service,
  :service_resource,
  :vpc_id,
  :subnet_id,
  :public_ipv_4_pool_id,
  :network_interface_id,
  :network_interface_description,
  :instance_id,
  :tags,
  :network_border_group,
  :security_groups,
  :sample_time)
  SENSITIVE = []
  include Aws::Structure
end

#tagsTypes::IpamPublicAddressTags

Tags associated with the IP address.



55028
55029
55030
55031
55032
55033
55034
55035
55036
55037
55038
55039
55040
55041
55042
55043
55044
55045
55046
55047
55048
55049
55050
# File 'lib/aws-sdk-ec2/types.rb', line 55028

class IpamDiscoveredPublicAddress < Struct.new(
  :ipam_resource_discovery_id,
  :address_region,
  :address,
  :address_owner_id,
  :address_allocation_id,
  :association_status,
  :address_type,
  :service,
  :service_resource,
  :vpc_id,
  :subnet_id,
  :public_ipv_4_pool_id,
  :network_interface_id,
  :network_interface_description,
  :instance_id,
  :tags,
  :network_border_group,
  :security_groups,
  :sample_time)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC that the resource with the assigned IP address is in.

Returns:

  • (String)


55028
55029
55030
55031
55032
55033
55034
55035
55036
55037
55038
55039
55040
55041
55042
55043
55044
55045
55046
55047
55048
55049
55050
# File 'lib/aws-sdk-ec2/types.rb', line 55028

class IpamDiscoveredPublicAddress < Struct.new(
  :ipam_resource_discovery_id,
  :address_region,
  :address,
  :address_owner_id,
  :address_allocation_id,
  :association_status,
  :address_type,
  :service,
  :service_resource,
  :vpc_id,
  :subnet_id,
  :public_ipv_4_pool_id,
  :network_interface_id,
  :network_interface_description,
  :instance_id,
  :tags,
  :network_border_group,
  :security_groups,
  :sample_time)
  SENSITIVE = []
  include Aws::Structure
end