Class: Aws::EC2::Types::IpamDiscoveredPublicAddress
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::IpamDiscoveredPublicAddress
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
A public IP Address discovered by IPAM.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#address ⇒ String
The IP address.
-
#address_allocation_id ⇒ String
The allocation ID of the resource the IP address is assigned to.
-
#address_owner_id ⇒ String
The ID of the owner of the resource the IP address is assigned to.
-
#address_region ⇒ String
The Region of the resource the IP address is assigned to.
-
#address_type ⇒ String
The IP address type.
-
#association_status ⇒ String
The association status.
-
#instance_id ⇒ String
The instance ID of the instance the assigned IP address is assigned to.
-
#ipam_resource_discovery_id ⇒ String
The resource discovery ID.
-
#network_border_group ⇒ String
The Availability Zone (AZ) or Local Zone (LZ) network border group that the resource that the IP address is assigned to is in.
-
#network_interface_description ⇒ String
The description of the network interface that IP address is assigned to.
-
#network_interface_id ⇒ String
The network interface ID of the resource with the assigned IP address.
-
#public_ipv_4_pool_id ⇒ String
The ID of the public IPv4 pool that the resource with the assigned IP address is from.
-
#sample_time ⇒ Time
The last successful resource discovery time.
-
#security_groups ⇒ Array<Types::IpamPublicAddressSecurityGroup>
Security groups associated with the resource that the IP address is assigned to.
-
#service ⇒ String
The Amazon Web Services service associated with the IP address.
-
#service_resource ⇒ String
The resource ARN or ID.
-
#subnet_id ⇒ String
The ID of the subnet that the resource with the assigned IP address is in.
-
#tags ⇒ Types::IpamPublicAddressTags
Tags associated with the IP address.
-
#vpc_id ⇒ String
The ID of the VPC that the resource with the assigned IP address is in.
Instance Attribute Details
#address ⇒ String
The IP address.
53209 53210 53211 53212 53213 53214 53215 53216 53217 53218 53219 53220 53221 53222 53223 53224 53225 53226 53227 53228 53229 53230 53231 |
# File 'lib/aws-sdk-ec2/types.rb', line 53209 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |
#address_allocation_id ⇒ String
The allocation ID of the resource the IP address is assigned to.
53209 53210 53211 53212 53213 53214 53215 53216 53217 53218 53219 53220 53221 53222 53223 53224 53225 53226 53227 53228 53229 53230 53231 |
# File 'lib/aws-sdk-ec2/types.rb', line 53209 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |
#address_owner_id ⇒ String
The ID of the owner of the resource the IP address is assigned to.
53209 53210 53211 53212 53213 53214 53215 53216 53217 53218 53219 53220 53221 53222 53223 53224 53225 53226 53227 53228 53229 53230 53231 |
# File 'lib/aws-sdk-ec2/types.rb', line 53209 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |
#address_region ⇒ String
The Region of the resource the IP address is assigned to.
53209 53210 53211 53212 53213 53214 53215 53216 53217 53218 53219 53220 53221 53222 53223 53224 53225 53226 53227 53228 53229 53230 53231 |
# File 'lib/aws-sdk-ec2/types.rb', line 53209 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |
#address_type ⇒ String
The IP address type.
53209 53210 53211 53212 53213 53214 53215 53216 53217 53218 53219 53220 53221 53222 53223 53224 53225 53226 53227 53228 53229 53230 53231 |
# File 'lib/aws-sdk-ec2/types.rb', line 53209 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |
#association_status ⇒ String
The association status.
53209 53210 53211 53212 53213 53214 53215 53216 53217 53218 53219 53220 53221 53222 53223 53224 53225 53226 53227 53228 53229 53230 53231 |
# File 'lib/aws-sdk-ec2/types.rb', line 53209 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The instance ID of the instance the assigned IP address is assigned to.
53209 53210 53211 53212 53213 53214 53215 53216 53217 53218 53219 53220 53221 53222 53223 53224 53225 53226 53227 53228 53229 53230 53231 |
# File 'lib/aws-sdk-ec2/types.rb', line 53209 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |
#ipam_resource_discovery_id ⇒ String
The resource discovery ID.
53209 53210 53211 53212 53213 53214 53215 53216 53217 53218 53219 53220 53221 53222 53223 53224 53225 53226 53227 53228 53229 53230 53231 |
# File 'lib/aws-sdk-ec2/types.rb', line 53209 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |
#network_border_group ⇒ String
The Availability Zone (AZ) or Local Zone (LZ) network border group that the resource that the IP address is assigned to is in. Defaults to an AZ network border group. For more information on available Local Zones, see [Local Zone availability] in the *Amazon EC2 User Guide*.
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-byoip.html#byoip-zone-avail
53209 53210 53211 53212 53213 53214 53215 53216 53217 53218 53219 53220 53221 53222 53223 53224 53225 53226 53227 53228 53229 53230 53231 |
# File 'lib/aws-sdk-ec2/types.rb', line 53209 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |
#network_interface_description ⇒ String
The description of the network interface that IP address is assigned to.
53209 53210 53211 53212 53213 53214 53215 53216 53217 53218 53219 53220 53221 53222 53223 53224 53225 53226 53227 53228 53229 53230 53231 |
# File 'lib/aws-sdk-ec2/types.rb', line 53209 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |
#network_interface_id ⇒ String
The network interface ID of the resource with the assigned IP address.
53209 53210 53211 53212 53213 53214 53215 53216 53217 53218 53219 53220 53221 53222 53223 53224 53225 53226 53227 53228 53229 53230 53231 |
# File 'lib/aws-sdk-ec2/types.rb', line 53209 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |
#public_ipv_4_pool_id ⇒ String
The ID of the public IPv4 pool that the resource with the assigned IP address is from.
53209 53210 53211 53212 53213 53214 53215 53216 53217 53218 53219 53220 53221 53222 53223 53224 53225 53226 53227 53228 53229 53230 53231 |
# File 'lib/aws-sdk-ec2/types.rb', line 53209 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |
#sample_time ⇒ Time
The last successful resource discovery time.
53209 53210 53211 53212 53213 53214 53215 53216 53217 53218 53219 53220 53221 53222 53223 53224 53225 53226 53227 53228 53229 53230 53231 |
# File 'lib/aws-sdk-ec2/types.rb', line 53209 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |
#security_groups ⇒ Array<Types::IpamPublicAddressSecurityGroup>
Security groups associated with the resource that the IP address is assigned to.
53209 53210 53211 53212 53213 53214 53215 53216 53217 53218 53219 53220 53221 53222 53223 53224 53225 53226 53227 53228 53229 53230 53231 |
# File 'lib/aws-sdk-ec2/types.rb', line 53209 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |
#service ⇒ String
The Amazon Web Services service associated with the IP address.
53209 53210 53211 53212 53213 53214 53215 53216 53217 53218 53219 53220 53221 53222 53223 53224 53225 53226 53227 53228 53229 53230 53231 |
# File 'lib/aws-sdk-ec2/types.rb', line 53209 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |
#service_resource ⇒ String
The resource ARN or ID.
53209 53210 53211 53212 53213 53214 53215 53216 53217 53218 53219 53220 53221 53222 53223 53224 53225 53226 53227 53228 53229 53230 53231 |
# File 'lib/aws-sdk-ec2/types.rb', line 53209 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |
#subnet_id ⇒ String
The ID of the subnet that the resource with the assigned IP address is in.
53209 53210 53211 53212 53213 53214 53215 53216 53217 53218 53219 53220 53221 53222 53223 53224 53225 53226 53227 53228 53229 53230 53231 |
# File 'lib/aws-sdk-ec2/types.rb', line 53209 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Types::IpamPublicAddressTags
Tags associated with the IP address.
53209 53210 53211 53212 53213 53214 53215 53216 53217 53218 53219 53220 53221 53222 53223 53224 53225 53226 53227 53228 53229 53230 53231 |
# File 'lib/aws-sdk-ec2/types.rb', line 53209 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC that the resource with the assigned IP address is in.
53209 53210 53211 53212 53213 53214 53215 53216 53217 53218 53219 53220 53221 53222 53223 53224 53225 53226 53227 53228 53229 53230 53231 |
# File 'lib/aws-sdk-ec2/types.rb', line 53209 class IpamDiscoveredPublicAddress < Struct.new( :ipam_resource_discovery_id, :address_region, :address, :address_owner_id, :address_allocation_id, :association_status, :address_type, :service, :service_resource, :vpc_id, :subnet_id, :public_ipv_4_pool_id, :network_interface_id, :network_interface_description, :instance_id, :tags, :network_border_group, :security_groups, :sample_time) SENSITIVE = [] include Aws::Structure end |