Class: Aws::EC2::Types::IpamDiscoveredResourceCidr

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

An IPAM discovered resource CIDR. A discovered resource is a resource CIDR monitored under a resource discovery. The following resources can be discovered: VPCs, Public IPv4 pools, VPC subnets, and Elastic IP addresses. The discovered resource CIDR is the IP address range in CIDR notation that is associated with the resource.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_zone_idString

The Availability Zone ID.

Returns:

  • (String)


55033
55034
55035
55036
55037
55038
55039
55040
55041
55042
55043
55044
55045
55046
55047
55048
55049
55050
# File 'lib/aws-sdk-ec2/types.rb', line 55033

class IpamDiscoveredResourceCidr < Struct.new(
  :ipam_resource_discovery_id,
  :resource_region,
  :resource_id,
  :resource_owner_id,
  :resource_cidr,
  :ip_source,
  :resource_type,
  :resource_tags,
  :ip_usage,
  :vpc_id,
  :subnet_id,
  :network_interface_attachment_status,
  :sample_time,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#ip_sourceString

The source that allocated the IP address space. ‘byoip` or `amazon` indicates public IP address space allocated by Amazon or space that you have allocated with Bring your own IP (BYOIP). `none` indicates private space.

Returns:

  • (String)


55033
55034
55035
55036
55037
55038
55039
55040
55041
55042
55043
55044
55045
55046
55047
55048
55049
55050
# File 'lib/aws-sdk-ec2/types.rb', line 55033

class IpamDiscoveredResourceCidr < Struct.new(
  :ipam_resource_discovery_id,
  :resource_region,
  :resource_id,
  :resource_owner_id,
  :resource_cidr,
  :ip_source,
  :resource_type,
  :resource_tags,
  :ip_usage,
  :vpc_id,
  :subnet_id,
  :network_interface_attachment_status,
  :sample_time,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#ip_usageFloat

The percentage of IP address space in use. To convert the decimal to a percentage, multiply the decimal by 100. Note the following:

  • For resources that are VPCs, this is the percentage of IP address space in the VPC that’s taken up by subnet CIDRs.

  • For resources that are subnets, if the subnet has an IPv4 CIDR provisioned to it, this is the percentage of IPv4 address space in the subnet that’s in use. If the subnet has an IPv6 CIDR provisioned to it, the percentage of IPv6 address space in use is not represented. The percentage of IPv6 address space in use cannot currently be calculated.

  • For resources that are public IPv4 pools, this is the percentage of IP address space in the pool that’s been allocated to Elastic IP addresses (EIPs).

Returns:

  • (Float)


55033
55034
55035
55036
55037
55038
55039
55040
55041
55042
55043
55044
55045
55046
55047
55048
55049
55050
# File 'lib/aws-sdk-ec2/types.rb', line 55033

class IpamDiscoveredResourceCidr < Struct.new(
  :ipam_resource_discovery_id,
  :resource_region,
  :resource_id,
  :resource_owner_id,
  :resource_cidr,
  :ip_source,
  :resource_type,
  :resource_tags,
  :ip_usage,
  :vpc_id,
  :subnet_id,
  :network_interface_attachment_status,
  :sample_time,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_resource_discovery_idString

The resource discovery ID.

Returns:

  • (String)


55033
55034
55035
55036
55037
55038
55039
55040
55041
55042
55043
55044
55045
55046
55047
55048
55049
55050
# File 'lib/aws-sdk-ec2/types.rb', line 55033

class IpamDiscoveredResourceCidr < Struct.new(
  :ipam_resource_discovery_id,
  :resource_region,
  :resource_id,
  :resource_owner_id,
  :resource_cidr,
  :ip_source,
  :resource_type,
  :resource_tags,
  :ip_usage,
  :vpc_id,
  :subnet_id,
  :network_interface_attachment_status,
  :sample_time,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#network_interface_attachment_statusString

For elastic network interfaces, this is the status of whether or not the elastic network interface is attached.

Returns:

  • (String)


55033
55034
55035
55036
55037
55038
55039
55040
55041
55042
55043
55044
55045
55046
55047
55048
55049
55050
# File 'lib/aws-sdk-ec2/types.rb', line 55033

class IpamDiscoveredResourceCidr < Struct.new(
  :ipam_resource_discovery_id,
  :resource_region,
  :resource_id,
  :resource_owner_id,
  :resource_cidr,
  :ip_source,
  :resource_type,
  :resource_tags,
  :ip_usage,
  :vpc_id,
  :subnet_id,
  :network_interface_attachment_status,
  :sample_time,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#resource_cidrString

The resource CIDR.

Returns:

  • (String)


55033
55034
55035
55036
55037
55038
55039
55040
55041
55042
55043
55044
55045
55046
55047
55048
55049
55050
# File 'lib/aws-sdk-ec2/types.rb', line 55033

class IpamDiscoveredResourceCidr < Struct.new(
  :ipam_resource_discovery_id,
  :resource_region,
  :resource_id,
  :resource_owner_id,
  :resource_cidr,
  :ip_source,
  :resource_type,
  :resource_tags,
  :ip_usage,
  :vpc_id,
  :subnet_id,
  :network_interface_attachment_status,
  :sample_time,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#resource_idString

The resource ID.

Returns:

  • (String)


55033
55034
55035
55036
55037
55038
55039
55040
55041
55042
55043
55044
55045
55046
55047
55048
55049
55050
# File 'lib/aws-sdk-ec2/types.rb', line 55033

class IpamDiscoveredResourceCidr < Struct.new(
  :ipam_resource_discovery_id,
  :resource_region,
  :resource_id,
  :resource_owner_id,
  :resource_cidr,
  :ip_source,
  :resource_type,
  :resource_tags,
  :ip_usage,
  :vpc_id,
  :subnet_id,
  :network_interface_attachment_status,
  :sample_time,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#resource_owner_idString

The resource owner ID.

Returns:

  • (String)


55033
55034
55035
55036
55037
55038
55039
55040
55041
55042
55043
55044
55045
55046
55047
55048
55049
55050
# File 'lib/aws-sdk-ec2/types.rb', line 55033

class IpamDiscoveredResourceCidr < Struct.new(
  :ipam_resource_discovery_id,
  :resource_region,
  :resource_id,
  :resource_owner_id,
  :resource_cidr,
  :ip_source,
  :resource_type,
  :resource_tags,
  :ip_usage,
  :vpc_id,
  :subnet_id,
  :network_interface_attachment_status,
  :sample_time,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#resource_regionString

The resource Region.

Returns:

  • (String)


55033
55034
55035
55036
55037
55038
55039
55040
55041
55042
55043
55044
55045
55046
55047
55048
55049
55050
# File 'lib/aws-sdk-ec2/types.rb', line 55033

class IpamDiscoveredResourceCidr < Struct.new(
  :ipam_resource_discovery_id,
  :resource_region,
  :resource_id,
  :resource_owner_id,
  :resource_cidr,
  :ip_source,
  :resource_type,
  :resource_tags,
  :ip_usage,
  :vpc_id,
  :subnet_id,
  :network_interface_attachment_status,
  :sample_time,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#resource_tagsArray<Types::IpamResourceTag>

The resource tags.

Returns:



55033
55034
55035
55036
55037
55038
55039
55040
55041
55042
55043
55044
55045
55046
55047
55048
55049
55050
# File 'lib/aws-sdk-ec2/types.rb', line 55033

class IpamDiscoveredResourceCidr < Struct.new(
  :ipam_resource_discovery_id,
  :resource_region,
  :resource_id,
  :resource_owner_id,
  :resource_cidr,
  :ip_source,
  :resource_type,
  :resource_tags,
  :ip_usage,
  :vpc_id,
  :subnet_id,
  :network_interface_attachment_status,
  :sample_time,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The resource type.

Returns:

  • (String)


55033
55034
55035
55036
55037
55038
55039
55040
55041
55042
55043
55044
55045
55046
55047
55048
55049
55050
# File 'lib/aws-sdk-ec2/types.rb', line 55033

class IpamDiscoveredResourceCidr < Struct.new(
  :ipam_resource_discovery_id,
  :resource_region,
  :resource_id,
  :resource_owner_id,
  :resource_cidr,
  :ip_source,
  :resource_type,
  :resource_tags,
  :ip_usage,
  :vpc_id,
  :subnet_id,
  :network_interface_attachment_status,
  :sample_time,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#sample_timeTime

The last successful resource discovery time.

Returns:

  • (Time)


55033
55034
55035
55036
55037
55038
55039
55040
55041
55042
55043
55044
55045
55046
55047
55048
55049
55050
# File 'lib/aws-sdk-ec2/types.rb', line 55033

class IpamDiscoveredResourceCidr < Struct.new(
  :ipam_resource_discovery_id,
  :resource_region,
  :resource_id,
  :resource_owner_id,
  :resource_cidr,
  :ip_source,
  :resource_type,
  :resource_tags,
  :ip_usage,
  :vpc_id,
  :subnet_id,
  :network_interface_attachment_status,
  :sample_time,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idString

The subnet ID.

Returns:

  • (String)


55033
55034
55035
55036
55037
55038
55039
55040
55041
55042
55043
55044
55045
55046
55047
55048
55049
55050
# File 'lib/aws-sdk-ec2/types.rb', line 55033

class IpamDiscoveredResourceCidr < Struct.new(
  :ipam_resource_discovery_id,
  :resource_region,
  :resource_id,
  :resource_owner_id,
  :resource_cidr,
  :ip_source,
  :resource_type,
  :resource_tags,
  :ip_usage,
  :vpc_id,
  :subnet_id,
  :network_interface_attachment_status,
  :sample_time,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The VPC ID.

Returns:

  • (String)


55033
55034
55035
55036
55037
55038
55039
55040
55041
55042
55043
55044
55045
55046
55047
55048
55049
55050
# File 'lib/aws-sdk-ec2/types.rb', line 55033

class IpamDiscoveredResourceCidr < Struct.new(
  :ipam_resource_discovery_id,
  :resource_region,
  :resource_id,
  :resource_owner_id,
  :resource_cidr,
  :ip_source,
  :resource_type,
  :resource_tags,
  :ip_usage,
  :vpc_id,
  :subnet_id,
  :network_interface_attachment_status,
  :sample_time,
  :availability_zone_id)
  SENSITIVE = []
  include Aws::Structure
end