Class: Aws::EC2::Types::IpamDiscoveredRoute

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains information about a BGP route discovered by IPAM resource discovery.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

The advertisement type of the route. Possible values:

  • regional - The IP address is advertised from a single location (regional services such as Amazon EC2).

  • global - The IP address is advertised from multiple global locations simultaneously (global services such as Amazon CloudFront).

Returns:

  • (String)


57813
57814
57815
57816
57817
57818
57819
57820
57821
57822
57823
57824
57825
57826
57827
# File 'lib/aws-sdk-ec2/types.rb', line 57813

class IpamDiscoveredRoute < Struct.new(
  :ipam_resource_discovery_id,
  :resource_region,
  :resource_owner_id,
  :cidr,
  :asn,
  :state,
  :advertisement_type,
  :network_border_group,
  :pool_id,
  :ipam_pool_id,
  :sample_time)
  SENSITIVE = []
  include Aws::Structure
end

#asnString

The Autonomous System Number (ASN) that originates the route.

Returns:

  • (String)


57813
57814
57815
57816
57817
57818
57819
57820
57821
57822
57823
57824
57825
57826
57827
# File 'lib/aws-sdk-ec2/types.rb', line 57813

class IpamDiscoveredRoute < Struct.new(
  :ipam_resource_discovery_id,
  :resource_region,
  :resource_owner_id,
  :cidr,
  :asn,
  :state,
  :advertisement_type,
  :network_border_group,
  :pool_id,
  :ipam_pool_id,
  :sample_time)
  SENSITIVE = []
  include Aws::Structure
end

#cidrString

The IP address prefix of the discovered route in CIDR notation.

Returns:

  • (String)


57813
57814
57815
57816
57817
57818
57819
57820
57821
57822
57823
57824
57825
57826
57827
# File 'lib/aws-sdk-ec2/types.rb', line 57813

class IpamDiscoveredRoute < Struct.new(
  :ipam_resource_discovery_id,
  :resource_region,
  :resource_owner_id,
  :cidr,
  :asn,
  :state,
  :advertisement_type,
  :network_border_group,
  :pool_id,
  :ipam_pool_id,
  :sample_time)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_pool_idString

The ID of the IPAM pool associated with the route.

Returns:

  • (String)


57813
57814
57815
57816
57817
57818
57819
57820
57821
57822
57823
57824
57825
57826
57827
# File 'lib/aws-sdk-ec2/types.rb', line 57813

class IpamDiscoveredRoute < Struct.new(
  :ipam_resource_discovery_id,
  :resource_region,
  :resource_owner_id,
  :cidr,
  :asn,
  :state,
  :advertisement_type,
  :network_border_group,
  :pool_id,
  :ipam_pool_id,
  :sample_time)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_resource_discovery_idString

The ID of the IPAM resource discovery that discovered the route.

Returns:

  • (String)


57813
57814
57815
57816
57817
57818
57819
57820
57821
57822
57823
57824
57825
57826
57827
# File 'lib/aws-sdk-ec2/types.rb', line 57813

class IpamDiscoveredRoute < Struct.new(
  :ipam_resource_discovery_id,
  :resource_region,
  :resource_owner_id,
  :cidr,
  :asn,
  :state,
  :advertisement_type,
  :network_border_group,
  :pool_id,
  :ipam_pool_id,
  :sample_time)
  SENSITIVE = []
  include Aws::Structure
end

#network_border_groupString

The network border group for the route.

Returns:

  • (String)


57813
57814
57815
57816
57817
57818
57819
57820
57821
57822
57823
57824
57825
57826
57827
# File 'lib/aws-sdk-ec2/types.rb', line 57813

class IpamDiscoveredRoute < Struct.new(
  :ipam_resource_discovery_id,
  :resource_region,
  :resource_owner_id,
  :cidr,
  :asn,
  :state,
  :advertisement_type,
  :network_border_group,
  :pool_id,
  :ipam_pool_id,
  :sample_time)
  SENSITIVE = []
  include Aws::Structure
end

#pool_idString

The ID of the BYOIP pool associated with the route.

Returns:

  • (String)


57813
57814
57815
57816
57817
57818
57819
57820
57821
57822
57823
57824
57825
57826
57827
# File 'lib/aws-sdk-ec2/types.rb', line 57813

class IpamDiscoveredRoute < Struct.new(
  :ipam_resource_discovery_id,
  :resource_region,
  :resource_owner_id,
  :cidr,
  :asn,
  :state,
  :advertisement_type,
  :network_border_group,
  :pool_id,
  :ipam_pool_id,
  :sample_time)
  SENSITIVE = []
  include Aws::Structure
end

#resource_owner_idString

The ID of the resource owner.

Returns:

  • (String)


57813
57814
57815
57816
57817
57818
57819
57820
57821
57822
57823
57824
57825
57826
57827
# File 'lib/aws-sdk-ec2/types.rb', line 57813

class IpamDiscoveredRoute < Struct.new(
  :ipam_resource_discovery_id,
  :resource_region,
  :resource_owner_id,
  :cidr,
  :asn,
  :state,
  :advertisement_type,
  :network_border_group,
  :pool_id,
  :ipam_pool_id,
  :sample_time)
  SENSITIVE = []
  include Aws::Structure
end

#resource_regionString

The Amazon Web Services Region where the route was discovered.

Returns:

  • (String)


57813
57814
57815
57816
57817
57818
57819
57820
57821
57822
57823
57824
57825
57826
57827
# File 'lib/aws-sdk-ec2/types.rb', line 57813

class IpamDiscoveredRoute < Struct.new(
  :ipam_resource_discovery_id,
  :resource_region,
  :resource_owner_id,
  :cidr,
  :asn,
  :state,
  :advertisement_type,
  :network_border_group,
  :pool_id,
  :ipam_pool_id,
  :sample_time)
  SENSITIVE = []
  include Aws::Structure
end

#sample_timeTime

The time when the route was last sampled.

Returns:

  • (Time)


57813
57814
57815
57816
57817
57818
57819
57820
57821
57822
57823
57824
57825
57826
57827
# File 'lib/aws-sdk-ec2/types.rb', line 57813

class IpamDiscoveredRoute < Struct.new(
  :ipam_resource_discovery_id,
  :resource_region,
  :resource_owner_id,
  :cidr,
  :asn,
  :state,
  :advertisement_type,
  :network_border_group,
  :pool_id,
  :ipam_pool_id,
  :sample_time)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of the BYOIP CIDR. Possible values:

  • advertised - The CIDR is being advertised.

  • deprovisioned - The CIDR has been deprovisioned.

  • failed-deprovision - Deprovisioning failed.

  • failed-provision - Provisioning failed.

  • pending-deprovision - Deprovisioning is in progress.

  • pending-provision - Provisioning is in progress.

  • provisioned - The CIDR is provisioned.

  • provisioned-not-publicly-advertisable - The CIDR is provisioned but not publicly advertisable.

Returns:

  • (String)


57813
57814
57815
57816
57817
57818
57819
57820
57821
57822
57823
57824
57825
57826
57827
# File 'lib/aws-sdk-ec2/types.rb', line 57813

class IpamDiscoveredRoute < Struct.new(
  :ipam_resource_discovery_id,
  :resource_region,
  :resource_owner_id,
  :cidr,
  :asn,
  :state,
  :advertisement_type,
  :network_border_group,
  :pool_id,
  :ipam_pool_id,
  :sample_time)
  SENSITIVE = []
  include Aws::Structure
end