Class: Aws::EC2::Types::IpamDiscoveredRoute
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::IpamDiscoveredRoute
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains information about a BGP route discovered by IPAM resource discovery.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#advertisement_type ⇒ String
The advertisement type of the route.
-
#asn ⇒ String
The Autonomous System Number (ASN) that originates the route.
-
#cidr ⇒ String
The IP address prefix of the discovered route in CIDR notation.
-
#ipam_pool_id ⇒ String
The ID of the IPAM pool associated with the route.
-
#ipam_resource_discovery_id ⇒ String
The ID of the IPAM resource discovery that discovered the route.
-
#network_border_group ⇒ String
The network border group for the route.
-
#pool_id ⇒ String
The ID of the BYOIP pool associated with the route.
-
#resource_owner_id ⇒ String
The ID of the resource owner.
-
#resource_region ⇒ String
The Amazon Web Services Region where the route was discovered.
-
#sample_time ⇒ Time
The time when the route was last sampled.
-
#state ⇒ String
The state of the BYOIP CIDR.
Instance Attribute Details
#advertisement_type ⇒ String
The advertisement type of the route. Possible values:
-
regional- The IP address is advertised from a single location (regional services such as Amazon EC2). -
global- The IP address is advertised from multiple global locations simultaneously (global services such as Amazon CloudFront).
57813 57814 57815 57816 57817 57818 57819 57820 57821 57822 57823 57824 57825 57826 57827 |
# File 'lib/aws-sdk-ec2/types.rb', line 57813 class IpamDiscoveredRoute < Struct.new( :ipam_resource_discovery_id, :resource_region, :resource_owner_id, :cidr, :asn, :state, :advertisement_type, :network_border_group, :pool_id, :ipam_pool_id, :sample_time) SENSITIVE = [] include Aws::Structure end |
#asn ⇒ String
The Autonomous System Number (ASN) that originates the route.
57813 57814 57815 57816 57817 57818 57819 57820 57821 57822 57823 57824 57825 57826 57827 |
# File 'lib/aws-sdk-ec2/types.rb', line 57813 class IpamDiscoveredRoute < Struct.new( :ipam_resource_discovery_id, :resource_region, :resource_owner_id, :cidr, :asn, :state, :advertisement_type, :network_border_group, :pool_id, :ipam_pool_id, :sample_time) SENSITIVE = [] include Aws::Structure end |
#cidr ⇒ String
The IP address prefix of the discovered route in CIDR notation.
57813 57814 57815 57816 57817 57818 57819 57820 57821 57822 57823 57824 57825 57826 57827 |
# File 'lib/aws-sdk-ec2/types.rb', line 57813 class IpamDiscoveredRoute < Struct.new( :ipam_resource_discovery_id, :resource_region, :resource_owner_id, :cidr, :asn, :state, :advertisement_type, :network_border_group, :pool_id, :ipam_pool_id, :sample_time) SENSITIVE = [] include Aws::Structure end |
#ipam_pool_id ⇒ String
The ID of the IPAM pool associated with the route.
57813 57814 57815 57816 57817 57818 57819 57820 57821 57822 57823 57824 57825 57826 57827 |
# File 'lib/aws-sdk-ec2/types.rb', line 57813 class IpamDiscoveredRoute < Struct.new( :ipam_resource_discovery_id, :resource_region, :resource_owner_id, :cidr, :asn, :state, :advertisement_type, :network_border_group, :pool_id, :ipam_pool_id, :sample_time) SENSITIVE = [] include Aws::Structure end |
#ipam_resource_discovery_id ⇒ String
The ID of the IPAM resource discovery that discovered the route.
57813 57814 57815 57816 57817 57818 57819 57820 57821 57822 57823 57824 57825 57826 57827 |
# File 'lib/aws-sdk-ec2/types.rb', line 57813 class IpamDiscoveredRoute < Struct.new( :ipam_resource_discovery_id, :resource_region, :resource_owner_id, :cidr, :asn, :state, :advertisement_type, :network_border_group, :pool_id, :ipam_pool_id, :sample_time) SENSITIVE = [] include Aws::Structure end |
#network_border_group ⇒ String
The network border group for the route.
57813 57814 57815 57816 57817 57818 57819 57820 57821 57822 57823 57824 57825 57826 57827 |
# File 'lib/aws-sdk-ec2/types.rb', line 57813 class IpamDiscoveredRoute < Struct.new( :ipam_resource_discovery_id, :resource_region, :resource_owner_id, :cidr, :asn, :state, :advertisement_type, :network_border_group, :pool_id, :ipam_pool_id, :sample_time) SENSITIVE = [] include Aws::Structure end |
#pool_id ⇒ String
The ID of the BYOIP pool associated with the route.
57813 57814 57815 57816 57817 57818 57819 57820 57821 57822 57823 57824 57825 57826 57827 |
# File 'lib/aws-sdk-ec2/types.rb', line 57813 class IpamDiscoveredRoute < Struct.new( :ipam_resource_discovery_id, :resource_region, :resource_owner_id, :cidr, :asn, :state, :advertisement_type, :network_border_group, :pool_id, :ipam_pool_id, :sample_time) SENSITIVE = [] include Aws::Structure end |
#resource_owner_id ⇒ String
The ID of the resource owner.
57813 57814 57815 57816 57817 57818 57819 57820 57821 57822 57823 57824 57825 57826 57827 |
# File 'lib/aws-sdk-ec2/types.rb', line 57813 class IpamDiscoveredRoute < Struct.new( :ipam_resource_discovery_id, :resource_region, :resource_owner_id, :cidr, :asn, :state, :advertisement_type, :network_border_group, :pool_id, :ipam_pool_id, :sample_time) SENSITIVE = [] include Aws::Structure end |
#resource_region ⇒ String
The Amazon Web Services Region where the route was discovered.
57813 57814 57815 57816 57817 57818 57819 57820 57821 57822 57823 57824 57825 57826 57827 |
# File 'lib/aws-sdk-ec2/types.rb', line 57813 class IpamDiscoveredRoute < Struct.new( :ipam_resource_discovery_id, :resource_region, :resource_owner_id, :cidr, :asn, :state, :advertisement_type, :network_border_group, :pool_id, :ipam_pool_id, :sample_time) SENSITIVE = [] include Aws::Structure end |
#sample_time ⇒ Time
The time when the route was last sampled.
57813 57814 57815 57816 57817 57818 57819 57820 57821 57822 57823 57824 57825 57826 57827 |
# File 'lib/aws-sdk-ec2/types.rb', line 57813 class IpamDiscoveredRoute < Struct.new( :ipam_resource_discovery_id, :resource_region, :resource_owner_id, :cidr, :asn, :state, :advertisement_type, :network_border_group, :pool_id, :ipam_pool_id, :sample_time) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the BYOIP CIDR. Possible values:
-
advertised- The CIDR is being advertised. -
deprovisioned- The CIDR has been deprovisioned. -
failed-deprovision- Deprovisioning failed. -
failed-provision- Provisioning failed. -
pending-deprovision- Deprovisioning is in progress. -
pending-provision- Provisioning is in progress. -
provisioned- The CIDR is provisioned. -
provisioned-not-publicly-advertisable- The CIDR is provisioned but not publicly advertisable.
57813 57814 57815 57816 57817 57818 57819 57820 57821 57822 57823 57824 57825 57826 57827 |
# File 'lib/aws-sdk-ec2/types.rb', line 57813 class IpamDiscoveredRoute < Struct.new( :ipam_resource_discovery_id, :resource_region, :resource_owner_id, :cidr, :asn, :state, :advertisement_type, :network_border_group, :pool_id, :ipam_pool_id, :sample_time) SENSITIVE = [] include Aws::Structure end |