Class: Aws::EC2::Types::IpamInternetRegistryAssociation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains information about an association between an IPAM and a Regional Internet Registry (RIR) for delegated RPKI management.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#child_request_xmlString

The XML content for the child request to be submitted to the internet registry to complete the BPKI setup.

Returns:

  • (String)


58001
58002
58003
58004
58005
58006
58007
58008
58009
58010
58011
58012
58013
58014
58015
# File 'lib/aws-sdk-ec2/types.rb', line 58001

class IpamInternetRegistryAssociation < Struct.new(
  :owner_id,
  :ipam_internet_registry_association_id,
  :ipam_internet_registry_association_arn,
  :ipam_id,
  :ipam_region,
  :rir,
  :organization_handle,
  :description,
  :state,
  :child_request_xml,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the internet registry association.

Returns:

  • (String)


58001
58002
58003
58004
58005
58006
58007
58008
58009
58010
58011
58012
58013
58014
58015
# File 'lib/aws-sdk-ec2/types.rb', line 58001

class IpamInternetRegistryAssociation < Struct.new(
  :owner_id,
  :ipam_internet_registry_association_id,
  :ipam_internet_registry_association_arn,
  :ipam_id,
  :ipam_region,
  :rir,
  :organization_handle,
  :description,
  :state,
  :child_request_xml,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_idString

The ID of the associated IPAM.

Returns:

  • (String)


58001
58002
58003
58004
58005
58006
58007
58008
58009
58010
58011
58012
58013
58014
58015
# File 'lib/aws-sdk-ec2/types.rb', line 58001

class IpamInternetRegistryAssociation < Struct.new(
  :owner_id,
  :ipam_internet_registry_association_id,
  :ipam_internet_registry_association_arn,
  :ipam_id,
  :ipam_region,
  :rir,
  :organization_handle,
  :description,
  :state,
  :child_request_xml,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_internet_registry_association_arnString

The Amazon Resource Name (ARN) of the internet registry association.

Returns:

  • (String)


58001
58002
58003
58004
58005
58006
58007
58008
58009
58010
58011
58012
58013
58014
58015
# File 'lib/aws-sdk-ec2/types.rb', line 58001

class IpamInternetRegistryAssociation < Struct.new(
  :owner_id,
  :ipam_internet_registry_association_id,
  :ipam_internet_registry_association_arn,
  :ipam_id,
  :ipam_region,
  :rir,
  :organization_handle,
  :description,
  :state,
  :child_request_xml,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_internet_registry_association_idString

The ID of the internet registry association.

Returns:

  • (String)


58001
58002
58003
58004
58005
58006
58007
58008
58009
58010
58011
58012
58013
58014
58015
# File 'lib/aws-sdk-ec2/types.rb', line 58001

class IpamInternetRegistryAssociation < Struct.new(
  :owner_id,
  :ipam_internet_registry_association_id,
  :ipam_internet_registry_association_arn,
  :ipam_id,
  :ipam_region,
  :rir,
  :organization_handle,
  :description,
  :state,
  :child_request_xml,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_regionString

The Amazon Web Services Region of the IPAM.

Returns:

  • (String)


58001
58002
58003
58004
58005
58006
58007
58008
58009
58010
58011
58012
58013
58014
58015
# File 'lib/aws-sdk-ec2/types.rb', line 58001

class IpamInternetRegistryAssociation < Struct.new(
  :owner_id,
  :ipam_internet_registry_association_id,
  :ipam_internet_registry_association_arn,
  :ipam_id,
  :ipam_region,
  :rir,
  :organization_handle,
  :description,
  :state,
  :child_request_xml,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#organization_handleString

The organization handle at the internet registry.

Returns:

  • (String)


58001
58002
58003
58004
58005
58006
58007
58008
58009
58010
58011
58012
58013
58014
58015
# File 'lib/aws-sdk-ec2/types.rb', line 58001

class IpamInternetRegistryAssociation < Struct.new(
  :owner_id,
  :ipam_internet_registry_association_id,
  :ipam_internet_registry_association_arn,
  :ipam_id,
  :ipam_region,
  :rir,
  :organization_handle,
  :description,
  :state,
  :child_request_xml,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#owner_idString

The ID of the Amazon Web Services account that owns the internet registry association.

Returns:

  • (String)


58001
58002
58003
58004
58005
58006
58007
58008
58009
58010
58011
58012
58013
58014
58015
# File 'lib/aws-sdk-ec2/types.rb', line 58001

class IpamInternetRegistryAssociation < Struct.new(
  :owner_id,
  :ipam_internet_registry_association_id,
  :ipam_internet_registry_association_arn,
  :ipam_id,
  :ipam_region,
  :rir,
  :organization_handle,
  :description,
  :state,
  :child_request_xml,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#rirString

The Regional Internet Registry. Possible values:

  • ripe - RIPE NCC (Europe, the Middle East, and Central Asia).

  • apnic - APNIC (Asia Pacific).

  • arin - ARIN (North America).

  • lacnic - LACNIC (Latin America and the Caribbean).

Returns:

  • (String)


58001
58002
58003
58004
58005
58006
58007
58008
58009
58010
58011
58012
58013
58014
58015
# File 'lib/aws-sdk-ec2/types.rb', line 58001

class IpamInternetRegistryAssociation < Struct.new(
  :owner_id,
  :ipam_internet_registry_association_id,
  :ipam_internet_registry_association_arn,
  :ipam_id,
  :ipam_region,
  :rir,
  :organization_handle,
  :description,
  :state,
  :child_request_xml,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of the internet registry association. Valid values: pending-activation | pending-enable | create-in-progress | create-failed | enable-in-progress | enable-complete | enable-failed | delete-in-progress | delete-complete | delete-failed.

Returns:

  • (String)


58001
58002
58003
58004
58005
58006
58007
58008
58009
58010
58011
58012
58013
58014
58015
# File 'lib/aws-sdk-ec2/types.rb', line 58001

class IpamInternetRegistryAssociation < Struct.new(
  :owner_id,
  :ipam_internet_registry_association_id,
  :ipam_internet_registry_association_arn,
  :ipam_id,
  :ipam_region,
  :rir,
  :organization_handle,
  :description,
  :state,
  :child_request_xml,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The tags assigned to the internet registry association.

Returns:



58001
58002
58003
58004
58005
58006
58007
58008
58009
58010
58011
58012
58013
58014
58015
# File 'lib/aws-sdk-ec2/types.rb', line 58001

class IpamInternetRegistryAssociation < Struct.new(
  :owner_id,
  :ipam_internet_registry_association_id,
  :ipam_internet_registry_association_arn,
  :ipam_id,
  :ipam_region,
  :rir,
  :organization_handle,
  :description,
  :state,
  :child_request_xml,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end