Class: Aws::EC2::Types::IpamOperatingRegion
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::IpamOperatingRegion
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
The operating Regions for an IPAM. Operating Regions are Amazon Web Services Regions where the IPAM is allowed to manage IP address CIDRs. IPAM only discovers and monitors resources in the Amazon Web Services Regions you select as operating Regions.
For more information about operating Regions, see [Create an IPAM] in the *Amazon VPC IPAM User Guide*.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#region_name ⇒ String
The name of the operating Region.
Instance Attribute Details
#region_name ⇒ String
The name of the operating Region.
55035 55036 55037 55038 55039 |
# File 'lib/aws-sdk-ec2/types.rb', line 55035 class IpamOperatingRegion < Struct.new( :region_name) SENSITIVE = [] include Aws::Structure end |