Class: Aws::EC2::Types::IpamOrganizationalUnitExclusion
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::IpamOrganizationalUnitExclusion
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
If your IPAM is integrated with Amazon Web Services Organizations and you add an organizational unit (OU) exclusion, IPAM will not manage the IP addresses in accounts in that OU exclusion.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#organizations_entity_path ⇒ String
An Amazon Web Services Organizations entity path.
Instance Attribute Details
#organizations_entity_path ⇒ String
An Amazon Web Services Organizations entity path. For more information on the entity path, see Understand the Amazon Web Services Organizations entity path in the Amazon Web Services Identity and Access Management User Guide.
57036 57037 57038 57039 57040 |
# File 'lib/aws-sdk-ec2/types.rb', line 57036 class IpamOrganizationalUnitExclusion < Struct.new( :organizations_entity_path) SENSITIVE = [] include Aws::Structure end |