Class: Aws::EC2::Types::IpamOrganizationalUnitExclusion

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

If your IPAM is integrated with Amazon Web Services Organizations and you add an organizational unit (OU) exclusion, IPAM will not manage the IP addresses in accounts in that OU exclusion.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#organizations_entity_pathString

An Amazon Web Services Organizations entity path. For more information on the entity path, see Understand the Amazon Web Services Organizations entity path in the Amazon Web Services Identity and Access Management User Guide.

Returns:

  • (String)


55531
55532
55533
55534
55535
# File 'lib/aws-sdk-ec2/types.rb', line 55531

class IpamOrganizationalUnitExclusion < Struct.new(
  :organizations_entity_path)
  SENSITIVE = []
  include Aws::Structure
end