Class: Aws::EC2::Types::IpamPolicy
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::IpamPolicy
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Information about an IPAM policy.
An IPAM policy is a set of rules that define how public IPv4 addresses from IPAM pools are allocated to Amazon Web Services resources. Each rule maps an Amazon Web Services service to IPAM pools that the service will use to get IP addresses. A single policy can have multiple rules and be applied to multiple Amazon Web Services Regions. If the IPAM pool run out of addresses then the services fallback to Amazon-provided IP addresses. A policy can be applied to an individual Amazon Web Services account or an entity within Amazon Web Services Organizations.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ipam_id ⇒ String
The ID of the IPAM this policy belongs to.
-
#ipam_policy_arn ⇒ String
The Amazon Resource Name (ARN) of the IPAM policy.
-
#ipam_policy_id ⇒ String
The ID of the IPAM policy.
-
#ipam_policy_region ⇒ String
The Region of the IPAM policy.
-
#owner_id ⇒ String
The account ID that owns the IPAM policy.
-
#state ⇒ String
The state of the IPAM policy.
-
#state_message ⇒ String
A message about the state of the IPAM policy.
-
#tags ⇒ Array<Types::Tag>
The tags assigned to the IPAM policy.
Instance Attribute Details
#ipam_id ⇒ String
The ID of the IPAM this policy belongs to.
54651 54652 54653 54654 54655 54656 54657 54658 54659 54660 54661 54662 |
# File 'lib/aws-sdk-ec2/types.rb', line 54651 class IpamPolicy < Struct.new( :owner_id, :ipam_policy_id, :ipam_policy_arn, :ipam_policy_region, :state, :state_message, :tags, :ipam_id) SENSITIVE = [] include Aws::Structure end |
#ipam_policy_arn ⇒ String
The Amazon Resource Name (ARN) of the IPAM policy.
54651 54652 54653 54654 54655 54656 54657 54658 54659 54660 54661 54662 |
# File 'lib/aws-sdk-ec2/types.rb', line 54651 class IpamPolicy < Struct.new( :owner_id, :ipam_policy_id, :ipam_policy_arn, :ipam_policy_region, :state, :state_message, :tags, :ipam_id) SENSITIVE = [] include Aws::Structure end |
#ipam_policy_id ⇒ String
The ID of the IPAM policy.
54651 54652 54653 54654 54655 54656 54657 54658 54659 54660 54661 54662 |
# File 'lib/aws-sdk-ec2/types.rb', line 54651 class IpamPolicy < Struct.new( :owner_id, :ipam_policy_id, :ipam_policy_arn, :ipam_policy_region, :state, :state_message, :tags, :ipam_id) SENSITIVE = [] include Aws::Structure end |
#ipam_policy_region ⇒ String
The Region of the IPAM policy.
54651 54652 54653 54654 54655 54656 54657 54658 54659 54660 54661 54662 |
# File 'lib/aws-sdk-ec2/types.rb', line 54651 class IpamPolicy < Struct.new( :owner_id, :ipam_policy_id, :ipam_policy_arn, :ipam_policy_region, :state, :state_message, :tags, :ipam_id) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
The account ID that owns the IPAM policy.
54651 54652 54653 54654 54655 54656 54657 54658 54659 54660 54661 54662 |
# File 'lib/aws-sdk-ec2/types.rb', line 54651 class IpamPolicy < Struct.new( :owner_id, :ipam_policy_id, :ipam_policy_arn, :ipam_policy_region, :state, :state_message, :tags, :ipam_id) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the IPAM policy.
54651 54652 54653 54654 54655 54656 54657 54658 54659 54660 54661 54662 |
# File 'lib/aws-sdk-ec2/types.rb', line 54651 class IpamPolicy < Struct.new( :owner_id, :ipam_policy_id, :ipam_policy_arn, :ipam_policy_region, :state, :state_message, :tags, :ipam_id) SENSITIVE = [] include Aws::Structure end |
#state_message ⇒ String
A message about the state of the IPAM policy.
54651 54652 54653 54654 54655 54656 54657 54658 54659 54660 54661 54662 |
# File 'lib/aws-sdk-ec2/types.rb', line 54651 class IpamPolicy < Struct.new( :owner_id, :ipam_policy_id, :ipam_policy_arn, :ipam_policy_region, :state, :state_message, :tags, :ipam_id) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags assigned to the IPAM policy.
54651 54652 54653 54654 54655 54656 54657 54658 54659 54660 54661 54662 |
# File 'lib/aws-sdk-ec2/types.rb', line 54651 class IpamPolicy < Struct.new( :owner_id, :ipam_policy_id, :ipam_policy_arn, :ipam_policy_region, :state, :state_message, :tags, :ipam_id) SENSITIVE = [] include Aws::Structure end |