Class: Aws::EC2::Types::IpamPolicyAllocationRule
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::IpamPolicyAllocationRule
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Information about an IPAM policy allocation rule.
Allocation rules are optional configurations within an IPAM policy that map Amazon Web Services resource types to specific IPAM pools. If no rules are defined, the resource types default to using Amazon-provided IP addresses.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#source_ipam_pool_id ⇒ String
The ID of the source IPAM pool for the allocation rule.
Instance Attribute Details
#source_ipam_pool_id ⇒ String
The ID of the source IPAM pool for the allocation rule.
An IPAM pool is a collection of IP addresses in IPAM that can be allocated to Amazon Web Services resources.
54373 54374 54375 54376 54377 |
# File 'lib/aws-sdk-ec2/types.rb', line 54373 class IpamPolicyAllocationRule < Struct.new( :source_ipam_pool_id) SENSITIVE = [] include Aws::Structure end |