Class: Aws::EC2::Types::IpamPolicyAllocationRuleRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::IpamPolicyAllocationRuleRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Information about a requested IPAM policy allocation rule.
Allocation rules are optional configurations within an IPAM policy that map Amazon Web Services resource types to specific IPAM pools. If no rules are defined, the resource types default to using Amazon-provided IP addresses.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#source_ipam_pool_id ⇒ String
The ID of the source IPAM pool for the requested allocation rule.
Instance Attribute Details
#source_ipam_pool_id ⇒ String
The ID of the source IPAM pool for the requested allocation rule.
An IPAM pool is a collection of IP addresses in IPAM that can be allocated to Amazon Web Services resources.
55785 55786 55787 55788 55789 |
# File 'lib/aws-sdk-ec2/types.rb', line 55785 class IpamPolicyAllocationRuleRequest < Struct.new( :source_ipam_pool_id) SENSITIVE = [] include Aws::Structure end |