Class: Aws::EC2::Types::IpamPolicyDocument
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::IpamPolicyDocument
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Information about an IPAM policy.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allocation_rules ⇒ Array<Types::IpamPolicyAllocationRule>
The allocation rules in the IPAM policy document.
-
#ipam_policy_id ⇒ String
The ID of the IPAM policy.
-
#locale ⇒ String
The locale of the IPAM policy document.
-
#resource_type ⇒ String
The resource type of the IPAM policy document.
Instance Attribute Details
#allocation_rules ⇒ Array<Types::IpamPolicyAllocationRule>
The allocation rules in the IPAM policy document.
Allocation rules are optional configurations within an IPAM policy that map Amazon Web Services resource types to specific IPAM pools. If no rules are defined, the resource types default to using Amazon-provided IP addresses.
55200 55201 55202 55203 55204 55205 55206 55207 |
# File 'lib/aws-sdk-ec2/types.rb', line 55200 class IpamPolicyDocument < Struct.new( :ipam_policy_id, :locale, :resource_type, :allocation_rules) SENSITIVE = [] include Aws::Structure end |
#ipam_policy_id ⇒ String
The ID of the IPAM policy.
55200 55201 55202 55203 55204 55205 55206 55207 |
# File 'lib/aws-sdk-ec2/types.rb', line 55200 class IpamPolicyDocument < Struct.new( :ipam_policy_id, :locale, :resource_type, :allocation_rules) SENSITIVE = [] include Aws::Structure end |
#locale ⇒ String
The locale of the IPAM policy document.
55200 55201 55202 55203 55204 55205 55206 55207 |
# File 'lib/aws-sdk-ec2/types.rb', line 55200 class IpamPolicyDocument < Struct.new( :ipam_policy_id, :locale, :resource_type, :allocation_rules) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The resource type of the IPAM policy document.
The Amazon Web Services service or resource type that can use IP addresses through IPAM policies. Supported services and resource types include:
-
Elastic IP addresses
^
55200 55201 55202 55203 55204 55205 55206 55207 |
# File 'lib/aws-sdk-ec2/types.rb', line 55200 class IpamPolicyDocument < Struct.new( :ipam_policy_id, :locale, :resource_type, :allocation_rules) SENSITIVE = [] include Aws::Structure end |