Class: Aws::EC2::Types::IpamPolicyDocument

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Information about an IPAM policy.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allocation_rulesArray<Types::IpamPolicyAllocationRule>

The allocation rules in the IPAM policy document.

Allocation rules are optional configurations within an IPAM policy that map Amazon Web Services resource types to specific IPAM pools. If no rules are defined, the resource types default to using Amazon-provided IP addresses.



53534
53535
53536
53537
53538
53539
53540
53541
# File 'lib/aws-sdk-ec2/types.rb', line 53534

class IpamPolicyDocument < Struct.new(
  :ipam_policy_id,
  :locale,
  :resource_type,
  :allocation_rules)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_policy_idString

The ID of the IPAM policy.

Returns:

  • (String)


53534
53535
53536
53537
53538
53539
53540
53541
# File 'lib/aws-sdk-ec2/types.rb', line 53534

class IpamPolicyDocument < Struct.new(
  :ipam_policy_id,
  :locale,
  :resource_type,
  :allocation_rules)
  SENSITIVE = []
  include Aws::Structure
end

#localeString

The locale of the IPAM policy document.

Returns:

  • (String)


53534
53535
53536
53537
53538
53539
53540
53541
# File 'lib/aws-sdk-ec2/types.rb', line 53534

class IpamPolicyDocument < Struct.new(
  :ipam_policy_id,
  :locale,
  :resource_type,
  :allocation_rules)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The resource type of the IPAM policy document.

The Amazon Web Services service or resource type that can use IP addresses through IPAM policies. Supported services and resource types include:

  • Elastic IP addresses

^

Returns:

  • (String)


53534
53535
53536
53537
53538
53539
53540
53541
# File 'lib/aws-sdk-ec2/types.rb', line 53534

class IpamPolicyDocument < Struct.new(
  :ipam_policy_id,
  :locale,
  :resource_type,
  :allocation_rules)
  SENSITIVE = []
  include Aws::Structure
end