Class: Aws::EC2::Types::IpamPolicyOrganizationTarget
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::IpamPolicyOrganizationTarget
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
The Amazon Web Services Organizations target for an IPAM policy.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#organization_target_id ⇒ String
The ID of the Amazon Web Services Organizations target.
Instance Attribute Details
#organization_target_id ⇒ String
The ID of the Amazon Web Services Organizations target.
A target can be an individual Amazon Web Services account or an entity within an Amazon Web Services Organization to which an IPAM policy can be applied.
54964 54965 54966 54967 54968 |
# File 'lib/aws-sdk-ec2/types.rb', line 54964 class IpamPolicyOrganizationTarget < Struct.new( :organization_target_id) SENSITIVE = [] include Aws::Structure end |