Class: Aws::EC2::Types::IpamPolicyOrganizationTarget

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

The Amazon Web Services Organizations target for an IPAM policy.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#organization_target_idString

The ID of the Amazon Web Services Organizations target.

A target can be an individual Amazon Web Services account or an entity within an Amazon Web Services Organization to which an IPAM policy can be applied.

Returns:

  • (String)


54455
54456
54457
54458
54459
# File 'lib/aws-sdk-ec2/types.rb', line 54455

class IpamPolicyOrganizationTarget < Struct.new(
  :organization_target_id)
  SENSITIVE = []
  include Aws::Structure
end