Class: Aws::EC2::Types::IpamPolicyOrganizationTarget
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::IpamPolicyOrganizationTarget
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
The Amazon Web Services Organizations target for an IPAM policy.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#organization_target_id ⇒ String
The ID of a Amazon Web Services Organizations target for an IPAM policy.
Instance Attribute Details
#organization_target_id ⇒ String
The ID of a Amazon Web Services Organizations target for an IPAM policy.
53552 53553 53554 53555 53556 |
# File 'lib/aws-sdk-ec2/types.rb', line 53552 class IpamPolicyOrganizationTarget < Struct.new( :organization_target_id) SENSITIVE = [] include Aws::Structure end |