Class: Aws::EC2::Types::IpamResourceDiscovery

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

A resource discovery is an IPAM component that enables IPAM to manage and monitor resources that belong to the owning account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The resource discovery description.

Returns:

  • (String)


56007
56008
56009
56010
56011
56012
56013
56014
56015
56016
56017
56018
56019
56020
# File 'lib/aws-sdk-ec2/types.rb', line 56007

class IpamResourceDiscovery < Struct.new(
  :owner_id,
  :ipam_resource_discovery_id,
  :ipam_resource_discovery_arn,
  :ipam_resource_discovery_region,
  :description,
  :operating_regions,
  :is_default,
  :state,
  :tags,
  :organizational_unit_exclusions)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_resource_discovery_arnString

The resource discovery Amazon Resource Name (ARN).

Returns:

  • (String)


56007
56008
56009
56010
56011
56012
56013
56014
56015
56016
56017
56018
56019
56020
# File 'lib/aws-sdk-ec2/types.rb', line 56007

class IpamResourceDiscovery < Struct.new(
  :owner_id,
  :ipam_resource_discovery_id,
  :ipam_resource_discovery_arn,
  :ipam_resource_discovery_region,
  :description,
  :operating_regions,
  :is_default,
  :state,
  :tags,
  :organizational_unit_exclusions)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_resource_discovery_idString

The resource discovery ID.

Returns:

  • (String)


56007
56008
56009
56010
56011
56012
56013
56014
56015
56016
56017
56018
56019
56020
# File 'lib/aws-sdk-ec2/types.rb', line 56007

class IpamResourceDiscovery < Struct.new(
  :owner_id,
  :ipam_resource_discovery_id,
  :ipam_resource_discovery_arn,
  :ipam_resource_discovery_region,
  :description,
  :operating_regions,
  :is_default,
  :state,
  :tags,
  :organizational_unit_exclusions)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_resource_discovery_regionString

The resource discovery Region.

Returns:

  • (String)


56007
56008
56009
56010
56011
56012
56013
56014
56015
56016
56017
56018
56019
56020
# File 'lib/aws-sdk-ec2/types.rb', line 56007

class IpamResourceDiscovery < Struct.new(
  :owner_id,
  :ipam_resource_discovery_id,
  :ipam_resource_discovery_arn,
  :ipam_resource_discovery_region,
  :description,
  :operating_regions,
  :is_default,
  :state,
  :tags,
  :organizational_unit_exclusions)
  SENSITIVE = []
  include Aws::Structure
end

#is_defaultBoolean

Defines if the resource discovery is the default. The default resource discovery is the resource discovery automatically created when you create an IPAM.

Returns:

  • (Boolean)


56007
56008
56009
56010
56011
56012
56013
56014
56015
56016
56017
56018
56019
56020
# File 'lib/aws-sdk-ec2/types.rb', line 56007

class IpamResourceDiscovery < Struct.new(
  :owner_id,
  :ipam_resource_discovery_id,
  :ipam_resource_discovery_arn,
  :ipam_resource_discovery_region,
  :description,
  :operating_regions,
  :is_default,
  :state,
  :tags,
  :organizational_unit_exclusions)
  SENSITIVE = []
  include Aws::Structure
end

#operating_regionsArray<Types::IpamOperatingRegion>

The operating Regions for the resource discovery. Operating Regions are Amazon Web Services Regions where the IPAM is allowed to manage IP address CIDRs. IPAM only discovers and monitors resources in the Amazon Web Services Regions you select as operating Regions.

Returns:



56007
56008
56009
56010
56011
56012
56013
56014
56015
56016
56017
56018
56019
56020
# File 'lib/aws-sdk-ec2/types.rb', line 56007

class IpamResourceDiscovery < Struct.new(
  :owner_id,
  :ipam_resource_discovery_id,
  :ipam_resource_discovery_arn,
  :ipam_resource_discovery_region,
  :description,
  :operating_regions,
  :is_default,
  :state,
  :tags,
  :organizational_unit_exclusions)
  SENSITIVE = []
  include Aws::Structure
end

#organizational_unit_exclusionsArray<Types::IpamOrganizationalUnitExclusion>

If your IPAM is integrated with Amazon Web Services Organizations and you add an organizational unit (OU) exclusion, IPAM will not manage the IP addresses in accounts in that OU exclusion.



56007
56008
56009
56010
56011
56012
56013
56014
56015
56016
56017
56018
56019
56020
# File 'lib/aws-sdk-ec2/types.rb', line 56007

class IpamResourceDiscovery < Struct.new(
  :owner_id,
  :ipam_resource_discovery_id,
  :ipam_resource_discovery_arn,
  :ipam_resource_discovery_region,
  :description,
  :operating_regions,
  :is_default,
  :state,
  :tags,
  :organizational_unit_exclusions)
  SENSITIVE = []
  include Aws::Structure
end

#owner_idString

The ID of the owner.

Returns:

  • (String)


56007
56008
56009
56010
56011
56012
56013
56014
56015
56016
56017
56018
56019
56020
# File 'lib/aws-sdk-ec2/types.rb', line 56007

class IpamResourceDiscovery < Struct.new(
  :owner_id,
  :ipam_resource_discovery_id,
  :ipam_resource_discovery_arn,
  :ipam_resource_discovery_region,
  :description,
  :operating_regions,
  :is_default,
  :state,
  :tags,
  :organizational_unit_exclusions)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The lifecycle state of the resource discovery.

  • ‘create-in-progress` - Resource discovery is being created.

  • ‘create-complete` - Resource discovery creation is complete.

  • ‘create-failed` - Resource discovery creation has failed.

  • ‘modify-in-progress` - Resource discovery is being modified.

  • ‘modify-complete` - Resource discovery modification is complete.

  • ‘modify-failed` - Resource discovery modification has failed.

  • ‘delete-in-progress` - Resource discovery is being deleted.

  • ‘delete-complete` - Resource discovery deletion is complete.

  • ‘delete-failed` - Resource discovery deletion has failed.

  • ‘isolate-in-progress` - Amazon Web Services account that created the resource discovery has been removed and the resource discovery is being isolated.

  • ‘isolate-complete` - Resource discovery isolation is complete.

  • ‘restore-in-progress` - Amazon Web Services account that created the resource discovery and was isolated has been restored.

Returns:

  • (String)


56007
56008
56009
56010
56011
56012
56013
56014
56015
56016
56017
56018
56019
56020
# File 'lib/aws-sdk-ec2/types.rb', line 56007

class IpamResourceDiscovery < Struct.new(
  :owner_id,
  :ipam_resource_discovery_id,
  :ipam_resource_discovery_arn,
  :ipam_resource_discovery_region,
  :description,
  :operating_regions,
  :is_default,
  :state,
  :tags,
  :organizational_unit_exclusions)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

A tag is a label that you assign to an Amazon Web Services resource. Each tag consists of a key and an optional value. You can use tags to search and filter your resources or track your Amazon Web Services costs.

Returns:



56007
56008
56009
56010
56011
56012
56013
56014
56015
56016
56017
56018
56019
56020
# File 'lib/aws-sdk-ec2/types.rb', line 56007

class IpamResourceDiscovery < Struct.new(
  :owner_id,
  :ipam_resource_discovery_id,
  :ipam_resource_discovery_arn,
  :ipam_resource_discovery_region,
  :description,
  :operating_regions,
  :is_default,
  :state,
  :tags,
  :organizational_unit_exclusions)
  SENSITIVE = []
  include Aws::Structure
end