Class: Aws::EC2::Types::IpamRoutingPolicyRegistration
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::IpamRoutingPolicyRegistration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains information about a routing policy registration that represents a Route Origin Authorization (ROA) managed through IPAM.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asns ⇒ Array<String>
The Autonomous System Numbers (ASNs) authorized to originate the prefix.
-
#cidr ⇒ String
The IP address prefix in CIDR notation authorized by the ROA.
-
#description ⇒ String
The description of the routing policy registration.
-
#latest_delta_id ⇒ String
The ID of the most recent delta that modified this registration.
-
#max_length ⇒ Integer
The maximum prefix length that the ASNs are authorized to announce.
-
#permit_more_specific_announcements ⇒ Boolean
Specifies whether to permit more specific route announcements than the CIDR prefix.
-
#state ⇒ String
The state of the routing policy registration.
Instance Attribute Details
#asns ⇒ Array<String>
The Autonomous System Numbers (ASNs) authorized to originate the prefix.
59905 59906 59907 59908 59909 59910 59911 59912 59913 59914 59915 |
# File 'lib/aws-sdk-ec2/types.rb', line 59905 class IpamRoutingPolicyRegistration < Struct.new( :cidr, :asns, :permit_more_specific_announcements, :max_length, :description, :latest_delta_id, :state) SENSITIVE = [] include Aws::Structure end |
#cidr ⇒ String
The IP address prefix in CIDR notation authorized by the ROA.
59905 59906 59907 59908 59909 59910 59911 59912 59913 59914 59915 |
# File 'lib/aws-sdk-ec2/types.rb', line 59905 class IpamRoutingPolicyRegistration < Struct.new( :cidr, :asns, :permit_more_specific_announcements, :max_length, :description, :latest_delta_id, :state) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the routing policy registration.
59905 59906 59907 59908 59909 59910 59911 59912 59913 59914 59915 |
# File 'lib/aws-sdk-ec2/types.rb', line 59905 class IpamRoutingPolicyRegistration < Struct.new( :cidr, :asns, :permit_more_specific_announcements, :max_length, :description, :latest_delta_id, :state) SENSITIVE = [] include Aws::Structure end |
#latest_delta_id ⇒ String
The ID of the most recent delta that modified this registration.
59905 59906 59907 59908 59909 59910 59911 59912 59913 59914 59915 |
# File 'lib/aws-sdk-ec2/types.rb', line 59905 class IpamRoutingPolicyRegistration < Struct.new( :cidr, :asns, :permit_more_specific_announcements, :max_length, :description, :latest_delta_id, :state) SENSITIVE = [] include Aws::Structure end |
#max_length ⇒ Integer
The maximum prefix length that the ASNs are authorized to announce.
59905 59906 59907 59908 59909 59910 59911 59912 59913 59914 59915 |
# File 'lib/aws-sdk-ec2/types.rb', line 59905 class IpamRoutingPolicyRegistration < Struct.new( :cidr, :asns, :permit_more_specific_announcements, :max_length, :description, :latest_delta_id, :state) SENSITIVE = [] include Aws::Structure end |
#permit_more_specific_announcements ⇒ Boolean
Specifies whether to permit more specific route announcements than
the CIDR prefix. When enabled, ASNs can announce sub-prefixes of the
authorized CIDR up to the specified maximum length. Default:
false.
59905 59906 59907 59908 59909 59910 59911 59912 59913 59914 59915 |
# File 'lib/aws-sdk-ec2/types.rb', line 59905 class IpamRoutingPolicyRegistration < Struct.new( :cidr, :asns, :permit_more_specific_announcements, :max_length, :description, :latest_delta_id, :state) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the routing policy registration. Valid values:
pending-activate | activate-failed | create-in-progress |
create-complete | update-in-progress | update-complete |
delete-in-progress | delete-complete.
59905 59906 59907 59908 59909 59910 59911 59912 59913 59914 59915 |
# File 'lib/aws-sdk-ec2/types.rb', line 59905 class IpamRoutingPolicyRegistration < Struct.new( :cidr, :asns, :permit_more_specific_announcements, :max_length, :description, :latest_delta_id, :state) SENSITIVE = [] include Aws::Structure end |