Class: Aws::EC2::Types::LaunchSpecification

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes the launch specification for an instance.

Constant Summary collapse

SENSITIVE =
[:user_data]

Instance Attribute Summary collapse

Instance Attribute Details

#addressing_typeString

Deprecated.

Returns:

  • (String)


60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
60554
60555
60556
# File 'lib/aws-sdk-ec2/types.rb', line 60538

class LaunchSpecification < Struct.new(
  :user_data,
  :addressing_type,
  :block_device_mappings,
  :ebs_optimized,
  :iam_instance_profile,
  :image_id,
  :instance_type,
  :kernel_id,
  :key_name,
  :network_interfaces,
  :placement,
  :ramdisk_id,
  :subnet_id,
  :security_groups,
  :monitoring)
  SENSITIVE = [:user_data]
  include Aws::Structure
end

#block_device_mappingsArray<Types::BlockDeviceMapping>

The block device mapping entries.

Returns:



60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
60554
60555
60556
# File 'lib/aws-sdk-ec2/types.rb', line 60538

class LaunchSpecification < Struct.new(
  :user_data,
  :addressing_type,
  :block_device_mappings,
  :ebs_optimized,
  :iam_instance_profile,
  :image_id,
  :instance_type,
  :kernel_id,
  :key_name,
  :network_interfaces,
  :placement,
  :ramdisk_id,
  :subnet_id,
  :security_groups,
  :monitoring)
  SENSITIVE = [:user_data]
  include Aws::Structure
end

#ebs_optimizedBoolean

Indicates whether the instance is optimized for EBS I/O. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal EBS I/O performance. This optimization isn't available with all instance types. Additional usage charges apply when using an EBS Optimized instance.

Default: false

Returns:

  • (Boolean)


60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
60554
60555
60556
# File 'lib/aws-sdk-ec2/types.rb', line 60538

class LaunchSpecification < Struct.new(
  :user_data,
  :addressing_type,
  :block_device_mappings,
  :ebs_optimized,
  :iam_instance_profile,
  :image_id,
  :instance_type,
  :kernel_id,
  :key_name,
  :network_interfaces,
  :placement,
  :ramdisk_id,
  :subnet_id,
  :security_groups,
  :monitoring)
  SENSITIVE = [:user_data]
  include Aws::Structure
end

#iam_instance_profileTypes::IamInstanceProfileSpecification

The IAM instance profile.



60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
60554
60555
60556
# File 'lib/aws-sdk-ec2/types.rb', line 60538

class LaunchSpecification < Struct.new(
  :user_data,
  :addressing_type,
  :block_device_mappings,
  :ebs_optimized,
  :iam_instance_profile,
  :image_id,
  :instance_type,
  :kernel_id,
  :key_name,
  :network_interfaces,
  :placement,
  :ramdisk_id,
  :subnet_id,
  :security_groups,
  :monitoring)
  SENSITIVE = [:user_data]
  include Aws::Structure
end

#image_idString

The ID of the AMI.

Returns:

  • (String)


60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
60554
60555
60556
# File 'lib/aws-sdk-ec2/types.rb', line 60538

class LaunchSpecification < Struct.new(
  :user_data,
  :addressing_type,
  :block_device_mappings,
  :ebs_optimized,
  :iam_instance_profile,
  :image_id,
  :instance_type,
  :kernel_id,
  :key_name,
  :network_interfaces,
  :placement,
  :ramdisk_id,
  :subnet_id,
  :security_groups,
  :monitoring)
  SENSITIVE = [:user_data]
  include Aws::Structure
end

#instance_typeString

The instance type. Only one instance type can be specified.

Returns:

  • (String)


60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
60554
60555
60556
# File 'lib/aws-sdk-ec2/types.rb', line 60538

class LaunchSpecification < Struct.new(
  :user_data,
  :addressing_type,
  :block_device_mappings,
  :ebs_optimized,
  :iam_instance_profile,
  :image_id,
  :instance_type,
  :kernel_id,
  :key_name,
  :network_interfaces,
  :placement,
  :ramdisk_id,
  :subnet_id,
  :security_groups,
  :monitoring)
  SENSITIVE = [:user_data]
  include Aws::Structure
end

#kernel_idString

The ID of the kernel.

Returns:

  • (String)


60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
60554
60555
60556
# File 'lib/aws-sdk-ec2/types.rb', line 60538

class LaunchSpecification < Struct.new(
  :user_data,
  :addressing_type,
  :block_device_mappings,
  :ebs_optimized,
  :iam_instance_profile,
  :image_id,
  :instance_type,
  :kernel_id,
  :key_name,
  :network_interfaces,
  :placement,
  :ramdisk_id,
  :subnet_id,
  :security_groups,
  :monitoring)
  SENSITIVE = [:user_data]
  include Aws::Structure
end

#key_nameString

The name of the key pair.

Returns:

  • (String)


60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
60554
60555
60556
# File 'lib/aws-sdk-ec2/types.rb', line 60538

class LaunchSpecification < Struct.new(
  :user_data,
  :addressing_type,
  :block_device_mappings,
  :ebs_optimized,
  :iam_instance_profile,
  :image_id,
  :instance_type,
  :kernel_id,
  :key_name,
  :network_interfaces,
  :placement,
  :ramdisk_id,
  :subnet_id,
  :security_groups,
  :monitoring)
  SENSITIVE = [:user_data]
  include Aws::Structure
end

#monitoringTypes::RunInstancesMonitoringEnabled

Describes the monitoring of an instance.



60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
60554
60555
60556
# File 'lib/aws-sdk-ec2/types.rb', line 60538

class LaunchSpecification < Struct.new(
  :user_data,
  :addressing_type,
  :block_device_mappings,
  :ebs_optimized,
  :iam_instance_profile,
  :image_id,
  :instance_type,
  :kernel_id,
  :key_name,
  :network_interfaces,
  :placement,
  :ramdisk_id,
  :subnet_id,
  :security_groups,
  :monitoring)
  SENSITIVE = [:user_data]
  include Aws::Structure
end

#network_interfacesArray<Types::InstanceNetworkInterfaceSpecification>

The network interfaces. If you specify a network interface, you must specify subnet IDs and security group IDs using the network interface.



60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
60554
60555
60556
# File 'lib/aws-sdk-ec2/types.rb', line 60538

class LaunchSpecification < Struct.new(
  :user_data,
  :addressing_type,
  :block_device_mappings,
  :ebs_optimized,
  :iam_instance_profile,
  :image_id,
  :instance_type,
  :kernel_id,
  :key_name,
  :network_interfaces,
  :placement,
  :ramdisk_id,
  :subnet_id,
  :security_groups,
  :monitoring)
  SENSITIVE = [:user_data]
  include Aws::Structure
end

#placementTypes::SpotPlacement

The placement information for the instance.



60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
60554
60555
60556
# File 'lib/aws-sdk-ec2/types.rb', line 60538

class LaunchSpecification < Struct.new(
  :user_data,
  :addressing_type,
  :block_device_mappings,
  :ebs_optimized,
  :iam_instance_profile,
  :image_id,
  :instance_type,
  :kernel_id,
  :key_name,
  :network_interfaces,
  :placement,
  :ramdisk_id,
  :subnet_id,
  :security_groups,
  :monitoring)
  SENSITIVE = [:user_data]
  include Aws::Structure
end

#ramdisk_idString

The ID of the RAM disk.

Returns:

  • (String)


60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
60554
60555
60556
# File 'lib/aws-sdk-ec2/types.rb', line 60538

class LaunchSpecification < Struct.new(
  :user_data,
  :addressing_type,
  :block_device_mappings,
  :ebs_optimized,
  :iam_instance_profile,
  :image_id,
  :instance_type,
  :kernel_id,
  :key_name,
  :network_interfaces,
  :placement,
  :ramdisk_id,
  :subnet_id,
  :security_groups,
  :monitoring)
  SENSITIVE = [:user_data]
  include Aws::Structure
end

#security_groupsArray<Types::GroupIdentifier>

The IDs of the security groups.

Returns:



60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
60554
60555
60556
# File 'lib/aws-sdk-ec2/types.rb', line 60538

class LaunchSpecification < Struct.new(
  :user_data,
  :addressing_type,
  :block_device_mappings,
  :ebs_optimized,
  :iam_instance_profile,
  :image_id,
  :instance_type,
  :kernel_id,
  :key_name,
  :network_interfaces,
  :placement,
  :ramdisk_id,
  :subnet_id,
  :security_groups,
  :monitoring)
  SENSITIVE = [:user_data]
  include Aws::Structure
end

#subnet_idString

The ID of the subnet in which to launch the instance.

Returns:

  • (String)


60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
60554
60555
60556
# File 'lib/aws-sdk-ec2/types.rb', line 60538

class LaunchSpecification < Struct.new(
  :user_data,
  :addressing_type,
  :block_device_mappings,
  :ebs_optimized,
  :iam_instance_profile,
  :image_id,
  :instance_type,
  :kernel_id,
  :key_name,
  :network_interfaces,
  :placement,
  :ramdisk_id,
  :subnet_id,
  :security_groups,
  :monitoring)
  SENSITIVE = [:user_data]
  include Aws::Structure
end

#user_dataString

The base64-encoded user data that instances use when starting up. User data is limited to 16 KB.

Returns:

  • (String)


60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
60554
60555
60556
# File 'lib/aws-sdk-ec2/types.rb', line 60538

class LaunchSpecification < Struct.new(
  :user_data,
  :addressing_type,
  :block_device_mappings,
  :ebs_optimized,
  :iam_instance_profile,
  :image_id,
  :instance_type,
  :kernel_id,
  :key_name,
  :network_interfaces,
  :placement,
  :ramdisk_id,
  :subnet_id,
  :security_groups,
  :monitoring)
  SENSITIVE = [:user_data]
  include Aws::Structure
end