Class: Aws::EC2::Types::LaunchSpecification
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::LaunchSpecification
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the launch specification for an instance.
Constant Summary collapse
- SENSITIVE =
[:user_data]
Instance Attribute Summary collapse
-
#addressing_type ⇒ String
Deprecated.
-
#block_device_mappings ⇒ Array<Types::BlockDeviceMapping>
The block device mapping entries.
-
#ebs_optimized ⇒ Boolean
Indicates whether the instance is optimized for EBS I/O.
-
#iam_instance_profile ⇒ Types::IamInstanceProfileSpecification
The IAM instance profile.
-
#image_id ⇒ String
The ID of the AMI.
-
#instance_type ⇒ String
The instance type.
-
#kernel_id ⇒ String
The ID of the kernel.
-
#key_name ⇒ String
The name of the key pair.
-
#monitoring ⇒ Types::RunInstancesMonitoringEnabled
Describes the monitoring of an instance.
-
#network_interfaces ⇒ Array<Types::InstanceNetworkInterfaceSpecification>
The network interfaces.
-
#placement ⇒ Types::SpotPlacement
The placement information for the instance.
-
#ramdisk_id ⇒ String
The ID of the RAM disk.
-
#security_groups ⇒ Array<Types::GroupIdentifier>
The IDs of the security groups.
-
#subnet_id ⇒ String
The ID of the subnet in which to launch the instance.
-
#user_data ⇒ String
The base64-encoded user data that instances use when starting up.
Instance Attribute Details
#addressing_type ⇒ String
Deprecated.
57451 57452 57453 57454 57455 57456 57457 57458 57459 57460 57461 57462 57463 57464 57465 57466 57467 57468 57469 |
# File 'lib/aws-sdk-ec2/types.rb', line 57451 class LaunchSpecification < Struct.new( :user_data, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :security_groups, :monitoring) SENSITIVE = [:user_data] include Aws::Structure end |
#block_device_mappings ⇒ Array<Types::BlockDeviceMapping>
The block device mapping entries.
57451 57452 57453 57454 57455 57456 57457 57458 57459 57460 57461 57462 57463 57464 57465 57466 57467 57468 57469 |
# File 'lib/aws-sdk-ec2/types.rb', line 57451 class LaunchSpecification < Struct.new( :user_data, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :security_groups, :monitoring) SENSITIVE = [:user_data] include Aws::Structure end |
#ebs_optimized ⇒ Boolean
Indicates whether the instance is optimized for EBS I/O. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal EBS I/O performance. This optimization isn’t available with all instance types. Additional usage charges apply when using an EBS Optimized instance.
Default: ‘false`
57451 57452 57453 57454 57455 57456 57457 57458 57459 57460 57461 57462 57463 57464 57465 57466 57467 57468 57469 |
# File 'lib/aws-sdk-ec2/types.rb', line 57451 class LaunchSpecification < Struct.new( :user_data, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :security_groups, :monitoring) SENSITIVE = [:user_data] include Aws::Structure end |
#iam_instance_profile ⇒ Types::IamInstanceProfileSpecification
The IAM instance profile.
57451 57452 57453 57454 57455 57456 57457 57458 57459 57460 57461 57462 57463 57464 57465 57466 57467 57468 57469 |
# File 'lib/aws-sdk-ec2/types.rb', line 57451 class LaunchSpecification < Struct.new( :user_data, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :security_groups, :monitoring) SENSITIVE = [:user_data] include Aws::Structure end |
#image_id ⇒ String
The ID of the AMI.
57451 57452 57453 57454 57455 57456 57457 57458 57459 57460 57461 57462 57463 57464 57465 57466 57467 57468 57469 |
# File 'lib/aws-sdk-ec2/types.rb', line 57451 class LaunchSpecification < Struct.new( :user_data, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :security_groups, :monitoring) SENSITIVE = [:user_data] include Aws::Structure end |
#instance_type ⇒ String
The instance type. Only one instance type can be specified.
57451 57452 57453 57454 57455 57456 57457 57458 57459 57460 57461 57462 57463 57464 57465 57466 57467 57468 57469 |
# File 'lib/aws-sdk-ec2/types.rb', line 57451 class LaunchSpecification < Struct.new( :user_data, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :security_groups, :monitoring) SENSITIVE = [:user_data] include Aws::Structure end |
#kernel_id ⇒ String
The ID of the kernel.
57451 57452 57453 57454 57455 57456 57457 57458 57459 57460 57461 57462 57463 57464 57465 57466 57467 57468 57469 |
# File 'lib/aws-sdk-ec2/types.rb', line 57451 class LaunchSpecification < Struct.new( :user_data, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :security_groups, :monitoring) SENSITIVE = [:user_data] include Aws::Structure end |
#key_name ⇒ String
The name of the key pair.
57451 57452 57453 57454 57455 57456 57457 57458 57459 57460 57461 57462 57463 57464 57465 57466 57467 57468 57469 |
# File 'lib/aws-sdk-ec2/types.rb', line 57451 class LaunchSpecification < Struct.new( :user_data, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :security_groups, :monitoring) SENSITIVE = [:user_data] include Aws::Structure end |
#monitoring ⇒ Types::RunInstancesMonitoringEnabled
Describes the monitoring of an instance.
57451 57452 57453 57454 57455 57456 57457 57458 57459 57460 57461 57462 57463 57464 57465 57466 57467 57468 57469 |
# File 'lib/aws-sdk-ec2/types.rb', line 57451 class LaunchSpecification < Struct.new( :user_data, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :security_groups, :monitoring) SENSITIVE = [:user_data] include Aws::Structure end |
#network_interfaces ⇒ Array<Types::InstanceNetworkInterfaceSpecification>
The network interfaces. If you specify a network interface, you must specify subnet IDs and security group IDs using the network interface.
57451 57452 57453 57454 57455 57456 57457 57458 57459 57460 57461 57462 57463 57464 57465 57466 57467 57468 57469 |
# File 'lib/aws-sdk-ec2/types.rb', line 57451 class LaunchSpecification < Struct.new( :user_data, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :security_groups, :monitoring) SENSITIVE = [:user_data] include Aws::Structure end |
#placement ⇒ Types::SpotPlacement
The placement information for the instance.
57451 57452 57453 57454 57455 57456 57457 57458 57459 57460 57461 57462 57463 57464 57465 57466 57467 57468 57469 |
# File 'lib/aws-sdk-ec2/types.rb', line 57451 class LaunchSpecification < Struct.new( :user_data, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :security_groups, :monitoring) SENSITIVE = [:user_data] include Aws::Structure end |
#ramdisk_id ⇒ String
The ID of the RAM disk.
57451 57452 57453 57454 57455 57456 57457 57458 57459 57460 57461 57462 57463 57464 57465 57466 57467 57468 57469 |
# File 'lib/aws-sdk-ec2/types.rb', line 57451 class LaunchSpecification < Struct.new( :user_data, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :security_groups, :monitoring) SENSITIVE = [:user_data] include Aws::Structure end |
#security_groups ⇒ Array<Types::GroupIdentifier>
The IDs of the security groups.
57451 57452 57453 57454 57455 57456 57457 57458 57459 57460 57461 57462 57463 57464 57465 57466 57467 57468 57469 |
# File 'lib/aws-sdk-ec2/types.rb', line 57451 class LaunchSpecification < Struct.new( :user_data, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :security_groups, :monitoring) SENSITIVE = [:user_data] include Aws::Structure end |
#subnet_id ⇒ String
The ID of the subnet in which to launch the instance.
57451 57452 57453 57454 57455 57456 57457 57458 57459 57460 57461 57462 57463 57464 57465 57466 57467 57468 57469 |
# File 'lib/aws-sdk-ec2/types.rb', line 57451 class LaunchSpecification < Struct.new( :user_data, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :security_groups, :monitoring) SENSITIVE = [:user_data] include Aws::Structure end |
#user_data ⇒ String
The base64-encoded user data that instances use when starting up. User data is limited to 16 KB.
57451 57452 57453 57454 57455 57456 57457 57458 57459 57460 57461 57462 57463 57464 57465 57466 57467 57468 57469 |
# File 'lib/aws-sdk-ec2/types.rb', line 57451 class LaunchSpecification < Struct.new( :user_data, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :security_groups, :monitoring) SENSITIVE = [:user_data] include Aws::Structure end |