Class: Aws::EC2::Types::LaunchSpecification
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::LaunchSpecification
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the launch specification for an instance.
Constant Summary collapse
- SENSITIVE =
[:user_data]
Instance Attribute Summary collapse
-
#addressing_type ⇒ String
Deprecated.
-
#block_device_mappings ⇒ Array<Types::BlockDeviceMapping>
The block device mapping entries.
-
#ebs_optimized ⇒ Boolean
Indicates whether the instance is optimized for EBS I/O.
-
#iam_instance_profile ⇒ Types::IamInstanceProfileSpecification
The IAM instance profile.
-
#image_id ⇒ String
The ID of the AMI.
-
#instance_type ⇒ String
The instance type.
-
#kernel_id ⇒ String
The ID of the kernel.
-
#key_name ⇒ String
The name of the key pair.
-
#monitoring ⇒ Types::RunInstancesMonitoringEnabled
Describes the monitoring of an instance.
-
#network_interfaces ⇒ Array<Types::InstanceNetworkInterfaceSpecification>
The network interfaces.
-
#placement ⇒ Types::SpotPlacement
The placement information for the instance.
-
#ramdisk_id ⇒ String
The ID of the RAM disk.
-
#security_groups ⇒ Array<Types::GroupIdentifier>
The IDs of the security groups.
-
#subnet_id ⇒ String
The ID of the subnet in which to launch the instance.
-
#user_data ⇒ String
The base64-encoded user data that instances use when starting up.
Instance Attribute Details
#addressing_type ⇒ String
Deprecated.
56948 56949 56950 56951 56952 56953 56954 56955 56956 56957 56958 56959 56960 56961 56962 56963 56964 56965 56966 |
# File 'lib/aws-sdk-ec2/types.rb', line 56948 class LaunchSpecification < Struct.new( :user_data, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :security_groups, :monitoring) SENSITIVE = [:user_data] include Aws::Structure end |
#block_device_mappings ⇒ Array<Types::BlockDeviceMapping>
The block device mapping entries.
56948 56949 56950 56951 56952 56953 56954 56955 56956 56957 56958 56959 56960 56961 56962 56963 56964 56965 56966 |
# File 'lib/aws-sdk-ec2/types.rb', line 56948 class LaunchSpecification < Struct.new( :user_data, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :security_groups, :monitoring) SENSITIVE = [:user_data] include Aws::Structure end |
#ebs_optimized ⇒ Boolean
Indicates whether the instance is optimized for EBS I/O. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal EBS I/O performance. This optimization isn’t available with all instance types. Additional usage charges apply when using an EBS Optimized instance.
Default: ‘false`
56948 56949 56950 56951 56952 56953 56954 56955 56956 56957 56958 56959 56960 56961 56962 56963 56964 56965 56966 |
# File 'lib/aws-sdk-ec2/types.rb', line 56948 class LaunchSpecification < Struct.new( :user_data, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :security_groups, :monitoring) SENSITIVE = [:user_data] include Aws::Structure end |
#iam_instance_profile ⇒ Types::IamInstanceProfileSpecification
The IAM instance profile.
56948 56949 56950 56951 56952 56953 56954 56955 56956 56957 56958 56959 56960 56961 56962 56963 56964 56965 56966 |
# File 'lib/aws-sdk-ec2/types.rb', line 56948 class LaunchSpecification < Struct.new( :user_data, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :security_groups, :monitoring) SENSITIVE = [:user_data] include Aws::Structure end |
#image_id ⇒ String
The ID of the AMI.
56948 56949 56950 56951 56952 56953 56954 56955 56956 56957 56958 56959 56960 56961 56962 56963 56964 56965 56966 |
# File 'lib/aws-sdk-ec2/types.rb', line 56948 class LaunchSpecification < Struct.new( :user_data, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :security_groups, :monitoring) SENSITIVE = [:user_data] include Aws::Structure end |
#instance_type ⇒ String
The instance type. Only one instance type can be specified.
56948 56949 56950 56951 56952 56953 56954 56955 56956 56957 56958 56959 56960 56961 56962 56963 56964 56965 56966 |
# File 'lib/aws-sdk-ec2/types.rb', line 56948 class LaunchSpecification < Struct.new( :user_data, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :security_groups, :monitoring) SENSITIVE = [:user_data] include Aws::Structure end |
#kernel_id ⇒ String
The ID of the kernel.
56948 56949 56950 56951 56952 56953 56954 56955 56956 56957 56958 56959 56960 56961 56962 56963 56964 56965 56966 |
# File 'lib/aws-sdk-ec2/types.rb', line 56948 class LaunchSpecification < Struct.new( :user_data, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :security_groups, :monitoring) SENSITIVE = [:user_data] include Aws::Structure end |
#key_name ⇒ String
The name of the key pair.
56948 56949 56950 56951 56952 56953 56954 56955 56956 56957 56958 56959 56960 56961 56962 56963 56964 56965 56966 |
# File 'lib/aws-sdk-ec2/types.rb', line 56948 class LaunchSpecification < Struct.new( :user_data, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :security_groups, :monitoring) SENSITIVE = [:user_data] include Aws::Structure end |
#monitoring ⇒ Types::RunInstancesMonitoringEnabled
Describes the monitoring of an instance.
56948 56949 56950 56951 56952 56953 56954 56955 56956 56957 56958 56959 56960 56961 56962 56963 56964 56965 56966 |
# File 'lib/aws-sdk-ec2/types.rb', line 56948 class LaunchSpecification < Struct.new( :user_data, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :security_groups, :monitoring) SENSITIVE = [:user_data] include Aws::Structure end |
#network_interfaces ⇒ Array<Types::InstanceNetworkInterfaceSpecification>
The network interfaces. If you specify a network interface, you must specify subnet IDs and security group IDs using the network interface.
56948 56949 56950 56951 56952 56953 56954 56955 56956 56957 56958 56959 56960 56961 56962 56963 56964 56965 56966 |
# File 'lib/aws-sdk-ec2/types.rb', line 56948 class LaunchSpecification < Struct.new( :user_data, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :security_groups, :monitoring) SENSITIVE = [:user_data] include Aws::Structure end |
#placement ⇒ Types::SpotPlacement
The placement information for the instance.
56948 56949 56950 56951 56952 56953 56954 56955 56956 56957 56958 56959 56960 56961 56962 56963 56964 56965 56966 |
# File 'lib/aws-sdk-ec2/types.rb', line 56948 class LaunchSpecification < Struct.new( :user_data, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :security_groups, :monitoring) SENSITIVE = [:user_data] include Aws::Structure end |
#ramdisk_id ⇒ String
The ID of the RAM disk.
56948 56949 56950 56951 56952 56953 56954 56955 56956 56957 56958 56959 56960 56961 56962 56963 56964 56965 56966 |
# File 'lib/aws-sdk-ec2/types.rb', line 56948 class LaunchSpecification < Struct.new( :user_data, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :security_groups, :monitoring) SENSITIVE = [:user_data] include Aws::Structure end |
#security_groups ⇒ Array<Types::GroupIdentifier>
The IDs of the security groups.
56948 56949 56950 56951 56952 56953 56954 56955 56956 56957 56958 56959 56960 56961 56962 56963 56964 56965 56966 |
# File 'lib/aws-sdk-ec2/types.rb', line 56948 class LaunchSpecification < Struct.new( :user_data, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :security_groups, :monitoring) SENSITIVE = [:user_data] include Aws::Structure end |
#subnet_id ⇒ String
The ID of the subnet in which to launch the instance.
56948 56949 56950 56951 56952 56953 56954 56955 56956 56957 56958 56959 56960 56961 56962 56963 56964 56965 56966 |
# File 'lib/aws-sdk-ec2/types.rb', line 56948 class LaunchSpecification < Struct.new( :user_data, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :security_groups, :monitoring) SENSITIVE = [:user_data] include Aws::Structure end |
#user_data ⇒ String
The base64-encoded user data that instances use when starting up. User data is limited to 16 KB.
56948 56949 56950 56951 56952 56953 56954 56955 56956 56957 56958 56959 56960 56961 56962 56963 56964 56965 56966 |
# File 'lib/aws-sdk-ec2/types.rb', line 56948 class LaunchSpecification < Struct.new( :user_data, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :security_groups, :monitoring) SENSITIVE = [:user_data] include Aws::Structure end |