Class: Aws::EC2::Types::LaunchTemplateBlockDeviceMappingRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes a block device mapping.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#device_nameString

The device name (for example, /dev/sdh or xvdh).

Returns:

  • (String)


59329
59330
59331
59332
59333
59334
59335
59336
# File 'lib/aws-sdk-ec2/types.rb', line 59329

class LaunchTemplateBlockDeviceMappingRequest < Struct.new(
  :device_name,
  :virtual_name,
  :ebs,
  :no_device)
  SENSITIVE = []
  include Aws::Structure
end

#ebsTypes::LaunchTemplateEbsBlockDeviceRequest

Parameters used to automatically set up EBS volumes when the instance is launched.



59329
59330
59331
59332
59333
59334
59335
59336
# File 'lib/aws-sdk-ec2/types.rb', line 59329

class LaunchTemplateBlockDeviceMappingRequest < Struct.new(
  :device_name,
  :virtual_name,
  :ebs,
  :no_device)
  SENSITIVE = []
  include Aws::Structure
end

#no_deviceString

To omit the device from the block device mapping, specify an empty string.

Returns:

  • (String)


59329
59330
59331
59332
59333
59334
59335
59336
# File 'lib/aws-sdk-ec2/types.rb', line 59329

class LaunchTemplateBlockDeviceMappingRequest < Struct.new(
  :device_name,
  :virtual_name,
  :ebs,
  :no_device)
  SENSITIVE = []
  include Aws::Structure
end

#virtual_nameString

The virtual device name (ephemeralN). Instance store volumes are numbered starting from 0. An instance type with 2 available instance store volumes can specify mappings for ephemeral0 and ephemeral1. The number of available instance store volumes depends on the instance type. After you connect to the instance, you must mount the volume.

Returns:

  • (String)


59329
59330
59331
59332
59333
59334
59335
59336
# File 'lib/aws-sdk-ec2/types.rb', line 59329

class LaunchTemplateBlockDeviceMappingRequest < Struct.new(
  :device_name,
  :virtual_name,
  :ebs,
  :no_device)
  SENSITIVE = []
  include Aws::Structure
end