Class: Aws::EC2::Types::LaunchTemplateEnclaveOptionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Indicates whether the instance is enabled for Amazon Web Services Nitro Enclaves. For more information, see What is Nitro Enclaves? in the Amazon Web Services Nitro Enclaves User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enabledBoolean

To enable the instance for Amazon Web Services Nitro Enclaves, set this parameter to true.

Returns:

  • (Boolean)


59841
59842
59843
59844
59845
# File 'lib/aws-sdk-ec2/types.rb', line 59841

class LaunchTemplateEnclaveOptionsRequest < Struct.new(
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end