Class: Aws::EC2::Types::LaunchTemplateEnclaveOptionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::LaunchTemplateEnclaveOptionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Indicates whether the instance is enabled for Amazon Web Services Nitro Enclaves. For more information, see What is Nitro Enclaves? in the Amazon Web Services Nitro Enclaves User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
To enable the instance for Amazon Web Services Nitro Enclaves, set this parameter to
true.
Instance Attribute Details
#enabled ⇒ Boolean
To enable the instance for Amazon Web Services Nitro Enclaves, set
this parameter to true.
58610 58611 58612 58613 58614 |
# File 'lib/aws-sdk-ec2/types.rb', line 58610 class LaunchTemplateEnclaveOptionsRequest < Struct.new( :enabled) SENSITIVE = [] include Aws::Structure end |