Class: Aws::EC2::Types::LaunchTemplateInstanceSecondaryInterfaceSpecification
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::LaunchTemplateInstanceSecondaryInterfaceSpecification
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a secondary interface specification in a launch template.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#delete_on_termination ⇒ Boolean
Indicates whether the secondary interface is deleted when the instance is terminated.
-
#device_index ⇒ Integer
The device index for the secondary interface attachment.
-
#interface_type ⇒ String
The type of secondary interface.
-
#network_card_index ⇒ Integer
The index of the network card.
-
#private_ip_address_count ⇒ Integer
The number of private IPv4 addresses to assign to the secondary interface.
-
#private_ip_addresses ⇒ Array<Types::SecondaryInterfacePrivateIpAddressSpecification>
The private IPv4 addresses to assign to the secondary interface.
-
#secondary_subnet_id ⇒ String
The ID of the secondary subnet.
Instance Attribute Details
#delete_on_termination ⇒ Boolean
Indicates whether the secondary interface is deleted when the instance is terminated.
The only supported value for this field is true.
60562 60563 60564 60565 60566 60567 60568 60569 60570 60571 60572 |
# File 'lib/aws-sdk-ec2/types.rb', line 60562 class LaunchTemplateInstanceSecondaryInterfaceSpecification < Struct.new( :delete_on_termination, :device_index, :private_ip_addresses, :private_ip_address_count, :secondary_subnet_id, :interface_type, :network_card_index) SENSITIVE = [] include Aws::Structure end |
#device_index ⇒ Integer
The device index for the secondary interface attachment.
60562 60563 60564 60565 60566 60567 60568 60569 60570 60571 60572 |
# File 'lib/aws-sdk-ec2/types.rb', line 60562 class LaunchTemplateInstanceSecondaryInterfaceSpecification < Struct.new( :delete_on_termination, :device_index, :private_ip_addresses, :private_ip_address_count, :secondary_subnet_id, :interface_type, :network_card_index) SENSITIVE = [] include Aws::Structure end |
#interface_type ⇒ String
The type of secondary interface.
60562 60563 60564 60565 60566 60567 60568 60569 60570 60571 60572 |
# File 'lib/aws-sdk-ec2/types.rb', line 60562 class LaunchTemplateInstanceSecondaryInterfaceSpecification < Struct.new( :delete_on_termination, :device_index, :private_ip_addresses, :private_ip_address_count, :secondary_subnet_id, :interface_type, :network_card_index) SENSITIVE = [] include Aws::Structure end |
#network_card_index ⇒ Integer
The index of the network card.
60562 60563 60564 60565 60566 60567 60568 60569 60570 60571 60572 |
# File 'lib/aws-sdk-ec2/types.rb', line 60562 class LaunchTemplateInstanceSecondaryInterfaceSpecification < Struct.new( :delete_on_termination, :device_index, :private_ip_addresses, :private_ip_address_count, :secondary_subnet_id, :interface_type, :network_card_index) SENSITIVE = [] include Aws::Structure end |
#private_ip_address_count ⇒ Integer
The number of private IPv4 addresses to assign to the secondary interface.
If you specify privateIpAddressCount you cannot specify
privateIpAddresses
60562 60563 60564 60565 60566 60567 60568 60569 60570 60571 60572 |
# File 'lib/aws-sdk-ec2/types.rb', line 60562 class LaunchTemplateInstanceSecondaryInterfaceSpecification < Struct.new( :delete_on_termination, :device_index, :private_ip_addresses, :private_ip_address_count, :secondary_subnet_id, :interface_type, :network_card_index) SENSITIVE = [] include Aws::Structure end |
#private_ip_addresses ⇒ Array<Types::SecondaryInterfacePrivateIpAddressSpecification>
The private IPv4 addresses to assign to the secondary interface.
If you specify privateIpAddresses you cannot specify
privateIpAddressCount
60562 60563 60564 60565 60566 60567 60568 60569 60570 60571 60572 |
# File 'lib/aws-sdk-ec2/types.rb', line 60562 class LaunchTemplateInstanceSecondaryInterfaceSpecification < Struct.new( :delete_on_termination, :device_index, :private_ip_addresses, :private_ip_address_count, :secondary_subnet_id, :interface_type, :network_card_index) SENSITIVE = [] include Aws::Structure end |
#secondary_subnet_id ⇒ String
The ID of the secondary subnet.
60562 60563 60564 60565 60566 60567 60568 60569 60570 60571 60572 |
# File 'lib/aws-sdk-ec2/types.rb', line 60562 class LaunchTemplateInstanceSecondaryInterfaceSpecification < Struct.new( :delete_on_termination, :device_index, :private_ip_addresses, :private_ip_address_count, :secondary_subnet_id, :interface_type, :network_card_index) SENSITIVE = [] include Aws::Structure end |