Class: Aws::EC2::Types::LaunchTemplateInstanceSecondaryInterfaceSpecification
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::LaunchTemplateInstanceSecondaryInterfaceSpecification
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a secondary interface specification in a launch template.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#delete_on_termination ⇒ Boolean
Indicates whether the secondary interface is deleted when the instance is terminated.
-
#device_index ⇒ Integer
The device index for the secondary interface attachment.
-
#interface_type ⇒ String
The type of secondary interface.
-
#network_card_index ⇒ Integer
The index of the network card.
-
#private_ip_address_count ⇒ Integer
The number of private IPv4 addresses to assign to the secondary interface.
-
#private_ip_addresses ⇒ Array<Types::SecondaryInterfacePrivateIpAddressSpecification>
The private IPv4 addresses to assign to the secondary interface.
-
#secondary_subnet_id ⇒ String
The ID of the secondary subnet.
Instance Attribute Details
#delete_on_termination ⇒ Boolean
Indicates whether the secondary interface is deleted when the instance is terminated.
The only supported value for this field is true.
59057 59058 59059 59060 59061 59062 59063 59064 59065 59066 59067 |
# File 'lib/aws-sdk-ec2/types.rb', line 59057 class LaunchTemplateInstanceSecondaryInterfaceSpecification < Struct.new( :delete_on_termination, :device_index, :private_ip_addresses, :private_ip_address_count, :secondary_subnet_id, :interface_type, :network_card_index) SENSITIVE = [] include Aws::Structure end |
#device_index ⇒ Integer
The device index for the secondary interface attachment.
59057 59058 59059 59060 59061 59062 59063 59064 59065 59066 59067 |
# File 'lib/aws-sdk-ec2/types.rb', line 59057 class LaunchTemplateInstanceSecondaryInterfaceSpecification < Struct.new( :delete_on_termination, :device_index, :private_ip_addresses, :private_ip_address_count, :secondary_subnet_id, :interface_type, :network_card_index) SENSITIVE = [] include Aws::Structure end |
#interface_type ⇒ String
The type of secondary interface.
59057 59058 59059 59060 59061 59062 59063 59064 59065 59066 59067 |
# File 'lib/aws-sdk-ec2/types.rb', line 59057 class LaunchTemplateInstanceSecondaryInterfaceSpecification < Struct.new( :delete_on_termination, :device_index, :private_ip_addresses, :private_ip_address_count, :secondary_subnet_id, :interface_type, :network_card_index) SENSITIVE = [] include Aws::Structure end |
#network_card_index ⇒ Integer
The index of the network card.
59057 59058 59059 59060 59061 59062 59063 59064 59065 59066 59067 |
# File 'lib/aws-sdk-ec2/types.rb', line 59057 class LaunchTemplateInstanceSecondaryInterfaceSpecification < Struct.new( :delete_on_termination, :device_index, :private_ip_addresses, :private_ip_address_count, :secondary_subnet_id, :interface_type, :network_card_index) SENSITIVE = [] include Aws::Structure end |
#private_ip_address_count ⇒ Integer
The number of private IPv4 addresses to assign to the secondary interface.
If you specify privateIpAddressCount you cannot specify
privateIpAddresses
59057 59058 59059 59060 59061 59062 59063 59064 59065 59066 59067 |
# File 'lib/aws-sdk-ec2/types.rb', line 59057 class LaunchTemplateInstanceSecondaryInterfaceSpecification < Struct.new( :delete_on_termination, :device_index, :private_ip_addresses, :private_ip_address_count, :secondary_subnet_id, :interface_type, :network_card_index) SENSITIVE = [] include Aws::Structure end |
#private_ip_addresses ⇒ Array<Types::SecondaryInterfacePrivateIpAddressSpecification>
The private IPv4 addresses to assign to the secondary interface.
If you specify privateIpAddresses you cannot specify
privateIpAddressCount
59057 59058 59059 59060 59061 59062 59063 59064 59065 59066 59067 |
# File 'lib/aws-sdk-ec2/types.rb', line 59057 class LaunchTemplateInstanceSecondaryInterfaceSpecification < Struct.new( :delete_on_termination, :device_index, :private_ip_addresses, :private_ip_address_count, :secondary_subnet_id, :interface_type, :network_card_index) SENSITIVE = [] include Aws::Structure end |
#secondary_subnet_id ⇒ String
The ID of the secondary subnet.
59057 59058 59059 59060 59061 59062 59063 59064 59065 59066 59067 |
# File 'lib/aws-sdk-ec2/types.rb', line 59057 class LaunchTemplateInstanceSecondaryInterfaceSpecification < Struct.new( :delete_on_termination, :device_index, :private_ip_addresses, :private_ip_address_count, :secondary_subnet_id, :interface_type, :network_card_index) SENSITIVE = [] include Aws::Structure end |