Class: Aws::EC2::Types::LaunchTemplateInstanceSecondaryInterfaceSpecification

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes a secondary interface specification in a launch template.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#delete_on_terminationBoolean

Indicates whether the secondary interface is deleted when the instance is terminated.

The only supported value for this field is ‘true`.

Returns:

  • (Boolean)


58120
58121
58122
58123
58124
58125
58126
58127
58128
58129
58130
# File 'lib/aws-sdk-ec2/types.rb', line 58120

class LaunchTemplateInstanceSecondaryInterfaceSpecification < Struct.new(
  :delete_on_termination,
  :device_index,
  :private_ip_addresses,
  :private_ip_address_count,
  :secondary_subnet_id,
  :interface_type,
  :network_card_index)
  SENSITIVE = []
  include Aws::Structure
end

#device_indexInteger

The device index for the secondary interface attachment.

Returns:

  • (Integer)


58120
58121
58122
58123
58124
58125
58126
58127
58128
58129
58130
# File 'lib/aws-sdk-ec2/types.rb', line 58120

class LaunchTemplateInstanceSecondaryInterfaceSpecification < Struct.new(
  :delete_on_termination,
  :device_index,
  :private_ip_addresses,
  :private_ip_address_count,
  :secondary_subnet_id,
  :interface_type,
  :network_card_index)
  SENSITIVE = []
  include Aws::Structure
end

#interface_typeString

The type of secondary interface.

Returns:

  • (String)


58120
58121
58122
58123
58124
58125
58126
58127
58128
58129
58130
# File 'lib/aws-sdk-ec2/types.rb', line 58120

class LaunchTemplateInstanceSecondaryInterfaceSpecification < Struct.new(
  :delete_on_termination,
  :device_index,
  :private_ip_addresses,
  :private_ip_address_count,
  :secondary_subnet_id,
  :interface_type,
  :network_card_index)
  SENSITIVE = []
  include Aws::Structure
end

#network_card_indexInteger

The index of the network card.

Returns:

  • (Integer)


58120
58121
58122
58123
58124
58125
58126
58127
58128
58129
58130
# File 'lib/aws-sdk-ec2/types.rb', line 58120

class LaunchTemplateInstanceSecondaryInterfaceSpecification < Struct.new(
  :delete_on_termination,
  :device_index,
  :private_ip_addresses,
  :private_ip_address_count,
  :secondary_subnet_id,
  :interface_type,
  :network_card_index)
  SENSITIVE = []
  include Aws::Structure
end

#private_ip_address_countInteger

The number of private IPv4 addresses to assign to the secondary interface.

If you specify ‘privateIpAddressCount` you cannot specify `privateIpAddresses`

Returns:

  • (Integer)


58120
58121
58122
58123
58124
58125
58126
58127
58128
58129
58130
# File 'lib/aws-sdk-ec2/types.rb', line 58120

class LaunchTemplateInstanceSecondaryInterfaceSpecification < Struct.new(
  :delete_on_termination,
  :device_index,
  :private_ip_addresses,
  :private_ip_address_count,
  :secondary_subnet_id,
  :interface_type,
  :network_card_index)
  SENSITIVE = []
  include Aws::Structure
end

#private_ip_addressesArray<Types::SecondaryInterfacePrivateIpAddressSpecification>

The private IPv4 addresses to assign to the secondary interface.

If you specify ‘privateIpAddresses` you cannot specify `privateIpAddressCount`



58120
58121
58122
58123
58124
58125
58126
58127
58128
58129
58130
# File 'lib/aws-sdk-ec2/types.rb', line 58120

class LaunchTemplateInstanceSecondaryInterfaceSpecification < Struct.new(
  :delete_on_termination,
  :device_index,
  :private_ip_addresses,
  :private_ip_address_count,
  :secondary_subnet_id,
  :interface_type,
  :network_card_index)
  SENSITIVE = []
  include Aws::Structure
end

#secondary_subnet_idString

The ID of the secondary subnet.

Returns:

  • (String)


58120
58121
58122
58123
58124
58125
58126
58127
58128
58129
58130
# File 'lib/aws-sdk-ec2/types.rb', line 58120

class LaunchTemplateInstanceSecondaryInterfaceSpecification < Struct.new(
  :delete_on_termination,
  :device_index,
  :private_ip_addresses,
  :private_ip_address_count,
  :secondary_subnet_id,
  :interface_type,
  :network_card_index)
  SENSITIVE = []
  include Aws::Structure
end