Class: Aws::EC2::Types::LaunchTemplateInstanceSecondaryInterfaceSpecificationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes a secondary interface specification for a launch template request.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#delete_on_terminationBoolean

Indicates whether the secondary interface is deleted when the instance is terminated.

The only supported value for this field is true.

Returns:

  • (Boolean)


59120
59121
59122
59123
59124
59125
59126
59127
59128
59129
59130
# File 'lib/aws-sdk-ec2/types.rb', line 59120

class LaunchTemplateInstanceSecondaryInterfaceSpecificationRequest < Struct.new(
  :delete_on_termination,
  :device_index,
  :private_ip_addresses,
  :private_ip_address_count,
  :secondary_subnet_id,
  :interface_type,
  :network_card_index)
  SENSITIVE = []
  include Aws::Structure
end

#device_indexInteger

The device index for the secondary interface attachment.

Returns:

  • (Integer)


59120
59121
59122
59123
59124
59125
59126
59127
59128
59129
59130
# File 'lib/aws-sdk-ec2/types.rb', line 59120

class LaunchTemplateInstanceSecondaryInterfaceSpecificationRequest < Struct.new(
  :delete_on_termination,
  :device_index,
  :private_ip_addresses,
  :private_ip_address_count,
  :secondary_subnet_id,
  :interface_type,
  :network_card_index)
  SENSITIVE = []
  include Aws::Structure
end

#interface_typeString

The type of secondary interface.

Returns:

  • (String)


59120
59121
59122
59123
59124
59125
59126
59127
59128
59129
59130
# File 'lib/aws-sdk-ec2/types.rb', line 59120

class LaunchTemplateInstanceSecondaryInterfaceSpecificationRequest < Struct.new(
  :delete_on_termination,
  :device_index,
  :private_ip_addresses,
  :private_ip_address_count,
  :secondary_subnet_id,
  :interface_type,
  :network_card_index)
  SENSITIVE = []
  include Aws::Structure
end

#network_card_indexInteger

The index of the network card.

Returns:

  • (Integer)


59120
59121
59122
59123
59124
59125
59126
59127
59128
59129
59130
# File 'lib/aws-sdk-ec2/types.rb', line 59120

class LaunchTemplateInstanceSecondaryInterfaceSpecificationRequest < Struct.new(
  :delete_on_termination,
  :device_index,
  :private_ip_addresses,
  :private_ip_address_count,
  :secondary_subnet_id,
  :interface_type,
  :network_card_index)
  SENSITIVE = []
  include Aws::Structure
end

#private_ip_address_countInteger

The number of private IPv4 addresses to assign to the secondary interface.

Returns:

  • (Integer)


59120
59121
59122
59123
59124
59125
59126
59127
59128
59129
59130
# File 'lib/aws-sdk-ec2/types.rb', line 59120

class LaunchTemplateInstanceSecondaryInterfaceSpecificationRequest < Struct.new(
  :delete_on_termination,
  :device_index,
  :private_ip_addresses,
  :private_ip_address_count,
  :secondary_subnet_id,
  :interface_type,
  :network_card_index)
  SENSITIVE = []
  include Aws::Structure
end

#private_ip_addressesArray<Types::SecondaryInterfacePrivateIpAddressSpecificationRequest>

The private IPv4 addresses to assign to the secondary interface.



59120
59121
59122
59123
59124
59125
59126
59127
59128
59129
59130
# File 'lib/aws-sdk-ec2/types.rb', line 59120

class LaunchTemplateInstanceSecondaryInterfaceSpecificationRequest < Struct.new(
  :delete_on_termination,
  :device_index,
  :private_ip_addresses,
  :private_ip_address_count,
  :secondary_subnet_id,
  :interface_type,
  :network_card_index)
  SENSITIVE = []
  include Aws::Structure
end

#secondary_subnet_idString

The ID of the secondary subnet.

Returns:

  • (String)


59120
59121
59122
59123
59124
59125
59126
59127
59128
59129
59130
# File 'lib/aws-sdk-ec2/types.rb', line 59120

class LaunchTemplateInstanceSecondaryInterfaceSpecificationRequest < Struct.new(
  :delete_on_termination,
  :device_index,
  :private_ip_addresses,
  :private_ip_address_count,
  :secondary_subnet_id,
  :interface_type,
  :network_card_index)
  SENSITIVE = []
  include Aws::Structure
end