Class: Aws::EC2::Types::LaunchTemplateInstanceSecondaryInterfaceSpecificationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::LaunchTemplateInstanceSecondaryInterfaceSpecificationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a secondary interface specification for a launch template request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#delete_on_termination ⇒ Boolean
Indicates whether the secondary interface is deleted when the instance is terminated.
-
#device_index ⇒ Integer
The device index for the secondary interface attachment.
-
#interface_type ⇒ String
The type of secondary interface.
-
#network_card_index ⇒ Integer
The index of the network card.
-
#private_ip_address_count ⇒ Integer
The number of private IPv4 addresses to assign to the secondary interface.
-
#private_ip_addresses ⇒ Array<Types::SecondaryInterfacePrivateIpAddressSpecificationRequest>
The private IPv4 addresses to assign to the secondary interface.
-
#secondary_subnet_id ⇒ String
The ID of the secondary subnet.
Instance Attribute Details
#delete_on_termination ⇒ Boolean
Indicates whether the secondary interface is deleted when the instance is terminated.
The only supported value for this field is true.
58885 58886 58887 58888 58889 58890 58891 58892 58893 58894 58895 |
# File 'lib/aws-sdk-ec2/types.rb', line 58885 class LaunchTemplateInstanceSecondaryInterfaceSpecificationRequest < Struct.new( :delete_on_termination, :device_index, :private_ip_addresses, :private_ip_address_count, :secondary_subnet_id, :interface_type, :network_card_index) SENSITIVE = [] include Aws::Structure end |
#device_index ⇒ Integer
The device index for the secondary interface attachment.
58885 58886 58887 58888 58889 58890 58891 58892 58893 58894 58895 |
# File 'lib/aws-sdk-ec2/types.rb', line 58885 class LaunchTemplateInstanceSecondaryInterfaceSpecificationRequest < Struct.new( :delete_on_termination, :device_index, :private_ip_addresses, :private_ip_address_count, :secondary_subnet_id, :interface_type, :network_card_index) SENSITIVE = [] include Aws::Structure end |
#interface_type ⇒ String
The type of secondary interface.
58885 58886 58887 58888 58889 58890 58891 58892 58893 58894 58895 |
# File 'lib/aws-sdk-ec2/types.rb', line 58885 class LaunchTemplateInstanceSecondaryInterfaceSpecificationRequest < Struct.new( :delete_on_termination, :device_index, :private_ip_addresses, :private_ip_address_count, :secondary_subnet_id, :interface_type, :network_card_index) SENSITIVE = [] include Aws::Structure end |
#network_card_index ⇒ Integer
The index of the network card.
58885 58886 58887 58888 58889 58890 58891 58892 58893 58894 58895 |
# File 'lib/aws-sdk-ec2/types.rb', line 58885 class LaunchTemplateInstanceSecondaryInterfaceSpecificationRequest < Struct.new( :delete_on_termination, :device_index, :private_ip_addresses, :private_ip_address_count, :secondary_subnet_id, :interface_type, :network_card_index) SENSITIVE = [] include Aws::Structure end |
#private_ip_address_count ⇒ Integer
The number of private IPv4 addresses to assign to the secondary interface.
58885 58886 58887 58888 58889 58890 58891 58892 58893 58894 58895 |
# File 'lib/aws-sdk-ec2/types.rb', line 58885 class LaunchTemplateInstanceSecondaryInterfaceSpecificationRequest < Struct.new( :delete_on_termination, :device_index, :private_ip_addresses, :private_ip_address_count, :secondary_subnet_id, :interface_type, :network_card_index) SENSITIVE = [] include Aws::Structure end |
#private_ip_addresses ⇒ Array<Types::SecondaryInterfacePrivateIpAddressSpecificationRequest>
The private IPv4 addresses to assign to the secondary interface.
58885 58886 58887 58888 58889 58890 58891 58892 58893 58894 58895 |
# File 'lib/aws-sdk-ec2/types.rb', line 58885 class LaunchTemplateInstanceSecondaryInterfaceSpecificationRequest < Struct.new( :delete_on_termination, :device_index, :private_ip_addresses, :private_ip_address_count, :secondary_subnet_id, :interface_type, :network_card_index) SENSITIVE = [] include Aws::Structure end |
#secondary_subnet_id ⇒ String
The ID of the secondary subnet.
58885 58886 58887 58888 58889 58890 58891 58892 58893 58894 58895 |
# File 'lib/aws-sdk-ec2/types.rb', line 58885 class LaunchTemplateInstanceSecondaryInterfaceSpecificationRequest < Struct.new( :delete_on_termination, :device_index, :private_ip_addresses, :private_ip_address_count, :secondary_subnet_id, :interface_type, :network_card_index) SENSITIVE = [] include Aws::Structure end |