Class: Aws::EC2::Types::LaunchTemplatePlacement
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::LaunchTemplatePlacement
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the placement of an instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#affinity ⇒ String
The affinity setting for the instance on the Dedicated Host.
-
#availability_zone ⇒ String
The Availability Zone of the instance.
-
#availability_zone_id ⇒ String
The ID of the Availability Zone of the instance.
-
#group_id ⇒ String
The Group ID of the placement group.
-
#group_name ⇒ String
The name of the placement group for the instance.
-
#host_id ⇒ String
The ID of the Dedicated Host for the instance.
-
#host_resource_group_arn ⇒ String
The ARN of the host resource group in which to launch the instances.
-
#partition_number ⇒ Integer
The number of the partition the instance should launch in.
-
#spread_domain ⇒ String
Reserved for future use.
-
#tenancy ⇒ String
The tenancy of the instance.
Instance Attribute Details
#affinity ⇒ String
The affinity setting for the instance on the Dedicated Host.
59349 59350 59351 59352 59353 59354 59355 59356 59357 59358 59359 59360 59361 59362 |
# File 'lib/aws-sdk-ec2/types.rb', line 59349 class LaunchTemplatePlacement < Struct.new( :availability_zone, :availability_zone_id, :affinity, :group_name, :host_id, :tenancy, :spread_domain, :host_resource_group_arn, :partition_number, :group_id) SENSITIVE = [] include Aws::Structure end |
#availability_zone ⇒ String
The Availability Zone of the instance.
59349 59350 59351 59352 59353 59354 59355 59356 59357 59358 59359 59360 59361 59362 |
# File 'lib/aws-sdk-ec2/types.rb', line 59349 class LaunchTemplatePlacement < Struct.new( :availability_zone, :availability_zone_id, :affinity, :group_name, :host_id, :tenancy, :spread_domain, :host_resource_group_arn, :partition_number, :group_id) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
The ID of the Availability Zone of the instance.
59349 59350 59351 59352 59353 59354 59355 59356 59357 59358 59359 59360 59361 59362 |
# File 'lib/aws-sdk-ec2/types.rb', line 59349 class LaunchTemplatePlacement < Struct.new( :availability_zone, :availability_zone_id, :affinity, :group_name, :host_id, :tenancy, :spread_domain, :host_resource_group_arn, :partition_number, :group_id) SENSITIVE = [] include Aws::Structure end |
#group_id ⇒ String
The Group ID of the placement group. You must specify the Placement Group Group ID to launch an instance in a shared placement group.
59349 59350 59351 59352 59353 59354 59355 59356 59357 59358 59359 59360 59361 59362 |
# File 'lib/aws-sdk-ec2/types.rb', line 59349 class LaunchTemplatePlacement < Struct.new( :availability_zone, :availability_zone_id, :affinity, :group_name, :host_id, :tenancy, :spread_domain, :host_resource_group_arn, :partition_number, :group_id) SENSITIVE = [] include Aws::Structure end |
#group_name ⇒ String
The name of the placement group for the instance.
59349 59350 59351 59352 59353 59354 59355 59356 59357 59358 59359 59360 59361 59362 |
# File 'lib/aws-sdk-ec2/types.rb', line 59349 class LaunchTemplatePlacement < Struct.new( :availability_zone, :availability_zone_id, :affinity, :group_name, :host_id, :tenancy, :spread_domain, :host_resource_group_arn, :partition_number, :group_id) SENSITIVE = [] include Aws::Structure end |
#host_id ⇒ String
The ID of the Dedicated Host for the instance.
59349 59350 59351 59352 59353 59354 59355 59356 59357 59358 59359 59360 59361 59362 |
# File 'lib/aws-sdk-ec2/types.rb', line 59349 class LaunchTemplatePlacement < Struct.new( :availability_zone, :availability_zone_id, :affinity, :group_name, :host_id, :tenancy, :spread_domain, :host_resource_group_arn, :partition_number, :group_id) SENSITIVE = [] include Aws::Structure end |
#host_resource_group_arn ⇒ String
The ARN of the host resource group in which to launch the instances.
59349 59350 59351 59352 59353 59354 59355 59356 59357 59358 59359 59360 59361 59362 |
# File 'lib/aws-sdk-ec2/types.rb', line 59349 class LaunchTemplatePlacement < Struct.new( :availability_zone, :availability_zone_id, :affinity, :group_name, :host_id, :tenancy, :spread_domain, :host_resource_group_arn, :partition_number, :group_id) SENSITIVE = [] include Aws::Structure end |
#partition_number ⇒ Integer
The number of the partition the instance should launch in. Valid
only if the placement group strategy is set to partition.
59349 59350 59351 59352 59353 59354 59355 59356 59357 59358 59359 59360 59361 59362 |
# File 'lib/aws-sdk-ec2/types.rb', line 59349 class LaunchTemplatePlacement < Struct.new( :availability_zone, :availability_zone_id, :affinity, :group_name, :host_id, :tenancy, :spread_domain, :host_resource_group_arn, :partition_number, :group_id) SENSITIVE = [] include Aws::Structure end |
#spread_domain ⇒ String
Reserved for future use.
59349 59350 59351 59352 59353 59354 59355 59356 59357 59358 59359 59360 59361 59362 |
# File 'lib/aws-sdk-ec2/types.rb', line 59349 class LaunchTemplatePlacement < Struct.new( :availability_zone, :availability_zone_id, :affinity, :group_name, :host_id, :tenancy, :spread_domain, :host_resource_group_arn, :partition_number, :group_id) SENSITIVE = [] include Aws::Structure end |
#tenancy ⇒ String
The tenancy of the instance. An instance with a tenancy of
dedicated runs on single-tenant hardware.
59349 59350 59351 59352 59353 59354 59355 59356 59357 59358 59359 59360 59361 59362 |
# File 'lib/aws-sdk-ec2/types.rb', line 59349 class LaunchTemplatePlacement < Struct.new( :availability_zone, :availability_zone_id, :affinity, :group_name, :host_id, :tenancy, :spread_domain, :host_resource_group_arn, :partition_number, :group_id) SENSITIVE = [] include Aws::Structure end |