Class: Aws::EC2::Types::LaunchTemplatePlacementRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::LaunchTemplatePlacementRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the placement of an instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#affinity ⇒ String
The affinity setting for an instance on a Dedicated Host.
-
#availability_zone ⇒ String
The Availability Zone for the instance.
-
#availability_zone_id ⇒ String
The ID of the Availability Zone for the instance.
-
#group_id ⇒ String
The Group Id of a placement group.
-
#group_name ⇒ String
The name of the placement group for the instance.
-
#host_id ⇒ String
The ID of the Dedicated Host for the instance.
-
#host_resource_group_arn ⇒ String
The ARN of the host resource group in which to launch the instances.
-
#partition_number ⇒ Integer
The number of the partition the instance should launch in.
-
#spread_domain ⇒ String
Reserved for future use.
-
#tenancy ⇒ String
The tenancy of the instance.
Instance Attribute Details
#affinity ⇒ String
The affinity setting for an instance on a Dedicated Host.
59420 59421 59422 59423 59424 59425 59426 59427 59428 59429 59430 59431 59432 59433 |
# File 'lib/aws-sdk-ec2/types.rb', line 59420 class LaunchTemplatePlacementRequest < Struct.new( :availability_zone, :availability_zone_id, :affinity, :group_name, :host_id, :tenancy, :spread_domain, :host_resource_group_arn, :partition_number, :group_id) SENSITIVE = [] include Aws::Structure end |
#availability_zone ⇒ String
The Availability Zone for the instance.
Either AvailabilityZone or AvailabilityZoneId can be specified,
but not both
59420 59421 59422 59423 59424 59425 59426 59427 59428 59429 59430 59431 59432 59433 |
# File 'lib/aws-sdk-ec2/types.rb', line 59420 class LaunchTemplatePlacementRequest < Struct.new( :availability_zone, :availability_zone_id, :affinity, :group_name, :host_id, :tenancy, :spread_domain, :host_resource_group_arn, :partition_number, :group_id) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
The ID of the Availability Zone for the instance.
Either AvailabilityZone or AvailabilityZoneId can be specified,
but not both
59420 59421 59422 59423 59424 59425 59426 59427 59428 59429 59430 59431 59432 59433 |
# File 'lib/aws-sdk-ec2/types.rb', line 59420 class LaunchTemplatePlacementRequest < Struct.new( :availability_zone, :availability_zone_id, :affinity, :group_name, :host_id, :tenancy, :spread_domain, :host_resource_group_arn, :partition_number, :group_id) SENSITIVE = [] include Aws::Structure end |
#group_id ⇒ String
The Group Id of a placement group. You must specify the Placement Group Group Id to launch an instance in a shared placement group.
59420 59421 59422 59423 59424 59425 59426 59427 59428 59429 59430 59431 59432 59433 |
# File 'lib/aws-sdk-ec2/types.rb', line 59420 class LaunchTemplatePlacementRequest < Struct.new( :availability_zone, :availability_zone_id, :affinity, :group_name, :host_id, :tenancy, :spread_domain, :host_resource_group_arn, :partition_number, :group_id) SENSITIVE = [] include Aws::Structure end |
#group_name ⇒ String
The name of the placement group for the instance.
59420 59421 59422 59423 59424 59425 59426 59427 59428 59429 59430 59431 59432 59433 |
# File 'lib/aws-sdk-ec2/types.rb', line 59420 class LaunchTemplatePlacementRequest < Struct.new( :availability_zone, :availability_zone_id, :affinity, :group_name, :host_id, :tenancy, :spread_domain, :host_resource_group_arn, :partition_number, :group_id) SENSITIVE = [] include Aws::Structure end |
#host_id ⇒ String
The ID of the Dedicated Host for the instance.
59420 59421 59422 59423 59424 59425 59426 59427 59428 59429 59430 59431 59432 59433 |
# File 'lib/aws-sdk-ec2/types.rb', line 59420 class LaunchTemplatePlacementRequest < Struct.new( :availability_zone, :availability_zone_id, :affinity, :group_name, :host_id, :tenancy, :spread_domain, :host_resource_group_arn, :partition_number, :group_id) SENSITIVE = [] include Aws::Structure end |
#host_resource_group_arn ⇒ String
The ARN of the host resource group in which to launch the instances.
If you specify a host resource group ARN, omit the Tenancy
parameter or set it to host.
59420 59421 59422 59423 59424 59425 59426 59427 59428 59429 59430 59431 59432 59433 |
# File 'lib/aws-sdk-ec2/types.rb', line 59420 class LaunchTemplatePlacementRequest < Struct.new( :availability_zone, :availability_zone_id, :affinity, :group_name, :host_id, :tenancy, :spread_domain, :host_resource_group_arn, :partition_number, :group_id) SENSITIVE = [] include Aws::Structure end |
#partition_number ⇒ Integer
The number of the partition the instance should launch in. Valid
only if the placement group strategy is set to partition.
59420 59421 59422 59423 59424 59425 59426 59427 59428 59429 59430 59431 59432 59433 |
# File 'lib/aws-sdk-ec2/types.rb', line 59420 class LaunchTemplatePlacementRequest < Struct.new( :availability_zone, :availability_zone_id, :affinity, :group_name, :host_id, :tenancy, :spread_domain, :host_resource_group_arn, :partition_number, :group_id) SENSITIVE = [] include Aws::Structure end |
#spread_domain ⇒ String
Reserved for future use.
59420 59421 59422 59423 59424 59425 59426 59427 59428 59429 59430 59431 59432 59433 |
# File 'lib/aws-sdk-ec2/types.rb', line 59420 class LaunchTemplatePlacementRequest < Struct.new( :availability_zone, :availability_zone_id, :affinity, :group_name, :host_id, :tenancy, :spread_domain, :host_resource_group_arn, :partition_number, :group_id) SENSITIVE = [] include Aws::Structure end |
#tenancy ⇒ String
The tenancy of the instance. An instance with a tenancy of dedicated runs on single-tenant hardware.
59420 59421 59422 59423 59424 59425 59426 59427 59428 59429 59430 59431 59432 59433 |
# File 'lib/aws-sdk-ec2/types.rb', line 59420 class LaunchTemplatePlacementRequest < Struct.new( :availability_zone, :availability_zone_id, :affinity, :group_name, :host_id, :tenancy, :spread_domain, :host_resource_group_arn, :partition_number, :group_id) SENSITIVE = [] include Aws::Structure end |