Class: Aws::EC2::Types::LaunchTemplatePrivateDnsNameOptionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::LaunchTemplatePrivateDnsNameOptionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the options for instance hostnames.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enable_resource_name_dns_a_record ⇒ Boolean
Indicates whether to respond to DNS queries for instance hostnames with DNS A records.
-
#enable_resource_name_dns_aaaa_record ⇒ Boolean
Indicates whether to respond to DNS queries for instance hostnames with DNS AAAA records.
-
#hostname_type ⇒ String
The type of hostname for Amazon EC2 instances.
Instance Attribute Details
#enable_resource_name_dns_a_record ⇒ Boolean
Indicates whether to respond to DNS queries for instance hostnames with DNS A records.
59497 59498 59499 59500 59501 59502 59503 |
# File 'lib/aws-sdk-ec2/types.rb', line 59497 class LaunchTemplatePrivateDnsNameOptionsRequest < Struct.new( :hostname_type, :enable_resource_name_dns_a_record, :enable_resource_name_dns_aaaa_record) SENSITIVE = [] include Aws::Structure end |
#enable_resource_name_dns_aaaa_record ⇒ Boolean
Indicates whether to respond to DNS queries for instance hostnames with DNS AAAA records.
59497 59498 59499 59500 59501 59502 59503 |
# File 'lib/aws-sdk-ec2/types.rb', line 59497 class LaunchTemplatePrivateDnsNameOptionsRequest < Struct.new( :hostname_type, :enable_resource_name_dns_a_record, :enable_resource_name_dns_aaaa_record) SENSITIVE = [] include Aws::Structure end |
#hostname_type ⇒ String
The type of hostname for Amazon EC2 instances. For IPv4 only subnets, an instance DNS name must be based on the instance IPv4 address. For IPv6 native subnets, an instance DNS name must be based on the instance ID. For dual-stack subnets, you can specify whether DNS names use the instance IPv4 address or the instance ID.
59497 59498 59499 59500 59501 59502 59503 |
# File 'lib/aws-sdk-ec2/types.rb', line 59497 class LaunchTemplatePrivateDnsNameOptionsRequest < Struct.new( :hostname_type, :enable_resource_name_dns_a_record, :enable_resource_name_dns_aaaa_record) SENSITIVE = [] include Aws::Structure end |