Class: Aws::EC2::Types::LocalGatewayRouteTableVpcAssociation
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::LocalGatewayRouteTableVpcAssociation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes an association between a local gateway route table and a VPC.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#local_gateway_id ⇒ String
The ID of the local gateway.
-
#local_gateway_route_table_arn ⇒ String
The Amazon Resource Name (ARN) of the local gateway route table for the association.
-
#local_gateway_route_table_id ⇒ String
The ID of the local gateway route table.
-
#local_gateway_route_table_vpc_association_id ⇒ String
The ID of the association.
-
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the local gateway route table for the association.
-
#state ⇒ String
The state of the association.
-
#tags ⇒ Array<Types::Tag>
The tags assigned to the association.
-
#vpc_id ⇒ String
The ID of the VPC.
Instance Attribute Details
#local_gateway_id ⇒ String
The ID of the local gateway.
63160 63161 63162 63163 63164 63165 63166 63167 63168 63169 63170 63171 |
# File 'lib/aws-sdk-ec2/types.rb', line 63160 class LocalGatewayRouteTableVpcAssociation < Struct.new( :local_gateway_route_table_vpc_association_id, :local_gateway_route_table_id, :local_gateway_route_table_arn, :local_gateway_id, :vpc_id, :owner_id, :state, :tags) SENSITIVE = [] include Aws::Structure end |
#local_gateway_route_table_arn ⇒ String
The Amazon Resource Name (ARN) of the local gateway route table for the association.
63160 63161 63162 63163 63164 63165 63166 63167 63168 63169 63170 63171 |
# File 'lib/aws-sdk-ec2/types.rb', line 63160 class LocalGatewayRouteTableVpcAssociation < Struct.new( :local_gateway_route_table_vpc_association_id, :local_gateway_route_table_id, :local_gateway_route_table_arn, :local_gateway_id, :vpc_id, :owner_id, :state, :tags) SENSITIVE = [] include Aws::Structure end |
#local_gateway_route_table_id ⇒ String
The ID of the local gateway route table.
63160 63161 63162 63163 63164 63165 63166 63167 63168 63169 63170 63171 |
# File 'lib/aws-sdk-ec2/types.rb', line 63160 class LocalGatewayRouteTableVpcAssociation < Struct.new( :local_gateway_route_table_vpc_association_id, :local_gateway_route_table_id, :local_gateway_route_table_arn, :local_gateway_id, :vpc_id, :owner_id, :state, :tags) SENSITIVE = [] include Aws::Structure end |
#local_gateway_route_table_vpc_association_id ⇒ String
The ID of the association.
63160 63161 63162 63163 63164 63165 63166 63167 63168 63169 63170 63171 |
# File 'lib/aws-sdk-ec2/types.rb', line 63160 class LocalGatewayRouteTableVpcAssociation < Struct.new( :local_gateway_route_table_vpc_association_id, :local_gateway_route_table_id, :local_gateway_route_table_arn, :local_gateway_id, :vpc_id, :owner_id, :state, :tags) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the local gateway route table for the association.
63160 63161 63162 63163 63164 63165 63166 63167 63168 63169 63170 63171 |
# File 'lib/aws-sdk-ec2/types.rb', line 63160 class LocalGatewayRouteTableVpcAssociation < Struct.new( :local_gateway_route_table_vpc_association_id, :local_gateway_route_table_id, :local_gateway_route_table_arn, :local_gateway_id, :vpc_id, :owner_id, :state, :tags) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the association.
63160 63161 63162 63163 63164 63165 63166 63167 63168 63169 63170 63171 |
# File 'lib/aws-sdk-ec2/types.rb', line 63160 class LocalGatewayRouteTableVpcAssociation < Struct.new( :local_gateway_route_table_vpc_association_id, :local_gateway_route_table_id, :local_gateway_route_table_arn, :local_gateway_id, :vpc_id, :owner_id, :state, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags assigned to the association.
63160 63161 63162 63163 63164 63165 63166 63167 63168 63169 63170 63171 |
# File 'lib/aws-sdk-ec2/types.rb', line 63160 class LocalGatewayRouteTableVpcAssociation < Struct.new( :local_gateway_route_table_vpc_association_id, :local_gateway_route_table_id, :local_gateway_route_table_arn, :local_gateway_id, :vpc_id, :owner_id, :state, :tags) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC.
63160 63161 63162 63163 63164 63165 63166 63167 63168 63169 63170 63171 |
# File 'lib/aws-sdk-ec2/types.rb', line 63160 class LocalGatewayRouteTableVpcAssociation < Struct.new( :local_gateway_route_table_vpc_association_id, :local_gateway_route_table_id, :local_gateway_route_table_arn, :local_gateway_id, :vpc_id, :owner_id, :state, :tags) SENSITIVE = [] include Aws::Structure end |