Class: Aws::EC2::Types::ModifyAccountVpcEncryptionControlRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


64136
64137
64138
64139
64140
64141
64142
64143
64144
64145
64146
64147
64148
64149
# File 'lib/aws-sdk-ec2/types.rb', line 64136

class ModifyAccountVpcEncryptionControlRequest < Struct.new(
  :dry_run,
  :mode,
  :internet_gateway,
  :egress_only_internet_gateway,
  :nat_gateway,
  :virtual_private_gateway,
  :vpc_peering,
  :lambda,
  :vpc_lattice,
  :elastic_file_system)
  SENSITIVE = []
  include Aws::Structure
end

#egress_only_internet_gatewayString

Specifies whether to exclude egress-only internet gateway resource from account-level encryption enforcement.

Returns:

  • (String)


64136
64137
64138
64139
64140
64141
64142
64143
64144
64145
64146
64147
64148
64149
# File 'lib/aws-sdk-ec2/types.rb', line 64136

class ModifyAccountVpcEncryptionControlRequest < Struct.new(
  :dry_run,
  :mode,
  :internet_gateway,
  :egress_only_internet_gateway,
  :nat_gateway,
  :virtual_private_gateway,
  :vpc_peering,
  :lambda,
  :vpc_lattice,
  :elastic_file_system)
  SENSITIVE = []
  include Aws::Structure
end

#elastic_file_systemString

Specifies whether to exclude Elastic File System service from account-level encryption enforcement.

Returns:

  • (String)


64136
64137
64138
64139
64140
64141
64142
64143
64144
64145
64146
64147
64148
64149
# File 'lib/aws-sdk-ec2/types.rb', line 64136

class ModifyAccountVpcEncryptionControlRequest < Struct.new(
  :dry_run,
  :mode,
  :internet_gateway,
  :egress_only_internet_gateway,
  :nat_gateway,
  :virtual_private_gateway,
  :vpc_peering,
  :lambda,
  :vpc_lattice,
  :elastic_file_system)
  SENSITIVE = []
  include Aws::Structure
end

#internet_gatewayString

Specifies whether to exclude internet gateway resource from account-level encryption enforcement.

Returns:

  • (String)


64136
64137
64138
64139
64140
64141
64142
64143
64144
64145
64146
64147
64148
64149
# File 'lib/aws-sdk-ec2/types.rb', line 64136

class ModifyAccountVpcEncryptionControlRequest < Struct.new(
  :dry_run,
  :mode,
  :internet_gateway,
  :egress_only_internet_gateway,
  :nat_gateway,
  :virtual_private_gateway,
  :vpc_peering,
  :lambda,
  :vpc_lattice,
  :elastic_file_system)
  SENSITIVE = []
  include Aws::Structure
end

#lambdaString

Specifies whether to exclude Lambda service from account-level encryption enforcement.

Returns:

  • (String)


64136
64137
64138
64139
64140
64141
64142
64143
64144
64145
64146
64147
64148
64149
# File 'lib/aws-sdk-ec2/types.rb', line 64136

class ModifyAccountVpcEncryptionControlRequest < Struct.new(
  :dry_run,
  :mode,
  :internet_gateway,
  :egress_only_internet_gateway,
  :nat_gateway,
  :virtual_private_gateway,
  :vpc_peering,
  :lambda,
  :vpc_lattice,
  :elastic_file_system)
  SENSITIVE = []
  include Aws::Structure
end

#modeString

The encryption mode for the account encryption control configuration.

Returns:

  • (String)


64136
64137
64138
64139
64140
64141
64142
64143
64144
64145
64146
64147
64148
64149
# File 'lib/aws-sdk-ec2/types.rb', line 64136

class ModifyAccountVpcEncryptionControlRequest < Struct.new(
  :dry_run,
  :mode,
  :internet_gateway,
  :egress_only_internet_gateway,
  :nat_gateway,
  :virtual_private_gateway,
  :vpc_peering,
  :lambda,
  :vpc_lattice,
  :elastic_file_system)
  SENSITIVE = []
  include Aws::Structure
end

#nat_gatewayString

Specifies whether to exclude NAT gateway resource from account-level encryption enforcement.

Returns:

  • (String)


64136
64137
64138
64139
64140
64141
64142
64143
64144
64145
64146
64147
64148
64149
# File 'lib/aws-sdk-ec2/types.rb', line 64136

class ModifyAccountVpcEncryptionControlRequest < Struct.new(
  :dry_run,
  :mode,
  :internet_gateway,
  :egress_only_internet_gateway,
  :nat_gateway,
  :virtual_private_gateway,
  :vpc_peering,
  :lambda,
  :vpc_lattice,
  :elastic_file_system)
  SENSITIVE = []
  include Aws::Structure
end

#virtual_private_gatewayString

Specifies whether to exclude virtual private gateway resource from account-level encryption enforcement.

Returns:

  • (String)


64136
64137
64138
64139
64140
64141
64142
64143
64144
64145
64146
64147
64148
64149
# File 'lib/aws-sdk-ec2/types.rb', line 64136

class ModifyAccountVpcEncryptionControlRequest < Struct.new(
  :dry_run,
  :mode,
  :internet_gateway,
  :egress_only_internet_gateway,
  :nat_gateway,
  :virtual_private_gateway,
  :vpc_peering,
  :lambda,
  :vpc_lattice,
  :elastic_file_system)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_latticeString

Specifies whether to exclude VPC Lattice service from account-level encryption enforcement.

Returns:

  • (String)


64136
64137
64138
64139
64140
64141
64142
64143
64144
64145
64146
64147
64148
64149
# File 'lib/aws-sdk-ec2/types.rb', line 64136

class ModifyAccountVpcEncryptionControlRequest < Struct.new(
  :dry_run,
  :mode,
  :internet_gateway,
  :egress_only_internet_gateway,
  :nat_gateway,
  :virtual_private_gateway,
  :vpc_peering,
  :lambda,
  :vpc_lattice,
  :elastic_file_system)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_peeringString

Specifies whether to exclude VPC peering connection resource from account-level encryption enforcement.

Returns:

  • (String)


64136
64137
64138
64139
64140
64141
64142
64143
64144
64145
64146
64147
64148
64149
# File 'lib/aws-sdk-ec2/types.rb', line 64136

class ModifyAccountVpcEncryptionControlRequest < Struct.new(
  :dry_run,
  :mode,
  :internet_gateway,
  :egress_only_internet_gateway,
  :nat_gateway,
  :virtual_private_gateway,
  :vpc_peering,
  :lambda,
  :vpc_lattice,
  :elastic_file_system)
  SENSITIVE = []
  include Aws::Structure
end