Class: Aws::EC2::Types::ModifyAccountVpcEncryptionControlRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyAccountVpcEncryptionControlRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#egress_only_internet_gateway ⇒ String
Specifies whether to exclude egress-only internet gateway resource from account-level encryption enforcement.
-
#elastic_file_system ⇒ String
Specifies whether to exclude Elastic File System service from account-level encryption enforcement.
-
#internet_gateway ⇒ String
Specifies whether to exclude internet gateway resource from account-level encryption enforcement.
-
#lambda ⇒ String
Specifies whether to exclude Lambda service from account-level encryption enforcement.
-
#mode ⇒ String
The encryption mode for the account encryption control configuration.
-
#nat_gateway ⇒ String
Specifies whether to exclude NAT gateway resource from account-level encryption enforcement.
-
#virtual_private_gateway ⇒ String
Specifies whether to exclude virtual private gateway resource from account-level encryption enforcement.
-
#vpc_lattice ⇒ String
Specifies whether to exclude VPC Lattice service from account-level encryption enforcement.
-
#vpc_peering ⇒ String
Specifies whether to exclude VPC peering connection resource from account-level encryption enforcement.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
62781 62782 62783 62784 62785 62786 62787 62788 62789 62790 62791 62792 62793 62794 |
# File 'lib/aws-sdk-ec2/types.rb', line 62781 class ModifyAccountVpcEncryptionControlRequest < Struct.new( :dry_run, :mode, :internet_gateway, :egress_only_internet_gateway, :nat_gateway, :virtual_private_gateway, :vpc_peering, :lambda, :vpc_lattice, :elastic_file_system) SENSITIVE = [] include Aws::Structure end |
#egress_only_internet_gateway ⇒ String
Specifies whether to exclude egress-only internet gateway resource from account-level encryption enforcement.
62781 62782 62783 62784 62785 62786 62787 62788 62789 62790 62791 62792 62793 62794 |
# File 'lib/aws-sdk-ec2/types.rb', line 62781 class ModifyAccountVpcEncryptionControlRequest < Struct.new( :dry_run, :mode, :internet_gateway, :egress_only_internet_gateway, :nat_gateway, :virtual_private_gateway, :vpc_peering, :lambda, :vpc_lattice, :elastic_file_system) SENSITIVE = [] include Aws::Structure end |
#elastic_file_system ⇒ String
Specifies whether to exclude Elastic File System service from account-level encryption enforcement.
62781 62782 62783 62784 62785 62786 62787 62788 62789 62790 62791 62792 62793 62794 |
# File 'lib/aws-sdk-ec2/types.rb', line 62781 class ModifyAccountVpcEncryptionControlRequest < Struct.new( :dry_run, :mode, :internet_gateway, :egress_only_internet_gateway, :nat_gateway, :virtual_private_gateway, :vpc_peering, :lambda, :vpc_lattice, :elastic_file_system) SENSITIVE = [] include Aws::Structure end |
#internet_gateway ⇒ String
Specifies whether to exclude internet gateway resource from account-level encryption enforcement.
62781 62782 62783 62784 62785 62786 62787 62788 62789 62790 62791 62792 62793 62794 |
# File 'lib/aws-sdk-ec2/types.rb', line 62781 class ModifyAccountVpcEncryptionControlRequest < Struct.new( :dry_run, :mode, :internet_gateway, :egress_only_internet_gateway, :nat_gateway, :virtual_private_gateway, :vpc_peering, :lambda, :vpc_lattice, :elastic_file_system) SENSITIVE = [] include Aws::Structure end |
#lambda ⇒ String
Specifies whether to exclude Lambda service from account-level encryption enforcement.
62781 62782 62783 62784 62785 62786 62787 62788 62789 62790 62791 62792 62793 62794 |
# File 'lib/aws-sdk-ec2/types.rb', line 62781 class ModifyAccountVpcEncryptionControlRequest < Struct.new( :dry_run, :mode, :internet_gateway, :egress_only_internet_gateway, :nat_gateway, :virtual_private_gateway, :vpc_peering, :lambda, :vpc_lattice, :elastic_file_system) SENSITIVE = [] include Aws::Structure end |
#mode ⇒ String
The encryption mode for the account encryption control configuration.
62781 62782 62783 62784 62785 62786 62787 62788 62789 62790 62791 62792 62793 62794 |
# File 'lib/aws-sdk-ec2/types.rb', line 62781 class ModifyAccountVpcEncryptionControlRequest < Struct.new( :dry_run, :mode, :internet_gateway, :egress_only_internet_gateway, :nat_gateway, :virtual_private_gateway, :vpc_peering, :lambda, :vpc_lattice, :elastic_file_system) SENSITIVE = [] include Aws::Structure end |
#nat_gateway ⇒ String
Specifies whether to exclude NAT gateway resource from account-level encryption enforcement.
62781 62782 62783 62784 62785 62786 62787 62788 62789 62790 62791 62792 62793 62794 |
# File 'lib/aws-sdk-ec2/types.rb', line 62781 class ModifyAccountVpcEncryptionControlRequest < Struct.new( :dry_run, :mode, :internet_gateway, :egress_only_internet_gateway, :nat_gateway, :virtual_private_gateway, :vpc_peering, :lambda, :vpc_lattice, :elastic_file_system) SENSITIVE = [] include Aws::Structure end |
#virtual_private_gateway ⇒ String
Specifies whether to exclude virtual private gateway resource from account-level encryption enforcement.
62781 62782 62783 62784 62785 62786 62787 62788 62789 62790 62791 62792 62793 62794 |
# File 'lib/aws-sdk-ec2/types.rb', line 62781 class ModifyAccountVpcEncryptionControlRequest < Struct.new( :dry_run, :mode, :internet_gateway, :egress_only_internet_gateway, :nat_gateway, :virtual_private_gateway, :vpc_peering, :lambda, :vpc_lattice, :elastic_file_system) SENSITIVE = [] include Aws::Structure end |
#vpc_lattice ⇒ String
Specifies whether to exclude VPC Lattice service from account-level encryption enforcement.
62781 62782 62783 62784 62785 62786 62787 62788 62789 62790 62791 62792 62793 62794 |
# File 'lib/aws-sdk-ec2/types.rb', line 62781 class ModifyAccountVpcEncryptionControlRequest < Struct.new( :dry_run, :mode, :internet_gateway, :egress_only_internet_gateway, :nat_gateway, :virtual_private_gateway, :vpc_peering, :lambda, :vpc_lattice, :elastic_file_system) SENSITIVE = [] include Aws::Structure end |
#vpc_peering ⇒ String
Specifies whether to exclude VPC peering connection resource from account-level encryption enforcement.
62781 62782 62783 62784 62785 62786 62787 62788 62789 62790 62791 62792 62793 62794 |
# File 'lib/aws-sdk-ec2/types.rb', line 62781 class ModifyAccountVpcEncryptionControlRequest < Struct.new( :dry_run, :mode, :internet_gateway, :egress_only_internet_gateway, :nat_gateway, :virtual_private_gateway, :vpc_peering, :lambda, :vpc_lattice, :elastic_file_system) SENSITIVE = [] include Aws::Structure end |