Class: Aws::EC2::Types::ModifyAddressAttributeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allocation_idString

[EC2-VPC] The allocation ID.

Returns:

  • (String)


61335
61336
61337
61338
61339
61340
61341
# File 'lib/aws-sdk-ec2/types.rb', line 61335

class ModifyAddressAttributeRequest < Struct.new(
  :allocation_id,
  :domain_name,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#domain_nameString

The domain name to modify for the IP address.

Returns:

  • (String)


61335
61336
61337
61338
61339
61340
61341
# File 'lib/aws-sdk-ec2/types.rb', line 61335

class ModifyAddressAttributeRequest < Struct.new(
  :allocation_id,
  :domain_name,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


61335
61336
61337
61338
61339
61340
61341
# File 'lib/aws-sdk-ec2/types.rb', line 61335

class ModifyAddressAttributeRequest < Struct.new(
  :allocation_id,
  :domain_name,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end