Class: Aws::EC2::Types::ModifyAddressAttributeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allocation_idString

[EC2-VPC] The allocation ID.

Returns:

  • (String)


61012
61013
61014
61015
61016
61017
61018
# File 'lib/aws-sdk-ec2/types.rb', line 61012

class ModifyAddressAttributeRequest < Struct.new(
  :allocation_id,
  :domain_name,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#domain_nameString

The domain name to modify for the IP address.

Returns:

  • (String)


61012
61013
61014
61015
61016
61017
61018
# File 'lib/aws-sdk-ec2/types.rb', line 61012

class ModifyAddressAttributeRequest < Struct.new(
  :allocation_id,
  :domain_name,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


61012
61013
61014
61015
61016
61017
61018
# File 'lib/aws-sdk-ec2/types.rb', line 61012

class ModifyAddressAttributeRequest < Struct.new(
  :allocation_id,
  :domain_name,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end