Class: Aws::EC2::Types::ModifyAddressAttributeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allocation_idString

[EC2-VPC] The allocation ID.

Returns:

  • (String)


59978
59979
59980
59981
59982
59983
59984
# File 'lib/aws-sdk-ec2/types.rb', line 59978

class ModifyAddressAttributeRequest < Struct.new(
  :allocation_id,
  :domain_name,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#domain_nameString

The domain name to modify for the IP address.

Returns:

  • (String)


59978
59979
59980
59981
59982
59983
59984
# File 'lib/aws-sdk-ec2/types.rb', line 59978

class ModifyAddressAttributeRequest < Struct.new(
  :allocation_id,
  :domain_name,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


59978
59979
59980
59981
59982
59983
59984
# File 'lib/aws-sdk-ec2/types.rb', line 59978

class ModifyAddressAttributeRequest < Struct.new(
  :allocation_id,
  :domain_name,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end