Class: Aws::EC2::Types::ModifyAddressAttributeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyAddressAttributeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allocation_id ⇒ String
[EC2-VPC] The allocation ID.
-
#domain_name ⇒ String
The domain name to modify for the IP address.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#allocation_id ⇒ String
[EC2-VPC] The allocation ID.
58946 58947 58948 58949 58950 58951 58952 |
# File 'lib/aws-sdk-ec2/types.rb', line 58946 class ModifyAddressAttributeRequest < Struct.new( :allocation_id, :domain_name, :dry_run) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
The domain name to modify for the IP address.
58946 58947 58948 58949 58950 58951 58952 |
# File 'lib/aws-sdk-ec2/types.rb', line 58946 class ModifyAddressAttributeRequest < Struct.new( :allocation_id, :domain_name, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
58946 58947 58948 58949 58950 58951 58952 |
# File 'lib/aws-sdk-ec2/types.rb', line 58946 class ModifyAddressAttributeRequest < Struct.new( :allocation_id, :domain_name, :dry_run) SENSITIVE = [] include Aws::Structure end |