Class: Aws::EC2::Types::ModifyApplicationStatusCheckRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aggregationString

The aggregation setting for the application status check. When set to included, the result of this check contributes to the instance-level application status reported by DescribeApplicationStatus. When set to excluded, the check runs independently and does not affect the instance-level status. Valid values: included | excluded.

Returns:

  • (String)


64303
64304
64305
64306
64307
64308
64309
64310
64311
64312
64313
64314
64315
64316
64317
64318
64319
64320
64321
64322
64323
# File 'lib/aws-sdk-ec2/types.rb', line 64303

class ModifyApplicationStatusCheckRequest < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#application_status_check_idString

The ID of the application status check to modify.

Returns:

  • (String)


64303
64304
64305
64306
64307
64308
64309
64310
64311
64312
64313
64314
64315
64316
64317
64318
64319
64320
64321
64322
64323
# File 'lib/aws-sdk-ec2/types.rb', line 64303

class ModifyApplicationStatusCheckRequest < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


64303
64304
64305
64306
64307
64308
64309
64310
64311
64312
64313
64314
64315
64316
64317
64318
64319
64320
64321
64322
64323
# File 'lib/aws-sdk-ec2/types.rb', line 64303

class ModifyApplicationStatusCheckRequest < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#device_indexInteger

The index of the network device to use for the health check. The value must be greater than or equal to 0.

Returns:

  • (Integer)


64303
64304
64305
64306
64307
64308
64309
64310
64311
64312
64313
64314
64315
64316
64317
64318
64319
64320
64321
64322
64323
# File 'lib/aws-sdk-ec2/types.rb', line 64303

class ModifyApplicationStatusCheckRequest < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


64303
64304
64305
64306
64307
64308
64309
64310
64311
64312
64313
64314
64315
64316
64317
64318
64319
64320
64321
64322
64323
# File 'lib/aws-sdk-ec2/types.rb', line 64303

class ModifyApplicationStatusCheckRequest < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#failure_thresholdInteger

The number of consecutive failed health checks before the application status is considered impaired. The value must be greater than 0.

Returns:

  • (Integer)


64303
64304
64305
64306
64307
64308
64309
64310
64311
64312
64313
64314
64315
64316
64317
64318
64319
64320
64321
64322
64323
# File 'lib/aws-sdk-ec2/types.rb', line 64303

class ModifyApplicationStatusCheckRequest < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#health_check_pathsArray<Types::HealthCheckPathRequestObject>

The health check paths to use for the application status check.



64303
64304
64305
64306
64307
64308
64309
64310
64311
64312
64313
64314
64315
64316
64317
64318
64319
64320
64321
64322
64323
# File 'lib/aws-sdk-ec2/types.rb', line 64303

class ModifyApplicationStatusCheckRequest < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#initialization_grace_period_secondsInteger

The number of seconds to wait before starting health checks after an instance is launched. Valid values: 1 to 600.

Returns:

  • (Integer)


64303
64304
64305
64306
64307
64308
64309
64310
64311
64312
64313
64314
64315
64316
64317
64318
64319
64320
64321
64322
64323
# File 'lib/aws-sdk-ec2/types.rb', line 64303

class ModifyApplicationStatusCheckRequest < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#intervalInteger

The interval, in seconds, between health checks. Valid value: 60.

Returns:

  • (Integer)


64303
64304
64305
64306
64307
64308
64309
64310
64311
64312
64313
64314
64315
64316
64317
64318
64319
64320
64321
64322
64323
# File 'lib/aws-sdk-ec2/types.rb', line 64303

class ModifyApplicationStatusCheckRequest < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#ip_scopeString

The IP scope to use for the health check. Valid value: private.

Returns:

  • (String)


64303
64304
64305
64306
64307
64308
64309
64310
64311
64312
64313
64314
64315
64316
64317
64318
64319
64320
64321
64322
64323
# File 'lib/aws-sdk-ec2/types.rb', line 64303

class ModifyApplicationStatusCheckRequest < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#ip_versionString

The IP version to use for the health check. Valid values: ipv4 and ipv6.

Returns:

  • (String)


64303
64304
64305
64306
64307
64308
64309
64310
64311
64312
64313
64314
64315
64316
64317
64318
64319
64320
64321
64322
64323
# File 'lib/aws-sdk-ec2/types.rb', line 64303

class ModifyApplicationStatusCheckRequest < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#pathString

The URL path to use for the health check HTTP request (for example, /health or /status).

Returns:

  • (String)


64303
64304
64305
64306
64307
64308
64309
64310
64311
64312
64313
64314
64315
64316
64317
64318
64319
64320
64321
64322
64323
# File 'lib/aws-sdk-ec2/types.rb', line 64303

class ModifyApplicationStatusCheckRequest < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#portInteger

The port to use for the health check. Valid values: 1 to 65535.

Returns:

  • (Integer)


64303
64304
64305
64306
64307
64308
64309
64310
64311
64312
64313
64314
64315
64316
64317
64318
64319
64320
64321
64322
64323
# File 'lib/aws-sdk-ec2/types.rb', line 64303

class ModifyApplicationStatusCheckRequest < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#protocolString

The protocol to use for the health check. Valid values: http | https.

Returns:

  • (String)


64303
64304
64305
64306
64307
64308
64309
64310
64311
64312
64313
64314
64315
64316
64317
64318
64319
64320
64321
64322
64323
# File 'lib/aws-sdk-ec2/types.rb', line 64303

class ModifyApplicationStatusCheckRequest < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#status_code_matcherString

The HTTP status codes that indicate a successful health check response. Specify a comma-separated list of individual status codes or ranges, for example, 200,202,300-399. For a range, the first value must be less than the second value. Maximum length: 64 characters.

Returns:

  • (String)


64303
64304
64305
64306
64307
64308
64309
64310
64311
64312
64313
64314
64315
64316
64317
64318
64319
64320
64321
64322
64323
# File 'lib/aws-sdk-ec2/types.rb', line 64303

class ModifyApplicationStatusCheckRequest < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#success_thresholdInteger

The number of consecutive successful health checks before the application status is considered healthy. The value must be greater than 0.

Returns:

  • (Integer)


64303
64304
64305
64306
64307
64308
64309
64310
64311
64312
64313
64314
64315
64316
64317
64318
64319
64320
64321
64322
64323
# File 'lib/aws-sdk-ec2/types.rb', line 64303

class ModifyApplicationStatusCheckRequest < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#timeoutInteger

The amount of time, in seconds, to wait for a health check response before considering it failed. Valid values: 1 to 30. The value must be less than Interval.

Returns:

  • (Integer)


64303
64304
64305
64306
64307
64308
64309
64310
64311
64312
64313
64314
64315
64316
64317
64318
64319
64320
64321
64322
64323
# File 'lib/aws-sdk-ec2/types.rb', line 64303

class ModifyApplicationStatusCheckRequest < Struct.new(
  :application_status_check_id,
  :aggregation,
  :health_check_paths,
  :protocol,
  :port,
  :path,
  :device_index,
  :ip_version,
  :ip_scope,
  :interval,
  :timeout,
  :failure_threshold,
  :success_threshold,
  :status_code_matcher,
  :initialization_grace_period_seconds,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end