Class: Aws::EC2::Types::ModifyAvailabilityZoneGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyAvailabilityZoneGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#group_name ⇒ String
The name of the Availability Zone group, Local Zone group, or Wavelength Zone group.
-
#opt_in_status ⇒ String
Indicates whether to opt in to the zone group.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
60818 60819 60820 60821 60822 60823 60824 |
# File 'lib/aws-sdk-ec2/types.rb', line 60818 class ModifyAvailabilityZoneGroupRequest < Struct.new( :group_name, :opt_in_status, :dry_run) SENSITIVE = [] include Aws::Structure end |
#group_name ⇒ String
The name of the Availability Zone group, Local Zone group, or Wavelength Zone group.
60818 60819 60820 60821 60822 60823 60824 |
# File 'lib/aws-sdk-ec2/types.rb', line 60818 class ModifyAvailabilityZoneGroupRequest < Struct.new( :group_name, :opt_in_status, :dry_run) SENSITIVE = [] include Aws::Structure end |
#opt_in_status ⇒ String
Indicates whether to opt in to the zone group. The only valid value is ‘opted-in`. You must contact Amazon Web Services Support to opt out of a Local Zone or Wavelength Zone group.
60818 60819 60820 60821 60822 60823 60824 |
# File 'lib/aws-sdk-ec2/types.rb', line 60818 class ModifyAvailabilityZoneGroupRequest < Struct.new( :group_name, :opt_in_status, :dry_run) SENSITIVE = [] include Aws::Structure end |