Class: Aws::EC2::Types::ModifyAvailabilityZoneGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


60325
60326
60327
60328
60329
60330
60331
# File 'lib/aws-sdk-ec2/types.rb', line 60325

class ModifyAvailabilityZoneGroupRequest < Struct.new(
  :group_name,
  :opt_in_status,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#group_nameString

The name of the Availability Zone group, Local Zone group, or Wavelength Zone group.

Returns:

  • (String)


60325
60326
60327
60328
60329
60330
60331
# File 'lib/aws-sdk-ec2/types.rb', line 60325

class ModifyAvailabilityZoneGroupRequest < Struct.new(
  :group_name,
  :opt_in_status,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#opt_in_statusString

Indicates whether to opt in to the zone group. The only valid value is ‘opted-in`. You must contact Amazon Web Services Support to opt out of a Local Zone or Wavelength Zone group.

Returns:

  • (String)


60325
60326
60327
60328
60329
60330
60331
# File 'lib/aws-sdk-ec2/types.rb', line 60325

class ModifyAvailabilityZoneGroupRequest < Struct.new(
  :group_name,
  :opt_in_status,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end