Class: Aws::EC2::Types::ModifyDefaultCreditSpecificationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cpu_creditsString

The credit option for CPU usage of the instance family.

Valid Values: standard | unlimited

Returns:

  • (String)


61880
61881
61882
61883
61884
61885
61886
# File 'lib/aws-sdk-ec2/types.rb', line 61880

class ModifyDefaultCreditSpecificationRequest < Struct.new(
  :dry_run,
  :instance_family,
  :cpu_credits)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


61880
61881
61882
61883
61884
61885
61886
# File 'lib/aws-sdk-ec2/types.rb', line 61880

class ModifyDefaultCreditSpecificationRequest < Struct.new(
  :dry_run,
  :instance_family,
  :cpu_credits)
  SENSITIVE = []
  include Aws::Structure
end

#instance_familyString

The instance family.

Returns:

  • (String)


61880
61881
61882
61883
61884
61885
61886
# File 'lib/aws-sdk-ec2/types.rb', line 61880

class ModifyDefaultCreditSpecificationRequest < Struct.new(
  :dry_run,
  :instance_family,
  :cpu_credits)
  SENSITIVE = []
  include Aws::Structure
end