Class: Aws::EC2::Types::ModifyDefaultCreditSpecificationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyDefaultCreditSpecificationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cpu_credits ⇒ String
The credit option for CPU usage of the instance family.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#instance_family ⇒ String
The instance family.
Instance Attribute Details
#cpu_credits ⇒ String
The credit option for CPU usage of the instance family.
Valid Values: ‘standard` | `unlimited`
60380 60381 60382 60383 60384 60385 60386 |
# File 'lib/aws-sdk-ec2/types.rb', line 60380 class ModifyDefaultCreditSpecificationRequest < Struct.new( :dry_run, :instance_family, :cpu_credits) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
60380 60381 60382 60383 60384 60385 60386 |
# File 'lib/aws-sdk-ec2/types.rb', line 60380 class ModifyDefaultCreditSpecificationRequest < Struct.new( :dry_run, :instance_family, :cpu_credits) SENSITIVE = [] include Aws::Structure end |
#instance_family ⇒ String
The instance family.
60380 60381 60382 60383 60384 60385 60386 |
# File 'lib/aws-sdk-ec2/types.rb', line 60380 class ModifyDefaultCreditSpecificationRequest < Struct.new( :dry_run, :instance_family, :cpu_credits) SENSITIVE = [] include Aws::Structure end |