Class: Aws::EC2::Types::ModifyFpgaImageAttributeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyFpgaImageAttributeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute ⇒ String
The name of the attribute.
-
#description ⇒ String
A description for the AFI.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#fpga_image_id ⇒ String
The ID of the AFI.
-
#load_permission ⇒ Types::LoadPermissionModifications
The load permission for the AFI.
-
#name ⇒ String
A name for the AFI.
-
#operation_type ⇒ String
The operation type.
-
#product_codes ⇒ Array<String>
The product codes.
-
#user_groups ⇒ Array<String>
The user groups.
-
#user_ids ⇒ Array<String>
The Amazon Web Services account IDs.
Instance Attribute Details
#attribute ⇒ String
The name of the attribute.
61601 61602 61603 61604 61605 61606 61607 61608 61609 61610 61611 61612 61613 61614 |
# File 'lib/aws-sdk-ec2/types.rb', line 61601 class ModifyFpgaImageAttributeRequest < Struct.new( :dry_run, :fpga_image_id, :attribute, :operation_type, :user_ids, :user_groups, :product_codes, :load_permission, :description, :name) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description for the AFI.
61601 61602 61603 61604 61605 61606 61607 61608 61609 61610 61611 61612 61613 61614 |
# File 'lib/aws-sdk-ec2/types.rb', line 61601 class ModifyFpgaImageAttributeRequest < Struct.new( :dry_run, :fpga_image_id, :attribute, :operation_type, :user_ids, :user_groups, :product_codes, :load_permission, :description, :name) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
61601 61602 61603 61604 61605 61606 61607 61608 61609 61610 61611 61612 61613 61614 |
# File 'lib/aws-sdk-ec2/types.rb', line 61601 class ModifyFpgaImageAttributeRequest < Struct.new( :dry_run, :fpga_image_id, :attribute, :operation_type, :user_ids, :user_groups, :product_codes, :load_permission, :description, :name) SENSITIVE = [] include Aws::Structure end |
#fpga_image_id ⇒ String
The ID of the AFI.
61601 61602 61603 61604 61605 61606 61607 61608 61609 61610 61611 61612 61613 61614 |
# File 'lib/aws-sdk-ec2/types.rb', line 61601 class ModifyFpgaImageAttributeRequest < Struct.new( :dry_run, :fpga_image_id, :attribute, :operation_type, :user_ids, :user_groups, :product_codes, :load_permission, :description, :name) SENSITIVE = [] include Aws::Structure end |
#load_permission ⇒ Types::LoadPermissionModifications
The load permission for the AFI.
61601 61602 61603 61604 61605 61606 61607 61608 61609 61610 61611 61612 61613 61614 |
# File 'lib/aws-sdk-ec2/types.rb', line 61601 class ModifyFpgaImageAttributeRequest < Struct.new( :dry_run, :fpga_image_id, :attribute, :operation_type, :user_ids, :user_groups, :product_codes, :load_permission, :description, :name) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A name for the AFI.
61601 61602 61603 61604 61605 61606 61607 61608 61609 61610 61611 61612 61613 61614 |
# File 'lib/aws-sdk-ec2/types.rb', line 61601 class ModifyFpgaImageAttributeRequest < Struct.new( :dry_run, :fpga_image_id, :attribute, :operation_type, :user_ids, :user_groups, :product_codes, :load_permission, :description, :name) SENSITIVE = [] include Aws::Structure end |
#operation_type ⇒ String
The operation type.
61601 61602 61603 61604 61605 61606 61607 61608 61609 61610 61611 61612 61613 61614 |
# File 'lib/aws-sdk-ec2/types.rb', line 61601 class ModifyFpgaImageAttributeRequest < Struct.new( :dry_run, :fpga_image_id, :attribute, :operation_type, :user_ids, :user_groups, :product_codes, :load_permission, :description, :name) SENSITIVE = [] include Aws::Structure end |
#product_codes ⇒ Array<String>
The product codes. After you add a product code to an AFI, it can’t be removed. This parameter is valid only when modifying the ‘productCodes` attribute.
61601 61602 61603 61604 61605 61606 61607 61608 61609 61610 61611 61612 61613 61614 |
# File 'lib/aws-sdk-ec2/types.rb', line 61601 class ModifyFpgaImageAttributeRequest < Struct.new( :dry_run, :fpga_image_id, :attribute, :operation_type, :user_ids, :user_groups, :product_codes, :load_permission, :description, :name) SENSITIVE = [] include Aws::Structure end |
#user_groups ⇒ Array<String>
The user groups. This parameter is valid only when modifying the ‘loadPermission` attribute.
61601 61602 61603 61604 61605 61606 61607 61608 61609 61610 61611 61612 61613 61614 |
# File 'lib/aws-sdk-ec2/types.rb', line 61601 class ModifyFpgaImageAttributeRequest < Struct.new( :dry_run, :fpga_image_id, :attribute, :operation_type, :user_ids, :user_groups, :product_codes, :load_permission, :description, :name) SENSITIVE = [] include Aws::Structure end |
#user_ids ⇒ Array<String>
The Amazon Web Services account IDs. This parameter is valid only when modifying the ‘loadPermission` attribute.
61601 61602 61603 61604 61605 61606 61607 61608 61609 61610 61611 61612 61613 61614 |
# File 'lib/aws-sdk-ec2/types.rb', line 61601 class ModifyFpgaImageAttributeRequest < Struct.new( :dry_run, :fpga_image_id, :attribute, :operation_type, :user_ids, :user_groups, :product_codes, :load_permission, :description, :name) SENSITIVE = [] include Aws::Structure end |