Class: Aws::EC2::Types::ModifyFpgaImageAttributeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributeString

The name of the attribute.

Returns:

  • (String)


61355
61356
61357
61358
61359
61360
61361
61362
61363
61364
61365
61366
61367
61368
# File 'lib/aws-sdk-ec2/types.rb', line 61355

class ModifyFpgaImageAttributeRequest < Struct.new(
  :dry_run,
  :fpga_image_id,
  :attribute,
  :operation_type,
  :user_ids,
  :user_groups,
  :product_codes,
  :load_permission,
  :description,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description for the AFI.

Returns:

  • (String)


61355
61356
61357
61358
61359
61360
61361
61362
61363
61364
61365
61366
61367
61368
# File 'lib/aws-sdk-ec2/types.rb', line 61355

class ModifyFpgaImageAttributeRequest < Struct.new(
  :dry_run,
  :fpga_image_id,
  :attribute,
  :operation_type,
  :user_ids,
  :user_groups,
  :product_codes,
  :load_permission,
  :description,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


61355
61356
61357
61358
61359
61360
61361
61362
61363
61364
61365
61366
61367
61368
# File 'lib/aws-sdk-ec2/types.rb', line 61355

class ModifyFpgaImageAttributeRequest < Struct.new(
  :dry_run,
  :fpga_image_id,
  :attribute,
  :operation_type,
  :user_ids,
  :user_groups,
  :product_codes,
  :load_permission,
  :description,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#fpga_image_idString

The ID of the AFI.

Returns:

  • (String)


61355
61356
61357
61358
61359
61360
61361
61362
61363
61364
61365
61366
61367
61368
# File 'lib/aws-sdk-ec2/types.rb', line 61355

class ModifyFpgaImageAttributeRequest < Struct.new(
  :dry_run,
  :fpga_image_id,
  :attribute,
  :operation_type,
  :user_ids,
  :user_groups,
  :product_codes,
  :load_permission,
  :description,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#load_permissionTypes::LoadPermissionModifications

The load permission for the AFI.



61355
61356
61357
61358
61359
61360
61361
61362
61363
61364
61365
61366
61367
61368
# File 'lib/aws-sdk-ec2/types.rb', line 61355

class ModifyFpgaImageAttributeRequest < Struct.new(
  :dry_run,
  :fpga_image_id,
  :attribute,
  :operation_type,
  :user_ids,
  :user_groups,
  :product_codes,
  :load_permission,
  :description,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A name for the AFI.

Returns:

  • (String)


61355
61356
61357
61358
61359
61360
61361
61362
61363
61364
61365
61366
61367
61368
# File 'lib/aws-sdk-ec2/types.rb', line 61355

class ModifyFpgaImageAttributeRequest < Struct.new(
  :dry_run,
  :fpga_image_id,
  :attribute,
  :operation_type,
  :user_ids,
  :user_groups,
  :product_codes,
  :load_permission,
  :description,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#operation_typeString

The operation type.

Returns:

  • (String)


61355
61356
61357
61358
61359
61360
61361
61362
61363
61364
61365
61366
61367
61368
# File 'lib/aws-sdk-ec2/types.rb', line 61355

class ModifyFpgaImageAttributeRequest < Struct.new(
  :dry_run,
  :fpga_image_id,
  :attribute,
  :operation_type,
  :user_ids,
  :user_groups,
  :product_codes,
  :load_permission,
  :description,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#product_codesArray<String>

The product codes. After you add a product code to an AFI, it can’t be removed. This parameter is valid only when modifying the ‘productCodes` attribute.

Returns:

  • (Array<String>)


61355
61356
61357
61358
61359
61360
61361
61362
61363
61364
61365
61366
61367
61368
# File 'lib/aws-sdk-ec2/types.rb', line 61355

class ModifyFpgaImageAttributeRequest < Struct.new(
  :dry_run,
  :fpga_image_id,
  :attribute,
  :operation_type,
  :user_ids,
  :user_groups,
  :product_codes,
  :load_permission,
  :description,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#user_groupsArray<String>

The user groups. This parameter is valid only when modifying the ‘loadPermission` attribute.

Returns:

  • (Array<String>)


61355
61356
61357
61358
61359
61360
61361
61362
61363
61364
61365
61366
61367
61368
# File 'lib/aws-sdk-ec2/types.rb', line 61355

class ModifyFpgaImageAttributeRequest < Struct.new(
  :dry_run,
  :fpga_image_id,
  :attribute,
  :operation_type,
  :user_ids,
  :user_groups,
  :product_codes,
  :load_permission,
  :description,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#user_idsArray<String>

The Amazon Web Services account IDs. This parameter is valid only when modifying the ‘loadPermission` attribute.

Returns:

  • (Array<String>)


61355
61356
61357
61358
61359
61360
61361
61362
61363
61364
61365
61366
61367
61368
# File 'lib/aws-sdk-ec2/types.rb', line 61355

class ModifyFpgaImageAttributeRequest < Struct.new(
  :dry_run,
  :fpga_image_id,
  :attribute,
  :operation_type,
  :user_ids,
  :user_groups,
  :product_codes,
  :load_permission,
  :description,
  :name)
  SENSITIVE = []
  include Aws::Structure
end