Class: Aws::EC2::Types::ModifyFpgaImageAttributeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributeString

The name of the attribute.

Returns:

  • (String)


60974
60975
60976
60977
60978
60979
60980
60981
60982
60983
60984
60985
60986
60987
# File 'lib/aws-sdk-ec2/types.rb', line 60974

class ModifyFpgaImageAttributeRequest < Struct.new(
  :dry_run,
  :fpga_image_id,
  :attribute,
  :operation_type,
  :user_ids,
  :user_groups,
  :product_codes,
  :load_permission,
  :description,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description for the AFI.

Returns:

  • (String)


60974
60975
60976
60977
60978
60979
60980
60981
60982
60983
60984
60985
60986
60987
# File 'lib/aws-sdk-ec2/types.rb', line 60974

class ModifyFpgaImageAttributeRequest < Struct.new(
  :dry_run,
  :fpga_image_id,
  :attribute,
  :operation_type,
  :user_ids,
  :user_groups,
  :product_codes,
  :load_permission,
  :description,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


60974
60975
60976
60977
60978
60979
60980
60981
60982
60983
60984
60985
60986
60987
# File 'lib/aws-sdk-ec2/types.rb', line 60974

class ModifyFpgaImageAttributeRequest < Struct.new(
  :dry_run,
  :fpga_image_id,
  :attribute,
  :operation_type,
  :user_ids,
  :user_groups,
  :product_codes,
  :load_permission,
  :description,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#fpga_image_idString

The ID of the AFI.

Returns:

  • (String)


60974
60975
60976
60977
60978
60979
60980
60981
60982
60983
60984
60985
60986
60987
# File 'lib/aws-sdk-ec2/types.rb', line 60974

class ModifyFpgaImageAttributeRequest < Struct.new(
  :dry_run,
  :fpga_image_id,
  :attribute,
  :operation_type,
  :user_ids,
  :user_groups,
  :product_codes,
  :load_permission,
  :description,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#load_permissionTypes::LoadPermissionModifications

The load permission for the AFI.



60974
60975
60976
60977
60978
60979
60980
60981
60982
60983
60984
60985
60986
60987
# File 'lib/aws-sdk-ec2/types.rb', line 60974

class ModifyFpgaImageAttributeRequest < Struct.new(
  :dry_run,
  :fpga_image_id,
  :attribute,
  :operation_type,
  :user_ids,
  :user_groups,
  :product_codes,
  :load_permission,
  :description,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A name for the AFI.

Returns:

  • (String)


60974
60975
60976
60977
60978
60979
60980
60981
60982
60983
60984
60985
60986
60987
# File 'lib/aws-sdk-ec2/types.rb', line 60974

class ModifyFpgaImageAttributeRequest < Struct.new(
  :dry_run,
  :fpga_image_id,
  :attribute,
  :operation_type,
  :user_ids,
  :user_groups,
  :product_codes,
  :load_permission,
  :description,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#operation_typeString

The operation type.

Returns:

  • (String)


60974
60975
60976
60977
60978
60979
60980
60981
60982
60983
60984
60985
60986
60987
# File 'lib/aws-sdk-ec2/types.rb', line 60974

class ModifyFpgaImageAttributeRequest < Struct.new(
  :dry_run,
  :fpga_image_id,
  :attribute,
  :operation_type,
  :user_ids,
  :user_groups,
  :product_codes,
  :load_permission,
  :description,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#product_codesArray<String>

The product codes. After you add a product code to an AFI, it can’t be removed. This parameter is valid only when modifying the ‘productCodes` attribute.

Returns:

  • (Array<String>)


60974
60975
60976
60977
60978
60979
60980
60981
60982
60983
60984
60985
60986
60987
# File 'lib/aws-sdk-ec2/types.rb', line 60974

class ModifyFpgaImageAttributeRequest < Struct.new(
  :dry_run,
  :fpga_image_id,
  :attribute,
  :operation_type,
  :user_ids,
  :user_groups,
  :product_codes,
  :load_permission,
  :description,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#user_groupsArray<String>

The user groups. This parameter is valid only when modifying the ‘loadPermission` attribute.

Returns:

  • (Array<String>)


60974
60975
60976
60977
60978
60979
60980
60981
60982
60983
60984
60985
60986
60987
# File 'lib/aws-sdk-ec2/types.rb', line 60974

class ModifyFpgaImageAttributeRequest < Struct.new(
  :dry_run,
  :fpga_image_id,
  :attribute,
  :operation_type,
  :user_ids,
  :user_groups,
  :product_codes,
  :load_permission,
  :description,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#user_idsArray<String>

The Amazon Web Services account IDs. This parameter is valid only when modifying the ‘loadPermission` attribute.

Returns:

  • (Array<String>)


60974
60975
60976
60977
60978
60979
60980
60981
60982
60983
60984
60985
60986
60987
# File 'lib/aws-sdk-ec2/types.rb', line 60974

class ModifyFpgaImageAttributeRequest < Struct.new(
  :dry_run,
  :fpga_image_id,
  :attribute,
  :operation_type,
  :user_ids,
  :user_groups,
  :product_codes,
  :load_permission,
  :description,
  :name)
  SENSITIVE = []
  include Aws::Structure
end