Class: Aws::EC2::Types::ModifyIdentityIdFormatRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyIdentityIdFormatRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#principal_arn ⇒ String
The ARN of the principal, which can be an IAM user, IAM role, or the root user.
-
#resource ⇒ String
The type of resource:
bundle|conversion-task|customer-gateway|dhcp-options|elastic-ip-allocation|elastic-ip-association|export-task|flow-log|image|import-task|internet-gateway|network-acl|network-acl-association|network-interface|network-interface-attachment|prefix-list|route-table|route-table-association|security-group|subnet|subnet-cidr-block-association|vpc|vpc-cidr-block-association|vpc-endpoint|vpc-peering-connection|vpn-connection|vpn-gateway. -
#use_long_ids ⇒ Boolean
Indicates whether the resource should use longer IDs (17-character IDs).
Instance Attribute Details
#principal_arn ⇒ String
The ARN of the principal, which can be an IAM user, IAM role, or the
root user. Specify all to modify the ID format for all IAM users,
IAM roles, and the root user of the account.
62228 62229 62230 62231 62232 62233 62234 |
# File 'lib/aws-sdk-ec2/types.rb', line 62228 class ModifyIdentityIdFormatRequest < Struct.new( :resource, :use_long_ids, :principal_arn) SENSITIVE = [] include Aws::Structure end |
#resource ⇒ String
The type of resource: bundle | conversion-task |
customer-gateway | dhcp-options | elastic-ip-allocation |
elastic-ip-association | export-task | flow-log | image
| import-task | internet-gateway | network-acl |
network-acl-association | network-interface |
network-interface-attachment | prefix-list | route-table |
route-table-association | security-group | subnet |
subnet-cidr-block-association | vpc |
vpc-cidr-block-association | vpc-endpoint |
vpc-peering-connection | vpn-connection | vpn-gateway.
Alternatively, use the all-current option to include all resource
types that are currently within their opt-in period for longer IDs.
62228 62229 62230 62231 62232 62233 62234 |
# File 'lib/aws-sdk-ec2/types.rb', line 62228 class ModifyIdentityIdFormatRequest < Struct.new( :resource, :use_long_ids, :principal_arn) SENSITIVE = [] include Aws::Structure end |
#use_long_ids ⇒ Boolean
Indicates whether the resource should use longer IDs (17-character IDs)
62228 62229 62230 62231 62232 62233 62234 |
# File 'lib/aws-sdk-ec2/types.rb', line 62228 class ModifyIdentityIdFormatRequest < Struct.new( :resource, :use_long_ids, :principal_arn) SENSITIVE = [] include Aws::Structure end |