Class: Aws::EC2::Types::ModifyImageAttributeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for ModifyImageAttribute.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributeString

The name of the attribute to modify.

Valid values: description | imdsSupport | launchPermission

Returns:

  • (String)


65166
65167
65168
65169
65170
65171
65172
65173
65174
65175
65176
65177
65178
65179
65180
65181
65182
# File 'lib/aws-sdk-ec2/types.rb', line 65166

class ModifyImageAttributeRequest < Struct.new(
  :attribute,
  :description,
  :image_id,
  :launch_permission,
  :operation_type,
  :product_codes,
  :user_groups,
  :user_ids,
  :value,
  :organization_arns,
  :organizational_unit_arns,
  :imds_support,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionTypes::AttributeValue

A new description for the AMI.



65166
65167
65168
65169
65170
65171
65172
65173
65174
65175
65176
65177
65178
65179
65180
65181
65182
# File 'lib/aws-sdk-ec2/types.rb', line 65166

class ModifyImageAttributeRequest < Struct.new(
  :attribute,
  :description,
  :image_id,
  :launch_permission,
  :operation_type,
  :product_codes,
  :user_groups,
  :user_ids,
  :value,
  :organization_arns,
  :organizational_unit_arns,
  :imds_support,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


65166
65167
65168
65169
65170
65171
65172
65173
65174
65175
65176
65177
65178
65179
65180
65181
65182
# File 'lib/aws-sdk-ec2/types.rb', line 65166

class ModifyImageAttributeRequest < Struct.new(
  :attribute,
  :description,
  :image_id,
  :launch_permission,
  :operation_type,
  :product_codes,
  :user_groups,
  :user_ids,
  :value,
  :organization_arns,
  :organizational_unit_arns,
  :imds_support,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#image_idString

The ID of the AMI.

Returns:

  • (String)


65166
65167
65168
65169
65170
65171
65172
65173
65174
65175
65176
65177
65178
65179
65180
65181
65182
# File 'lib/aws-sdk-ec2/types.rb', line 65166

class ModifyImageAttributeRequest < Struct.new(
  :attribute,
  :description,
  :image_id,
  :launch_permission,
  :operation_type,
  :product_codes,
  :user_groups,
  :user_ids,
  :value,
  :organization_arns,
  :organizational_unit_arns,
  :imds_support,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#imds_supportTypes::AttributeValue

Set to v2.0 to indicate that IMDSv2 is specified in the AMI. Instances launched from this AMI will have HttpTokens automatically set to required so that, by default, the instance requires that IMDSv2 is used when requesting instance metadata. In addition, HttpPutResponseHopLimit is set to 2. For more information, see Configure the AMI in the Amazon EC2 User Guide.

Do not use this parameter unless your AMI software supports IMDSv2. After you set the value to v2.0, you can't undo it. The only way to “reset” your AMI is to create a new AMI from the underlying snapshot.



65166
65167
65168
65169
65170
65171
65172
65173
65174
65175
65176
65177
65178
65179
65180
65181
65182
# File 'lib/aws-sdk-ec2/types.rb', line 65166

class ModifyImageAttributeRequest < Struct.new(
  :attribute,
  :description,
  :image_id,
  :launch_permission,
  :operation_type,
  :product_codes,
  :user_groups,
  :user_ids,
  :value,
  :organization_arns,
  :organizational_unit_arns,
  :imds_support,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#launch_permissionTypes::LaunchPermissionModifications

A new launch permission for the AMI.



65166
65167
65168
65169
65170
65171
65172
65173
65174
65175
65176
65177
65178
65179
65180
65181
65182
# File 'lib/aws-sdk-ec2/types.rb', line 65166

class ModifyImageAttributeRequest < Struct.new(
  :attribute,
  :description,
  :image_id,
  :launch_permission,
  :operation_type,
  :product_codes,
  :user_groups,
  :user_ids,
  :value,
  :organization_arns,
  :organizational_unit_arns,
  :imds_support,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#operation_typeString

The operation type. This parameter can be used only when the Attribute parameter is launchPermission.

Returns:

  • (String)


65166
65167
65168
65169
65170
65171
65172
65173
65174
65175
65176
65177
65178
65179
65180
65181
65182
# File 'lib/aws-sdk-ec2/types.rb', line 65166

class ModifyImageAttributeRequest < Struct.new(
  :attribute,
  :description,
  :image_id,
  :launch_permission,
  :operation_type,
  :product_codes,
  :user_groups,
  :user_ids,
  :value,
  :organization_arns,
  :organizational_unit_arns,
  :imds_support,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#organization_arnsArray<String>

The Amazon Resource Name (ARN) of an organization. This parameter can be used only when the Attribute parameter is launchPermission.

Returns:

  • (Array<String>)


65166
65167
65168
65169
65170
65171
65172
65173
65174
65175
65176
65177
65178
65179
65180
65181
65182
# File 'lib/aws-sdk-ec2/types.rb', line 65166

class ModifyImageAttributeRequest < Struct.new(
  :attribute,
  :description,
  :image_id,
  :launch_permission,
  :operation_type,
  :product_codes,
  :user_groups,
  :user_ids,
  :value,
  :organization_arns,
  :organizational_unit_arns,
  :imds_support,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#organizational_unit_arnsArray<String>

The Amazon Resource Name (ARN) of an organizational unit (OU). This parameter can be used only when the Attribute parameter is launchPermission.

Returns:

  • (Array<String>)


65166
65167
65168
65169
65170
65171
65172
65173
65174
65175
65176
65177
65178
65179
65180
65181
65182
# File 'lib/aws-sdk-ec2/types.rb', line 65166

class ModifyImageAttributeRequest < Struct.new(
  :attribute,
  :description,
  :image_id,
  :launch_permission,
  :operation_type,
  :product_codes,
  :user_groups,
  :user_ids,
  :value,
  :organization_arns,
  :organizational_unit_arns,
  :imds_support,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#product_codesArray<String>

Not supported.

Returns:

  • (Array<String>)


65166
65167
65168
65169
65170
65171
65172
65173
65174
65175
65176
65177
65178
65179
65180
65181
65182
# File 'lib/aws-sdk-ec2/types.rb', line 65166

class ModifyImageAttributeRequest < Struct.new(
  :attribute,
  :description,
  :image_id,
  :launch_permission,
  :operation_type,
  :product_codes,
  :user_groups,
  :user_ids,
  :value,
  :organization_arns,
  :organizational_unit_arns,
  :imds_support,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#user_groupsArray<String>

The user groups. This parameter can be used only when the Attribute parameter is launchPermission.

Returns:

  • (Array<String>)


65166
65167
65168
65169
65170
65171
65172
65173
65174
65175
65176
65177
65178
65179
65180
65181
65182
# File 'lib/aws-sdk-ec2/types.rb', line 65166

class ModifyImageAttributeRequest < Struct.new(
  :attribute,
  :description,
  :image_id,
  :launch_permission,
  :operation_type,
  :product_codes,
  :user_groups,
  :user_ids,
  :value,
  :organization_arns,
  :organizational_unit_arns,
  :imds_support,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#user_idsArray<String>

The Amazon Web Services account IDs. This parameter can be used only when the Attribute parameter is launchPermission.

Returns:

  • (Array<String>)


65166
65167
65168
65169
65170
65171
65172
65173
65174
65175
65176
65177
65178
65179
65180
65181
65182
# File 'lib/aws-sdk-ec2/types.rb', line 65166

class ModifyImageAttributeRequest < Struct.new(
  :attribute,
  :description,
  :image_id,
  :launch_permission,
  :operation_type,
  :product_codes,
  :user_groups,
  :user_ids,
  :value,
  :organization_arns,
  :organizational_unit_arns,
  :imds_support,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#valueString

The value of the attribute being modified. This parameter can be used only when the Attribute parameter is description or imdsSupport.

Returns:

  • (String)


65166
65167
65168
65169
65170
65171
65172
65173
65174
65175
65176
65177
65178
65179
65180
65181
65182
# File 'lib/aws-sdk-ec2/types.rb', line 65166

class ModifyImageAttributeRequest < Struct.new(
  :attribute,
  :description,
  :image_id,
  :launch_permission,
  :operation_type,
  :product_codes,
  :user_groups,
  :user_ids,
  :value,
  :organization_arns,
  :organizational_unit_arns,
  :imds_support,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end