Class: Aws::EC2::Types::ModifyImageAttributeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyImageAttributeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for ModifyImageAttribute.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute ⇒ String
The name of the attribute to modify.
-
#description ⇒ Types::AttributeValue
A new description for the AMI.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#image_id ⇒ String
The ID of the AMI.
-
#imds_support ⇒ Types::AttributeValue
Set to ‘v2.0` to indicate that IMDSv2 is specified in the AMI.
-
#launch_permission ⇒ Types::LaunchPermissionModifications
A new launch permission for the AMI.
-
#operation_type ⇒ String
The operation type.
-
#organization_arns ⇒ Array<String>
The Amazon Resource Name (ARN) of an organization.
-
#organizational_unit_arns ⇒ Array<String>
The Amazon Resource Name (ARN) of an organizational unit (OU).
-
#product_codes ⇒ Array<String>
Not supported.
-
#user_groups ⇒ Array<String>
The user groups.
-
#user_ids ⇒ Array<String>
The Amazon Web Services account IDs.
-
#value ⇒ String
The value of the attribute being modified.
Instance Attribute Details
#attribute ⇒ String
The name of the attribute to modify.
Valid values: ‘description` | `imdsSupport` | `launchPermission`
61234 61235 61236 61237 61238 61239 61240 61241 61242 61243 61244 61245 61246 61247 61248 61249 61250 |
# File 'lib/aws-sdk-ec2/types.rb', line 61234 class ModifyImageAttributeRequest < Struct.new( :attribute, :description, :image_id, :launch_permission, :operation_type, :product_codes, :user_groups, :user_ids, :value, :organization_arns, :organizational_unit_arns, :imds_support, :dry_run) SENSITIVE = [] include Aws::Structure end |
#description ⇒ Types::AttributeValue
A new description for the AMI.
61234 61235 61236 61237 61238 61239 61240 61241 61242 61243 61244 61245 61246 61247 61248 61249 61250 |
# File 'lib/aws-sdk-ec2/types.rb', line 61234 class ModifyImageAttributeRequest < Struct.new( :attribute, :description, :image_id, :launch_permission, :operation_type, :product_codes, :user_groups, :user_ids, :value, :organization_arns, :organizational_unit_arns, :imds_support, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
61234 61235 61236 61237 61238 61239 61240 61241 61242 61243 61244 61245 61246 61247 61248 61249 61250 |
# File 'lib/aws-sdk-ec2/types.rb', line 61234 class ModifyImageAttributeRequest < Struct.new( :attribute, :description, :image_id, :launch_permission, :operation_type, :product_codes, :user_groups, :user_ids, :value, :organization_arns, :organizational_unit_arns, :imds_support, :dry_run) SENSITIVE = [] include Aws::Structure end |
#image_id ⇒ String
The ID of the AMI.
61234 61235 61236 61237 61238 61239 61240 61241 61242 61243 61244 61245 61246 61247 61248 61249 61250 |
# File 'lib/aws-sdk-ec2/types.rb', line 61234 class ModifyImageAttributeRequest < Struct.new( :attribute, :description, :image_id, :launch_permission, :operation_type, :product_codes, :user_groups, :user_ids, :value, :organization_arns, :organizational_unit_arns, :imds_support, :dry_run) SENSITIVE = [] include Aws::Structure end |
#imds_support ⇒ Types::AttributeValue
Set to ‘v2.0` to indicate that IMDSv2 is specified in the AMI. Instances launched from this AMI will have `HttpTokens` automatically set to `required` so that, by default, the instance requires that IMDSv2 is used when requesting instance metadata. In addition, `HttpPutResponseHopLimit` is set to `2`. For more information, see [Configure the AMI] in the *Amazon EC2 User Guide*.
Do not use this parameter unless your AMI software supports IMDSv2. After you set the value to ‘v2.0`, you can’t undo it. The only way to “reset” your AMI is to create a new AMI from the underlying snapshot.
61234 61235 61236 61237 61238 61239 61240 61241 61242 61243 61244 61245 61246 61247 61248 61249 61250 |
# File 'lib/aws-sdk-ec2/types.rb', line 61234 class ModifyImageAttributeRequest < Struct.new( :attribute, :description, :image_id, :launch_permission, :operation_type, :product_codes, :user_groups, :user_ids, :value, :organization_arns, :organizational_unit_arns, :imds_support, :dry_run) SENSITIVE = [] include Aws::Structure end |
#launch_permission ⇒ Types::LaunchPermissionModifications
A new launch permission for the AMI.
61234 61235 61236 61237 61238 61239 61240 61241 61242 61243 61244 61245 61246 61247 61248 61249 61250 |
# File 'lib/aws-sdk-ec2/types.rb', line 61234 class ModifyImageAttributeRequest < Struct.new( :attribute, :description, :image_id, :launch_permission, :operation_type, :product_codes, :user_groups, :user_ids, :value, :organization_arns, :organizational_unit_arns, :imds_support, :dry_run) SENSITIVE = [] include Aws::Structure end |
#operation_type ⇒ String
The operation type. This parameter can be used only when the ‘Attribute` parameter is `launchPermission`.
61234 61235 61236 61237 61238 61239 61240 61241 61242 61243 61244 61245 61246 61247 61248 61249 61250 |
# File 'lib/aws-sdk-ec2/types.rb', line 61234 class ModifyImageAttributeRequest < Struct.new( :attribute, :description, :image_id, :launch_permission, :operation_type, :product_codes, :user_groups, :user_ids, :value, :organization_arns, :organizational_unit_arns, :imds_support, :dry_run) SENSITIVE = [] include Aws::Structure end |
#organization_arns ⇒ Array<String>
The Amazon Resource Name (ARN) of an organization. This parameter can be used only when the ‘Attribute` parameter is `launchPermission`.
61234 61235 61236 61237 61238 61239 61240 61241 61242 61243 61244 61245 61246 61247 61248 61249 61250 |
# File 'lib/aws-sdk-ec2/types.rb', line 61234 class ModifyImageAttributeRequest < Struct.new( :attribute, :description, :image_id, :launch_permission, :operation_type, :product_codes, :user_groups, :user_ids, :value, :organization_arns, :organizational_unit_arns, :imds_support, :dry_run) SENSITIVE = [] include Aws::Structure end |
#organizational_unit_arns ⇒ Array<String>
The Amazon Resource Name (ARN) of an organizational unit (OU). This parameter can be used only when the ‘Attribute` parameter is `launchPermission`.
61234 61235 61236 61237 61238 61239 61240 61241 61242 61243 61244 61245 61246 61247 61248 61249 61250 |
# File 'lib/aws-sdk-ec2/types.rb', line 61234 class ModifyImageAttributeRequest < Struct.new( :attribute, :description, :image_id, :launch_permission, :operation_type, :product_codes, :user_groups, :user_ids, :value, :organization_arns, :organizational_unit_arns, :imds_support, :dry_run) SENSITIVE = [] include Aws::Structure end |
#product_codes ⇒ Array<String>
Not supported.
61234 61235 61236 61237 61238 61239 61240 61241 61242 61243 61244 61245 61246 61247 61248 61249 61250 |
# File 'lib/aws-sdk-ec2/types.rb', line 61234 class ModifyImageAttributeRequest < Struct.new( :attribute, :description, :image_id, :launch_permission, :operation_type, :product_codes, :user_groups, :user_ids, :value, :organization_arns, :organizational_unit_arns, :imds_support, :dry_run) SENSITIVE = [] include Aws::Structure end |
#user_groups ⇒ Array<String>
The user groups. This parameter can be used only when the ‘Attribute` parameter is `launchPermission`.
61234 61235 61236 61237 61238 61239 61240 61241 61242 61243 61244 61245 61246 61247 61248 61249 61250 |
# File 'lib/aws-sdk-ec2/types.rb', line 61234 class ModifyImageAttributeRequest < Struct.new( :attribute, :description, :image_id, :launch_permission, :operation_type, :product_codes, :user_groups, :user_ids, :value, :organization_arns, :organizational_unit_arns, :imds_support, :dry_run) SENSITIVE = [] include Aws::Structure end |
#user_ids ⇒ Array<String>
The Amazon Web Services account IDs. This parameter can be used only when the ‘Attribute` parameter is `launchPermission`.
61234 61235 61236 61237 61238 61239 61240 61241 61242 61243 61244 61245 61246 61247 61248 61249 61250 |
# File 'lib/aws-sdk-ec2/types.rb', line 61234 class ModifyImageAttributeRequest < Struct.new( :attribute, :description, :image_id, :launch_permission, :operation_type, :product_codes, :user_groups, :user_ids, :value, :organization_arns, :organizational_unit_arns, :imds_support, :dry_run) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
The value of the attribute being modified. This parameter can be used only when the ‘Attribute` parameter is `description` or `imdsSupport`.
61234 61235 61236 61237 61238 61239 61240 61241 61242 61243 61244 61245 61246 61247 61248 61249 61250 |
# File 'lib/aws-sdk-ec2/types.rb', line 61234 class ModifyImageAttributeRequest < Struct.new( :attribute, :description, :image_id, :launch_permission, :operation_type, :product_codes, :user_groups, :user_ids, :value, :organization_arns, :organizational_unit_arns, :imds_support, :dry_run) SENSITIVE = [] include Aws::Structure end |