Class: Aws::EC2::Types::ModifyInstanceCapacityReservationAttributesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyInstanceCapacityReservationAttributesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_reservation_specification ⇒ Types::CapacityReservationSpecification
Information about the Capacity Reservation targeting option.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#instance_id ⇒ String
The ID of the instance to be modified.
Instance Attribute Details
#capacity_reservation_specification ⇒ Types::CapacityReservationSpecification
Information about the Capacity Reservation targeting option.
62431 62432 62433 62434 62435 62436 62437 |
# File 'lib/aws-sdk-ec2/types.rb', line 62431 class ModifyInstanceCapacityReservationAttributesRequest < Struct.new( :instance_id, :capacity_reservation_specification, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
62431 62432 62433 62434 62435 62436 62437 |
# File 'lib/aws-sdk-ec2/types.rb', line 62431 class ModifyInstanceCapacityReservationAttributesRequest < Struct.new( :instance_id, :capacity_reservation_specification, :dry_run) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the instance to be modified.
62431 62432 62433 62434 62435 62436 62437 |
# File 'lib/aws-sdk-ec2/types.rb', line 62431 class ModifyInstanceCapacityReservationAttributesRequest < Struct.new( :instance_id, :capacity_reservation_specification, :dry_run) SENSITIVE = [] include Aws::Structure end |