Class: Aws::EC2::Types::ModifyInstanceConnectEndpointRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


61543
61544
61545
61546
61547
61548
61549
61550
61551
# File 'lib/aws-sdk-ec2/types.rb', line 61543

class ModifyInstanceConnectEndpointRequest < Struct.new(
  :dry_run,
  :instance_connect_endpoint_id,
  :ip_address_type,
  :security_group_ids,
  :preserve_client_ip)
  SENSITIVE = []
  include Aws::Structure
end

#instance_connect_endpoint_idString

The ID of the EC2 Instance Connect Endpoint to modify.

Returns:

  • (String)


61543
61544
61545
61546
61547
61548
61549
61550
61551
# File 'lib/aws-sdk-ec2/types.rb', line 61543

class ModifyInstanceConnectEndpointRequest < Struct.new(
  :dry_run,
  :instance_connect_endpoint_id,
  :ip_address_type,
  :security_group_ids,
  :preserve_client_ip)
  SENSITIVE = []
  include Aws::Structure
end

#ip_address_typeString

The new IP address type for the EC2 Instance Connect Endpoint.

<note markdown=“1”> ‘PreserveClientIp` is only supported on IPv4 EC2 Instance Connect Endpoints. To use `PreserveClientIp`, the value for `IpAddressType` must be `ipv4`.

</note>

Returns:

  • (String)


61543
61544
61545
61546
61547
61548
61549
61550
61551
# File 'lib/aws-sdk-ec2/types.rb', line 61543

class ModifyInstanceConnectEndpointRequest < Struct.new(
  :dry_run,
  :instance_connect_endpoint_id,
  :ip_address_type,
  :security_group_ids,
  :preserve_client_ip)
  SENSITIVE = []
  include Aws::Structure
end

#preserve_client_ipBoolean

Indicates whether the client IP address is preserved as the source when you connect to a resource. The following are the possible values.

  • ‘true` - Use the IP address of the client. Your instance must have an IPv4 address.

  • ‘false` - Use the IP address of the network interface.

Returns:

  • (Boolean)


61543
61544
61545
61546
61547
61548
61549
61550
61551
# File 'lib/aws-sdk-ec2/types.rb', line 61543

class ModifyInstanceConnectEndpointRequest < Struct.new(
  :dry_run,
  :instance_connect_endpoint_id,
  :ip_address_type,
  :security_group_ids,
  :preserve_client_ip)
  SENSITIVE = []
  include Aws::Structure
end

#security_group_idsArray<String>

Changes the security groups for the EC2 Instance Connect Endpoint. The new set of groups you specify replaces the current set. You must specify at least one group, even if it’s just the default security group in the VPC. You must specify the ID of the security group, not the name.

Returns:

  • (Array<String>)


61543
61544
61545
61546
61547
61548
61549
61550
61551
# File 'lib/aws-sdk-ec2/types.rb', line 61543

class ModifyInstanceConnectEndpointRequest < Struct.new(
  :dry_run,
  :instance_connect_endpoint_id,
  :ip_address_type,
  :security_group_ids,
  :preserve_client_ip)
  SENSITIVE = []
  include Aws::Structure
end