Class: Aws::EC2::Types::ModifyInstanceCpuOptionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#core_countInteger

The number of CPU cores to activate for the specified instance.

Returns:

  • (Integer)


62226
62227
62228
62229
62230
62231
62232
62233
62234
# File 'lib/aws-sdk-ec2/types.rb', line 62226

class ModifyInstanceCpuOptionsRequest < Struct.new(
  :instance_id,
  :core_count,
  :threads_per_core,
  :nested_virtualization,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


62226
62227
62228
62229
62230
62231
62232
62233
62234
# File 'lib/aws-sdk-ec2/types.rb', line 62226

class ModifyInstanceCpuOptionsRequest < Struct.new(
  :instance_id,
  :core_count,
  :threads_per_core,
  :nested_virtualization,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The ID of the instance to update.

Returns:

  • (String)


62226
62227
62228
62229
62230
62231
62232
62233
62234
# File 'lib/aws-sdk-ec2/types.rb', line 62226

class ModifyInstanceCpuOptionsRequest < Struct.new(
  :instance_id,
  :core_count,
  :threads_per_core,
  :nested_virtualization,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#nested_virtualizationString

Indicates whether to enable or disable nested virtualization for the instance. When nested virtualization is enabled, Virtual Secure Mode (VSM) is automatically disabled for the instance.

Returns:

  • (String)


62226
62227
62228
62229
62230
62231
62232
62233
62234
# File 'lib/aws-sdk-ec2/types.rb', line 62226

class ModifyInstanceCpuOptionsRequest < Struct.new(
  :instance_id,
  :core_count,
  :threads_per_core,
  :nested_virtualization,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#threads_per_coreInteger

The number of threads to run for each CPU core.

Returns:

  • (Integer)


62226
62227
62228
62229
62230
62231
62232
62233
62234
# File 'lib/aws-sdk-ec2/types.rb', line 62226

class ModifyInstanceCpuOptionsRequest < Struct.new(
  :instance_id,
  :core_count,
  :threads_per_core,
  :nested_virtualization,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end