Class: Aws::EC2::Types::ModifyInstanceCpuOptionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyInstanceCpuOptionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#core_count ⇒ Integer
The number of CPU cores to activate for the specified instance.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#instance_id ⇒ String
The ID of the instance to update.
-
#nested_virtualization ⇒ String
Indicates whether to enable or disable nested virtualization for the instance.
-
#threads_per_core ⇒ Integer
The number of threads to run for each CPU core.
Instance Attribute Details
#core_count ⇒ Integer
The number of CPU cores to activate for the specified instance.
61986 61987 61988 61989 61990 61991 61992 61993 61994 |
# File 'lib/aws-sdk-ec2/types.rb', line 61986 class ModifyInstanceCpuOptionsRequest < Struct.new( :instance_id, :core_count, :threads_per_core, :nested_virtualization, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
61986 61987 61988 61989 61990 61991 61992 61993 61994 |
# File 'lib/aws-sdk-ec2/types.rb', line 61986 class ModifyInstanceCpuOptionsRequest < Struct.new( :instance_id, :core_count, :threads_per_core, :nested_virtualization, :dry_run) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the instance to update.
61986 61987 61988 61989 61990 61991 61992 61993 61994 |
# File 'lib/aws-sdk-ec2/types.rb', line 61986 class ModifyInstanceCpuOptionsRequest < Struct.new( :instance_id, :core_count, :threads_per_core, :nested_virtualization, :dry_run) SENSITIVE = [] include Aws::Structure end |
#nested_virtualization ⇒ String
Indicates whether to enable or disable nested virtualization for the instance. When nested virtualization is enabled, Virtual Secure Mode (VSM) is automatically disabled for the instance.
61986 61987 61988 61989 61990 61991 61992 61993 61994 |
# File 'lib/aws-sdk-ec2/types.rb', line 61986 class ModifyInstanceCpuOptionsRequest < Struct.new( :instance_id, :core_count, :threads_per_core, :nested_virtualization, :dry_run) SENSITIVE = [] include Aws::Structure end |
#threads_per_core ⇒ Integer
The number of threads to run for each CPU core.
61986 61987 61988 61989 61990 61991 61992 61993 61994 |
# File 'lib/aws-sdk-ec2/types.rb', line 61986 class ModifyInstanceCpuOptionsRequest < Struct.new( :instance_id, :core_count, :threads_per_core, :nested_virtualization, :dry_run) SENSITIVE = [] include Aws::Structure end |