Class: Aws::EC2::Types::ModifyInstanceCreditSpecificationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyInstanceCreditSpecificationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#instance_credit_specifications ⇒ Array<Types::InstanceCreditSpecificationRequest>
Information about the credit option for CPU usage.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring Idempotency.
64233 64234 64235 64236 64237 64238 64239 |
# File 'lib/aws-sdk-ec2/types.rb', line 64233 class ModifyInstanceCreditSpecificationRequest < Struct.new( :dry_run, :client_token, :instance_credit_specifications) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
64233 64234 64235 64236 64237 64238 64239 |
# File 'lib/aws-sdk-ec2/types.rb', line 64233 class ModifyInstanceCreditSpecificationRequest < Struct.new( :dry_run, :client_token, :instance_credit_specifications) SENSITIVE = [] include Aws::Structure end |
#instance_credit_specifications ⇒ Array<Types::InstanceCreditSpecificationRequest>
Information about the credit option for CPU usage.
64233 64234 64235 64236 64237 64238 64239 |
# File 'lib/aws-sdk-ec2/types.rb', line 64233 class ModifyInstanceCreditSpecificationRequest < Struct.new( :dry_run, :client_token, :instance_credit_specifications) SENSITIVE = [] include Aws::Structure end |