Class: Aws::EC2::Types::ModifyInstanceCreditSpecificationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see [Ensuring Idempotency].

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html

Returns:

  • (String)


61655
61656
61657
61658
61659
61660
61661
# File 'lib/aws-sdk-ec2/types.rb', line 61655

class ModifyInstanceCreditSpecificationRequest < Struct.new(
  :dry_run,
  :client_token,
  :instance_credit_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


61655
61656
61657
61658
61659
61660
61661
# File 'lib/aws-sdk-ec2/types.rb', line 61655

class ModifyInstanceCreditSpecificationRequest < Struct.new(
  :dry_run,
  :client_token,
  :instance_credit_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#instance_credit_specificationsArray<Types::InstanceCreditSpecificationRequest>

Information about the credit option for CPU usage.



61655
61656
61657
61658
61659
61660
61661
# File 'lib/aws-sdk-ec2/types.rb', line 61655

class ModifyInstanceCreditSpecificationRequest < Struct.new(
  :dry_run,
  :client_token,
  :instance_credit_specifications)
  SENSITIVE = []
  include Aws::Structure
end