Class: Aws::EC2::Types::ModifyInstanceEventStartTimeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyInstanceEventStartTimeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#instance_event_id ⇒ String
The ID of the event whose date and time you are modifying.
-
#instance_id ⇒ String
The ID of the instance with the scheduled event.
-
#not_before ⇒ Time
The new date and time when the event will take place.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
65636 65637 65638 65639 65640 65641 65642 65643 |
# File 'lib/aws-sdk-ec2/types.rb', line 65636 class ModifyInstanceEventStartTimeRequest < Struct.new( :dry_run, :instance_id, :instance_event_id, :not_before) SENSITIVE = [] include Aws::Structure end |
#instance_event_id ⇒ String
The ID of the event whose date and time you are modifying.
65636 65637 65638 65639 65640 65641 65642 65643 |
# File 'lib/aws-sdk-ec2/types.rb', line 65636 class ModifyInstanceEventStartTimeRequest < Struct.new( :dry_run, :instance_id, :instance_event_id, :not_before) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the instance with the scheduled event.
65636 65637 65638 65639 65640 65641 65642 65643 |
# File 'lib/aws-sdk-ec2/types.rb', line 65636 class ModifyInstanceEventStartTimeRequest < Struct.new( :dry_run, :instance_id, :instance_event_id, :not_before) SENSITIVE = [] include Aws::Structure end |
#not_before ⇒ Time
The new date and time when the event will take place.
65636 65637 65638 65639 65640 65641 65642 65643 |
# File 'lib/aws-sdk-ec2/types.rb', line 65636 class ModifyInstanceEventStartTimeRequest < Struct.new( :dry_run, :instance_id, :instance_event_id, :not_before) SENSITIVE = [] include Aws::Structure end |