Class: Aws::EC2::Types::ModifyInstanceEventStartTimeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


62791
62792
62793
62794
62795
62796
62797
62798
# File 'lib/aws-sdk-ec2/types.rb', line 62791

class ModifyInstanceEventStartTimeRequest < Struct.new(
  :dry_run,
  :instance_id,
  :instance_event_id,
  :not_before)
  SENSITIVE = []
  include Aws::Structure
end

#instance_event_idString

The ID of the event whose date and time you are modifying.

Returns:

  • (String)


62791
62792
62793
62794
62795
62796
62797
62798
# File 'lib/aws-sdk-ec2/types.rb', line 62791

class ModifyInstanceEventStartTimeRequest < Struct.new(
  :dry_run,
  :instance_id,
  :instance_event_id,
  :not_before)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The ID of the instance with the scheduled event.

Returns:

  • (String)


62791
62792
62793
62794
62795
62796
62797
62798
# File 'lib/aws-sdk-ec2/types.rb', line 62791

class ModifyInstanceEventStartTimeRequest < Struct.new(
  :dry_run,
  :instance_id,
  :instance_event_id,
  :not_before)
  SENSITIVE = []
  include Aws::Structure
end

#not_beforeTime

The new date and time when the event will take place.

Returns:

  • (Time)


62791
62792
62793
62794
62795
62796
62797
62798
# File 'lib/aws-sdk-ec2/types.rb', line 62791

class ModifyInstanceEventStartTimeRequest < Struct.new(
  :dry_run,
  :instance_id,
  :instance_event_id,
  :not_before)
  SENSITIVE = []
  include Aws::Structure
end