Class: Aws::EC2::Types::ModifyInstanceMaintenanceOptionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_recoveryString

Disables the automatic recovery behavior of your instance or sets it to default.

Returns:

  • (String)


60355
60356
60357
60358
60359
60360
60361
60362
# File 'lib/aws-sdk-ec2/types.rb', line 60355

class ModifyInstanceMaintenanceOptionsRequest < Struct.new(
  :instance_id,
  :auto_recovery,
  :reboot_migration,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


60355
60356
60357
60358
60359
60360
60361
60362
# File 'lib/aws-sdk-ec2/types.rb', line 60355

class ModifyInstanceMaintenanceOptionsRequest < Struct.new(
  :instance_id,
  :auto_recovery,
  :reboot_migration,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The ID of the instance.

Returns:

  • (String)


60355
60356
60357
60358
60359
60360
60361
60362
# File 'lib/aws-sdk-ec2/types.rb', line 60355

class ModifyInstanceMaintenanceOptionsRequest < Struct.new(
  :instance_id,
  :auto_recovery,
  :reboot_migration,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#reboot_migrationString

Specifies whether to attempt reboot migration during a user-initiated reboot of an instance that has a scheduled ‘system-reboot` event:

  • ‘default` - Amazon EC2 attempts to migrate the instance to new hardware (reboot migration). If successful, the `system-reboot` event is cleared. If unsuccessful, an in-place reboot occurs and the event remains scheduled.

  • ‘disabled` - Amazon EC2 keeps the instance on the same hardware (in-place reboot). The `system-reboot` event remains scheduled.

This setting only applies to supported instances that have a scheduled reboot event. For more information, see [Enable or disable reboot migration] in the *Amazon EC2 User Guide*.

[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/schedevents_actions_reboot.html#reboot-migration

Returns:

  • (String)


60355
60356
60357
60358
60359
60360
60361
60362
# File 'lib/aws-sdk-ec2/types.rb', line 60355

class ModifyInstanceMaintenanceOptionsRequest < Struct.new(
  :instance_id,
  :auto_recovery,
  :reboot_migration,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end