Class: Aws::EC2::Types::ModifyInstanceMetadataDefaultsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyInstanceMetadataDefaultsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#http_endpoint ⇒ String
Enables or disables the IMDS endpoint on an instance.
-
#http_put_response_hop_limit ⇒ Integer
The maximum number of hops that the metadata token can travel.
-
#http_tokens ⇒ String
Indicates whether IMDSv2 is required.
-
#http_tokens_enforced ⇒ String
Specifies whether to enforce the requirement of IMDSv2 on an instance at the time of launch.
-
#instance_metadata_tags ⇒ String
Enables or disables access to an instance’s tags from the instance metadata.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
61505 61506 61507 61508 61509 61510 61511 61512 61513 61514 |
# File 'lib/aws-sdk-ec2/types.rb', line 61505 class ModifyInstanceMetadataDefaultsRequest < Struct.new( :http_tokens, :http_put_response_hop_limit, :http_endpoint, :instance_metadata_tags, :dry_run, :http_tokens_enforced) SENSITIVE = [] include Aws::Structure end |
#http_endpoint ⇒ String
Enables or disables the IMDS endpoint on an instance. When disabled, the instance metadata can’t be accessed.
61505 61506 61507 61508 61509 61510 61511 61512 61513 61514 |
# File 'lib/aws-sdk-ec2/types.rb', line 61505 class ModifyInstanceMetadataDefaultsRequest < Struct.new( :http_tokens, :http_put_response_hop_limit, :http_endpoint, :instance_metadata_tags, :dry_run, :http_tokens_enforced) SENSITIVE = [] include Aws::Structure end |
#http_put_response_hop_limit ⇒ Integer
The maximum number of hops that the metadata token can travel. To indicate no preference, specify ‘-1`.
Possible values: Integers from ‘1` to `64`, and `-1` to indicate no preference
61505 61506 61507 61508 61509 61510 61511 61512 61513 61514 |
# File 'lib/aws-sdk-ec2/types.rb', line 61505 class ModifyInstanceMetadataDefaultsRequest < Struct.new( :http_tokens, :http_put_response_hop_limit, :http_endpoint, :instance_metadata_tags, :dry_run, :http_tokens_enforced) SENSITIVE = [] include Aws::Structure end |
#http_tokens ⇒ String
Indicates whether IMDSv2 is required.
-
‘optional` – IMDSv2 is optional, which means that you can use either IMDSv2 or IMDSv1.
-
‘required` – IMDSv2 is required, which means that IMDSv1 is disabled, and you must use IMDSv2.
61505 61506 61507 61508 61509 61510 61511 61512 61513 61514 |
# File 'lib/aws-sdk-ec2/types.rb', line 61505 class ModifyInstanceMetadataDefaultsRequest < Struct.new( :http_tokens, :http_put_response_hop_limit, :http_endpoint, :instance_metadata_tags, :dry_run, :http_tokens_enforced) SENSITIVE = [] include Aws::Structure end |
#http_tokens_enforced ⇒ String
Specifies whether to enforce the requirement of IMDSv2 on an instance at the time of launch. When enforcement is enabled, the instance can’t launch unless IMDSv2 (‘HttpTokens`) is set to `required`. For more information, see [Enforce IMDSv2 at the account level] in the *Amazon EC2 User Guide*.
61505 61506 61507 61508 61509 61510 61511 61512 61513 61514 |
# File 'lib/aws-sdk-ec2/types.rb', line 61505 class ModifyInstanceMetadataDefaultsRequest < Struct.new( :http_tokens, :http_put_response_hop_limit, :http_endpoint, :instance_metadata_tags, :dry_run, :http_tokens_enforced) SENSITIVE = [] include Aws::Structure end |
#instance_metadata_tags ⇒ String
Enables or disables access to an instance’s tags from the instance metadata. For more information, see [View tags for your EC2 instances using instance metadata] in the *Amazon EC2 User Guide*.
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/work-with-tags-in-IMDS.html
61505 61506 61507 61508 61509 61510 61511 61512 61513 61514 |
# File 'lib/aws-sdk-ec2/types.rb', line 61505 class ModifyInstanceMetadataDefaultsRequest < Struct.new( :http_tokens, :http_put_response_hop_limit, :http_endpoint, :instance_metadata_tags, :dry_run, :http_tokens_enforced) SENSITIVE = [] include Aws::Structure end |