Class: Aws::EC2::Types::ModifyIpamPolicyAllocationRulesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allocation_rulesArray<Types::IpamPolicyAllocationRuleRequest>

The new allocation rules to apply to the IPAM policy.

Allocation rules are optional configurations within an IPAM policy that map Amazon Web Services resource types to specific IPAM pools. If no rules are defined, the resource types default to using Amazon-provided IP addresses.



62884
62885
62886
62887
62888
62889
62890
62891
62892
# File 'lib/aws-sdk-ec2/types.rb', line 62884

class ModifyIpamPolicyAllocationRulesRequest < Struct.new(
  :dry_run,
  :ipam_policy_id,
  :locale,
  :resource_type,
  :allocation_rules)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


62884
62885
62886
62887
62888
62889
62890
62891
62892
# File 'lib/aws-sdk-ec2/types.rb', line 62884

class ModifyIpamPolicyAllocationRulesRequest < Struct.new(
  :dry_run,
  :ipam_policy_id,
  :locale,
  :resource_type,
  :allocation_rules)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_policy_idString

The ID of the IPAM policy whose allocation rules you want to modify.

Returns:

  • (String)


62884
62885
62886
62887
62888
62889
62890
62891
62892
# File 'lib/aws-sdk-ec2/types.rb', line 62884

class ModifyIpamPolicyAllocationRulesRequest < Struct.new(
  :dry_run,
  :ipam_policy_id,
  :locale,
  :resource_type,
  :allocation_rules)
  SENSITIVE = []
  include Aws::Structure
end

#localeString

The locale for which to modify the allocation rules.

Returns:

  • (String)


62884
62885
62886
62887
62888
62889
62890
62891
62892
# File 'lib/aws-sdk-ec2/types.rb', line 62884

class ModifyIpamPolicyAllocationRulesRequest < Struct.new(
  :dry_run,
  :ipam_policy_id,
  :locale,
  :resource_type,
  :allocation_rules)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The resource type for which to modify the allocation rules.

The Amazon Web Services service or resource type that can use IP addresses through IPAM policies. Supported services and resource types include:

  • Elastic IP addresses

^

Returns:

  • (String)


62884
62885
62886
62887
62888
62889
62890
62891
62892
# File 'lib/aws-sdk-ec2/types.rb', line 62884

class ModifyIpamPolicyAllocationRulesRequest < Struct.new(
  :dry_run,
  :ipam_policy_id,
  :locale,
  :resource_type,
  :allocation_rules)
  SENSITIVE = []
  include Aws::Structure
end