Class: Aws::EC2::Types::ModifyIpamPoolAllocationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The new description for the IPAM pool allocation. If you submit a null value, the description is removed from the allocation.

Returns:

  • (String)


63233
63234
63235
63236
63237
63238
63239
# File 'lib/aws-sdk-ec2/types.rb', line 63233

class ModifyIpamPoolAllocationRequest < Struct.new(
  :dry_run,
  :ipam_pool_allocation_id,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


63233
63234
63235
63236
63237
63238
63239
# File 'lib/aws-sdk-ec2/types.rb', line 63233

class ModifyIpamPoolAllocationRequest < Struct.new(
  :dry_run,
  :ipam_pool_allocation_id,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_pool_allocation_idString

The ID of the IPAM pool allocation you want to modify.

Returns:

  • (String)


63233
63234
63235
63236
63237
63238
63239
# File 'lib/aws-sdk-ec2/types.rb', line 63233

class ModifyIpamPoolAllocationRequest < Struct.new(
  :dry_run,
  :ipam_pool_allocation_id,
  :description)
  SENSITIVE = []
  include Aws::Structure
end