Class: Aws::EC2::Types::ModifyIpamPoolAllocationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The new description for the IPAM pool allocation. If you submit a null value, the description is removed from the allocation.

Returns:

  • (String)


62930
62931
62932
62933
62934
62935
62936
# File 'lib/aws-sdk-ec2/types.rb', line 62930

class ModifyIpamPoolAllocationRequest < Struct.new(
  :dry_run,
  :ipam_pool_allocation_id,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


62930
62931
62932
62933
62934
62935
62936
# File 'lib/aws-sdk-ec2/types.rb', line 62930

class ModifyIpamPoolAllocationRequest < Struct.new(
  :dry_run,
  :ipam_pool_allocation_id,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_pool_allocation_idString

The ID of the IPAM pool allocation you want to modify.

Returns:

  • (String)


62930
62931
62932
62933
62934
62935
62936
# File 'lib/aws-sdk-ec2/types.rb', line 62930

class ModifyIpamPoolAllocationRequest < Struct.new(
  :dry_run,
  :ipam_pool_allocation_id,
  :description)
  SENSITIVE = []
  include Aws::Structure
end