Class: Aws::EC2::Types::ModifyIpamPoolAllocationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyIpamPoolAllocationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The new description for the IPAM pool allocation.
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#ipam_pool_allocation_id ⇒ String
The ID of the IPAM pool allocation you want to modify.
Instance Attribute Details
#description ⇒ String
The new description for the IPAM pool allocation. If you submit a ‘null` value, the description is removed from the allocation.
62924 62925 62926 62927 62928 62929 62930 |
# File 'lib/aws-sdk-ec2/types.rb', line 62924 class ModifyIpamPoolAllocationRequest < Struct.new( :dry_run, :ipam_pool_allocation_id, :description) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
62924 62925 62926 62927 62928 62929 62930 |
# File 'lib/aws-sdk-ec2/types.rb', line 62924 class ModifyIpamPoolAllocationRequest < Struct.new( :dry_run, :ipam_pool_allocation_id, :description) SENSITIVE = [] include Aws::Structure end |
#ipam_pool_allocation_id ⇒ String
The ID of the IPAM pool allocation you want to modify.
62924 62925 62926 62927 62928 62929 62930 |
# File 'lib/aws-sdk-ec2/types.rb', line 62924 class ModifyIpamPoolAllocationRequest < Struct.new( :dry_run, :ipam_pool_allocation_id, :description) SENSITIVE = [] include Aws::Structure end |