Class: Aws::EC2::Types::ModifyIpamResourceCidrRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyIpamResourceCidrRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#current_ipam_scope_id ⇒ String
The ID of the current scope that the resource CIDR is in.
-
#destination_ipam_scope_id ⇒ String
The ID of the scope you want to transfer the resource CIDR to.
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#monitored ⇒ Boolean
Determines if the resource is monitored by IPAM.
-
#resource_cidr ⇒ String
The CIDR of the resource you want to modify.
-
#resource_id ⇒ String
The ID of the resource you want to modify.
-
#resource_region ⇒ String
The Amazon Web Services Region of the resource you want to modify.
Instance Attribute Details
#current_ipam_scope_id ⇒ String
The ID of the current scope that the resource CIDR is in.
62600 62601 62602 62603 62604 62605 62606 62607 62608 62609 62610 |
# File 'lib/aws-sdk-ec2/types.rb', line 62600 class ModifyIpamResourceCidrRequest < Struct.new( :dry_run, :resource_id, :resource_cidr, :resource_region, :current_ipam_scope_id, :destination_ipam_scope_id, :monitored) SENSITIVE = [] include Aws::Structure end |
#destination_ipam_scope_id ⇒ String
The ID of the scope you want to transfer the resource CIDR to.
62600 62601 62602 62603 62604 62605 62606 62607 62608 62609 62610 |
# File 'lib/aws-sdk-ec2/types.rb', line 62600 class ModifyIpamResourceCidrRequest < Struct.new( :dry_run, :resource_id, :resource_cidr, :resource_region, :current_ipam_scope_id, :destination_ipam_scope_id, :monitored) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
62600 62601 62602 62603 62604 62605 62606 62607 62608 62609 62610 |
# File 'lib/aws-sdk-ec2/types.rb', line 62600 class ModifyIpamResourceCidrRequest < Struct.new( :dry_run, :resource_id, :resource_cidr, :resource_region, :current_ipam_scope_id, :destination_ipam_scope_id, :monitored) SENSITIVE = [] include Aws::Structure end |
#monitored ⇒ Boolean
Determines if the resource is monitored by IPAM. If a resource is monitored, the resource is discovered by IPAM and you can view details about the resource’s CIDR.
62600 62601 62602 62603 62604 62605 62606 62607 62608 62609 62610 |
# File 'lib/aws-sdk-ec2/types.rb', line 62600 class ModifyIpamResourceCidrRequest < Struct.new( :dry_run, :resource_id, :resource_cidr, :resource_region, :current_ipam_scope_id, :destination_ipam_scope_id, :monitored) SENSITIVE = [] include Aws::Structure end |
#resource_cidr ⇒ String
The CIDR of the resource you want to modify.
62600 62601 62602 62603 62604 62605 62606 62607 62608 62609 62610 |
# File 'lib/aws-sdk-ec2/types.rb', line 62600 class ModifyIpamResourceCidrRequest < Struct.new( :dry_run, :resource_id, :resource_cidr, :resource_region, :current_ipam_scope_id, :destination_ipam_scope_id, :monitored) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
The ID of the resource you want to modify.
62600 62601 62602 62603 62604 62605 62606 62607 62608 62609 62610 |
# File 'lib/aws-sdk-ec2/types.rb', line 62600 class ModifyIpamResourceCidrRequest < Struct.new( :dry_run, :resource_id, :resource_cidr, :resource_region, :current_ipam_scope_id, :destination_ipam_scope_id, :monitored) SENSITIVE = [] include Aws::Structure end |
#resource_region ⇒ String
The Amazon Web Services Region of the resource you want to modify.
62600 62601 62602 62603 62604 62605 62606 62607 62608 62609 62610 |
# File 'lib/aws-sdk-ec2/types.rb', line 62600 class ModifyIpamResourceCidrRequest < Struct.new( :dry_run, :resource_id, :resource_cidr, :resource_region, :current_ipam_scope_id, :destination_ipam_scope_id, :monitored) SENSITIVE = [] include Aws::Structure end |