Class: Aws::EC2::Types::ModifyIpamRoutingPolicyRegistrationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyIpamRoutingPolicyRegistrationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asns ⇒ Array<String>
The updated list of Autonomous System Numbers (ASNs) authorized to originate the prefix.
-
#cidr ⇒ String
The IP address prefix in CIDR notation identifying the routing policy registration to modify.
-
#client_token ⇒ String
A unique, case-sensitive identifier to ensure that the operation completes no more than one time.
-
#description ⇒ String
A new description for the routing policy registration.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#force ⇒ Boolean
Forces the modification even if it conflicts with an announced route.
-
#ipam_internet_registry_association_id ⇒ String
The ID of the IPAM internet registry association.
-
#max_length ⇒ Integer
The new maximum prefix length that the ASNs are authorized to announce.
-
#permit_more_specific_announcements ⇒ Boolean
Specifies whether to permit more specific route announcements than the CIDR prefix.
Instance Attribute Details
#asns ⇒ Array<String>
The updated list of Autonomous System Numbers (ASNs) authorized to originate the prefix.
66765 66766 66767 66768 66769 66770 66771 66772 66773 66774 66775 66776 66777 |
# File 'lib/aws-sdk-ec2/types.rb', line 66765 class ModifyIpamRoutingPolicyRegistrationRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id, :cidr, :asns, :permit_more_specific_announcements, :max_length, :description, :force, :client_token) SENSITIVE = [] include Aws::Structure end |
#cidr ⇒ String
The IP address prefix in CIDR notation identifying the routing policy registration to modify.
66765 66766 66767 66768 66769 66770 66771 66772 66773 66774 66775 66776 66777 |
# File 'lib/aws-sdk-ec2/types.rb', line 66765 class ModifyIpamRoutingPolicyRegistrationRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id, :cidr, :asns, :permit_more_specific_announcements, :max_length, :description, :force, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, the operation ignores the request, but does not return an error.
A suitable default value is auto-generated. You should normally not need to pass this option.
66765 66766 66767 66768 66769 66770 66771 66772 66773 66774 66775 66776 66777 |
# File 'lib/aws-sdk-ec2/types.rb', line 66765 class ModifyIpamRoutingPolicyRegistrationRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id, :cidr, :asns, :permit_more_specific_announcements, :max_length, :description, :force, :client_token) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A new description for the routing policy registration.
66765 66766 66767 66768 66769 66770 66771 66772 66773 66774 66775 66776 66777 |
# File 'lib/aws-sdk-ec2/types.rb', line 66765 class ModifyIpamRoutingPolicyRegistrationRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id, :cidr, :asns, :permit_more_specific_announcements, :max_length, :description, :force, :client_token) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
66765 66766 66767 66768 66769 66770 66771 66772 66773 66774 66775 66776 66777 |
# File 'lib/aws-sdk-ec2/types.rb', line 66765 class ModifyIpamRoutingPolicyRegistrationRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id, :cidr, :asns, :permit_more_specific_announcements, :max_length, :description, :force, :client_token) SENSITIVE = [] include Aws::Structure end |
#force ⇒ Boolean
Forces the modification even if it conflicts with an announced
route. Default: false.
66765 66766 66767 66768 66769 66770 66771 66772 66773 66774 66775 66776 66777 |
# File 'lib/aws-sdk-ec2/types.rb', line 66765 class ModifyIpamRoutingPolicyRegistrationRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id, :cidr, :asns, :permit_more_specific_announcements, :max_length, :description, :force, :client_token) SENSITIVE = [] include Aws::Structure end |
#ipam_internet_registry_association_id ⇒ String
The ID of the IPAM internet registry association.
66765 66766 66767 66768 66769 66770 66771 66772 66773 66774 66775 66776 66777 |
# File 'lib/aws-sdk-ec2/types.rb', line 66765 class ModifyIpamRoutingPolicyRegistrationRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id, :cidr, :asns, :permit_more_specific_announcements, :max_length, :description, :force, :client_token) SENSITIVE = [] include Aws::Structure end |
#max_length ⇒ Integer
The new maximum prefix length that the ASNs are authorized to announce. Must be greater than or equal to the prefix length of the CIDR.
66765 66766 66767 66768 66769 66770 66771 66772 66773 66774 66775 66776 66777 |
# File 'lib/aws-sdk-ec2/types.rb', line 66765 class ModifyIpamRoutingPolicyRegistrationRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id, :cidr, :asns, :permit_more_specific_announcements, :max_length, :description, :force, :client_token) SENSITIVE = [] include Aws::Structure end |
#permit_more_specific_announcements ⇒ Boolean
Specifies whether to permit more specific route announcements than
the CIDR prefix. Default: false.
66765 66766 66767 66768 66769 66770 66771 66772 66773 66774 66775 66776 66777 |
# File 'lib/aws-sdk-ec2/types.rb', line 66765 class ModifyIpamRoutingPolicyRegistrationRequest < Struct.new( :dry_run, :ipam_internet_registry_association_id, :cidr, :asns, :permit_more_specific_announcements, :max_length, :description, :force, :client_token) SENSITIVE = [] include Aws::Structure end |