Class: Aws::EC2::Types::ModifyIpamScopeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description of the scope you want to modify.

Returns:

  • (String)


61271
61272
61273
61274
61275
61276
61277
61278
61279
# File 'lib/aws-sdk-ec2/types.rb', line 61271

class ModifyIpamScopeRequest < Struct.new(
  :dry_run,
  :ipam_scope_id,
  :description,
  :external_authority_configuration,
  :remove_external_authority_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


61271
61272
61273
61274
61275
61276
61277
61278
61279
# File 'lib/aws-sdk-ec2/types.rb', line 61271

class ModifyIpamScopeRequest < Struct.new(
  :dry_run,
  :ipam_scope_id,
  :description,
  :external_authority_configuration,
  :remove_external_authority_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#external_authority_configurationTypes::ExternalAuthorityConfiguration

The configuration that links an Amazon VPC IPAM scope to an external authority system. It specifies the type of external system and the external resource identifier that identifies your account or instance in that system.

In IPAM, an external authority is a third-party IP address management system that provides CIDR blocks when you provision address space for top-level IPAM pools. This allows you to use your existing IP management system to control which address ranges are allocated to Amazon Web Services while using Amazon VPC IPAM to manage subnets within those ranges.



61271
61272
61273
61274
61275
61276
61277
61278
61279
# File 'lib/aws-sdk-ec2/types.rb', line 61271

class ModifyIpamScopeRequest < Struct.new(
  :dry_run,
  :ipam_scope_id,
  :description,
  :external_authority_configuration,
  :remove_external_authority_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_scope_idString

The ID of the scope you want to modify.

Returns:

  • (String)


61271
61272
61273
61274
61275
61276
61277
61278
61279
# File 'lib/aws-sdk-ec2/types.rb', line 61271

class ModifyIpamScopeRequest < Struct.new(
  :dry_run,
  :ipam_scope_id,
  :description,
  :external_authority_configuration,
  :remove_external_authority_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#remove_external_authority_configurationBoolean

Remove the external authority configuration. ‘true` to remove.

Returns:

  • (Boolean)


61271
61272
61273
61274
61275
61276
61277
61278
61279
# File 'lib/aws-sdk-ec2/types.rb', line 61271

class ModifyIpamScopeRequest < Struct.new(
  :dry_run,
  :ipam_scope_id,
  :description,
  :external_authority_configuration,
  :remove_external_authority_configuration)
  SENSITIVE = []
  include Aws::Structure
end