Class: Aws::EC2::Types::ModifyLaunchTemplateRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier you provide to ensure the idempotency of the request. If a client token isn't specified, a randomly generated token is used in the request to ensure idempotency.

For more information, see Ensuring idempotency.

Constraint: Maximum 128 ASCII characters.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


63824
63825
63826
63827
63828
63829
63830
63831
63832
# File 'lib/aws-sdk-ec2/types.rb', line 63824

class ModifyLaunchTemplateRequest < Struct.new(
  :dry_run,
  :client_token,
  :launch_template_id,
  :launch_template_name,
  :default_version)
  SENSITIVE = []
  include Aws::Structure
end

#default_versionString

The version number of the launch template to set as the default version.

Returns:

  • (String)


63824
63825
63826
63827
63828
63829
63830
63831
63832
# File 'lib/aws-sdk-ec2/types.rb', line 63824

class ModifyLaunchTemplateRequest < Struct.new(
  :dry_run,
  :client_token,
  :launch_template_id,
  :launch_template_name,
  :default_version)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


63824
63825
63826
63827
63828
63829
63830
63831
63832
# File 'lib/aws-sdk-ec2/types.rb', line 63824

class ModifyLaunchTemplateRequest < Struct.new(
  :dry_run,
  :client_token,
  :launch_template_id,
  :launch_template_name,
  :default_version)
  SENSITIVE = []
  include Aws::Structure
end

#launch_template_idString

The ID of the launch template.

You must specify either the launch template ID or the launch template name, but not both.

Returns:

  • (String)


63824
63825
63826
63827
63828
63829
63830
63831
63832
# File 'lib/aws-sdk-ec2/types.rb', line 63824

class ModifyLaunchTemplateRequest < Struct.new(
  :dry_run,
  :client_token,
  :launch_template_id,
  :launch_template_name,
  :default_version)
  SENSITIVE = []
  include Aws::Structure
end

#launch_template_nameString

The name of the launch template.

You must specify either the launch template ID or the launch template name, but not both.

Returns:

  • (String)


63824
63825
63826
63827
63828
63829
63830
63831
63832
# File 'lib/aws-sdk-ec2/types.rb', line 63824

class ModifyLaunchTemplateRequest < Struct.new(
  :dry_run,
  :client_token,
  :launch_template_id,
  :launch_template_name,
  :default_version)
  SENSITIVE = []
  include Aws::Structure
end