Class: Aws::EC2::Types::ModifyLocalGatewayRouteRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#destination_cidr_blockString

The CIDR block used for destination matches. The value that you provide must match the CIDR of an existing route in the table.

Returns:

  • (String)


63309
63310
63311
63312
63313
63314
63315
63316
63317
63318
# File 'lib/aws-sdk-ec2/types.rb', line 63309

class ModifyLocalGatewayRouteRequest < Struct.new(
  :destination_cidr_block,
  :local_gateway_route_table_id,
  :local_gateway_virtual_interface_group_id,
  :network_interface_id,
  :dry_run,
  :destination_prefix_list_id)
  SENSITIVE = []
  include Aws::Structure
end

#destination_prefix_list_idString

The ID of the prefix list. Use a prefix list in place of ‘DestinationCidrBlock`. You cannot use `DestinationPrefixListId` and `DestinationCidrBlock` in the same request.

Returns:

  • (String)


63309
63310
63311
63312
63313
63314
63315
63316
63317
63318
# File 'lib/aws-sdk-ec2/types.rb', line 63309

class ModifyLocalGatewayRouteRequest < Struct.new(
  :destination_cidr_block,
  :local_gateway_route_table_id,
  :local_gateway_virtual_interface_group_id,
  :network_interface_id,
  :dry_run,
  :destination_prefix_list_id)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


63309
63310
63311
63312
63313
63314
63315
63316
63317
63318
# File 'lib/aws-sdk-ec2/types.rb', line 63309

class ModifyLocalGatewayRouteRequest < Struct.new(
  :destination_cidr_block,
  :local_gateway_route_table_id,
  :local_gateway_virtual_interface_group_id,
  :network_interface_id,
  :dry_run,
  :destination_prefix_list_id)
  SENSITIVE = []
  include Aws::Structure
end

#local_gateway_route_table_idString

The ID of the local gateway route table.

Returns:

  • (String)


63309
63310
63311
63312
63313
63314
63315
63316
63317
63318
# File 'lib/aws-sdk-ec2/types.rb', line 63309

class ModifyLocalGatewayRouteRequest < Struct.new(
  :destination_cidr_block,
  :local_gateway_route_table_id,
  :local_gateway_virtual_interface_group_id,
  :network_interface_id,
  :dry_run,
  :destination_prefix_list_id)
  SENSITIVE = []
  include Aws::Structure
end

#local_gateway_virtual_interface_group_idString

The ID of the virtual interface group.

Returns:

  • (String)


63309
63310
63311
63312
63313
63314
63315
63316
63317
63318
# File 'lib/aws-sdk-ec2/types.rb', line 63309

class ModifyLocalGatewayRouteRequest < Struct.new(
  :destination_cidr_block,
  :local_gateway_route_table_id,
  :local_gateway_virtual_interface_group_id,
  :network_interface_id,
  :dry_run,
  :destination_prefix_list_id)
  SENSITIVE = []
  include Aws::Structure
end

#network_interface_idString

The ID of the network interface.

Returns:

  • (String)


63309
63310
63311
63312
63313
63314
63315
63316
63317
63318
# File 'lib/aws-sdk-ec2/types.rb', line 63309

class ModifyLocalGatewayRouteRequest < Struct.new(
  :destination_cidr_block,
  :local_gateway_route_table_id,
  :local_gateway_virtual_interface_group_id,
  :network_interface_id,
  :dry_run,
  :destination_prefix_list_id)
  SENSITIVE = []
  include Aws::Structure
end