Class: Aws::EC2::Types::ModifyLocalGatewayRouteRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyLocalGatewayRouteRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination_cidr_block ⇒ String
The CIDR block used for destination matches.
-
#destination_prefix_list_id ⇒ String
The ID of the prefix list.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#local_gateway_route_table_id ⇒ String
The ID of the local gateway route table.
-
#local_gateway_virtual_interface_group_id ⇒ String
The ID of the virtual interface group.
-
#network_interface_id ⇒ String
The ID of the network interface.
Instance Attribute Details
#destination_cidr_block ⇒ String
The CIDR block used for destination matches. The value that you provide must match the CIDR of an existing route in the table.
62452 62453 62454 62455 62456 62457 62458 62459 62460 62461 |
# File 'lib/aws-sdk-ec2/types.rb', line 62452 class ModifyLocalGatewayRouteRequest < Struct.new( :destination_cidr_block, :local_gateway_route_table_id, :local_gateway_virtual_interface_group_id, :network_interface_id, :dry_run, :destination_prefix_list_id) SENSITIVE = [] include Aws::Structure end |
#destination_prefix_list_id ⇒ String
The ID of the prefix list. Use a prefix list in place of ‘DestinationCidrBlock`. You cannot use `DestinationPrefixListId` and `DestinationCidrBlock` in the same request.
62452 62453 62454 62455 62456 62457 62458 62459 62460 62461 |
# File 'lib/aws-sdk-ec2/types.rb', line 62452 class ModifyLocalGatewayRouteRequest < Struct.new( :destination_cidr_block, :local_gateway_route_table_id, :local_gateway_virtual_interface_group_id, :network_interface_id, :dry_run, :destination_prefix_list_id) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
62452 62453 62454 62455 62456 62457 62458 62459 62460 62461 |
# File 'lib/aws-sdk-ec2/types.rb', line 62452 class ModifyLocalGatewayRouteRequest < Struct.new( :destination_cidr_block, :local_gateway_route_table_id, :local_gateway_virtual_interface_group_id, :network_interface_id, :dry_run, :destination_prefix_list_id) SENSITIVE = [] include Aws::Structure end |
#local_gateway_route_table_id ⇒ String
The ID of the local gateway route table.
62452 62453 62454 62455 62456 62457 62458 62459 62460 62461 |
# File 'lib/aws-sdk-ec2/types.rb', line 62452 class ModifyLocalGatewayRouteRequest < Struct.new( :destination_cidr_block, :local_gateway_route_table_id, :local_gateway_virtual_interface_group_id, :network_interface_id, :dry_run, :destination_prefix_list_id) SENSITIVE = [] include Aws::Structure end |
#local_gateway_virtual_interface_group_id ⇒ String
The ID of the virtual interface group.
62452 62453 62454 62455 62456 62457 62458 62459 62460 62461 |
# File 'lib/aws-sdk-ec2/types.rb', line 62452 class ModifyLocalGatewayRouteRequest < Struct.new( :destination_cidr_block, :local_gateway_route_table_id, :local_gateway_virtual_interface_group_id, :network_interface_id, :dry_run, :destination_prefix_list_id) SENSITIVE = [] include Aws::Structure end |
#network_interface_id ⇒ String
The ID of the network interface.
62452 62453 62454 62455 62456 62457 62458 62459 62460 62461 |
# File 'lib/aws-sdk-ec2/types.rb', line 62452 class ModifyLocalGatewayRouteRequest < Struct.new( :destination_cidr_block, :local_gateway_route_table_id, :local_gateway_virtual_interface_group_id, :network_interface_id, :dry_run, :destination_prefix_list_id) SENSITIVE = [] include Aws::Structure end |