Class: Aws::EC2::Types::ModifyManagedResourceVisibilityRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyManagedResourceVisibilityRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#default_visibility ⇒ String
The default visibility setting for managed resources.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
Instance Attribute Details
#default_visibility ⇒ String
The default visibility setting for managed resources. Valid values:
hidden | visible.
64124 64125 64126 64127 64128 64129 |
# File 'lib/aws-sdk-ec2/types.rb', line 64124 class ModifyManagedResourceVisibilityRequest < Struct.new( :dry_run, :default_visibility) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
64124 64125 64126 64127 64128 64129 |
# File 'lib/aws-sdk-ec2/types.rb', line 64124 class ModifyManagedResourceVisibilityRequest < Struct.new( :dry_run, :default_visibility) SENSITIVE = [] include Aws::Structure end |