Class: Aws::EC2::Types::ModifyPrivateDnsNameOptionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyPrivateDnsNameOptionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#enable_resource_name_dns_a_record ⇒ Boolean
Indicates whether to respond to DNS queries for instance hostnames with DNS A records.
-
#enable_resource_name_dns_aaaa_record ⇒ Boolean
Indicates whether to respond to DNS queries for instance hostnames with DNS AAAA records.
-
#instance_id ⇒ String
The ID of the instance.
-
#private_dns_hostname_type ⇒ String
The type of hostname for EC2 instances.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
63575 63576 63577 63578 63579 63580 63581 63582 63583 |
# File 'lib/aws-sdk-ec2/types.rb', line 63575 class ModifyPrivateDnsNameOptionsRequest < Struct.new( :dry_run, :instance_id, :private_dns_hostname_type, :enable_resource_name_dns_a_record, :enable_resource_name_dns_aaaa_record) SENSITIVE = [] include Aws::Structure end |
#enable_resource_name_dns_a_record ⇒ Boolean
Indicates whether to respond to DNS queries for instance hostnames with DNS A records.
63575 63576 63577 63578 63579 63580 63581 63582 63583 |
# File 'lib/aws-sdk-ec2/types.rb', line 63575 class ModifyPrivateDnsNameOptionsRequest < Struct.new( :dry_run, :instance_id, :private_dns_hostname_type, :enable_resource_name_dns_a_record, :enable_resource_name_dns_aaaa_record) SENSITIVE = [] include Aws::Structure end |
#enable_resource_name_dns_aaaa_record ⇒ Boolean
Indicates whether to respond to DNS queries for instance hostnames with DNS AAAA records.
63575 63576 63577 63578 63579 63580 63581 63582 63583 |
# File 'lib/aws-sdk-ec2/types.rb', line 63575 class ModifyPrivateDnsNameOptionsRequest < Struct.new( :dry_run, :instance_id, :private_dns_hostname_type, :enable_resource_name_dns_a_record, :enable_resource_name_dns_aaaa_record) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the instance.
63575 63576 63577 63578 63579 63580 63581 63582 63583 |
# File 'lib/aws-sdk-ec2/types.rb', line 63575 class ModifyPrivateDnsNameOptionsRequest < Struct.new( :dry_run, :instance_id, :private_dns_hostname_type, :enable_resource_name_dns_a_record, :enable_resource_name_dns_aaaa_record) SENSITIVE = [] include Aws::Structure end |
#private_dns_hostname_type ⇒ String
The type of hostname for EC2 instances. For IPv4 only subnets, an instance DNS name must be based on the instance IPv4 address. For IPv6 only subnets, an instance DNS name must be based on the instance ID. For dual-stack subnets, you can specify whether DNS names use the instance IPv4 address or the instance ID.
63575 63576 63577 63578 63579 63580 63581 63582 63583 |
# File 'lib/aws-sdk-ec2/types.rb', line 63575 class ModifyPrivateDnsNameOptionsRequest < Struct.new( :dry_run, :instance_id, :private_dns_hostname_type, :enable_resource_name_dns_a_record, :enable_resource_name_dns_aaaa_record) SENSITIVE = [] include Aws::Structure end |