Class: Aws::EC2::Types::ModifyPublicIpDnsNameOptionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyPublicIpDnsNameOptionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#hostname_type ⇒ String
The public hostname type.
-
#network_interface_id ⇒ String
A network interface ID.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
63192 63193 63194 63195 63196 63197 63198 |
# File 'lib/aws-sdk-ec2/types.rb', line 63192 class ModifyPublicIpDnsNameOptionsRequest < Struct.new( :network_interface_id, :hostname_type, :dry_run) SENSITIVE = [] include Aws::Structure end |
#hostname_type ⇒ String
The public hostname type. For more information, see [EC2 instance hostnames, DNS names, and domains] in the *Amazon EC2 User Guide*.
-
‘public-dual-stack-dns-name`: A dual-stack public hostname for a network interface. Requests from within the VPC resolve to both the private IPv4 address and the IPv6 Global Unicast Address of the network interface. Requests from the internet resolve to both the public IPv4 and the IPv6 GUA address of the network interface.
-
‘public-ipv4-dns-name`: An IPv4-enabled public hostname for a network interface. Requests from within the VPC resolve to the private primary IPv4 address of the network interface. Requests from the internet resolve to the public IPv4 address of the network interface.
-
‘public-ipv6-dns-name`: An IPv6-enabled public hostname for a network interface. Requests from within the VPC or from the internet resolve to the IPv6 GUA of the network interface.
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-instance-naming.html
63192 63193 63194 63195 63196 63197 63198 |
# File 'lib/aws-sdk-ec2/types.rb', line 63192 class ModifyPublicIpDnsNameOptionsRequest < Struct.new( :network_interface_id, :hostname_type, :dry_run) SENSITIVE = [] include Aws::Structure end |
#network_interface_id ⇒ String
A network interface ID.
63192 63193 63194 63195 63196 63197 63198 |
# File 'lib/aws-sdk-ec2/types.rb', line 63192 class ModifyPublicIpDnsNameOptionsRequest < Struct.new( :network_interface_id, :hostname_type, :dry_run) SENSITIVE = [] include Aws::Structure end |