Class: Aws::EC2::Types::ModifySecurityGroupRulesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifySecurityGroupRulesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#group_id ⇒ String
The ID of the security group.
-
#security_group_rules ⇒ Array<Types::SecurityGroupRuleUpdate>
Information about the security group properties to update.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
64483 64484 64485 64486 64487 64488 64489 |
# File 'lib/aws-sdk-ec2/types.rb', line 64483 class ModifySecurityGroupRulesRequest < Struct.new( :group_id, :security_group_rules, :dry_run) SENSITIVE = [] include Aws::Structure end |
#group_id ⇒ String
The ID of the security group.
64483 64484 64485 64486 64487 64488 64489 |
# File 'lib/aws-sdk-ec2/types.rb', line 64483 class ModifySecurityGroupRulesRequest < Struct.new( :group_id, :security_group_rules, :dry_run) SENSITIVE = [] include Aws::Structure end |
#security_group_rules ⇒ Array<Types::SecurityGroupRuleUpdate>
Information about the security group properties to update.
64483 64484 64485 64486 64487 64488 64489 |
# File 'lib/aws-sdk-ec2/types.rb', line 64483 class ModifySecurityGroupRulesRequest < Struct.new( :group_id, :security_group_rules, :dry_run) SENSITIVE = [] include Aws::Structure end |