Class: Aws::EC2::Types::ModifySecurityGroupRulesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


64332
64333
64334
64335
64336
64337
64338
# File 'lib/aws-sdk-ec2/types.rb', line 64332

class ModifySecurityGroupRulesRequest < Struct.new(
  :group_id,
  :security_group_rules,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#group_idString

The ID of the security group.

Returns:

  • (String)


64332
64333
64334
64335
64336
64337
64338
# File 'lib/aws-sdk-ec2/types.rb', line 64332

class ModifySecurityGroupRulesRequest < Struct.new(
  :group_id,
  :security_group_rules,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#security_group_rulesArray<Types::SecurityGroupRuleUpdate>

Information about the security group properties to update.

Returns:



64332
64333
64334
64335
64336
64337
64338
# File 'lib/aws-sdk-ec2/types.rb', line 64332

class ModifySecurityGroupRulesRequest < Struct.new(
  :group_id,
  :security_group_rules,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end