Class: Aws::EC2::Types::ModifySnapshotAttributeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributeString

The snapshot attribute to modify. Only volume creation permissions can be modified.

Returns:

  • (String)


64400
64401
64402
64403
64404
64405
64406
64407
64408
64409
64410
# File 'lib/aws-sdk-ec2/types.rb', line 64400

class ModifySnapshotAttributeRequest < Struct.new(
  :attribute,
  :create_volume_permission,
  :group_names,
  :operation_type,
  :snapshot_id,
  :user_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#create_volume_permissionTypes::CreateVolumePermissionModifications

A JSON representation of the snapshot attribute modification.



64400
64401
64402
64403
64404
64405
64406
64407
64408
64409
64410
# File 'lib/aws-sdk-ec2/types.rb', line 64400

class ModifySnapshotAttributeRequest < Struct.new(
  :attribute,
  :create_volume_permission,
  :group_names,
  :operation_type,
  :snapshot_id,
  :user_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


64400
64401
64402
64403
64404
64405
64406
64407
64408
64409
64410
# File 'lib/aws-sdk-ec2/types.rb', line 64400

class ModifySnapshotAttributeRequest < Struct.new(
  :attribute,
  :create_volume_permission,
  :group_names,
  :operation_type,
  :snapshot_id,
  :user_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#group_namesArray<String>

The group to modify for the snapshot.

Returns:

  • (Array<String>)


64400
64401
64402
64403
64404
64405
64406
64407
64408
64409
64410
# File 'lib/aws-sdk-ec2/types.rb', line 64400

class ModifySnapshotAttributeRequest < Struct.new(
  :attribute,
  :create_volume_permission,
  :group_names,
  :operation_type,
  :snapshot_id,
  :user_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#operation_typeString

The type of operation to perform to the attribute.

Returns:

  • (String)


64400
64401
64402
64403
64404
64405
64406
64407
64408
64409
64410
# File 'lib/aws-sdk-ec2/types.rb', line 64400

class ModifySnapshotAttributeRequest < Struct.new(
  :attribute,
  :create_volume_permission,
  :group_names,
  :operation_type,
  :snapshot_id,
  :user_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_idString

The ID of the snapshot.

Returns:

  • (String)


64400
64401
64402
64403
64404
64405
64406
64407
64408
64409
64410
# File 'lib/aws-sdk-ec2/types.rb', line 64400

class ModifySnapshotAttributeRequest < Struct.new(
  :attribute,
  :create_volume_permission,
  :group_names,
  :operation_type,
  :snapshot_id,
  :user_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#user_idsArray<String>

The account ID to modify for the snapshot.

Returns:

  • (Array<String>)


64400
64401
64402
64403
64404
64405
64406
64407
64408
64409
64410
# File 'lib/aws-sdk-ec2/types.rb', line 64400

class ModifySnapshotAttributeRequest < Struct.new(
  :attribute,
  :create_volume_permission,
  :group_names,
  :operation_type,
  :snapshot_id,
  :user_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end