Class: Aws::EC2::Types::ModifySnapshotAttributeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifySnapshotAttributeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute ⇒ String
The snapshot attribute to modify.
-
#create_volume_permission ⇒ Types::CreateVolumePermissionModifications
A JSON representation of the snapshot attribute modification.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#group_names ⇒ Array<String>
The group to modify for the snapshot.
-
#operation_type ⇒ String
The type of operation to perform to the attribute.
-
#snapshot_id ⇒ String
The ID of the snapshot.
-
#user_ids ⇒ Array<String>
The account ID to modify for the snapshot.
Instance Attribute Details
#attribute ⇒ String
The snapshot attribute to modify. Only volume creation permissions can be modified.
64077 64078 64079 64080 64081 64082 64083 64084 64085 64086 64087 |
# File 'lib/aws-sdk-ec2/types.rb', line 64077 class ModifySnapshotAttributeRequest < Struct.new( :attribute, :create_volume_permission, :group_names, :operation_type, :snapshot_id, :user_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#create_volume_permission ⇒ Types::CreateVolumePermissionModifications
A JSON representation of the snapshot attribute modification.
64077 64078 64079 64080 64081 64082 64083 64084 64085 64086 64087 |
# File 'lib/aws-sdk-ec2/types.rb', line 64077 class ModifySnapshotAttributeRequest < Struct.new( :attribute, :create_volume_permission, :group_names, :operation_type, :snapshot_id, :user_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
64077 64078 64079 64080 64081 64082 64083 64084 64085 64086 64087 |
# File 'lib/aws-sdk-ec2/types.rb', line 64077 class ModifySnapshotAttributeRequest < Struct.new( :attribute, :create_volume_permission, :group_names, :operation_type, :snapshot_id, :user_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#group_names ⇒ Array<String>
The group to modify for the snapshot.
64077 64078 64079 64080 64081 64082 64083 64084 64085 64086 64087 |
# File 'lib/aws-sdk-ec2/types.rb', line 64077 class ModifySnapshotAttributeRequest < Struct.new( :attribute, :create_volume_permission, :group_names, :operation_type, :snapshot_id, :user_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#operation_type ⇒ String
The type of operation to perform to the attribute.
64077 64078 64079 64080 64081 64082 64083 64084 64085 64086 64087 |
# File 'lib/aws-sdk-ec2/types.rb', line 64077 class ModifySnapshotAttributeRequest < Struct.new( :attribute, :create_volume_permission, :group_names, :operation_type, :snapshot_id, :user_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#snapshot_id ⇒ String
The ID of the snapshot.
64077 64078 64079 64080 64081 64082 64083 64084 64085 64086 64087 |
# File 'lib/aws-sdk-ec2/types.rb', line 64077 class ModifySnapshotAttributeRequest < Struct.new( :attribute, :create_volume_permission, :group_names, :operation_type, :snapshot_id, :user_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#user_ids ⇒ Array<String>
The account ID to modify for the snapshot.
64077 64078 64079 64080 64081 64082 64083 64084 64085 64086 64087 |
# File 'lib/aws-sdk-ec2/types.rb', line 64077 class ModifySnapshotAttributeRequest < Struct.new( :attribute, :create_volume_permission, :group_names, :operation_type, :snapshot_id, :user_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |