Class: Aws::EC2::Types::ModifySnapshotTierRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


64112
64113
64114
64115
64116
64117
64118
# File 'lib/aws-sdk-ec2/types.rb', line 64112

class ModifySnapshotTierRequest < Struct.new(
  :snapshot_id,
  :storage_tier,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_idString

The ID of the snapshot.

Returns:

  • (String)


64112
64113
64114
64115
64116
64117
64118
# File 'lib/aws-sdk-ec2/types.rb', line 64112

class ModifySnapshotTierRequest < Struct.new(
  :snapshot_id,
  :storage_tier,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#storage_tierString

The name of the storage tier. You must specify archive.

Returns:

  • (String)


64112
64113
64114
64115
64116
64117
64118
# File 'lib/aws-sdk-ec2/types.rb', line 64112

class ModifySnapshotTierRequest < Struct.new(
  :snapshot_id,
  :storage_tier,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end