Class: Aws::EC2::Types::ModifySnapshotTierRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifySnapshotTierRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#snapshot_id ⇒ String
The ID of the snapshot.
-
#storage_tier ⇒ String
The name of the storage tier.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
63427 63428 63429 63430 63431 63432 63433 |
# File 'lib/aws-sdk-ec2/types.rb', line 63427 class ModifySnapshotTierRequest < Struct.new( :snapshot_id, :storage_tier, :dry_run) SENSITIVE = [] include Aws::Structure end |
#snapshot_id ⇒ String
The ID of the snapshot.
63427 63428 63429 63430 63431 63432 63433 |
# File 'lib/aws-sdk-ec2/types.rb', line 63427 class ModifySnapshotTierRequest < Struct.new( :snapshot_id, :storage_tier, :dry_run) SENSITIVE = [] include Aws::Structure end |
#storage_tier ⇒ String
The name of the storage tier. You must specify ‘archive`.
63427 63428 63429 63430 63431 63432 63433 |
# File 'lib/aws-sdk-ec2/types.rb', line 63427 class ModifySnapshotTierRequest < Struct.new( :snapshot_id, :storage_tier, :dry_run) SENSITIVE = [] include Aws::Structure end |