Class: Aws::EC2::Types::ModifySpotFleetRequestRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for ModifySpotFleetRequest.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contextString

Reserved.

Returns:

  • (String)


64172
64173
64174
64175
64176
64177
64178
64179
64180
64181
# File 'lib/aws-sdk-ec2/types.rb', line 64172

class ModifySpotFleetRequestRequest < Struct.new(
  :launch_template_configs,
  :on_demand_target_capacity,
  :context,
  :spot_fleet_request_id,
  :target_capacity,
  :excess_capacity_termination_policy)
  SENSITIVE = []
  include Aws::Structure
end

#excess_capacity_termination_policyString

Indicates whether running instances should be terminated if the target capacity of the Spot Fleet request is decreased below the current size of the Spot Fleet.

Supported only for fleets of type maintain.

Returns:

  • (String)


64172
64173
64174
64175
64176
64177
64178
64179
64180
64181
# File 'lib/aws-sdk-ec2/types.rb', line 64172

class ModifySpotFleetRequestRequest < Struct.new(
  :launch_template_configs,
  :on_demand_target_capacity,
  :context,
  :spot_fleet_request_id,
  :target_capacity,
  :excess_capacity_termination_policy)
  SENSITIVE = []
  include Aws::Structure
end

#launch_template_configsArray<Types::LaunchTemplateConfig>

The launch template and overrides. You can only use this parameter if you specified a launch template (LaunchTemplateConfigs) in your Spot Fleet request. If you specified LaunchSpecifications in your Spot Fleet request, then omit this parameter.

Returns:



64172
64173
64174
64175
64176
64177
64178
64179
64180
64181
# File 'lib/aws-sdk-ec2/types.rb', line 64172

class ModifySpotFleetRequestRequest < Struct.new(
  :launch_template_configs,
  :on_demand_target_capacity,
  :context,
  :spot_fleet_request_id,
  :target_capacity,
  :excess_capacity_termination_policy)
  SENSITIVE = []
  include Aws::Structure
end

#on_demand_target_capacityInteger

The number of On-Demand Instances in the fleet.

Returns:

  • (Integer)


64172
64173
64174
64175
64176
64177
64178
64179
64180
64181
# File 'lib/aws-sdk-ec2/types.rb', line 64172

class ModifySpotFleetRequestRequest < Struct.new(
  :launch_template_configs,
  :on_demand_target_capacity,
  :context,
  :spot_fleet_request_id,
  :target_capacity,
  :excess_capacity_termination_policy)
  SENSITIVE = []
  include Aws::Structure
end

#spot_fleet_request_idString

The ID of the Spot Fleet request.

Returns:

  • (String)


64172
64173
64174
64175
64176
64177
64178
64179
64180
64181
# File 'lib/aws-sdk-ec2/types.rb', line 64172

class ModifySpotFleetRequestRequest < Struct.new(
  :launch_template_configs,
  :on_demand_target_capacity,
  :context,
  :spot_fleet_request_id,
  :target_capacity,
  :excess_capacity_termination_policy)
  SENSITIVE = []
  include Aws::Structure
end

#target_capacityInteger

The size of the fleet.

Returns:

  • (Integer)


64172
64173
64174
64175
64176
64177
64178
64179
64180
64181
# File 'lib/aws-sdk-ec2/types.rb', line 64172

class ModifySpotFleetRequestRequest < Struct.new(
  :launch_template_configs,
  :on_demand_target_capacity,
  :context,
  :spot_fleet_request_id,
  :target_capacity,
  :excess_capacity_termination_policy)
  SENSITIVE = []
  include Aws::Structure
end