Class: Aws::EC2::Types::ModifySpotFleetRequestRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifySpotFleetRequestRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for ModifySpotFleetRequest.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#context ⇒ String
Reserved.
-
#excess_capacity_termination_policy ⇒ String
Indicates whether running instances should be terminated if the target capacity of the Spot Fleet request is decreased below the current size of the Spot Fleet.
-
#launch_template_configs ⇒ Array<Types::LaunchTemplateConfig>
The launch template and overrides.
-
#on_demand_target_capacity ⇒ Integer
The number of On-Demand Instances in the fleet.
-
#spot_fleet_request_id ⇒ String
The ID of the Spot Fleet request.
-
#target_capacity ⇒ Integer
The size of the fleet.
Instance Attribute Details
#context ⇒ String
Reserved.
63030 63031 63032 63033 63034 63035 63036 63037 63038 63039 |
# File 'lib/aws-sdk-ec2/types.rb', line 63030 class ModifySpotFleetRequestRequest < Struct.new( :launch_template_configs, :on_demand_target_capacity, :context, :spot_fleet_request_id, :target_capacity, :excess_capacity_termination_policy) SENSITIVE = [] include Aws::Structure end |
#excess_capacity_termination_policy ⇒ String
Indicates whether running instances should be terminated if the target capacity of the Spot Fleet request is decreased below the current size of the Spot Fleet.
Supported only for fleets of type ‘maintain`.
63030 63031 63032 63033 63034 63035 63036 63037 63038 63039 |
# File 'lib/aws-sdk-ec2/types.rb', line 63030 class ModifySpotFleetRequestRequest < Struct.new( :launch_template_configs, :on_demand_target_capacity, :context, :spot_fleet_request_id, :target_capacity, :excess_capacity_termination_policy) SENSITIVE = [] include Aws::Structure end |
#launch_template_configs ⇒ Array<Types::LaunchTemplateConfig>
The launch template and overrides. You can only use this parameter if you specified a launch template (‘LaunchTemplateConfigs`) in your Spot Fleet request. If you specified `LaunchSpecifications` in your Spot Fleet request, then omit this parameter.
63030 63031 63032 63033 63034 63035 63036 63037 63038 63039 |
# File 'lib/aws-sdk-ec2/types.rb', line 63030 class ModifySpotFleetRequestRequest < Struct.new( :launch_template_configs, :on_demand_target_capacity, :context, :spot_fleet_request_id, :target_capacity, :excess_capacity_termination_policy) SENSITIVE = [] include Aws::Structure end |
#on_demand_target_capacity ⇒ Integer
The number of On-Demand Instances in the fleet.
63030 63031 63032 63033 63034 63035 63036 63037 63038 63039 |
# File 'lib/aws-sdk-ec2/types.rb', line 63030 class ModifySpotFleetRequestRequest < Struct.new( :launch_template_configs, :on_demand_target_capacity, :context, :spot_fleet_request_id, :target_capacity, :excess_capacity_termination_policy) SENSITIVE = [] include Aws::Structure end |
#spot_fleet_request_id ⇒ String
The ID of the Spot Fleet request.
63030 63031 63032 63033 63034 63035 63036 63037 63038 63039 |
# File 'lib/aws-sdk-ec2/types.rb', line 63030 class ModifySpotFleetRequestRequest < Struct.new( :launch_template_configs, :on_demand_target_capacity, :context, :spot_fleet_request_id, :target_capacity, :excess_capacity_termination_policy) SENSITIVE = [] include Aws::Structure end |
#target_capacity ⇒ Integer
The size of the fleet.
63030 63031 63032 63033 63034 63035 63036 63037 63038 63039 |
# File 'lib/aws-sdk-ec2/types.rb', line 63030 class ModifySpotFleetRequestRequest < Struct.new( :launch_template_configs, :on_demand_target_capacity, :context, :spot_fleet_request_id, :target_capacity, :excess_capacity_termination_policy) SENSITIVE = [] include Aws::Structure end |