Class: Aws::EC2::Types::ModifyTrafficMirrorSessionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyTrafficMirrorSessionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description to assign to the Traffic Mirror session.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#packet_length ⇒ Integer
The number of bytes in each packet to mirror.
-
#remove_fields ⇒ Array<String>
The properties that you want to remove from the Traffic Mirror session.
-
#session_number ⇒ Integer
The session number determines the order in which sessions are evaluated when an interface is used by multiple sessions.
-
#traffic_mirror_filter_id ⇒ String
The ID of the Traffic Mirror filter.
-
#traffic_mirror_session_id ⇒ String
The ID of the Traffic Mirror session.
-
#traffic_mirror_target_id ⇒ String
The Traffic Mirror target.
-
#virtual_network_id ⇒ Integer
The virtual network ID of the Traffic Mirror session.
Instance Attribute Details
#description ⇒ String
The description to assign to the Traffic Mirror session.
64507 64508 64509 64510 64511 64512 64513 64514 64515 64516 64517 64518 64519 |
# File 'lib/aws-sdk-ec2/types.rb', line 64507 class ModifyTrafficMirrorSessionRequest < Struct.new( :traffic_mirror_session_id, :traffic_mirror_target_id, :traffic_mirror_filter_id, :packet_length, :session_number, :virtual_network_id, :description, :remove_fields, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
64507 64508 64509 64510 64511 64512 64513 64514 64515 64516 64517 64518 64519 |
# File 'lib/aws-sdk-ec2/types.rb', line 64507 class ModifyTrafficMirrorSessionRequest < Struct.new( :traffic_mirror_session_id, :traffic_mirror_target_id, :traffic_mirror_filter_id, :packet_length, :session_number, :virtual_network_id, :description, :remove_fields, :dry_run) SENSITIVE = [] include Aws::Structure end |
#packet_length ⇒ Integer
The number of bytes in each packet to mirror. These are bytes after the VXLAN header. To mirror a subset, set this to the length (in bytes) to mirror. For example, if you set this value to 100, then the first 100 bytes that meet the filter criteria are copied to the target. Do not specify this parameter when you want to mirror the entire packet.
For sessions with Network Load Balancer (NLB) traffic mirror
targets, the default PacketLength will be set to 8500. Valid
values are 1-8500. Setting a PacketLength greater than 8500 will
result in an error response.
64507 64508 64509 64510 64511 64512 64513 64514 64515 64516 64517 64518 64519 |
# File 'lib/aws-sdk-ec2/types.rb', line 64507 class ModifyTrafficMirrorSessionRequest < Struct.new( :traffic_mirror_session_id, :traffic_mirror_target_id, :traffic_mirror_filter_id, :packet_length, :session_number, :virtual_network_id, :description, :remove_fields, :dry_run) SENSITIVE = [] include Aws::Structure end |
#remove_fields ⇒ Array<String>
The properties that you want to remove from the Traffic Mirror session.
When you remove a property from a Traffic Mirror session, the property is set to the default.
64507 64508 64509 64510 64511 64512 64513 64514 64515 64516 64517 64518 64519 |
# File 'lib/aws-sdk-ec2/types.rb', line 64507 class ModifyTrafficMirrorSessionRequest < Struct.new( :traffic_mirror_session_id, :traffic_mirror_target_id, :traffic_mirror_filter_id, :packet_length, :session_number, :virtual_network_id, :description, :remove_fields, :dry_run) SENSITIVE = [] include Aws::Structure end |
#session_number ⇒ Integer
The session number determines the order in which sessions are evaluated when an interface is used by multiple sessions. The first session with a matching filter is the one that mirrors the packets.
Valid values are 1-32766.
64507 64508 64509 64510 64511 64512 64513 64514 64515 64516 64517 64518 64519 |
# File 'lib/aws-sdk-ec2/types.rb', line 64507 class ModifyTrafficMirrorSessionRequest < Struct.new( :traffic_mirror_session_id, :traffic_mirror_target_id, :traffic_mirror_filter_id, :packet_length, :session_number, :virtual_network_id, :description, :remove_fields, :dry_run) SENSITIVE = [] include Aws::Structure end |
#traffic_mirror_filter_id ⇒ String
The ID of the Traffic Mirror filter.
64507 64508 64509 64510 64511 64512 64513 64514 64515 64516 64517 64518 64519 |
# File 'lib/aws-sdk-ec2/types.rb', line 64507 class ModifyTrafficMirrorSessionRequest < Struct.new( :traffic_mirror_session_id, :traffic_mirror_target_id, :traffic_mirror_filter_id, :packet_length, :session_number, :virtual_network_id, :description, :remove_fields, :dry_run) SENSITIVE = [] include Aws::Structure end |
#traffic_mirror_session_id ⇒ String
The ID of the Traffic Mirror session.
64507 64508 64509 64510 64511 64512 64513 64514 64515 64516 64517 64518 64519 |
# File 'lib/aws-sdk-ec2/types.rb', line 64507 class ModifyTrafficMirrorSessionRequest < Struct.new( :traffic_mirror_session_id, :traffic_mirror_target_id, :traffic_mirror_filter_id, :packet_length, :session_number, :virtual_network_id, :description, :remove_fields, :dry_run) SENSITIVE = [] include Aws::Structure end |
#traffic_mirror_target_id ⇒ String
The Traffic Mirror target. The target must be in the same VPC as the source, or have a VPC peering connection with the source.
64507 64508 64509 64510 64511 64512 64513 64514 64515 64516 64517 64518 64519 |
# File 'lib/aws-sdk-ec2/types.rb', line 64507 class ModifyTrafficMirrorSessionRequest < Struct.new( :traffic_mirror_session_id, :traffic_mirror_target_id, :traffic_mirror_filter_id, :packet_length, :session_number, :virtual_network_id, :description, :remove_fields, :dry_run) SENSITIVE = [] include Aws::Structure end |
#virtual_network_id ⇒ Integer
The virtual network ID of the Traffic Mirror session.
64507 64508 64509 64510 64511 64512 64513 64514 64515 64516 64517 64518 64519 |
# File 'lib/aws-sdk-ec2/types.rb', line 64507 class ModifyTrafficMirrorSessionRequest < Struct.new( :traffic_mirror_session_id, :traffic_mirror_target_id, :traffic_mirror_filter_id, :packet_length, :session_number, :virtual_network_id, :description, :remove_fields, :dry_run) SENSITIVE = [] include Aws::Structure end |