Class: Aws::EC2::Types::ModifyTransitGatewayMeteringPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyTransitGatewayMeteringPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#add_middlebox_attachment_ids ⇒ Array<String>
The IDs of middlebox attachments to add to the metering policy.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#remove_middlebox_attachment_ids ⇒ Array<String>
The IDs of middlebox attachments to remove from the metering policy.
-
#transit_gateway_metering_policy_id ⇒ String
The ID of the transit gateway metering policy to modify.
Instance Attribute Details
#add_middlebox_attachment_ids ⇒ Array<String>
The IDs of middlebox attachments to add to the metering policy.
65008 65009 65010 65011 65012 65013 65014 65015 |
# File 'lib/aws-sdk-ec2/types.rb', line 65008 class ModifyTransitGatewayMeteringPolicyRequest < Struct.new( :transit_gateway_metering_policy_id, :add_middlebox_attachment_ids, :remove_middlebox_attachment_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
65008 65009 65010 65011 65012 65013 65014 65015 |
# File 'lib/aws-sdk-ec2/types.rb', line 65008 class ModifyTransitGatewayMeteringPolicyRequest < Struct.new( :transit_gateway_metering_policy_id, :add_middlebox_attachment_ids, :remove_middlebox_attachment_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#remove_middlebox_attachment_ids ⇒ Array<String>
The IDs of middlebox attachments to remove from the metering policy.
65008 65009 65010 65011 65012 65013 65014 65015 |
# File 'lib/aws-sdk-ec2/types.rb', line 65008 class ModifyTransitGatewayMeteringPolicyRequest < Struct.new( :transit_gateway_metering_policy_id, :add_middlebox_attachment_ids, :remove_middlebox_attachment_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_metering_policy_id ⇒ String
The ID of the transit gateway metering policy to modify.
65008 65009 65010 65011 65012 65013 65014 65015 |
# File 'lib/aws-sdk-ec2/types.rb', line 65008 class ModifyTransitGatewayMeteringPolicyRequest < Struct.new( :transit_gateway_metering_policy_id, :add_middlebox_attachment_ids, :remove_middlebox_attachment_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |