Class: Aws::EC2::Types::ModifyTransitGatewayMeteringPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#add_middlebox_attachment_idsArray<String>

The IDs of middlebox attachments to add to the metering policy.

Returns:

  • (Array<String>)


64302
64303
64304
64305
64306
64307
64308
64309
# File 'lib/aws-sdk-ec2/types.rb', line 64302

class ModifyTransitGatewayMeteringPolicyRequest < Struct.new(
  :transit_gateway_metering_policy_id,
  :add_middlebox_attachment_ids,
  :remove_middlebox_attachment_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


64302
64303
64304
64305
64306
64307
64308
64309
# File 'lib/aws-sdk-ec2/types.rb', line 64302

class ModifyTransitGatewayMeteringPolicyRequest < Struct.new(
  :transit_gateway_metering_policy_id,
  :add_middlebox_attachment_ids,
  :remove_middlebox_attachment_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#remove_middlebox_attachment_idsArray<String>

The IDs of middlebox attachments to remove from the metering policy.

Returns:

  • (Array<String>)


64302
64303
64304
64305
64306
64307
64308
64309
# File 'lib/aws-sdk-ec2/types.rb', line 64302

class ModifyTransitGatewayMeteringPolicyRequest < Struct.new(
  :transit_gateway_metering_policy_id,
  :add_middlebox_attachment_ids,
  :remove_middlebox_attachment_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_metering_policy_idString

The ID of the transit gateway metering policy to modify.

Returns:

  • (String)


64302
64303
64304
64305
64306
64307
64308
64309
# File 'lib/aws-sdk-ec2/types.rb', line 64302

class ModifyTransitGatewayMeteringPolicyRequest < Struct.new(
  :transit_gateway_metering_policy_id,
  :add_middlebox_attachment_ids,
  :remove_middlebox_attachment_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end