Class: Aws::EC2::Types::ModifyTransitGatewayOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyTransitGatewayOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
The transit gateway options.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#add_transit_gateway_cidr_blocks ⇒ Array<String>
Adds IPv4 or IPv6 CIDR blocks for the transit gateway.
-
#amazon_side_asn ⇒ Integer
A private Autonomous System Number (ASN) for the Amazon side of a BGP session.
-
#association_default_route_table_id ⇒ String
The ID of the default association route table.
-
#auto_accept_shared_attachments ⇒ String
Enable or disable automatic acceptance of attachment requests.
-
#default_route_table_association ⇒ String
Enable or disable automatic association with the default association route table.
-
#default_route_table_propagation ⇒ String
Indicates whether resource attachments automatically propagate routes to the default propagation route table.
-
#dns_support ⇒ String
Enable or disable DNS support.
-
#encryption_support ⇒ String
Enable or disable encryption support for VPC Encryption Control.
-
#propagation_default_route_table_id ⇒ String
The ID of the default propagation route table.
-
#remove_transit_gateway_cidr_blocks ⇒ Array<String>
Removes CIDR blocks for the transit gateway.
-
#security_group_referencing_support ⇒ String
Enables you to reference a security group across VPCs attached to a transit gateway to simplify security group management.
-
#vpn_ecmp_support ⇒ String
Enable or disable Equal Cost Multipath Protocol support.
Instance Attribute Details
#add_transit_gateway_cidr_blocks ⇒ Array<String>
Adds IPv4 or IPv6 CIDR blocks for the transit gateway. Must be a size /24 CIDR block or larger for IPv4, or a size /64 CIDR block or larger for IPv6.
63519 63520 63521 63522 63523 63524 63525 63526 63527 63528 63529 63530 63531 63532 63533 63534 |
# File 'lib/aws-sdk-ec2/types.rb', line 63519 class ModifyTransitGatewayOptions < Struct.new( :add_transit_gateway_cidr_blocks, :remove_transit_gateway_cidr_blocks, :vpn_ecmp_support, :dns_support, :security_group_referencing_support, :auto_accept_shared_attachments, :default_route_table_association, :association_default_route_table_id, :default_route_table_propagation, :propagation_default_route_table_id, :amazon_side_asn, :encryption_support) SENSITIVE = [] include Aws::Structure end |
#amazon_side_asn ⇒ Integer
A private Autonomous System Number (ASN) for the Amazon side of a BGP session. The range is 64512 to 65534 for 16-bit ASNs and 4200000000 to 4294967294 for 32-bit ASNs.
The modify ASN operation is not allowed on a transit gateway if it has the following attachments:
-
Dynamic VPN
-
Static VPN
-
Direct Connect Gateway
-
Connect
You must first delete all transit gateway attachments configured prior to modifying the ASN on the transit gateway.
63519 63520 63521 63522 63523 63524 63525 63526 63527 63528 63529 63530 63531 63532 63533 63534 |
# File 'lib/aws-sdk-ec2/types.rb', line 63519 class ModifyTransitGatewayOptions < Struct.new( :add_transit_gateway_cidr_blocks, :remove_transit_gateway_cidr_blocks, :vpn_ecmp_support, :dns_support, :security_group_referencing_support, :auto_accept_shared_attachments, :default_route_table_association, :association_default_route_table_id, :default_route_table_propagation, :propagation_default_route_table_id, :amazon_side_asn, :encryption_support) SENSITIVE = [] include Aws::Structure end |
#association_default_route_table_id ⇒ String
The ID of the default association route table.
63519 63520 63521 63522 63523 63524 63525 63526 63527 63528 63529 63530 63531 63532 63533 63534 |
# File 'lib/aws-sdk-ec2/types.rb', line 63519 class ModifyTransitGatewayOptions < Struct.new( :add_transit_gateway_cidr_blocks, :remove_transit_gateway_cidr_blocks, :vpn_ecmp_support, :dns_support, :security_group_referencing_support, :auto_accept_shared_attachments, :default_route_table_association, :association_default_route_table_id, :default_route_table_propagation, :propagation_default_route_table_id, :amazon_side_asn, :encryption_support) SENSITIVE = [] include Aws::Structure end |
#auto_accept_shared_attachments ⇒ String
Enable or disable automatic acceptance of attachment requests.
63519 63520 63521 63522 63523 63524 63525 63526 63527 63528 63529 63530 63531 63532 63533 63534 |
# File 'lib/aws-sdk-ec2/types.rb', line 63519 class ModifyTransitGatewayOptions < Struct.new( :add_transit_gateway_cidr_blocks, :remove_transit_gateway_cidr_blocks, :vpn_ecmp_support, :dns_support, :security_group_referencing_support, :auto_accept_shared_attachments, :default_route_table_association, :association_default_route_table_id, :default_route_table_propagation, :propagation_default_route_table_id, :amazon_side_asn, :encryption_support) SENSITIVE = [] include Aws::Structure end |
#default_route_table_association ⇒ String
Enable or disable automatic association with the default association route table.
63519 63520 63521 63522 63523 63524 63525 63526 63527 63528 63529 63530 63531 63532 63533 63534 |
# File 'lib/aws-sdk-ec2/types.rb', line 63519 class ModifyTransitGatewayOptions < Struct.new( :add_transit_gateway_cidr_blocks, :remove_transit_gateway_cidr_blocks, :vpn_ecmp_support, :dns_support, :security_group_referencing_support, :auto_accept_shared_attachments, :default_route_table_association, :association_default_route_table_id, :default_route_table_propagation, :propagation_default_route_table_id, :amazon_side_asn, :encryption_support) SENSITIVE = [] include Aws::Structure end |
#default_route_table_propagation ⇒ String
Indicates whether resource attachments automatically propagate routes to the default propagation route table. Enabled by default. If ‘defaultRouteTablePropagation` is set to `enable`, Amazon Web Services Transit Gateway will create the default transit gateway route table.
63519 63520 63521 63522 63523 63524 63525 63526 63527 63528 63529 63530 63531 63532 63533 63534 |
# File 'lib/aws-sdk-ec2/types.rb', line 63519 class ModifyTransitGatewayOptions < Struct.new( :add_transit_gateway_cidr_blocks, :remove_transit_gateway_cidr_blocks, :vpn_ecmp_support, :dns_support, :security_group_referencing_support, :auto_accept_shared_attachments, :default_route_table_association, :association_default_route_table_id, :default_route_table_propagation, :propagation_default_route_table_id, :amazon_side_asn, :encryption_support) SENSITIVE = [] include Aws::Structure end |
#dns_support ⇒ String
Enable or disable DNS support.
63519 63520 63521 63522 63523 63524 63525 63526 63527 63528 63529 63530 63531 63532 63533 63534 |
# File 'lib/aws-sdk-ec2/types.rb', line 63519 class ModifyTransitGatewayOptions < Struct.new( :add_transit_gateway_cidr_blocks, :remove_transit_gateway_cidr_blocks, :vpn_ecmp_support, :dns_support, :security_group_referencing_support, :auto_accept_shared_attachments, :default_route_table_association, :association_default_route_table_id, :default_route_table_propagation, :propagation_default_route_table_id, :amazon_side_asn, :encryption_support) SENSITIVE = [] include Aws::Structure end |
#encryption_support ⇒ String
Enable or disable encryption support for VPC Encryption Control.
63519 63520 63521 63522 63523 63524 63525 63526 63527 63528 63529 63530 63531 63532 63533 63534 |
# File 'lib/aws-sdk-ec2/types.rb', line 63519 class ModifyTransitGatewayOptions < Struct.new( :add_transit_gateway_cidr_blocks, :remove_transit_gateway_cidr_blocks, :vpn_ecmp_support, :dns_support, :security_group_referencing_support, :auto_accept_shared_attachments, :default_route_table_association, :association_default_route_table_id, :default_route_table_propagation, :propagation_default_route_table_id, :amazon_side_asn, :encryption_support) SENSITIVE = [] include Aws::Structure end |
#propagation_default_route_table_id ⇒ String
The ID of the default propagation route table.
63519 63520 63521 63522 63523 63524 63525 63526 63527 63528 63529 63530 63531 63532 63533 63534 |
# File 'lib/aws-sdk-ec2/types.rb', line 63519 class ModifyTransitGatewayOptions < Struct.new( :add_transit_gateway_cidr_blocks, :remove_transit_gateway_cidr_blocks, :vpn_ecmp_support, :dns_support, :security_group_referencing_support, :auto_accept_shared_attachments, :default_route_table_association, :association_default_route_table_id, :default_route_table_propagation, :propagation_default_route_table_id, :amazon_side_asn, :encryption_support) SENSITIVE = [] include Aws::Structure end |
#remove_transit_gateway_cidr_blocks ⇒ Array<String>
Removes CIDR blocks for the transit gateway.
63519 63520 63521 63522 63523 63524 63525 63526 63527 63528 63529 63530 63531 63532 63533 63534 |
# File 'lib/aws-sdk-ec2/types.rb', line 63519 class ModifyTransitGatewayOptions < Struct.new( :add_transit_gateway_cidr_blocks, :remove_transit_gateway_cidr_blocks, :vpn_ecmp_support, :dns_support, :security_group_referencing_support, :auto_accept_shared_attachments, :default_route_table_association, :association_default_route_table_id, :default_route_table_propagation, :propagation_default_route_table_id, :amazon_side_asn, :encryption_support) SENSITIVE = [] include Aws::Structure end |
#security_group_referencing_support ⇒ String
Enables you to reference a security group across VPCs attached to a transit gateway to simplify security group management.
This option is disabled by default.
For more information about security group referencing, see [Security group referencing] in the *Amazon Web Services Transit Gateways Guide*.
[1]: docs.aws.amazon.com/vpc/latest/tgw/tgw-vpc-attachments.html#vpc-attachment-security
63519 63520 63521 63522 63523 63524 63525 63526 63527 63528 63529 63530 63531 63532 63533 63534 |
# File 'lib/aws-sdk-ec2/types.rb', line 63519 class ModifyTransitGatewayOptions < Struct.new( :add_transit_gateway_cidr_blocks, :remove_transit_gateway_cidr_blocks, :vpn_ecmp_support, :dns_support, :security_group_referencing_support, :auto_accept_shared_attachments, :default_route_table_association, :association_default_route_table_id, :default_route_table_propagation, :propagation_default_route_table_id, :amazon_side_asn, :encryption_support) SENSITIVE = [] include Aws::Structure end |
#vpn_ecmp_support ⇒ String
Enable or disable Equal Cost Multipath Protocol support.
63519 63520 63521 63522 63523 63524 63525 63526 63527 63528 63529 63530 63531 63532 63533 63534 |
# File 'lib/aws-sdk-ec2/types.rb', line 63519 class ModifyTransitGatewayOptions < Struct.new( :add_transit_gateway_cidr_blocks, :remove_transit_gateway_cidr_blocks, :vpn_ecmp_support, :dns_support, :security_group_referencing_support, :auto_accept_shared_attachments, :default_route_table_association, :association_default_route_table_id, :default_route_table_propagation, :propagation_default_route_table_id, :amazon_side_asn, :encryption_support) SENSITIVE = [] include Aws::Structure end |