Class: Aws::EC2::Types::ModifyTransitGatewayPolicyTableEntryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyTransitGatewayPolicyTableEntryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#policy_rule ⇒ Types::TransitGatewayRequestPolicyRule
The updated matching criteria for the policy table entry.
-
#policy_rule_number ⇒ String
The rule number of the policy table entry to modify.
-
#target_route_table_id ⇒ String
The ID of the transit gateway route table to use for traffic matching this rule.
-
#transit_gateway_policy_table_id ⇒ String
The ID of the transit gateway policy table.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
68088 68089 68090 68091 68092 68093 68094 68095 68096 |
# File 'lib/aws-sdk-ec2/types.rb', line 68088 class ModifyTransitGatewayPolicyTableEntryRequest < Struct.new( :transit_gateway_policy_table_id, :policy_rule_number, :policy_rule, :target_route_table_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#policy_rule ⇒ Types::TransitGatewayRequestPolicyRule
The updated matching criteria for the policy table entry. Unspecified fields retain their current values.
68088 68089 68090 68091 68092 68093 68094 68095 68096 |
# File 'lib/aws-sdk-ec2/types.rb', line 68088 class ModifyTransitGatewayPolicyTableEntryRequest < Struct.new( :transit_gateway_policy_table_id, :policy_rule_number, :policy_rule, :target_route_table_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#policy_rule_number ⇒ String
The rule number of the policy table entry to modify.
68088 68089 68090 68091 68092 68093 68094 68095 68096 |
# File 'lib/aws-sdk-ec2/types.rb', line 68088 class ModifyTransitGatewayPolicyTableEntryRequest < Struct.new( :transit_gateway_policy_table_id, :policy_rule_number, :policy_rule, :target_route_table_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#target_route_table_id ⇒ String
The ID of the transit gateway route table to use for traffic matching this rule.
68088 68089 68090 68091 68092 68093 68094 68095 68096 |
# File 'lib/aws-sdk-ec2/types.rb', line 68088 class ModifyTransitGatewayPolicyTableEntryRequest < Struct.new( :transit_gateway_policy_table_id, :policy_rule_number, :policy_rule, :target_route_table_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_policy_table_id ⇒ String
The ID of the transit gateway policy table.
68088 68089 68090 68091 68092 68093 68094 68095 68096 |
# File 'lib/aws-sdk-ec2/types.rb', line 68088 class ModifyTransitGatewayPolicyTableEntryRequest < Struct.new( :transit_gateway_policy_table_id, :policy_rule_number, :policy_rule, :target_route_table_id, :dry_run) SENSITIVE = [] include Aws::Structure end |