Class: Aws::EC2::Types::ModifyTransitGatewayPolicyTableEntryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


66653
66654
66655
66656
66657
66658
66659
66660
66661
# File 'lib/aws-sdk-ec2/types.rb', line 66653

class ModifyTransitGatewayPolicyTableEntryRequest < Struct.new(
  :transit_gateway_policy_table_id,
  :policy_rule_number,
  :policy_rule,
  :target_route_table_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#policy_ruleTypes::TransitGatewayRequestPolicyRule

The updated matching criteria for the policy table entry. Unspecified fields retain their current values.



66653
66654
66655
66656
66657
66658
66659
66660
66661
# File 'lib/aws-sdk-ec2/types.rb', line 66653

class ModifyTransitGatewayPolicyTableEntryRequest < Struct.new(
  :transit_gateway_policy_table_id,
  :policy_rule_number,
  :policy_rule,
  :target_route_table_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#policy_rule_numberString

The rule number of the policy table entry to modify.

Returns:

  • (String)


66653
66654
66655
66656
66657
66658
66659
66660
66661
# File 'lib/aws-sdk-ec2/types.rb', line 66653

class ModifyTransitGatewayPolicyTableEntryRequest < Struct.new(
  :transit_gateway_policy_table_id,
  :policy_rule_number,
  :policy_rule,
  :target_route_table_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#target_route_table_idString

The ID of the transit gateway route table to use for traffic matching this rule.

Returns:

  • (String)


66653
66654
66655
66656
66657
66658
66659
66660
66661
# File 'lib/aws-sdk-ec2/types.rb', line 66653

class ModifyTransitGatewayPolicyTableEntryRequest < Struct.new(
  :transit_gateway_policy_table_id,
  :policy_rule_number,
  :policy_rule,
  :target_route_table_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_policy_table_idString

The ID of the transit gateway policy table.

Returns:

  • (String)


66653
66654
66655
66656
66657
66658
66659
66660
66661
# File 'lib/aws-sdk-ec2/types.rb', line 66653

class ModifyTransitGatewayPolicyTableEntryRequest < Struct.new(
  :transit_gateway_policy_table_id,
  :policy_rule_number,
  :policy_rule,
  :target_route_table_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end