Class: Aws::EC2::Types::ModifyTransitGatewayPolicyTableEntryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


65286
65287
65288
65289
65290
65291
65292
65293
65294
# File 'lib/aws-sdk-ec2/types.rb', line 65286

class ModifyTransitGatewayPolicyTableEntryRequest < Struct.new(
  :transit_gateway_policy_table_id,
  :policy_rule_number,
  :policy_rule,
  :target_route_table_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#policy_ruleTypes::TransitGatewayRequestPolicyRule

The updated matching criteria for the policy table entry. Unspecified fields retain their current values.



65286
65287
65288
65289
65290
65291
65292
65293
65294
# File 'lib/aws-sdk-ec2/types.rb', line 65286

class ModifyTransitGatewayPolicyTableEntryRequest < Struct.new(
  :transit_gateway_policy_table_id,
  :policy_rule_number,
  :policy_rule,
  :target_route_table_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#policy_rule_numberString

The rule number of the policy table entry to modify.

Returns:

  • (String)


65286
65287
65288
65289
65290
65291
65292
65293
65294
# File 'lib/aws-sdk-ec2/types.rb', line 65286

class ModifyTransitGatewayPolicyTableEntryRequest < Struct.new(
  :transit_gateway_policy_table_id,
  :policy_rule_number,
  :policy_rule,
  :target_route_table_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#target_route_table_idString

The ID of the transit gateway route table to use for traffic matching this rule.

Returns:

  • (String)


65286
65287
65288
65289
65290
65291
65292
65293
65294
# File 'lib/aws-sdk-ec2/types.rb', line 65286

class ModifyTransitGatewayPolicyTableEntryRequest < Struct.new(
  :transit_gateway_policy_table_id,
  :policy_rule_number,
  :policy_rule,
  :target_route_table_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_policy_table_idString

The ID of the transit gateway policy table.

Returns:

  • (String)


65286
65287
65288
65289
65290
65291
65292
65293
65294
# File 'lib/aws-sdk-ec2/types.rb', line 65286

class ModifyTransitGatewayPolicyTableEntryRequest < Struct.new(
  :transit_gateway_policy_table_id,
  :policy_rule_number,
  :policy_rule,
  :target_route_table_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end