Class: Aws::EC2::Types::ModifyTransitGatewayRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description for the transit gateway.

Returns:

  • (String)


68187
68188
68189
68190
68191
68192
68193
68194
# File 'lib/aws-sdk-ec2/types.rb', line 68187

class ModifyTransitGatewayRequest < Struct.new(
  :transit_gateway_id,
  :description,
  :options,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


68187
68188
68189
68190
68191
68192
68193
68194
# File 'lib/aws-sdk-ec2/types.rb', line 68187

class ModifyTransitGatewayRequest < Struct.new(
  :transit_gateway_id,
  :description,
  :options,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#optionsTypes::ModifyTransitGatewayOptions

The options to modify.



68187
68188
68189
68190
68191
68192
68193
68194
# File 'lib/aws-sdk-ec2/types.rb', line 68187

class ModifyTransitGatewayRequest < Struct.new(
  :transit_gateway_id,
  :description,
  :options,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_idString

The ID of the transit gateway.

Returns:

  • (String)


68187
68188
68189
68190
68191
68192
68193
68194
# File 'lib/aws-sdk-ec2/types.rb', line 68187

class ModifyTransitGatewayRequest < Struct.new(
  :transit_gateway_id,
  :description,
  :options,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end