Class: Aws::EC2::Types::ModifyTransitGatewayRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description for the transit gateway.

Returns:

  • (String)


64744
64745
64746
64747
64748
64749
64750
64751
# File 'lib/aws-sdk-ec2/types.rb', line 64744

class ModifyTransitGatewayRequest < Struct.new(
  :transit_gateway_id,
  :description,
  :options,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


64744
64745
64746
64747
64748
64749
64750
64751
# File 'lib/aws-sdk-ec2/types.rb', line 64744

class ModifyTransitGatewayRequest < Struct.new(
  :transit_gateway_id,
  :description,
  :options,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#optionsTypes::ModifyTransitGatewayOptions

The options to modify.



64744
64745
64746
64747
64748
64749
64750
64751
# File 'lib/aws-sdk-ec2/types.rb', line 64744

class ModifyTransitGatewayRequest < Struct.new(
  :transit_gateway_id,
  :description,
  :options,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_idString

The ID of the transit gateway.

Returns:

  • (String)


64744
64745
64746
64747
64748
64749
64750
64751
# File 'lib/aws-sdk-ec2/types.rb', line 64744

class ModifyTransitGatewayRequest < Struct.new(
  :transit_gateway_id,
  :description,
  :options,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end