Class: Aws::EC2::Types::ModifyTransitGatewayRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description for the transit gateway.

Returns:

  • (String)


64506
64507
64508
64509
64510
64511
64512
64513
# File 'lib/aws-sdk-ec2/types.rb', line 64506

class ModifyTransitGatewayRequest < Struct.new(
  :transit_gateway_id,
  :description,
  :options,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


64506
64507
64508
64509
64510
64511
64512
64513
# File 'lib/aws-sdk-ec2/types.rb', line 64506

class ModifyTransitGatewayRequest < Struct.new(
  :transit_gateway_id,
  :description,
  :options,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#optionsTypes::ModifyTransitGatewayOptions

The options to modify.



64506
64507
64508
64509
64510
64511
64512
64513
# File 'lib/aws-sdk-ec2/types.rb', line 64506

class ModifyTransitGatewayRequest < Struct.new(
  :transit_gateway_id,
  :description,
  :options,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_idString

The ID of the transit gateway.

Returns:

  • (String)


64506
64507
64508
64509
64510
64511
64512
64513
# File 'lib/aws-sdk-ec2/types.rb', line 64506

class ModifyTransitGatewayRequest < Struct.new(
  :transit_gateway_id,
  :description,
  :options,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end