Class: Aws::EC2::Types::ModifyTransitGatewayRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyTransitGatewayRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description for the transit gateway.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#options ⇒ Types::ModifyTransitGatewayOptions
The options to modify.
-
#transit_gateway_id ⇒ String
The ID of the transit gateway.
Instance Attribute Details
#description ⇒ String
The description for the transit gateway.
64494 64495 64496 64497 64498 64499 64500 64501 |
# File 'lib/aws-sdk-ec2/types.rb', line 64494 class ModifyTransitGatewayRequest < Struct.new( :transit_gateway_id, :description, :options, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
64494 64495 64496 64497 64498 64499 64500 64501 |
# File 'lib/aws-sdk-ec2/types.rb', line 64494 class ModifyTransitGatewayRequest < Struct.new( :transit_gateway_id, :description, :options, :dry_run) SENSITIVE = [] include Aws::Structure end |
#options ⇒ Types::ModifyTransitGatewayOptions
The options to modify.
64494 64495 64496 64497 64498 64499 64500 64501 |
# File 'lib/aws-sdk-ec2/types.rb', line 64494 class ModifyTransitGatewayRequest < Struct.new( :transit_gateway_id, :description, :options, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_id ⇒ String
The ID of the transit gateway.
64494 64495 64496 64497 64498 64499 64500 64501 |
# File 'lib/aws-sdk-ec2/types.rb', line 64494 class ModifyTransitGatewayRequest < Struct.new( :transit_gateway_id, :description, :options, :dry_run) SENSITIVE = [] include Aws::Structure end |