Class: Aws::EC2::Types::ModifyTransitGatewayVpcAttachmentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyTransitGatewayVpcAttachmentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#add_subnet_ids ⇒ Array<String>
The IDs of one or more subnets to add.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#options ⇒ Types::ModifyTransitGatewayVpcAttachmentRequestOptions
The new VPC attachment options.
-
#remove_subnet_ids ⇒ Array<String>
The IDs of one or more subnets to remove.
-
#transit_gateway_attachment_id ⇒ String
The ID of the attachment.
Instance Attribute Details
#add_subnet_ids ⇒ Array<String>
The IDs of one or more subnets to add. You can specify at most one subnet per Availability Zone.
68234 68235 68236 68237 68238 68239 68240 68241 68242 |
# File 'lib/aws-sdk-ec2/types.rb', line 68234 class ModifyTransitGatewayVpcAttachmentRequest < Struct.new( :transit_gateway_attachment_id, :add_subnet_ids, :remove_subnet_ids, :options, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
68234 68235 68236 68237 68238 68239 68240 68241 68242 |
# File 'lib/aws-sdk-ec2/types.rb', line 68234 class ModifyTransitGatewayVpcAttachmentRequest < Struct.new( :transit_gateway_attachment_id, :add_subnet_ids, :remove_subnet_ids, :options, :dry_run) SENSITIVE = [] include Aws::Structure end |
#options ⇒ Types::ModifyTransitGatewayVpcAttachmentRequestOptions
The new VPC attachment options.
68234 68235 68236 68237 68238 68239 68240 68241 68242 |
# File 'lib/aws-sdk-ec2/types.rb', line 68234 class ModifyTransitGatewayVpcAttachmentRequest < Struct.new( :transit_gateway_attachment_id, :add_subnet_ids, :remove_subnet_ids, :options, :dry_run) SENSITIVE = [] include Aws::Structure end |
#remove_subnet_ids ⇒ Array<String>
The IDs of one or more subnets to remove.
68234 68235 68236 68237 68238 68239 68240 68241 68242 |
# File 'lib/aws-sdk-ec2/types.rb', line 68234 class ModifyTransitGatewayVpcAttachmentRequest < Struct.new( :transit_gateway_attachment_id, :add_subnet_ids, :remove_subnet_ids, :options, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_attachment_id ⇒ String
The ID of the attachment.
68234 68235 68236 68237 68238 68239 68240 68241 68242 |
# File 'lib/aws-sdk-ec2/types.rb', line 68234 class ModifyTransitGatewayVpcAttachmentRequest < Struct.new( :transit_gateway_attachment_id, :add_subnet_ids, :remove_subnet_ids, :options, :dry_run) SENSITIVE = [] include Aws::Structure end |