Class: Aws::EC2::Types::ModifyTransitGatewayVpcAttachmentRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#add_subnet_idsArray<String>

The IDs of one or more subnets to add. You can specify at most one subnet per Availability Zone.

Returns:

  • (Array<String>)


65100
65101
65102
65103
65104
65105
65106
65107
65108
# File 'lib/aws-sdk-ec2/types.rb', line 65100

class ModifyTransitGatewayVpcAttachmentRequest < Struct.new(
  :transit_gateway_attachment_id,
  :add_subnet_ids,
  :remove_subnet_ids,
  :options,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


65100
65101
65102
65103
65104
65105
65106
65107
65108
# File 'lib/aws-sdk-ec2/types.rb', line 65100

class ModifyTransitGatewayVpcAttachmentRequest < Struct.new(
  :transit_gateway_attachment_id,
  :add_subnet_ids,
  :remove_subnet_ids,
  :options,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#optionsTypes::ModifyTransitGatewayVpcAttachmentRequestOptions

The new VPC attachment options.



65100
65101
65102
65103
65104
65105
65106
65107
65108
# File 'lib/aws-sdk-ec2/types.rb', line 65100

class ModifyTransitGatewayVpcAttachmentRequest < Struct.new(
  :transit_gateway_attachment_id,
  :add_subnet_ids,
  :remove_subnet_ids,
  :options,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#remove_subnet_idsArray<String>

The IDs of one or more subnets to remove.

Returns:

  • (Array<String>)


65100
65101
65102
65103
65104
65105
65106
65107
65108
# File 'lib/aws-sdk-ec2/types.rb', line 65100

class ModifyTransitGatewayVpcAttachmentRequest < Struct.new(
  :transit_gateway_attachment_id,
  :add_subnet_ids,
  :remove_subnet_ids,
  :options,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_attachment_idString

The ID of the attachment.

Returns:

  • (String)


65100
65101
65102
65103
65104
65105
65106
65107
65108
# File 'lib/aws-sdk-ec2/types.rb', line 65100

class ModifyTransitGatewayVpcAttachmentRequest < Struct.new(
  :transit_gateway_attachment_id,
  :add_subnet_ids,
  :remove_subnet_ids,
  :options,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end