Class: Aws::EC2::Types::ModifyTransitGatewayVpcAttachmentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyTransitGatewayVpcAttachmentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#add_subnet_ids ⇒ Array<String>
The IDs of one or more subnets to add.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#options ⇒ Types::ModifyTransitGatewayVpcAttachmentRequestOptions
The new VPC attachment options.
-
#remove_subnet_ids ⇒ Array<String>
The IDs of one or more subnets to remove.
-
#transit_gateway_attachment_id ⇒ String
The ID of the attachment.
Instance Attribute Details
#add_subnet_ids ⇒ Array<String>
The IDs of one or more subnets to add. You can specify at most one subnet per Availability Zone.
64553 64554 64555 64556 64557 64558 64559 64560 64561 |
# File 'lib/aws-sdk-ec2/types.rb', line 64553 class ModifyTransitGatewayVpcAttachmentRequest < Struct.new( :transit_gateway_attachment_id, :add_subnet_ids, :remove_subnet_ids, :options, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
64553 64554 64555 64556 64557 64558 64559 64560 64561 |
# File 'lib/aws-sdk-ec2/types.rb', line 64553 class ModifyTransitGatewayVpcAttachmentRequest < Struct.new( :transit_gateway_attachment_id, :add_subnet_ids, :remove_subnet_ids, :options, :dry_run) SENSITIVE = [] include Aws::Structure end |
#options ⇒ Types::ModifyTransitGatewayVpcAttachmentRequestOptions
The new VPC attachment options.
64553 64554 64555 64556 64557 64558 64559 64560 64561 |
# File 'lib/aws-sdk-ec2/types.rb', line 64553 class ModifyTransitGatewayVpcAttachmentRequest < Struct.new( :transit_gateway_attachment_id, :add_subnet_ids, :remove_subnet_ids, :options, :dry_run) SENSITIVE = [] include Aws::Structure end |
#remove_subnet_ids ⇒ Array<String>
The IDs of one or more subnets to remove.
64553 64554 64555 64556 64557 64558 64559 64560 64561 |
# File 'lib/aws-sdk-ec2/types.rb', line 64553 class ModifyTransitGatewayVpcAttachmentRequest < Struct.new( :transit_gateway_attachment_id, :add_subnet_ids, :remove_subnet_ids, :options, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_attachment_id ⇒ String
The ID of the attachment.
64553 64554 64555 64556 64557 64558 64559 64560 64561 |
# File 'lib/aws-sdk-ec2/types.rb', line 64553 class ModifyTransitGatewayVpcAttachmentRequest < Struct.new( :transit_gateway_attachment_id, :add_subnet_ids, :remove_subnet_ids, :options, :dry_run) SENSITIVE = [] include Aws::Structure end |