Class: Aws::EC2::Types::ModifyTransitGatewayVpcAttachmentRequestOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyTransitGatewayVpcAttachmentRequestOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the options for a VPC attachment.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#appliance_mode_support ⇒ String
Enable or disable support for appliance mode.
-
#dns_support ⇒ String
Enable or disable DNS support.
-
#ipv_6_support ⇒ String
Specifies whether IPv6 support is enabled for the attachment.
-
#security_group_referencing_support ⇒ String
Enables you to reference a security group across VPCs attached to a transit gateway to simplify security group management.
Instance Attribute Details
#appliance_mode_support ⇒ String
Enable or disable support for appliance mode. If enabled, a traffic
flow between a source and destination uses the same Availability
Zone for the VPC attachment for the lifetime of that flow. The
default is disable.
65472 65473 65474 65475 65476 65477 65478 65479 |
# File 'lib/aws-sdk-ec2/types.rb', line 65472 class ModifyTransitGatewayVpcAttachmentRequestOptions < Struct.new( :dns_support, :security_group_referencing_support, :ipv_6_support, :appliance_mode_support) SENSITIVE = [] include Aws::Structure end |
#dns_support ⇒ String
Enable or disable DNS support. The default is enable.
65472 65473 65474 65475 65476 65477 65478 65479 |
# File 'lib/aws-sdk-ec2/types.rb', line 65472 class ModifyTransitGatewayVpcAttachmentRequestOptions < Struct.new( :dns_support, :security_group_referencing_support, :ipv_6_support, :appliance_mode_support) SENSITIVE = [] include Aws::Structure end |
#ipv_6_support ⇒ String
Specifies whether IPv6 support is enabled for the attachment. When enabled, the transit gateway network interface receives an IPv6 address. When you enable route propagation, IPv6 VPC CIDRs propagate to the transit gateway route tables. When disabled, the network interface does not receive an IPv6 address, and IPv6 routes do not propagate. The setting does not filter IPv6 traffic.
65472 65473 65474 65475 65476 65477 65478 65479 |
# File 'lib/aws-sdk-ec2/types.rb', line 65472 class ModifyTransitGatewayVpcAttachmentRequestOptions < Struct.new( :dns_support, :security_group_referencing_support, :ipv_6_support, :appliance_mode_support) SENSITIVE = [] include Aws::Structure end |
#security_group_referencing_support ⇒ String
Enables you to reference a security group across VPCs attached to a transit gateway to simplify security group management.
This option is disabled by default.
For more information about security group referencing, see Security group referencing in the Amazon Web Services Transit Gateways Guide.
65472 65473 65474 65475 65476 65477 65478 65479 |
# File 'lib/aws-sdk-ec2/types.rb', line 65472 class ModifyTransitGatewayVpcAttachmentRequestOptions < Struct.new( :dns_support, :security_group_referencing_support, :ipv_6_support, :appliance_mode_support) SENSITIVE = [] include Aws::Structure end |