Class: Aws::EC2::Types::ModifyVerifiedAccessEndpointPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see [Ensuring idempotency].

**A suitable default value is auto-generated.** You should normally not need to pass this option.

[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html

Returns:

  • (String)


64713
64714
64715
64716
64717
64718
64719
64720
64721
64722
# File 'lib/aws-sdk-ec2/types.rb', line 64713

class ModifyVerifiedAccessEndpointPolicyRequest < Struct.new(
  :verified_access_endpoint_id,
  :policy_enabled,
  :policy_document,
  :client_token,
  :dry_run,
  :sse_specification)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


64713
64714
64715
64716
64717
64718
64719
64720
64721
64722
# File 'lib/aws-sdk-ec2/types.rb', line 64713

class ModifyVerifiedAccessEndpointPolicyRequest < Struct.new(
  :verified_access_endpoint_id,
  :policy_enabled,
  :policy_document,
  :client_token,
  :dry_run,
  :sse_specification)
  SENSITIVE = []
  include Aws::Structure
end

#policy_documentString

The Verified Access policy document.

Returns:

  • (String)


64713
64714
64715
64716
64717
64718
64719
64720
64721
64722
# File 'lib/aws-sdk-ec2/types.rb', line 64713

class ModifyVerifiedAccessEndpointPolicyRequest < Struct.new(
  :verified_access_endpoint_id,
  :policy_enabled,
  :policy_document,
  :client_token,
  :dry_run,
  :sse_specification)
  SENSITIVE = []
  include Aws::Structure
end

#policy_enabledBoolean

The status of the Verified Access policy.

Returns:

  • (Boolean)


64713
64714
64715
64716
64717
64718
64719
64720
64721
64722
# File 'lib/aws-sdk-ec2/types.rb', line 64713

class ModifyVerifiedAccessEndpointPolicyRequest < Struct.new(
  :verified_access_endpoint_id,
  :policy_enabled,
  :policy_document,
  :client_token,
  :dry_run,
  :sse_specification)
  SENSITIVE = []
  include Aws::Structure
end

#sse_specificationTypes::VerifiedAccessSseSpecificationRequest

The options for server side encryption.



64713
64714
64715
64716
64717
64718
64719
64720
64721
64722
# File 'lib/aws-sdk-ec2/types.rb', line 64713

class ModifyVerifiedAccessEndpointPolicyRequest < Struct.new(
  :verified_access_endpoint_id,
  :policy_enabled,
  :policy_document,
  :client_token,
  :dry_run,
  :sse_specification)
  SENSITIVE = []
  include Aws::Structure
end

#verified_access_endpoint_idString

The ID of the Verified Access endpoint.

Returns:

  • (String)


64713
64714
64715
64716
64717
64718
64719
64720
64721
64722
# File 'lib/aws-sdk-ec2/types.rb', line 64713

class ModifyVerifiedAccessEndpointPolicyRequest < Struct.new(
  :verified_access_endpoint_id,
  :policy_enabled,
  :policy_document,
  :client_token,
  :dry_run,
  :sse_specification)
  SENSITIVE = []
  include Aws::Structure
end