Class: Aws::EC2::Types::ModifyVerifiedAccessEndpointPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyVerifiedAccessEndpointPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#policy_document ⇒ String
The Verified Access policy document.
-
#policy_enabled ⇒ Boolean
The status of the Verified Access policy.
-
#sse_specification ⇒ Types::VerifiedAccessSseSpecificationRequest
The options for server side encryption.
-
#verified_access_endpoint_id ⇒ String
The ID of the Verified Access endpoint.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see [Ensuring idempotency].
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html
64713 64714 64715 64716 64717 64718 64719 64720 64721 64722 |
# File 'lib/aws-sdk-ec2/types.rb', line 64713 class ModifyVerifiedAccessEndpointPolicyRequest < Struct.new( :verified_access_endpoint_id, :policy_enabled, :policy_document, :client_token, :dry_run, :sse_specification) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
64713 64714 64715 64716 64717 64718 64719 64720 64721 64722 |
# File 'lib/aws-sdk-ec2/types.rb', line 64713 class ModifyVerifiedAccessEndpointPolicyRequest < Struct.new( :verified_access_endpoint_id, :policy_enabled, :policy_document, :client_token, :dry_run, :sse_specification) SENSITIVE = [] include Aws::Structure end |
#policy_document ⇒ String
The Verified Access policy document.
64713 64714 64715 64716 64717 64718 64719 64720 64721 64722 |
# File 'lib/aws-sdk-ec2/types.rb', line 64713 class ModifyVerifiedAccessEndpointPolicyRequest < Struct.new( :verified_access_endpoint_id, :policy_enabled, :policy_document, :client_token, :dry_run, :sse_specification) SENSITIVE = [] include Aws::Structure end |
#policy_enabled ⇒ Boolean
The status of the Verified Access policy.
64713 64714 64715 64716 64717 64718 64719 64720 64721 64722 |
# File 'lib/aws-sdk-ec2/types.rb', line 64713 class ModifyVerifiedAccessEndpointPolicyRequest < Struct.new( :verified_access_endpoint_id, :policy_enabled, :policy_document, :client_token, :dry_run, :sse_specification) SENSITIVE = [] include Aws::Structure end |
#sse_specification ⇒ Types::VerifiedAccessSseSpecificationRequest
The options for server side encryption.
64713 64714 64715 64716 64717 64718 64719 64720 64721 64722 |
# File 'lib/aws-sdk-ec2/types.rb', line 64713 class ModifyVerifiedAccessEndpointPolicyRequest < Struct.new( :verified_access_endpoint_id, :policy_enabled, :policy_document, :client_token, :dry_run, :sse_specification) SENSITIVE = [] include Aws::Structure end |
#verified_access_endpoint_id ⇒ String
The ID of the Verified Access endpoint.
64713 64714 64715 64716 64717 64718 64719 64720 64721 64722 |
# File 'lib/aws-sdk-ec2/types.rb', line 64713 class ModifyVerifiedAccessEndpointPolicyRequest < Struct.new( :verified_access_endpoint_id, :policy_enabled, :policy_document, :client_token, :dry_run, :sse_specification) SENSITIVE = [] include Aws::Structure end |