Class: Aws::EC2::Types::ModifyVerifiedAccessEndpointPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see [Ensuring idempotency].

**A suitable default value is auto-generated.** You should normally not need to pass this option.

[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html

Returns:

  • (String)


62872
62873
62874
62875
62876
62877
62878
62879
62880
62881
# File 'lib/aws-sdk-ec2/types.rb', line 62872

class ModifyVerifiedAccessEndpointPolicyRequest < Struct.new(
  :verified_access_endpoint_id,
  :policy_enabled,
  :policy_document,
  :client_token,
  :dry_run,
  :sse_specification)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


62872
62873
62874
62875
62876
62877
62878
62879
62880
62881
# File 'lib/aws-sdk-ec2/types.rb', line 62872

class ModifyVerifiedAccessEndpointPolicyRequest < Struct.new(
  :verified_access_endpoint_id,
  :policy_enabled,
  :policy_document,
  :client_token,
  :dry_run,
  :sse_specification)
  SENSITIVE = []
  include Aws::Structure
end

#policy_documentString

The Verified Access policy document.

Returns:

  • (String)


62872
62873
62874
62875
62876
62877
62878
62879
62880
62881
# File 'lib/aws-sdk-ec2/types.rb', line 62872

class ModifyVerifiedAccessEndpointPolicyRequest < Struct.new(
  :verified_access_endpoint_id,
  :policy_enabled,
  :policy_document,
  :client_token,
  :dry_run,
  :sse_specification)
  SENSITIVE = []
  include Aws::Structure
end

#policy_enabledBoolean

The status of the Verified Access policy.

Returns:

  • (Boolean)


62872
62873
62874
62875
62876
62877
62878
62879
62880
62881
# File 'lib/aws-sdk-ec2/types.rb', line 62872

class ModifyVerifiedAccessEndpointPolicyRequest < Struct.new(
  :verified_access_endpoint_id,
  :policy_enabled,
  :policy_document,
  :client_token,
  :dry_run,
  :sse_specification)
  SENSITIVE = []
  include Aws::Structure
end

#sse_specificationTypes::VerifiedAccessSseSpecificationRequest

The options for server side encryption.



62872
62873
62874
62875
62876
62877
62878
62879
62880
62881
# File 'lib/aws-sdk-ec2/types.rb', line 62872

class ModifyVerifiedAccessEndpointPolicyRequest < Struct.new(
  :verified_access_endpoint_id,
  :policy_enabled,
  :policy_document,
  :client_token,
  :dry_run,
  :sse_specification)
  SENSITIVE = []
  include Aws::Structure
end

#verified_access_endpoint_idString

The ID of the Verified Access endpoint.

Returns:

  • (String)


62872
62873
62874
62875
62876
62877
62878
62879
62880
62881
# File 'lib/aws-sdk-ec2/types.rb', line 62872

class ModifyVerifiedAccessEndpointPolicyRequest < Struct.new(
  :verified_access_endpoint_id,
  :policy_enabled,
  :policy_document,
  :client_token,
  :dry_run,
  :sse_specification)
  SENSITIVE = []
  include Aws::Structure
end