Class: Aws::EC2::Types::ModifyVerifiedAccessEndpointRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cidr_optionsTypes::ModifyVerifiedAccessEndpointCidrOptions

The CIDR options.



64984
64985
64986
64987
64988
64989
64990
64991
64992
64993
64994
64995
64996
# File 'lib/aws-sdk-ec2/types.rb', line 64984

class ModifyVerifiedAccessEndpointRequest < Struct.new(
  :verified_access_endpoint_id,
  :verified_access_group_id,
  :load_balancer_options,
  :network_interface_options,
  :description,
  :client_token,
  :dry_run,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see [Ensuring idempotency].

**A suitable default value is auto-generated.** You should normally not need to pass this option.

[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html

Returns:

  • (String)


64984
64985
64986
64987
64988
64989
64990
64991
64992
64993
64994
64995
64996
# File 'lib/aws-sdk-ec2/types.rb', line 64984

class ModifyVerifiedAccessEndpointRequest < Struct.new(
  :verified_access_endpoint_id,
  :verified_access_group_id,
  :load_balancer_options,
  :network_interface_options,
  :description,
  :client_token,
  :dry_run,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description for the Verified Access endpoint.

Returns:

  • (String)


64984
64985
64986
64987
64988
64989
64990
64991
64992
64993
64994
64995
64996
# File 'lib/aws-sdk-ec2/types.rb', line 64984

class ModifyVerifiedAccessEndpointRequest < Struct.new(
  :verified_access_endpoint_id,
  :verified_access_group_id,
  :load_balancer_options,
  :network_interface_options,
  :description,
  :client_token,
  :dry_run,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


64984
64985
64986
64987
64988
64989
64990
64991
64992
64993
64994
64995
64996
# File 'lib/aws-sdk-ec2/types.rb', line 64984

class ModifyVerifiedAccessEndpointRequest < Struct.new(
  :verified_access_endpoint_id,
  :verified_access_group_id,
  :load_balancer_options,
  :network_interface_options,
  :description,
  :client_token,
  :dry_run,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#load_balancer_optionsTypes::ModifyVerifiedAccessEndpointLoadBalancerOptions

The load balancer details if creating the Verified Access endpoint as ‘load-balancer`type.



64984
64985
64986
64987
64988
64989
64990
64991
64992
64993
64994
64995
64996
# File 'lib/aws-sdk-ec2/types.rb', line 64984

class ModifyVerifiedAccessEndpointRequest < Struct.new(
  :verified_access_endpoint_id,
  :verified_access_group_id,
  :load_balancer_options,
  :network_interface_options,
  :description,
  :client_token,
  :dry_run,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#network_interface_optionsTypes::ModifyVerifiedAccessEndpointEniOptions

The network interface options.



64984
64985
64986
64987
64988
64989
64990
64991
64992
64993
64994
64995
64996
# File 'lib/aws-sdk-ec2/types.rb', line 64984

class ModifyVerifiedAccessEndpointRequest < Struct.new(
  :verified_access_endpoint_id,
  :verified_access_group_id,
  :load_balancer_options,
  :network_interface_options,
  :description,
  :client_token,
  :dry_run,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#rds_optionsTypes::ModifyVerifiedAccessEndpointRdsOptions

The RDS options.



64984
64985
64986
64987
64988
64989
64990
64991
64992
64993
64994
64995
64996
# File 'lib/aws-sdk-ec2/types.rb', line 64984

class ModifyVerifiedAccessEndpointRequest < Struct.new(
  :verified_access_endpoint_id,
  :verified_access_group_id,
  :load_balancer_options,
  :network_interface_options,
  :description,
  :client_token,
  :dry_run,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#verified_access_endpoint_idString

The ID of the Verified Access endpoint.

Returns:

  • (String)


64984
64985
64986
64987
64988
64989
64990
64991
64992
64993
64994
64995
64996
# File 'lib/aws-sdk-ec2/types.rb', line 64984

class ModifyVerifiedAccessEndpointRequest < Struct.new(
  :verified_access_endpoint_id,
  :verified_access_group_id,
  :load_balancer_options,
  :network_interface_options,
  :description,
  :client_token,
  :dry_run,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#verified_access_group_idString

The ID of the Verified Access group.

Returns:

  • (String)


64984
64985
64986
64987
64988
64989
64990
64991
64992
64993
64994
64995
64996
# File 'lib/aws-sdk-ec2/types.rb', line 64984

class ModifyVerifiedAccessEndpointRequest < Struct.new(
  :verified_access_endpoint_id,
  :verified_access_group_id,
  :load_balancer_options,
  :network_interface_options,
  :description,
  :client_token,
  :dry_run,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end