Class: Aws::EC2::Types::ModifyVerifiedAccessEndpointRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyVerifiedAccessEndpointRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cidr_options ⇒ Types::ModifyVerifiedAccessEndpointCidrOptions
The CIDR options.
-
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request.
-
#description ⇒ String
A description for the Verified Access endpoint.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#load_balancer_options ⇒ Types::ModifyVerifiedAccessEndpointLoadBalancerOptions
The load balancer details if creating the Verified Access endpoint as ‘load-balancer`type.
-
#network_interface_options ⇒ Types::ModifyVerifiedAccessEndpointEniOptions
The network interface options.
-
#rds_options ⇒ Types::ModifyVerifiedAccessEndpointRdsOptions
The RDS options.
-
#verified_access_endpoint_id ⇒ String
The ID of the Verified Access endpoint.
-
#verified_access_group_id ⇒ String
The ID of the Verified Access group.
Instance Attribute Details
#cidr_options ⇒ Types::ModifyVerifiedAccessEndpointCidrOptions
The CIDR options.
63950 63951 63952 63953 63954 63955 63956 63957 63958 63959 63960 63961 63962 |
# File 'lib/aws-sdk-ec2/types.rb', line 63950 class ModifyVerifiedAccessEndpointRequest < Struct.new( :verified_access_endpoint_id, :verified_access_group_id, :load_balancer_options, :network_interface_options, :description, :client_token, :dry_run, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see [Ensuring idempotency].
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html
63950 63951 63952 63953 63954 63955 63956 63957 63958 63959 63960 63961 63962 |
# File 'lib/aws-sdk-ec2/types.rb', line 63950 class ModifyVerifiedAccessEndpointRequest < Struct.new( :verified_access_endpoint_id, :verified_access_group_id, :load_balancer_options, :network_interface_options, :description, :client_token, :dry_run, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description for the Verified Access endpoint.
63950 63951 63952 63953 63954 63955 63956 63957 63958 63959 63960 63961 63962 |
# File 'lib/aws-sdk-ec2/types.rb', line 63950 class ModifyVerifiedAccessEndpointRequest < Struct.new( :verified_access_endpoint_id, :verified_access_group_id, :load_balancer_options, :network_interface_options, :description, :client_token, :dry_run, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
63950 63951 63952 63953 63954 63955 63956 63957 63958 63959 63960 63961 63962 |
# File 'lib/aws-sdk-ec2/types.rb', line 63950 class ModifyVerifiedAccessEndpointRequest < Struct.new( :verified_access_endpoint_id, :verified_access_group_id, :load_balancer_options, :network_interface_options, :description, :client_token, :dry_run, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#load_balancer_options ⇒ Types::ModifyVerifiedAccessEndpointLoadBalancerOptions
The load balancer details if creating the Verified Access endpoint as ‘load-balancer`type.
63950 63951 63952 63953 63954 63955 63956 63957 63958 63959 63960 63961 63962 |
# File 'lib/aws-sdk-ec2/types.rb', line 63950 class ModifyVerifiedAccessEndpointRequest < Struct.new( :verified_access_endpoint_id, :verified_access_group_id, :load_balancer_options, :network_interface_options, :description, :client_token, :dry_run, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#network_interface_options ⇒ Types::ModifyVerifiedAccessEndpointEniOptions
The network interface options.
63950 63951 63952 63953 63954 63955 63956 63957 63958 63959 63960 63961 63962 |
# File 'lib/aws-sdk-ec2/types.rb', line 63950 class ModifyVerifiedAccessEndpointRequest < Struct.new( :verified_access_endpoint_id, :verified_access_group_id, :load_balancer_options, :network_interface_options, :description, :client_token, :dry_run, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#rds_options ⇒ Types::ModifyVerifiedAccessEndpointRdsOptions
The RDS options.
63950 63951 63952 63953 63954 63955 63956 63957 63958 63959 63960 63961 63962 |
# File 'lib/aws-sdk-ec2/types.rb', line 63950 class ModifyVerifiedAccessEndpointRequest < Struct.new( :verified_access_endpoint_id, :verified_access_group_id, :load_balancer_options, :network_interface_options, :description, :client_token, :dry_run, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#verified_access_endpoint_id ⇒ String
The ID of the Verified Access endpoint.
63950 63951 63952 63953 63954 63955 63956 63957 63958 63959 63960 63961 63962 |
# File 'lib/aws-sdk-ec2/types.rb', line 63950 class ModifyVerifiedAccessEndpointRequest < Struct.new( :verified_access_endpoint_id, :verified_access_group_id, :load_balancer_options, :network_interface_options, :description, :client_token, :dry_run, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#verified_access_group_id ⇒ String
The ID of the Verified Access group.
63950 63951 63952 63953 63954 63955 63956 63957 63958 63959 63960 63961 63962 |
# File 'lib/aws-sdk-ec2/types.rb', line 63950 class ModifyVerifiedAccessEndpointRequest < Struct.new( :verified_access_endpoint_id, :verified_access_group_id, :load_balancer_options, :network_interface_options, :description, :client_token, :dry_run, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |