Class: Aws::EC2::Types::ModifyVerifiedAccessGroupPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyVerifiedAccessGroupPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#policy_document ⇒ String
The Verified Access policy document.
-
#policy_enabled ⇒ Boolean
The status of the Verified Access policy.
-
#sse_specification ⇒ Types::VerifiedAccessSseSpecificationRequest
The options for server side encryption.
-
#verified_access_group_id ⇒ String
The ID of the Verified Access group.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring idempotency.
A suitable default value is auto-generated. You should normally not need to pass this option.
68616 68617 68618 68619 68620 68621 68622 68623 68624 68625 |
# File 'lib/aws-sdk-ec2/types.rb', line 68616 class ModifyVerifiedAccessGroupPolicyRequest < Struct.new( :verified_access_group_id, :policy_enabled, :policy_document, :client_token, :dry_run, :sse_specification) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
68616 68617 68618 68619 68620 68621 68622 68623 68624 68625 |
# File 'lib/aws-sdk-ec2/types.rb', line 68616 class ModifyVerifiedAccessGroupPolicyRequest < Struct.new( :verified_access_group_id, :policy_enabled, :policy_document, :client_token, :dry_run, :sse_specification) SENSITIVE = [] include Aws::Structure end |
#policy_document ⇒ String
The Verified Access policy document.
68616 68617 68618 68619 68620 68621 68622 68623 68624 68625 |
# File 'lib/aws-sdk-ec2/types.rb', line 68616 class ModifyVerifiedAccessGroupPolicyRequest < Struct.new( :verified_access_group_id, :policy_enabled, :policy_document, :client_token, :dry_run, :sse_specification) SENSITIVE = [] include Aws::Structure end |
#policy_enabled ⇒ Boolean
The status of the Verified Access policy.
68616 68617 68618 68619 68620 68621 68622 68623 68624 68625 |
# File 'lib/aws-sdk-ec2/types.rb', line 68616 class ModifyVerifiedAccessGroupPolicyRequest < Struct.new( :verified_access_group_id, :policy_enabled, :policy_document, :client_token, :dry_run, :sse_specification) SENSITIVE = [] include Aws::Structure end |
#sse_specification ⇒ Types::VerifiedAccessSseSpecificationRequest
The options for server side encryption.
68616 68617 68618 68619 68620 68621 68622 68623 68624 68625 |
# File 'lib/aws-sdk-ec2/types.rb', line 68616 class ModifyVerifiedAccessGroupPolicyRequest < Struct.new( :verified_access_group_id, :policy_enabled, :policy_document, :client_token, :dry_run, :sse_specification) SENSITIVE = [] include Aws::Structure end |
#verified_access_group_id ⇒ String
The ID of the Verified Access group.
68616 68617 68618 68619 68620 68621 68622 68623 68624 68625 |
# File 'lib/aws-sdk-ec2/types.rb', line 68616 class ModifyVerifiedAccessGroupPolicyRequest < Struct.new( :verified_access_group_id, :policy_enabled, :policy_document, :client_token, :dry_run, :sse_specification) SENSITIVE = [] include Aws::Structure end |