Class: Aws::EC2::Types::ModifyVerifiedAccessGroupPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyVerifiedAccessGroupPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#policy_document ⇒ String
The Verified Access policy document.
-
#policy_enabled ⇒ Boolean
The status of the Verified Access policy.
-
#sse_specification ⇒ Types::VerifiedAccessSseSpecificationRequest
The options for server side encryption.
-
#verified_access_group_id ⇒ String
The ID of the Verified Access group.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring idempotency.
A suitable default value is auto-generated. You should normally not need to pass this option.
65791 65792 65793 65794 65795 65796 65797 65798 65799 65800 |
# File 'lib/aws-sdk-ec2/types.rb', line 65791 class ModifyVerifiedAccessGroupPolicyRequest < Struct.new( :verified_access_group_id, :policy_enabled, :policy_document, :client_token, :dry_run, :sse_specification) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
65791 65792 65793 65794 65795 65796 65797 65798 65799 65800 |
# File 'lib/aws-sdk-ec2/types.rb', line 65791 class ModifyVerifiedAccessGroupPolicyRequest < Struct.new( :verified_access_group_id, :policy_enabled, :policy_document, :client_token, :dry_run, :sse_specification) SENSITIVE = [] include Aws::Structure end |
#policy_document ⇒ String
The Verified Access policy document.
65791 65792 65793 65794 65795 65796 65797 65798 65799 65800 |
# File 'lib/aws-sdk-ec2/types.rb', line 65791 class ModifyVerifiedAccessGroupPolicyRequest < Struct.new( :verified_access_group_id, :policy_enabled, :policy_document, :client_token, :dry_run, :sse_specification) SENSITIVE = [] include Aws::Structure end |
#policy_enabled ⇒ Boolean
The status of the Verified Access policy.
65791 65792 65793 65794 65795 65796 65797 65798 65799 65800 |
# File 'lib/aws-sdk-ec2/types.rb', line 65791 class ModifyVerifiedAccessGroupPolicyRequest < Struct.new( :verified_access_group_id, :policy_enabled, :policy_document, :client_token, :dry_run, :sse_specification) SENSITIVE = [] include Aws::Structure end |
#sse_specification ⇒ Types::VerifiedAccessSseSpecificationRequest
The options for server side encryption.
65791 65792 65793 65794 65795 65796 65797 65798 65799 65800 |
# File 'lib/aws-sdk-ec2/types.rb', line 65791 class ModifyVerifiedAccessGroupPolicyRequest < Struct.new( :verified_access_group_id, :policy_enabled, :policy_document, :client_token, :dry_run, :sse_specification) SENSITIVE = [] include Aws::Structure end |
#verified_access_group_id ⇒ String
The ID of the Verified Access group.
65791 65792 65793 65794 65795 65796 65797 65798 65799 65800 |
# File 'lib/aws-sdk-ec2/types.rb', line 65791 class ModifyVerifiedAccessGroupPolicyRequest < Struct.new( :verified_access_group_id, :policy_enabled, :policy_document, :client_token, :dry_run, :sse_specification) SENSITIVE = [] include Aws::Structure end |