Class: Aws::EC2::Types::ModifyVerifiedAccessGroupPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see [Ensuring idempotency].

**A suitable default value is auto-generated.** You should normally not need to pass this option.

[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html

Returns:

  • (String)


65048
65049
65050
65051
65052
65053
65054
65055
65056
65057
# File 'lib/aws-sdk-ec2/types.rb', line 65048

class ModifyVerifiedAccessGroupPolicyRequest < Struct.new(
  :verified_access_group_id,
  :policy_enabled,
  :policy_document,
  :client_token,
  :dry_run,
  :sse_specification)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


65048
65049
65050
65051
65052
65053
65054
65055
65056
65057
# File 'lib/aws-sdk-ec2/types.rb', line 65048

class ModifyVerifiedAccessGroupPolicyRequest < Struct.new(
  :verified_access_group_id,
  :policy_enabled,
  :policy_document,
  :client_token,
  :dry_run,
  :sse_specification)
  SENSITIVE = []
  include Aws::Structure
end

#policy_documentString

The Verified Access policy document.

Returns:

  • (String)


65048
65049
65050
65051
65052
65053
65054
65055
65056
65057
# File 'lib/aws-sdk-ec2/types.rb', line 65048

class ModifyVerifiedAccessGroupPolicyRequest < Struct.new(
  :verified_access_group_id,
  :policy_enabled,
  :policy_document,
  :client_token,
  :dry_run,
  :sse_specification)
  SENSITIVE = []
  include Aws::Structure
end

#policy_enabledBoolean

The status of the Verified Access policy.

Returns:

  • (Boolean)


65048
65049
65050
65051
65052
65053
65054
65055
65056
65057
# File 'lib/aws-sdk-ec2/types.rb', line 65048

class ModifyVerifiedAccessGroupPolicyRequest < Struct.new(
  :verified_access_group_id,
  :policy_enabled,
  :policy_document,
  :client_token,
  :dry_run,
  :sse_specification)
  SENSITIVE = []
  include Aws::Structure
end

#sse_specificationTypes::VerifiedAccessSseSpecificationRequest

The options for server side encryption.



65048
65049
65050
65051
65052
65053
65054
65055
65056
65057
# File 'lib/aws-sdk-ec2/types.rb', line 65048

class ModifyVerifiedAccessGroupPolicyRequest < Struct.new(
  :verified_access_group_id,
  :policy_enabled,
  :policy_document,
  :client_token,
  :dry_run,
  :sse_specification)
  SENSITIVE = []
  include Aws::Structure
end

#verified_access_group_idString

The ID of the Verified Access group.

Returns:

  • (String)


65048
65049
65050
65051
65052
65053
65054
65055
65056
65057
# File 'lib/aws-sdk-ec2/types.rb', line 65048

class ModifyVerifiedAccessGroupPolicyRequest < Struct.new(
  :verified_access_group_id,
  :policy_enabled,
  :policy_document,
  :client_token,
  :dry_run,
  :sse_specification)
  SENSITIVE = []
  include Aws::Structure
end