Class: Aws::EC2::Types::ModifyVerifiedAccessGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyVerifiedAccessGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request.
-
#description ⇒ String
A description for the Verified Access group.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#verified_access_group_id ⇒ String
The ID of the Verified Access group.
-
#verified_access_instance_id ⇒ String
The ID of the Verified Access instance.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring idempotency.
A suitable default value is auto-generated. You should normally not need to pass this option.
65681 65682 65683 65684 65685 65686 65687 65688 65689 |
# File 'lib/aws-sdk-ec2/types.rb', line 65681 class ModifyVerifiedAccessGroupRequest < Struct.new( :verified_access_group_id, :verified_access_instance_id, :description, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description for the Verified Access group.
65681 65682 65683 65684 65685 65686 65687 65688 65689 |
# File 'lib/aws-sdk-ec2/types.rb', line 65681 class ModifyVerifiedAccessGroupRequest < Struct.new( :verified_access_group_id, :verified_access_instance_id, :description, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
65681 65682 65683 65684 65685 65686 65687 65688 65689 |
# File 'lib/aws-sdk-ec2/types.rb', line 65681 class ModifyVerifiedAccessGroupRequest < Struct.new( :verified_access_group_id, :verified_access_instance_id, :description, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#verified_access_group_id ⇒ String
The ID of the Verified Access group.
65681 65682 65683 65684 65685 65686 65687 65688 65689 |
# File 'lib/aws-sdk-ec2/types.rb', line 65681 class ModifyVerifiedAccessGroupRequest < Struct.new( :verified_access_group_id, :verified_access_instance_id, :description, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#verified_access_instance_id ⇒ String
The ID of the Verified Access instance.
65681 65682 65683 65684 65685 65686 65687 65688 65689 |
# File 'lib/aws-sdk-ec2/types.rb', line 65681 class ModifyVerifiedAccessGroupRequest < Struct.new( :verified_access_group_id, :verified_access_instance_id, :description, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |