Class: Aws::EC2::Types::ModifyVerifiedAccessGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


65530
65531
65532
65533
65534
65535
65536
65537
65538
# File 'lib/aws-sdk-ec2/types.rb', line 65530

class ModifyVerifiedAccessGroupRequest < Struct.new(
  :verified_access_group_id,
  :verified_access_instance_id,
  :description,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description for the Verified Access group.

Returns:

  • (String)


65530
65531
65532
65533
65534
65535
65536
65537
65538
# File 'lib/aws-sdk-ec2/types.rb', line 65530

class ModifyVerifiedAccessGroupRequest < Struct.new(
  :verified_access_group_id,
  :verified_access_instance_id,
  :description,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


65530
65531
65532
65533
65534
65535
65536
65537
65538
# File 'lib/aws-sdk-ec2/types.rb', line 65530

class ModifyVerifiedAccessGroupRequest < Struct.new(
  :verified_access_group_id,
  :verified_access_instance_id,
  :description,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#verified_access_group_idString

The ID of the Verified Access group.

Returns:

  • (String)


65530
65531
65532
65533
65534
65535
65536
65537
65538
# File 'lib/aws-sdk-ec2/types.rb', line 65530

class ModifyVerifiedAccessGroupRequest < Struct.new(
  :verified_access_group_id,
  :verified_access_instance_id,
  :description,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#verified_access_instance_idString

The ID of the Verified Access instance.

Returns:

  • (String)


65530
65531
65532
65533
65534
65535
65536
65537
65538
# File 'lib/aws-sdk-ec2/types.rb', line 65530

class ModifyVerifiedAccessGroupRequest < Struct.new(
  :verified_access_group_id,
  :verified_access_instance_id,
  :description,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end