Class: Aws::EC2::Types::ModifyVerifiedAccessGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyVerifiedAccessGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request.
-
#description ⇒ String
A description for the Verified Access group.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#verified_access_group_id ⇒ String
The ID of the Verified Access group.
-
#verified_access_instance_id ⇒ String
The ID of the Verified Access instance.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see [Ensuring idempotency].
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html
64538 64539 64540 64541 64542 64543 64544 64545 64546 |
# File 'lib/aws-sdk-ec2/types.rb', line 64538 class ModifyVerifiedAccessGroupRequest < Struct.new( :verified_access_group_id, :verified_access_instance_id, :description, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description for the Verified Access group.
64538 64539 64540 64541 64542 64543 64544 64545 64546 |
# File 'lib/aws-sdk-ec2/types.rb', line 64538 class ModifyVerifiedAccessGroupRequest < Struct.new( :verified_access_group_id, :verified_access_instance_id, :description, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
64538 64539 64540 64541 64542 64543 64544 64545 64546 |
# File 'lib/aws-sdk-ec2/types.rb', line 64538 class ModifyVerifiedAccessGroupRequest < Struct.new( :verified_access_group_id, :verified_access_instance_id, :description, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#verified_access_group_id ⇒ String
The ID of the Verified Access group.
64538 64539 64540 64541 64542 64543 64544 64545 64546 |
# File 'lib/aws-sdk-ec2/types.rb', line 64538 class ModifyVerifiedAccessGroupRequest < Struct.new( :verified_access_group_id, :verified_access_instance_id, :description, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#verified_access_instance_id ⇒ String
The ID of the Verified Access instance.
64538 64539 64540 64541 64542 64543 64544 64545 64546 |
# File 'lib/aws-sdk-ec2/types.rb', line 64538 class ModifyVerifiedAccessGroupRequest < Struct.new( :verified_access_group_id, :verified_access_instance_id, :description, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |