Class: Aws::EC2::Types::ModifyVerifiedAccessInstanceLoggingConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyVerifiedAccessInstanceLoggingConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_logs ⇒ Types::VerifiedAccessLogOptions
The configuration options for Verified Access instances.
-
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#verified_access_instance_id ⇒ String
The ID of the Verified Access instance.
Instance Attribute Details
#access_logs ⇒ Types::VerifiedAccessLogOptions
The configuration options for Verified Access instances.
65273 65274 65275 65276 65277 65278 65279 65280 |
# File 'lib/aws-sdk-ec2/types.rb', line 65273 class ModifyVerifiedAccessInstanceLoggingConfigurationRequest < Struct.new( :verified_access_instance_id, :access_logs, :dry_run, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see [Ensuring idempotency].
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html
65273 65274 65275 65276 65277 65278 65279 65280 |
# File 'lib/aws-sdk-ec2/types.rb', line 65273 class ModifyVerifiedAccessInstanceLoggingConfigurationRequest < Struct.new( :verified_access_instance_id, :access_logs, :dry_run, :client_token) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
65273 65274 65275 65276 65277 65278 65279 65280 |
# File 'lib/aws-sdk-ec2/types.rb', line 65273 class ModifyVerifiedAccessInstanceLoggingConfigurationRequest < Struct.new( :verified_access_instance_id, :access_logs, :dry_run, :client_token) SENSITIVE = [] include Aws::Structure end |
#verified_access_instance_id ⇒ String
The ID of the Verified Access instance.
65273 65274 65275 65276 65277 65278 65279 65280 |
# File 'lib/aws-sdk-ec2/types.rb', line 65273 class ModifyVerifiedAccessInstanceLoggingConfigurationRequest < Struct.new( :verified_access_instance_id, :access_logs, :dry_run, :client_token) SENSITIVE = [] include Aws::Structure end |