Class: Aws::EC2::Types::ModifyVerifiedAccessInstanceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cidr_endpoints_custom_sub_domainString

The custom subdomain.

Returns:

  • (String)


68776
68777
68778
68779
68780
68781
68782
68783
68784
# File 'lib/aws-sdk-ec2/types.rb', line 68776

class ModifyVerifiedAccessInstanceRequest < Struct.new(
  :verified_access_instance_id,
  :description,
  :dry_run,
  :client_token,
  :cidr_endpoints_custom_sub_domain)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


68776
68777
68778
68779
68780
68781
68782
68783
68784
# File 'lib/aws-sdk-ec2/types.rb', line 68776

class ModifyVerifiedAccessInstanceRequest < Struct.new(
  :verified_access_instance_id,
  :description,
  :dry_run,
  :client_token,
  :cidr_endpoints_custom_sub_domain)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description for the Verified Access instance.

Returns:

  • (String)


68776
68777
68778
68779
68780
68781
68782
68783
68784
# File 'lib/aws-sdk-ec2/types.rb', line 68776

class ModifyVerifiedAccessInstanceRequest < Struct.new(
  :verified_access_instance_id,
  :description,
  :dry_run,
  :client_token,
  :cidr_endpoints_custom_sub_domain)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


68776
68777
68778
68779
68780
68781
68782
68783
68784
# File 'lib/aws-sdk-ec2/types.rb', line 68776

class ModifyVerifiedAccessInstanceRequest < Struct.new(
  :verified_access_instance_id,
  :description,
  :dry_run,
  :client_token,
  :cidr_endpoints_custom_sub_domain)
  SENSITIVE = []
  include Aws::Structure
end

#verified_access_instance_idString

The ID of the Verified Access instance.

Returns:

  • (String)


68776
68777
68778
68779
68780
68781
68782
68783
68784
# File 'lib/aws-sdk-ec2/types.rb', line 68776

class ModifyVerifiedAccessInstanceRequest < Struct.new(
  :verified_access_instance_id,
  :description,
  :dry_run,
  :client_token,
  :cidr_endpoints_custom_sub_domain)
  SENSITIVE = []
  include Aws::Structure
end