Class: Aws::EC2::Types::ModifyVerifiedAccessInstanceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyVerifiedAccessInstanceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cidr_endpoints_custom_sub_domain ⇒ String
The custom subdomain.
-
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request.
-
#description ⇒ String
A description for the Verified Access instance.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#verified_access_instance_id ⇒ String
The ID of the Verified Access instance.
Instance Attribute Details
#cidr_endpoints_custom_sub_domain ⇒ String
The custom subdomain.
64645 64646 64647 64648 64649 64650 64651 64652 64653 |
# File 'lib/aws-sdk-ec2/types.rb', line 64645 class ModifyVerifiedAccessInstanceRequest < Struct.new( :verified_access_instance_id, :description, :dry_run, :client_token, :cidr_endpoints_custom_sub_domain) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see [Ensuring idempotency].
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html
64645 64646 64647 64648 64649 64650 64651 64652 64653 |
# File 'lib/aws-sdk-ec2/types.rb', line 64645 class ModifyVerifiedAccessInstanceRequest < Struct.new( :verified_access_instance_id, :description, :dry_run, :client_token, :cidr_endpoints_custom_sub_domain) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description for the Verified Access instance.
64645 64646 64647 64648 64649 64650 64651 64652 64653 |
# File 'lib/aws-sdk-ec2/types.rb', line 64645 class ModifyVerifiedAccessInstanceRequest < Struct.new( :verified_access_instance_id, :description, :dry_run, :client_token, :cidr_endpoints_custom_sub_domain) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
64645 64646 64647 64648 64649 64650 64651 64652 64653 |
# File 'lib/aws-sdk-ec2/types.rb', line 64645 class ModifyVerifiedAccessInstanceRequest < Struct.new( :verified_access_instance_id, :description, :dry_run, :client_token, :cidr_endpoints_custom_sub_domain) SENSITIVE = [] include Aws::Structure end |
#verified_access_instance_id ⇒ String
The ID of the Verified Access instance.
64645 64646 64647 64648 64649 64650 64651 64652 64653 |
# File 'lib/aws-sdk-ec2/types.rb', line 64645 class ModifyVerifiedAccessInstanceRequest < Struct.new( :verified_access_instance_id, :description, :dry_run, :client_token, :cidr_endpoints_custom_sub_domain) SENSITIVE = [] include Aws::Structure end |