Class: Aws::EC2::Types::ModifyVerifiedAccessTrustProviderRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


66146
66147
66148
66149
66150
66151
66152
66153
66154
66155
66156
66157
# File 'lib/aws-sdk-ec2/types.rb', line 66146

class ModifyVerifiedAccessTrustProviderRequest < Struct.new(
  :verified_access_trust_provider_id,
  :oidc_options,
  :device_options,
  :description,
  :dry_run,
  :client_token,
  :sse_specification,
  :native_application_oidc_options)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description for the Verified Access trust provider.

Returns:

  • (String)


66146
66147
66148
66149
66150
66151
66152
66153
66154
66155
66156
66157
# File 'lib/aws-sdk-ec2/types.rb', line 66146

class ModifyVerifiedAccessTrustProviderRequest < Struct.new(
  :verified_access_trust_provider_id,
  :oidc_options,
  :device_options,
  :description,
  :dry_run,
  :client_token,
  :sse_specification,
  :native_application_oidc_options)
  SENSITIVE = []
  include Aws::Structure
end

#device_optionsTypes::ModifyVerifiedAccessTrustProviderDeviceOptions

The options for a device-based trust provider. This parameter is required when the provider type is device.



66146
66147
66148
66149
66150
66151
66152
66153
66154
66155
66156
66157
# File 'lib/aws-sdk-ec2/types.rb', line 66146

class ModifyVerifiedAccessTrustProviderRequest < Struct.new(
  :verified_access_trust_provider_id,
  :oidc_options,
  :device_options,
  :description,
  :dry_run,
  :client_token,
  :sse_specification,
  :native_application_oidc_options)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


66146
66147
66148
66149
66150
66151
66152
66153
66154
66155
66156
66157
# File 'lib/aws-sdk-ec2/types.rb', line 66146

class ModifyVerifiedAccessTrustProviderRequest < Struct.new(
  :verified_access_trust_provider_id,
  :oidc_options,
  :device_options,
  :description,
  :dry_run,
  :client_token,
  :sse_specification,
  :native_application_oidc_options)
  SENSITIVE = []
  include Aws::Structure
end

#native_application_oidc_optionsTypes::ModifyVerifiedAccessNativeApplicationOidcOptions

The OpenID Connect (OIDC) options.



66146
66147
66148
66149
66150
66151
66152
66153
66154
66155
66156
66157
# File 'lib/aws-sdk-ec2/types.rb', line 66146

class ModifyVerifiedAccessTrustProviderRequest < Struct.new(
  :verified_access_trust_provider_id,
  :oidc_options,
  :device_options,
  :description,
  :dry_run,
  :client_token,
  :sse_specification,
  :native_application_oidc_options)
  SENSITIVE = []
  include Aws::Structure
end

#oidc_optionsTypes::ModifyVerifiedAccessTrustProviderOidcOptions

The options for an OpenID Connect-compatible user-identity trust provider.



66146
66147
66148
66149
66150
66151
66152
66153
66154
66155
66156
66157
# File 'lib/aws-sdk-ec2/types.rb', line 66146

class ModifyVerifiedAccessTrustProviderRequest < Struct.new(
  :verified_access_trust_provider_id,
  :oidc_options,
  :device_options,
  :description,
  :dry_run,
  :client_token,
  :sse_specification,
  :native_application_oidc_options)
  SENSITIVE = []
  include Aws::Structure
end

#sse_specificationTypes::VerifiedAccessSseSpecificationRequest

The options for server side encryption.



66146
66147
66148
66149
66150
66151
66152
66153
66154
66155
66156
66157
# File 'lib/aws-sdk-ec2/types.rb', line 66146

class ModifyVerifiedAccessTrustProviderRequest < Struct.new(
  :verified_access_trust_provider_id,
  :oidc_options,
  :device_options,
  :description,
  :dry_run,
  :client_token,
  :sse_specification,
  :native_application_oidc_options)
  SENSITIVE = []
  include Aws::Structure
end

#verified_access_trust_provider_idString

The ID of the Verified Access trust provider.

Returns:

  • (String)


66146
66147
66148
66149
66150
66151
66152
66153
66154
66155
66156
66157
# File 'lib/aws-sdk-ec2/types.rb', line 66146

class ModifyVerifiedAccessTrustProviderRequest < Struct.new(
  :verified_access_trust_provider_id,
  :oidc_options,
  :device_options,
  :description,
  :dry_run,
  :client_token,
  :sse_specification,
  :native_application_oidc_options)
  SENSITIVE = []
  include Aws::Structure
end