Class: Aws::EC2::Types::ModifyVerifiedAccessTrustProviderRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyVerifiedAccessTrustProviderRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request.
-
#description ⇒ String
A description for the Verified Access trust provider.
-
#device_options ⇒ Types::ModifyVerifiedAccessTrustProviderDeviceOptions
The options for a device-based trust provider.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#native_application_oidc_options ⇒ Types::ModifyVerifiedAccessNativeApplicationOidcOptions
The OpenID Connect (OIDC) options.
-
#oidc_options ⇒ Types::ModifyVerifiedAccessTrustProviderOidcOptions
The options for an OpenID Connect-compatible user-identity trust provider.
-
#sse_specification ⇒ Types::VerifiedAccessSseSpecificationRequest
The options for server side encryption.
-
#verified_access_trust_provider_id ⇒ String
The ID of the Verified Access trust provider.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see [Ensuring idempotency].
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html
63418 63419 63420 63421 63422 63423 63424 63425 63426 63427 63428 63429 |
# File 'lib/aws-sdk-ec2/types.rb', line 63418 class ModifyVerifiedAccessTrustProviderRequest < Struct.new( :verified_access_trust_provider_id, :oidc_options, :device_options, :description, :dry_run, :client_token, :sse_specification, :native_application_oidc_options) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description for the Verified Access trust provider.
63418 63419 63420 63421 63422 63423 63424 63425 63426 63427 63428 63429 |
# File 'lib/aws-sdk-ec2/types.rb', line 63418 class ModifyVerifiedAccessTrustProviderRequest < Struct.new( :verified_access_trust_provider_id, :oidc_options, :device_options, :description, :dry_run, :client_token, :sse_specification, :native_application_oidc_options) SENSITIVE = [] include Aws::Structure end |
#device_options ⇒ Types::ModifyVerifiedAccessTrustProviderDeviceOptions
The options for a device-based trust provider. This parameter is required when the provider type is ‘device`.
63418 63419 63420 63421 63422 63423 63424 63425 63426 63427 63428 63429 |
# File 'lib/aws-sdk-ec2/types.rb', line 63418 class ModifyVerifiedAccessTrustProviderRequest < Struct.new( :verified_access_trust_provider_id, :oidc_options, :device_options, :description, :dry_run, :client_token, :sse_specification, :native_application_oidc_options) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
63418 63419 63420 63421 63422 63423 63424 63425 63426 63427 63428 63429 |
# File 'lib/aws-sdk-ec2/types.rb', line 63418 class ModifyVerifiedAccessTrustProviderRequest < Struct.new( :verified_access_trust_provider_id, :oidc_options, :device_options, :description, :dry_run, :client_token, :sse_specification, :native_application_oidc_options) SENSITIVE = [] include Aws::Structure end |
#native_application_oidc_options ⇒ Types::ModifyVerifiedAccessNativeApplicationOidcOptions
The OpenID Connect (OIDC) options.
63418 63419 63420 63421 63422 63423 63424 63425 63426 63427 63428 63429 |
# File 'lib/aws-sdk-ec2/types.rb', line 63418 class ModifyVerifiedAccessTrustProviderRequest < Struct.new( :verified_access_trust_provider_id, :oidc_options, :device_options, :description, :dry_run, :client_token, :sse_specification, :native_application_oidc_options) SENSITIVE = [] include Aws::Structure end |
#oidc_options ⇒ Types::ModifyVerifiedAccessTrustProviderOidcOptions
The options for an OpenID Connect-compatible user-identity trust provider.
63418 63419 63420 63421 63422 63423 63424 63425 63426 63427 63428 63429 |
# File 'lib/aws-sdk-ec2/types.rb', line 63418 class ModifyVerifiedAccessTrustProviderRequest < Struct.new( :verified_access_trust_provider_id, :oidc_options, :device_options, :description, :dry_run, :client_token, :sse_specification, :native_application_oidc_options) SENSITIVE = [] include Aws::Structure end |
#sse_specification ⇒ Types::VerifiedAccessSseSpecificationRequest
The options for server side encryption.
63418 63419 63420 63421 63422 63423 63424 63425 63426 63427 63428 63429 |
# File 'lib/aws-sdk-ec2/types.rb', line 63418 class ModifyVerifiedAccessTrustProviderRequest < Struct.new( :verified_access_trust_provider_id, :oidc_options, :device_options, :description, :dry_run, :client_token, :sse_specification, :native_application_oidc_options) SENSITIVE = [] include Aws::Structure end |
#verified_access_trust_provider_id ⇒ String
The ID of the Verified Access trust provider.
63418 63419 63420 63421 63422 63423 63424 63425 63426 63427 63428 63429 |
# File 'lib/aws-sdk-ec2/types.rb', line 63418 class ModifyVerifiedAccessTrustProviderRequest < Struct.new( :verified_access_trust_provider_id, :oidc_options, :device_options, :description, :dry_run, :client_token, :sse_specification, :native_application_oidc_options) SENSITIVE = [] include Aws::Structure end |