Class: Aws::EC2::Types::ModifyVolumeAttributeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_enable_ioTypes::AttributeBooleanValue

Indicates whether the volume should be auto-enabled for I/O operations.



65552
65553
65554
65555
65556
65557
65558
# File 'lib/aws-sdk-ec2/types.rb', line 65552

class ModifyVolumeAttributeRequest < Struct.new(
  :auto_enable_io,
  :volume_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


65552
65553
65554
65555
65556
65557
65558
# File 'lib/aws-sdk-ec2/types.rb', line 65552

class ModifyVolumeAttributeRequest < Struct.new(
  :auto_enable_io,
  :volume_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#volume_idString

The ID of the volume.

Returns:

  • (String)


65552
65553
65554
65555
65556
65557
65558
# File 'lib/aws-sdk-ec2/types.rb', line 65552

class ModifyVolumeAttributeRequest < Struct.new(
  :auto_enable_io,
  :volume_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end