Class: Aws::EC2::Types::ModifyVolumeAttributeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyVolumeAttributeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_enable_io ⇒ Types::AttributeBooleanValue
Indicates whether the volume should be auto-enabled for I/O operations.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#volume_id ⇒ String
The ID of the volume.
Instance Attribute Details
#auto_enable_io ⇒ Types::AttributeBooleanValue
Indicates whether the volume should be auto-enabled for I/O operations.
65302 65303 65304 65305 65306 65307 65308 |
# File 'lib/aws-sdk-ec2/types.rb', line 65302 class ModifyVolumeAttributeRequest < Struct.new( :auto_enable_io, :volume_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
65302 65303 65304 65305 65306 65307 65308 |
# File 'lib/aws-sdk-ec2/types.rb', line 65302 class ModifyVolumeAttributeRequest < Struct.new( :auto_enable_io, :volume_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#volume_id ⇒ String
The ID of the volume.
65302 65303 65304 65305 65306 65307 65308 |
# File 'lib/aws-sdk-ec2/types.rb', line 65302 class ModifyVolumeAttributeRequest < Struct.new( :auto_enable_io, :volume_id, :dry_run) SENSITIVE = [] include Aws::Structure end |