Class: Aws::EC2::Types::ModifyVolumeAttributeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_enable_ioTypes::AttributeBooleanValue

Indicates whether the volume should be auto-enabled for I/O operations.



64725
64726
64727
64728
64729
64730
64731
# File 'lib/aws-sdk-ec2/types.rb', line 64725

class ModifyVolumeAttributeRequest < Struct.new(
  :auto_enable_io,
  :volume_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


64725
64726
64727
64728
64729
64730
64731
# File 'lib/aws-sdk-ec2/types.rb', line 64725

class ModifyVolumeAttributeRequest < Struct.new(
  :auto_enable_io,
  :volume_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#volume_idString

The ID of the volume.

Returns:

  • (String)


64725
64726
64727
64728
64729
64730
64731
# File 'lib/aws-sdk-ec2/types.rb', line 64725

class ModifyVolumeAttributeRequest < Struct.new(
  :auto_enable_io,
  :volume_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end