Class: Aws::EC2::Types::ModifyVpcBlockPublicAccessExclusionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyVpcBlockPublicAccessExclusionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#exclusion_id ⇒ String
The ID of an exclusion.
-
#internet_gateway_exclusion_mode ⇒ String
The exclusion mode for internet gateway traffic.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
63654 63655 63656 63657 63658 63659 63660 |
# File 'lib/aws-sdk-ec2/types.rb', line 63654 class ModifyVpcBlockPublicAccessExclusionRequest < Struct.new( :dry_run, :exclusion_id, :internet_gateway_exclusion_mode) SENSITIVE = [] include Aws::Structure end |
#exclusion_id ⇒ String
The ID of an exclusion.
63654 63655 63656 63657 63658 63659 63660 |
# File 'lib/aws-sdk-ec2/types.rb', line 63654 class ModifyVpcBlockPublicAccessExclusionRequest < Struct.new( :dry_run, :exclusion_id, :internet_gateway_exclusion_mode) SENSITIVE = [] include Aws::Structure end |
#internet_gateway_exclusion_mode ⇒ String
The exclusion mode for internet gateway traffic.
-
‘allow-bidirectional`: Allow all internet traffic to and from the excluded VPCs and subnets.
-
‘allow-egress`: Allow outbound internet traffic from the excluded VPCs and subnets. Block inbound internet traffic to the excluded VPCs and subnets. Only applies when VPC Block Public Access is set to Bidirectional.
63654 63655 63656 63657 63658 63659 63660 |
# File 'lib/aws-sdk-ec2/types.rb', line 63654 class ModifyVpcBlockPublicAccessExclusionRequest < Struct.new( :dry_run, :exclusion_id, :internet_gateway_exclusion_mode) SENSITIVE = [] include Aws::Structure end |