Class: Aws::EC2::Types::ModifyVpcBlockPublicAccessOptionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyVpcBlockPublicAccessOptionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#internet_gateway_block_mode ⇒ String
The mode of VPC BPA.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
63593 63594 63595 63596 63597 63598 |
# File 'lib/aws-sdk-ec2/types.rb', line 63593 class ModifyVpcBlockPublicAccessOptionsRequest < Struct.new( :dry_run, :internet_gateway_block_mode) SENSITIVE = [] include Aws::Structure end |
#internet_gateway_block_mode ⇒ String
The mode of VPC BPA.
-
‘off`: VPC BPA is not enabled and traffic is allowed to and from internet gateways and egress-only internet gateways in this Region.
-
‘block-bidirectional`: Block all traffic to and from internet gateways and egress-only internet gateways in this Region (except for excluded VPCs and subnets).
-
‘block-ingress`: Block all internet traffic to the VPCs in this Region (except for VPCs or subnets which are excluded). Only traffic to and from NAT gateways and egress-only internet gateways is allowed because these gateways only allow outbound connections to be established.
63593 63594 63595 63596 63597 63598 |
# File 'lib/aws-sdk-ec2/types.rb', line 63593 class ModifyVpcBlockPublicAccessOptionsRequest < Struct.new( :dry_run, :internet_gateway_block_mode) SENSITIVE = [] include Aws::Structure end |