Class: Aws::EC2::Types::ModifyVpcEncryptionControlRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyVpcEncryptionControlRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#egress_only_internet_gateway_exclusion ⇒ String
Specifies whether to exclude egress-only internet gateway traffic from encryption enforcement.
-
#elastic_file_system_exclusion ⇒ String
Specifies whether to exclude Elastic File System traffic from encryption enforcement.
-
#internet_gateway_exclusion ⇒ String
Specifies whether to exclude internet gateway traffic from encryption enforcement.
-
#lambda_exclusion ⇒ String
Specifies whether to exclude Lambda function traffic from encryption enforcement.
-
#mode ⇒ String
The encryption mode for the VPC Encryption Control configuration.
-
#nat_gateway_exclusion ⇒ String
Specifies whether to exclude NAT gateway traffic from encryption enforcement.
-
#virtual_private_gateway_exclusion ⇒ String
Specifies whether to exclude virtual private gateway traffic from encryption enforcement.
-
#vpc_encryption_control_id ⇒ String
The ID of the VPC Encryption Control resource to modify.
-
#vpc_lattice_exclusion ⇒ String
Specifies whether to exclude VPC Lattice traffic from encryption enforcement.
-
#vpc_peering_exclusion ⇒ String
Specifies whether to exclude VPC peering connection traffic from encryption enforcement.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
65198 65199 65200 65201 65202 65203 65204 65205 65206 65207 65208 65209 65210 65211 65212 |
# File 'lib/aws-sdk-ec2/types.rb', line 65198 class ModifyVpcEncryptionControlRequest < Struct.new( :dry_run, :vpc_encryption_control_id, :mode, :internet_gateway_exclusion, :egress_only_internet_gateway_exclusion, :nat_gateway_exclusion, :virtual_private_gateway_exclusion, :vpc_peering_exclusion, :lambda_exclusion, :vpc_lattice_exclusion, :elastic_file_system_exclusion) SENSITIVE = [] include Aws::Structure end |
#egress_only_internet_gateway_exclusion ⇒ String
Specifies whether to exclude egress-only internet gateway traffic from encryption enforcement.
65198 65199 65200 65201 65202 65203 65204 65205 65206 65207 65208 65209 65210 65211 65212 |
# File 'lib/aws-sdk-ec2/types.rb', line 65198 class ModifyVpcEncryptionControlRequest < Struct.new( :dry_run, :vpc_encryption_control_id, :mode, :internet_gateway_exclusion, :egress_only_internet_gateway_exclusion, :nat_gateway_exclusion, :virtual_private_gateway_exclusion, :vpc_peering_exclusion, :lambda_exclusion, :vpc_lattice_exclusion, :elastic_file_system_exclusion) SENSITIVE = [] include Aws::Structure end |
#elastic_file_system_exclusion ⇒ String
Specifies whether to exclude Elastic File System traffic from encryption enforcement.
65198 65199 65200 65201 65202 65203 65204 65205 65206 65207 65208 65209 65210 65211 65212 |
# File 'lib/aws-sdk-ec2/types.rb', line 65198 class ModifyVpcEncryptionControlRequest < Struct.new( :dry_run, :vpc_encryption_control_id, :mode, :internet_gateway_exclusion, :egress_only_internet_gateway_exclusion, :nat_gateway_exclusion, :virtual_private_gateway_exclusion, :vpc_peering_exclusion, :lambda_exclusion, :vpc_lattice_exclusion, :elastic_file_system_exclusion) SENSITIVE = [] include Aws::Structure end |
#internet_gateway_exclusion ⇒ String
Specifies whether to exclude internet gateway traffic from encryption enforcement.
65198 65199 65200 65201 65202 65203 65204 65205 65206 65207 65208 65209 65210 65211 65212 |
# File 'lib/aws-sdk-ec2/types.rb', line 65198 class ModifyVpcEncryptionControlRequest < Struct.new( :dry_run, :vpc_encryption_control_id, :mode, :internet_gateway_exclusion, :egress_only_internet_gateway_exclusion, :nat_gateway_exclusion, :virtual_private_gateway_exclusion, :vpc_peering_exclusion, :lambda_exclusion, :vpc_lattice_exclusion, :elastic_file_system_exclusion) SENSITIVE = [] include Aws::Structure end |
#lambda_exclusion ⇒ String
Specifies whether to exclude Lambda function traffic from encryption enforcement.
65198 65199 65200 65201 65202 65203 65204 65205 65206 65207 65208 65209 65210 65211 65212 |
# File 'lib/aws-sdk-ec2/types.rb', line 65198 class ModifyVpcEncryptionControlRequest < Struct.new( :dry_run, :vpc_encryption_control_id, :mode, :internet_gateway_exclusion, :egress_only_internet_gateway_exclusion, :nat_gateway_exclusion, :virtual_private_gateway_exclusion, :vpc_peering_exclusion, :lambda_exclusion, :vpc_lattice_exclusion, :elastic_file_system_exclusion) SENSITIVE = [] include Aws::Structure end |
#mode ⇒ String
The encryption mode for the VPC Encryption Control configuration.
65198 65199 65200 65201 65202 65203 65204 65205 65206 65207 65208 65209 65210 65211 65212 |
# File 'lib/aws-sdk-ec2/types.rb', line 65198 class ModifyVpcEncryptionControlRequest < Struct.new( :dry_run, :vpc_encryption_control_id, :mode, :internet_gateway_exclusion, :egress_only_internet_gateway_exclusion, :nat_gateway_exclusion, :virtual_private_gateway_exclusion, :vpc_peering_exclusion, :lambda_exclusion, :vpc_lattice_exclusion, :elastic_file_system_exclusion) SENSITIVE = [] include Aws::Structure end |
#nat_gateway_exclusion ⇒ String
Specifies whether to exclude NAT gateway traffic from encryption enforcement.
65198 65199 65200 65201 65202 65203 65204 65205 65206 65207 65208 65209 65210 65211 65212 |
# File 'lib/aws-sdk-ec2/types.rb', line 65198 class ModifyVpcEncryptionControlRequest < Struct.new( :dry_run, :vpc_encryption_control_id, :mode, :internet_gateway_exclusion, :egress_only_internet_gateway_exclusion, :nat_gateway_exclusion, :virtual_private_gateway_exclusion, :vpc_peering_exclusion, :lambda_exclusion, :vpc_lattice_exclusion, :elastic_file_system_exclusion) SENSITIVE = [] include Aws::Structure end |
#virtual_private_gateway_exclusion ⇒ String
Specifies whether to exclude virtual private gateway traffic from encryption enforcement.
65198 65199 65200 65201 65202 65203 65204 65205 65206 65207 65208 65209 65210 65211 65212 |
# File 'lib/aws-sdk-ec2/types.rb', line 65198 class ModifyVpcEncryptionControlRequest < Struct.new( :dry_run, :vpc_encryption_control_id, :mode, :internet_gateway_exclusion, :egress_only_internet_gateway_exclusion, :nat_gateway_exclusion, :virtual_private_gateway_exclusion, :vpc_peering_exclusion, :lambda_exclusion, :vpc_lattice_exclusion, :elastic_file_system_exclusion) SENSITIVE = [] include Aws::Structure end |
#vpc_encryption_control_id ⇒ String
The ID of the VPC Encryption Control resource to modify.
65198 65199 65200 65201 65202 65203 65204 65205 65206 65207 65208 65209 65210 65211 65212 |
# File 'lib/aws-sdk-ec2/types.rb', line 65198 class ModifyVpcEncryptionControlRequest < Struct.new( :dry_run, :vpc_encryption_control_id, :mode, :internet_gateway_exclusion, :egress_only_internet_gateway_exclusion, :nat_gateway_exclusion, :virtual_private_gateway_exclusion, :vpc_peering_exclusion, :lambda_exclusion, :vpc_lattice_exclusion, :elastic_file_system_exclusion) SENSITIVE = [] include Aws::Structure end |
#vpc_lattice_exclusion ⇒ String
Specifies whether to exclude VPC Lattice traffic from encryption enforcement.
65198 65199 65200 65201 65202 65203 65204 65205 65206 65207 65208 65209 65210 65211 65212 |
# File 'lib/aws-sdk-ec2/types.rb', line 65198 class ModifyVpcEncryptionControlRequest < Struct.new( :dry_run, :vpc_encryption_control_id, :mode, :internet_gateway_exclusion, :egress_only_internet_gateway_exclusion, :nat_gateway_exclusion, :virtual_private_gateway_exclusion, :vpc_peering_exclusion, :lambda_exclusion, :vpc_lattice_exclusion, :elastic_file_system_exclusion) SENSITIVE = [] include Aws::Structure end |
#vpc_peering_exclusion ⇒ String
Specifies whether to exclude VPC peering connection traffic from encryption enforcement.
65198 65199 65200 65201 65202 65203 65204 65205 65206 65207 65208 65209 65210 65211 65212 |
# File 'lib/aws-sdk-ec2/types.rb', line 65198 class ModifyVpcEncryptionControlRequest < Struct.new( :dry_run, :vpc_encryption_control_id, :mode, :internet_gateway_exclusion, :egress_only_internet_gateway_exclusion, :nat_gateway_exclusion, :virtual_private_gateway_exclusion, :vpc_peering_exclusion, :lambda_exclusion, :vpc_lattice_exclusion, :elastic_file_system_exclusion) SENSITIVE = [] include Aws::Structure end |