Class: Aws::EC2::Types::ModifyVpcEndpointConnectionNotificationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyVpcEndpointConnectionNotificationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection_events ⇒ Array<String>
The events for the endpoint.
-
#connection_notification_arn ⇒ String
The ARN for the SNS topic for the notification.
-
#connection_notification_id ⇒ String
The ID of the notification.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#connection_events ⇒ Array<String>
The events for the endpoint. Valid values are Accept, Connect,
Delete, and Reject.
66227 66228 66229 66230 66231 66232 66233 66234 |
# File 'lib/aws-sdk-ec2/types.rb', line 66227 class ModifyVpcEndpointConnectionNotificationRequest < Struct.new( :dry_run, :connection_notification_id, :connection_notification_arn, :connection_events) SENSITIVE = [] include Aws::Structure end |
#connection_notification_arn ⇒ String
The ARN for the SNS topic for the notification.
66227 66228 66229 66230 66231 66232 66233 66234 |
# File 'lib/aws-sdk-ec2/types.rb', line 66227 class ModifyVpcEndpointConnectionNotificationRequest < Struct.new( :dry_run, :connection_notification_id, :connection_notification_arn, :connection_events) SENSITIVE = [] include Aws::Structure end |
#connection_notification_id ⇒ String
The ID of the notification.
66227 66228 66229 66230 66231 66232 66233 66234 |
# File 'lib/aws-sdk-ec2/types.rb', line 66227 class ModifyVpcEndpointConnectionNotificationRequest < Struct.new( :dry_run, :connection_notification_id, :connection_notification_arn, :connection_events) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
66227 66228 66229 66230 66231 66232 66233 66234 |
# File 'lib/aws-sdk-ec2/types.rb', line 66227 class ModifyVpcEndpointConnectionNotificationRequest < Struct.new( :dry_run, :connection_notification_id, :connection_notification_arn, :connection_events) SENSITIVE = [] include Aws::Structure end |