Class: Aws::EC2::Types::ModifyVpcEndpointConnectionNotificationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#connection_eventsArray<String>

The events for the endpoint. Valid values are ‘Accept`, `Connect`, `Delete`, and `Reject`.

Returns:

  • (Array<String>)


65812
65813
65814
65815
65816
65817
65818
65819
# File 'lib/aws-sdk-ec2/types.rb', line 65812

class ModifyVpcEndpointConnectionNotificationRequest < Struct.new(
  :dry_run,
  :connection_notification_id,
  :connection_notification_arn,
  :connection_events)
  SENSITIVE = []
  include Aws::Structure
end

#connection_notification_arnString

The ARN for the SNS topic for the notification.

Returns:

  • (String)


65812
65813
65814
65815
65816
65817
65818
65819
# File 'lib/aws-sdk-ec2/types.rb', line 65812

class ModifyVpcEndpointConnectionNotificationRequest < Struct.new(
  :dry_run,
  :connection_notification_id,
  :connection_notification_arn,
  :connection_events)
  SENSITIVE = []
  include Aws::Structure
end

#connection_notification_idString

The ID of the notification.

Returns:

  • (String)


65812
65813
65814
65815
65816
65817
65818
65819
# File 'lib/aws-sdk-ec2/types.rb', line 65812

class ModifyVpcEndpointConnectionNotificationRequest < Struct.new(
  :dry_run,
  :connection_notification_id,
  :connection_notification_arn,
  :connection_events)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


65812
65813
65814
65815
65816
65817
65818
65819
# File 'lib/aws-sdk-ec2/types.rb', line 65812

class ModifyVpcEndpointConnectionNotificationRequest < Struct.new(
  :dry_run,
  :connection_notification_id,
  :connection_notification_arn,
  :connection_events)
  SENSITIVE = []
  include Aws::Structure
end