Class: Aws::EC2::Types::ModifyVpcEndpointPayerResponsibilityRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


69415
69416
69417
69418
69419
69420
69421
69422
69423
# File 'lib/aws-sdk-ec2/types.rb', line 69415

class ModifyVpcEndpointPayerResponsibilityRequest < Struct.new(
  :dry_run,
  :service_id,
  :vpc_endpoint_id,
  :payer_responsibility,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end

#payer_responsibilityString

The Amazon Web Services account to which the usage of VPC endpoint is charged.

Returns:

  • (String)


69415
69416
69417
69418
69419
69420
69421
69422
69423
# File 'lib/aws-sdk-ec2/types.rb', line 69415

class ModifyVpcEndpointPayerResponsibilityRequest < Struct.new(
  :dry_run,
  :service_id,
  :vpc_endpoint_id,
  :payer_responsibility,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end

#scopeString

The scope of usage/charges for which the billing account is being modified.

Returns:

  • (String)


69415
69416
69417
69418
69419
69420
69421
69422
69423
# File 'lib/aws-sdk-ec2/types.rb', line 69415

class ModifyVpcEndpointPayerResponsibilityRequest < Struct.new(
  :dry_run,
  :service_id,
  :vpc_endpoint_id,
  :payer_responsibility,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end

#service_idString

The ID of the VPC endpoint service.

Returns:

  • (String)


69415
69416
69417
69418
69419
69420
69421
69422
69423
# File 'lib/aws-sdk-ec2/types.rb', line 69415

class ModifyVpcEndpointPayerResponsibilityRequest < Struct.new(
  :dry_run,
  :service_id,
  :vpc_endpoint_id,
  :payer_responsibility,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_endpoint_idString

The ID of the VPC endpoint.

Returns:

  • (String)


69415
69416
69417
69418
69419
69420
69421
69422
69423
# File 'lib/aws-sdk-ec2/types.rb', line 69415

class ModifyVpcEndpointPayerResponsibilityRequest < Struct.new(
  :dry_run,
  :service_id,
  :vpc_endpoint_id,
  :payer_responsibility,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end