Class: Aws::EC2::Types::ModifyVpcEndpointPayerResponsibilityRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyVpcEndpointPayerResponsibilityRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#payer_responsibility ⇒ String
The Amazon Web Services account to which the usage of VPC endpoint is charged.
-
#scope ⇒ String
The scope of usage/charges for which the billing account is being modified.
-
#service_id ⇒ String
The ID of the VPC endpoint service.
-
#vpc_endpoint_id ⇒ String
The ID of the VPC endpoint.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
66276 66277 66278 66279 66280 66281 66282 66283 66284 |
# File 'lib/aws-sdk-ec2/types.rb', line 66276 class ModifyVpcEndpointPayerResponsibilityRequest < Struct.new( :dry_run, :service_id, :vpc_endpoint_id, :payer_responsibility, :scope) SENSITIVE = [] include Aws::Structure end |
#payer_responsibility ⇒ String
The Amazon Web Services account to which the usage of VPC endpoint is charged.
66276 66277 66278 66279 66280 66281 66282 66283 66284 |
# File 'lib/aws-sdk-ec2/types.rb', line 66276 class ModifyVpcEndpointPayerResponsibilityRequest < Struct.new( :dry_run, :service_id, :vpc_endpoint_id, :payer_responsibility, :scope) SENSITIVE = [] include Aws::Structure end |
#scope ⇒ String
The scope of usage/charges for which the billing account is being modified.
66276 66277 66278 66279 66280 66281 66282 66283 66284 |
# File 'lib/aws-sdk-ec2/types.rb', line 66276 class ModifyVpcEndpointPayerResponsibilityRequest < Struct.new( :dry_run, :service_id, :vpc_endpoint_id, :payer_responsibility, :scope) SENSITIVE = [] include Aws::Structure end |
#service_id ⇒ String
The ID of the VPC endpoint service.
66276 66277 66278 66279 66280 66281 66282 66283 66284 |
# File 'lib/aws-sdk-ec2/types.rb', line 66276 class ModifyVpcEndpointPayerResponsibilityRequest < Struct.new( :dry_run, :service_id, :vpc_endpoint_id, :payer_responsibility, :scope) SENSITIVE = [] include Aws::Structure end |
#vpc_endpoint_id ⇒ String
The ID of the VPC endpoint.
66276 66277 66278 66279 66280 66281 66282 66283 66284 |
# File 'lib/aws-sdk-ec2/types.rb', line 66276 class ModifyVpcEndpointPayerResponsibilityRequest < Struct.new( :dry_run, :service_id, :vpc_endpoint_id, :payer_responsibility, :scope) SENSITIVE = [] include Aws::Structure end |