Class: Aws::EC2::Types::ModifyVpcEndpointRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#add_route_table_idsArray<String>

(Gateway endpoint) The IDs of the route tables to associate with the endpoint.

Returns:

  • (Array<String>)


66704
66705
66706
66707
66708
66709
66710
66711
66712
66713
66714
66715
66716
66717
66718
66719
66720
66721
# File 'lib/aws-sdk-ec2/types.rb', line 66704

class ModifyVpcEndpointRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_id,
  :reset_policy,
  :policy_document,
  :add_route_table_ids,
  :remove_route_table_ids,
  :add_subnet_ids,
  :remove_subnet_ids,
  :add_security_group_ids,
  :remove_security_group_ids,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :subnet_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#add_security_group_idsArray<String>

(Interface endpoint) The IDs of the security groups to associate with the endpoint network interfaces.

Returns:

  • (Array<String>)


66704
66705
66706
66707
66708
66709
66710
66711
66712
66713
66714
66715
66716
66717
66718
66719
66720
66721
# File 'lib/aws-sdk-ec2/types.rb', line 66704

class ModifyVpcEndpointRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_id,
  :reset_policy,
  :policy_document,
  :add_route_table_ids,
  :remove_route_table_ids,
  :add_subnet_ids,
  :remove_subnet_ids,
  :add_security_group_ids,
  :remove_security_group_ids,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :subnet_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#add_subnet_idsArray<String>

(Interface and Gateway Load Balancer endpoints) The IDs of the subnets in which to serve the endpoint. For a Gateway Load Balancer endpoint, you can specify only one subnet.

Returns:

  • (Array<String>)


66704
66705
66706
66707
66708
66709
66710
66711
66712
66713
66714
66715
66716
66717
66718
66719
66720
66721
# File 'lib/aws-sdk-ec2/types.rb', line 66704

class ModifyVpcEndpointRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_id,
  :reset_policy,
  :policy_document,
  :add_route_table_ids,
  :remove_route_table_ids,
  :add_subnet_ids,
  :remove_subnet_ids,
  :add_security_group_ids,
  :remove_security_group_ids,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :subnet_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#dns_optionsTypes::DnsOptionsSpecification

The DNS options for the endpoint.



66704
66705
66706
66707
66708
66709
66710
66711
66712
66713
66714
66715
66716
66717
66718
66719
66720
66721
# File 'lib/aws-sdk-ec2/types.rb', line 66704

class ModifyVpcEndpointRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_id,
  :reset_policy,
  :policy_document,
  :add_route_table_ids,
  :remove_route_table_ids,
  :add_subnet_ids,
  :remove_subnet_ids,
  :add_security_group_ids,
  :remove_security_group_ids,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :subnet_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


66704
66705
66706
66707
66708
66709
66710
66711
66712
66713
66714
66715
66716
66717
66718
66719
66720
66721
# File 'lib/aws-sdk-ec2/types.rb', line 66704

class ModifyVpcEndpointRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_id,
  :reset_policy,
  :policy_document,
  :add_route_table_ids,
  :remove_route_table_ids,
  :add_subnet_ids,
  :remove_subnet_ids,
  :add_security_group_ids,
  :remove_security_group_ids,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :subnet_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#ip_address_typeString

The IP address type for the endpoint.

Returns:

  • (String)


66704
66705
66706
66707
66708
66709
66710
66711
66712
66713
66714
66715
66716
66717
66718
66719
66720
66721
# File 'lib/aws-sdk-ec2/types.rb', line 66704

class ModifyVpcEndpointRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_id,
  :reset_policy,
  :policy_document,
  :add_route_table_ids,
  :remove_route_table_ids,
  :add_subnet_ids,
  :remove_subnet_ids,
  :add_security_group_ids,
  :remove_security_group_ids,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :subnet_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#policy_documentString

(Interface and gateway endpoints) A policy to attach to the endpoint that controls access to the service. The policy must be in valid JSON format.

Returns:

  • (String)


66704
66705
66706
66707
66708
66709
66710
66711
66712
66713
66714
66715
66716
66717
66718
66719
66720
66721
# File 'lib/aws-sdk-ec2/types.rb', line 66704

class ModifyVpcEndpointRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_id,
  :reset_policy,
  :policy_document,
  :add_route_table_ids,
  :remove_route_table_ids,
  :add_subnet_ids,
  :remove_subnet_ids,
  :add_security_group_ids,
  :remove_security_group_ids,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :subnet_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#private_dns_enabledBoolean

(Interface endpoint) Indicates whether a private hosted zone is associated with the VPC.

Returns:

  • (Boolean)


66704
66705
66706
66707
66708
66709
66710
66711
66712
66713
66714
66715
66716
66717
66718
66719
66720
66721
# File 'lib/aws-sdk-ec2/types.rb', line 66704

class ModifyVpcEndpointRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_id,
  :reset_policy,
  :policy_document,
  :add_route_table_ids,
  :remove_route_table_ids,
  :add_subnet_ids,
  :remove_subnet_ids,
  :add_security_group_ids,
  :remove_security_group_ids,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :subnet_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#remove_route_table_idsArray<String>

(Gateway endpoint) The IDs of the route tables to disassociate from the endpoint.

Returns:

  • (Array<String>)


66704
66705
66706
66707
66708
66709
66710
66711
66712
66713
66714
66715
66716
66717
66718
66719
66720
66721
# File 'lib/aws-sdk-ec2/types.rb', line 66704

class ModifyVpcEndpointRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_id,
  :reset_policy,
  :policy_document,
  :add_route_table_ids,
  :remove_route_table_ids,
  :add_subnet_ids,
  :remove_subnet_ids,
  :add_security_group_ids,
  :remove_security_group_ids,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :subnet_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#remove_security_group_idsArray<String>

(Interface endpoint) The IDs of the security groups to disassociate from the endpoint network interfaces.

Returns:

  • (Array<String>)


66704
66705
66706
66707
66708
66709
66710
66711
66712
66713
66714
66715
66716
66717
66718
66719
66720
66721
# File 'lib/aws-sdk-ec2/types.rb', line 66704

class ModifyVpcEndpointRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_id,
  :reset_policy,
  :policy_document,
  :add_route_table_ids,
  :remove_route_table_ids,
  :add_subnet_ids,
  :remove_subnet_ids,
  :add_security_group_ids,
  :remove_security_group_ids,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :subnet_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#remove_subnet_idsArray<String>

(Interface endpoint) The IDs of the subnets from which to remove the endpoint.

Returns:

  • (Array<String>)


66704
66705
66706
66707
66708
66709
66710
66711
66712
66713
66714
66715
66716
66717
66718
66719
66720
66721
# File 'lib/aws-sdk-ec2/types.rb', line 66704

class ModifyVpcEndpointRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_id,
  :reset_policy,
  :policy_document,
  :add_route_table_ids,
  :remove_route_table_ids,
  :add_subnet_ids,
  :remove_subnet_ids,
  :add_security_group_ids,
  :remove_security_group_ids,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :subnet_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#reset_policyBoolean

(Gateway endpoint) Specify true to reset the policy document to the default policy. The default policy allows full access to the service.

Returns:

  • (Boolean)


66704
66705
66706
66707
66708
66709
66710
66711
66712
66713
66714
66715
66716
66717
66718
66719
66720
66721
# File 'lib/aws-sdk-ec2/types.rb', line 66704

class ModifyVpcEndpointRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_id,
  :reset_policy,
  :policy_document,
  :add_route_table_ids,
  :remove_route_table_ids,
  :add_subnet_ids,
  :remove_subnet_ids,
  :add_security_group_ids,
  :remove_security_group_ids,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :subnet_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_configurationsArray<Types::SubnetConfiguration>

The subnet configurations for the endpoint.

Returns:



66704
66705
66706
66707
66708
66709
66710
66711
66712
66713
66714
66715
66716
66717
66718
66719
66720
66721
# File 'lib/aws-sdk-ec2/types.rb', line 66704

class ModifyVpcEndpointRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_id,
  :reset_policy,
  :policy_document,
  :add_route_table_ids,
  :remove_route_table_ids,
  :add_subnet_ids,
  :remove_subnet_ids,
  :add_security_group_ids,
  :remove_security_group_ids,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :subnet_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_endpoint_idString

The ID of the endpoint.

Returns:

  • (String)


66704
66705
66706
66707
66708
66709
66710
66711
66712
66713
66714
66715
66716
66717
66718
66719
66720
66721
# File 'lib/aws-sdk-ec2/types.rb', line 66704

class ModifyVpcEndpointRequest < Struct.new(
  :dry_run,
  :vpc_endpoint_id,
  :reset_policy,
  :policy_document,
  :add_route_table_ids,
  :remove_route_table_ids,
  :add_subnet_ids,
  :remove_subnet_ids,
  :add_security_group_ids,
  :remove_security_group_ids,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :subnet_configurations)
  SENSITIVE = []
  include Aws::Structure
end