Class: Aws::EC2::Types::ModifyVpcEndpointRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyVpcEndpointRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#add_route_table_ids ⇒ Array<String>
(Gateway endpoint) The IDs of the route tables to associate with the endpoint.
-
#add_security_group_ids ⇒ Array<String>
(Interface endpoint) The IDs of the security groups to associate with the endpoint network interfaces.
-
#add_subnet_ids ⇒ Array<String>
(Interface and Gateway Load Balancer endpoints) The IDs of the subnets in which to serve the endpoint.
-
#dns_options ⇒ Types::DnsOptionsSpecification
The DNS options for the endpoint.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#ip_address_type ⇒ String
The IP address type for the endpoint.
-
#policy_document ⇒ String
(Interface and gateway endpoints) A policy to attach to the endpoint that controls access to the service.
-
#private_dns_enabled ⇒ Boolean
(Interface endpoint) Indicates whether a private hosted zone is associated with the VPC.
-
#remove_route_table_ids ⇒ Array<String>
(Gateway endpoint) The IDs of the route tables to disassociate from the endpoint.
-
#remove_security_group_ids ⇒ Array<String>
(Interface endpoint) The IDs of the security groups to disassociate from the endpoint network interfaces.
-
#remove_subnet_ids ⇒ Array<String>
(Interface endpoint) The IDs of the subnets from which to remove the endpoint.
-
#reset_policy ⇒ Boolean
(Gateway endpoint) Specify ‘true` to reset the policy document to the default policy.
-
#subnet_configurations ⇒ Array<Types::SubnetConfiguration>
The subnet configurations for the endpoint.
-
#vpc_endpoint_id ⇒ String
The ID of the endpoint.
Instance Attribute Details
#add_route_table_ids ⇒ Array<String>
(Gateway endpoint) The IDs of the route tables to associate with the endpoint.
66013 66014 66015 66016 66017 66018 66019 66020 66021 66022 66023 66024 66025 66026 66027 66028 66029 66030 |
# File 'lib/aws-sdk-ec2/types.rb', line 66013 class ModifyVpcEndpointRequest < Struct.new( :dry_run, :vpc_endpoint_id, :reset_policy, :policy_document, :add_route_table_ids, :remove_route_table_ids, :add_subnet_ids, :remove_subnet_ids, :add_security_group_ids, :remove_security_group_ids, :ip_address_type, :dns_options, :private_dns_enabled, :subnet_configurations) SENSITIVE = [] include Aws::Structure end |
#add_security_group_ids ⇒ Array<String>
(Interface endpoint) The IDs of the security groups to associate with the endpoint network interfaces.
66013 66014 66015 66016 66017 66018 66019 66020 66021 66022 66023 66024 66025 66026 66027 66028 66029 66030 |
# File 'lib/aws-sdk-ec2/types.rb', line 66013 class ModifyVpcEndpointRequest < Struct.new( :dry_run, :vpc_endpoint_id, :reset_policy, :policy_document, :add_route_table_ids, :remove_route_table_ids, :add_subnet_ids, :remove_subnet_ids, :add_security_group_ids, :remove_security_group_ids, :ip_address_type, :dns_options, :private_dns_enabled, :subnet_configurations) SENSITIVE = [] include Aws::Structure end |
#add_subnet_ids ⇒ Array<String>
(Interface and Gateway Load Balancer endpoints) The IDs of the subnets in which to serve the endpoint. For a Gateway Load Balancer endpoint, you can specify only one subnet.
66013 66014 66015 66016 66017 66018 66019 66020 66021 66022 66023 66024 66025 66026 66027 66028 66029 66030 |
# File 'lib/aws-sdk-ec2/types.rb', line 66013 class ModifyVpcEndpointRequest < Struct.new( :dry_run, :vpc_endpoint_id, :reset_policy, :policy_document, :add_route_table_ids, :remove_route_table_ids, :add_subnet_ids, :remove_subnet_ids, :add_security_group_ids, :remove_security_group_ids, :ip_address_type, :dns_options, :private_dns_enabled, :subnet_configurations) SENSITIVE = [] include Aws::Structure end |
#dns_options ⇒ Types::DnsOptionsSpecification
The DNS options for the endpoint.
66013 66014 66015 66016 66017 66018 66019 66020 66021 66022 66023 66024 66025 66026 66027 66028 66029 66030 |
# File 'lib/aws-sdk-ec2/types.rb', line 66013 class ModifyVpcEndpointRequest < Struct.new( :dry_run, :vpc_endpoint_id, :reset_policy, :policy_document, :add_route_table_ids, :remove_route_table_ids, :add_subnet_ids, :remove_subnet_ids, :add_security_group_ids, :remove_security_group_ids, :ip_address_type, :dns_options, :private_dns_enabled, :subnet_configurations) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
66013 66014 66015 66016 66017 66018 66019 66020 66021 66022 66023 66024 66025 66026 66027 66028 66029 66030 |
# File 'lib/aws-sdk-ec2/types.rb', line 66013 class ModifyVpcEndpointRequest < Struct.new( :dry_run, :vpc_endpoint_id, :reset_policy, :policy_document, :add_route_table_ids, :remove_route_table_ids, :add_subnet_ids, :remove_subnet_ids, :add_security_group_ids, :remove_security_group_ids, :ip_address_type, :dns_options, :private_dns_enabled, :subnet_configurations) SENSITIVE = [] include Aws::Structure end |
#ip_address_type ⇒ String
The IP address type for the endpoint.
66013 66014 66015 66016 66017 66018 66019 66020 66021 66022 66023 66024 66025 66026 66027 66028 66029 66030 |
# File 'lib/aws-sdk-ec2/types.rb', line 66013 class ModifyVpcEndpointRequest < Struct.new( :dry_run, :vpc_endpoint_id, :reset_policy, :policy_document, :add_route_table_ids, :remove_route_table_ids, :add_subnet_ids, :remove_subnet_ids, :add_security_group_ids, :remove_security_group_ids, :ip_address_type, :dns_options, :private_dns_enabled, :subnet_configurations) SENSITIVE = [] include Aws::Structure end |
#policy_document ⇒ String
(Interface and gateway endpoints) A policy to attach to the endpoint that controls access to the service. The policy must be in valid JSON format.
66013 66014 66015 66016 66017 66018 66019 66020 66021 66022 66023 66024 66025 66026 66027 66028 66029 66030 |
# File 'lib/aws-sdk-ec2/types.rb', line 66013 class ModifyVpcEndpointRequest < Struct.new( :dry_run, :vpc_endpoint_id, :reset_policy, :policy_document, :add_route_table_ids, :remove_route_table_ids, :add_subnet_ids, :remove_subnet_ids, :add_security_group_ids, :remove_security_group_ids, :ip_address_type, :dns_options, :private_dns_enabled, :subnet_configurations) SENSITIVE = [] include Aws::Structure end |
#private_dns_enabled ⇒ Boolean
(Interface endpoint) Indicates whether a private hosted zone is associated with the VPC.
66013 66014 66015 66016 66017 66018 66019 66020 66021 66022 66023 66024 66025 66026 66027 66028 66029 66030 |
# File 'lib/aws-sdk-ec2/types.rb', line 66013 class ModifyVpcEndpointRequest < Struct.new( :dry_run, :vpc_endpoint_id, :reset_policy, :policy_document, :add_route_table_ids, :remove_route_table_ids, :add_subnet_ids, :remove_subnet_ids, :add_security_group_ids, :remove_security_group_ids, :ip_address_type, :dns_options, :private_dns_enabled, :subnet_configurations) SENSITIVE = [] include Aws::Structure end |
#remove_route_table_ids ⇒ Array<String>
(Gateway endpoint) The IDs of the route tables to disassociate from the endpoint.
66013 66014 66015 66016 66017 66018 66019 66020 66021 66022 66023 66024 66025 66026 66027 66028 66029 66030 |
# File 'lib/aws-sdk-ec2/types.rb', line 66013 class ModifyVpcEndpointRequest < Struct.new( :dry_run, :vpc_endpoint_id, :reset_policy, :policy_document, :add_route_table_ids, :remove_route_table_ids, :add_subnet_ids, :remove_subnet_ids, :add_security_group_ids, :remove_security_group_ids, :ip_address_type, :dns_options, :private_dns_enabled, :subnet_configurations) SENSITIVE = [] include Aws::Structure end |
#remove_security_group_ids ⇒ Array<String>
(Interface endpoint) The IDs of the security groups to disassociate from the endpoint network interfaces.
66013 66014 66015 66016 66017 66018 66019 66020 66021 66022 66023 66024 66025 66026 66027 66028 66029 66030 |
# File 'lib/aws-sdk-ec2/types.rb', line 66013 class ModifyVpcEndpointRequest < Struct.new( :dry_run, :vpc_endpoint_id, :reset_policy, :policy_document, :add_route_table_ids, :remove_route_table_ids, :add_subnet_ids, :remove_subnet_ids, :add_security_group_ids, :remove_security_group_ids, :ip_address_type, :dns_options, :private_dns_enabled, :subnet_configurations) SENSITIVE = [] include Aws::Structure end |
#remove_subnet_ids ⇒ Array<String>
(Interface endpoint) The IDs of the subnets from which to remove the endpoint.
66013 66014 66015 66016 66017 66018 66019 66020 66021 66022 66023 66024 66025 66026 66027 66028 66029 66030 |
# File 'lib/aws-sdk-ec2/types.rb', line 66013 class ModifyVpcEndpointRequest < Struct.new( :dry_run, :vpc_endpoint_id, :reset_policy, :policy_document, :add_route_table_ids, :remove_route_table_ids, :add_subnet_ids, :remove_subnet_ids, :add_security_group_ids, :remove_security_group_ids, :ip_address_type, :dns_options, :private_dns_enabled, :subnet_configurations) SENSITIVE = [] include Aws::Structure end |
#reset_policy ⇒ Boolean
(Gateway endpoint) Specify ‘true` to reset the policy document to the default policy. The default policy allows full access to the service.
66013 66014 66015 66016 66017 66018 66019 66020 66021 66022 66023 66024 66025 66026 66027 66028 66029 66030 |
# File 'lib/aws-sdk-ec2/types.rb', line 66013 class ModifyVpcEndpointRequest < Struct.new( :dry_run, :vpc_endpoint_id, :reset_policy, :policy_document, :add_route_table_ids, :remove_route_table_ids, :add_subnet_ids, :remove_subnet_ids, :add_security_group_ids, :remove_security_group_ids, :ip_address_type, :dns_options, :private_dns_enabled, :subnet_configurations) SENSITIVE = [] include Aws::Structure end |
#subnet_configurations ⇒ Array<Types::SubnetConfiguration>
The subnet configurations for the endpoint.
66013 66014 66015 66016 66017 66018 66019 66020 66021 66022 66023 66024 66025 66026 66027 66028 66029 66030 |
# File 'lib/aws-sdk-ec2/types.rb', line 66013 class ModifyVpcEndpointRequest < Struct.new( :dry_run, :vpc_endpoint_id, :reset_policy, :policy_document, :add_route_table_ids, :remove_route_table_ids, :add_subnet_ids, :remove_subnet_ids, :add_security_group_ids, :remove_security_group_ids, :ip_address_type, :dns_options, :private_dns_enabled, :subnet_configurations) SENSITIVE = [] include Aws::Structure end |
#vpc_endpoint_id ⇒ String
The ID of the endpoint.
66013 66014 66015 66016 66017 66018 66019 66020 66021 66022 66023 66024 66025 66026 66027 66028 66029 66030 |
# File 'lib/aws-sdk-ec2/types.rb', line 66013 class ModifyVpcEndpointRequest < Struct.new( :dry_run, :vpc_endpoint_id, :reset_policy, :policy_document, :add_route_table_ids, :remove_route_table_ids, :add_subnet_ids, :remove_subnet_ids, :add_security_group_ids, :remove_security_group_ids, :ip_address_type, :dns_options, :private_dns_enabled, :subnet_configurations) SENSITIVE = [] include Aws::Structure end |