Class: Aws::EC2::Types::ModifyVpcEndpointServiceConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyVpcEndpointServiceConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#acceptance_required ⇒ Boolean
Indicates whether requests to create an endpoint to the service must be accepted.
-
#add_gateway_load_balancer_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of Gateway Load Balancers to add to the service configuration.
-
#add_network_load_balancer_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of Network Load Balancers to add to the service configuration.
-
#add_supported_ip_address_types ⇒ Array<String>
The IP address types to add to the service configuration.
-
#add_supported_regions ⇒ Array<String>
The supported Regions to add to the service configuration.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#private_dns_name ⇒ String
(Interface endpoint configuration) The private DNS name to assign to the endpoint service.
-
#remove_gateway_load_balancer_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of Gateway Load Balancers to remove from the service configuration.
-
#remove_network_load_balancer_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of Network Load Balancers to remove from the service configuration.
-
#remove_private_dns_name ⇒ Boolean
(Interface endpoint configuration) Removes the private DNS name of the endpoint service.
-
#remove_supported_ip_address_types ⇒ Array<String>
The IP address types to remove from the service configuration.
-
#remove_supported_regions ⇒ Array<String>
The supported Regions to remove from the service configuration.
-
#service_id ⇒ String
The ID of the service.
Instance Attribute Details
#acceptance_required ⇒ Boolean
Indicates whether requests to create an endpoint to the service must be accepted.
66109 66110 66111 66112 66113 66114 66115 66116 66117 66118 66119 66120 66121 66122 66123 66124 66125 |
# File 'lib/aws-sdk-ec2/types.rb', line 66109 class ModifyVpcEndpointServiceConfigurationRequest < Struct.new( :dry_run, :service_id, :private_dns_name, :remove_private_dns_name, :acceptance_required, :add_network_load_balancer_arns, :remove_network_load_balancer_arns, :add_gateway_load_balancer_arns, :remove_gateway_load_balancer_arns, :add_supported_ip_address_types, :remove_supported_ip_address_types, :add_supported_regions, :remove_supported_regions) SENSITIVE = [] include Aws::Structure end |
#add_gateway_load_balancer_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of Gateway Load Balancers to add to the service configuration.
66109 66110 66111 66112 66113 66114 66115 66116 66117 66118 66119 66120 66121 66122 66123 66124 66125 |
# File 'lib/aws-sdk-ec2/types.rb', line 66109 class ModifyVpcEndpointServiceConfigurationRequest < Struct.new( :dry_run, :service_id, :private_dns_name, :remove_private_dns_name, :acceptance_required, :add_network_load_balancer_arns, :remove_network_load_balancer_arns, :add_gateway_load_balancer_arns, :remove_gateway_load_balancer_arns, :add_supported_ip_address_types, :remove_supported_ip_address_types, :add_supported_regions, :remove_supported_regions) SENSITIVE = [] include Aws::Structure end |
#add_network_load_balancer_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of Network Load Balancers to add to the service configuration.
66109 66110 66111 66112 66113 66114 66115 66116 66117 66118 66119 66120 66121 66122 66123 66124 66125 |
# File 'lib/aws-sdk-ec2/types.rb', line 66109 class ModifyVpcEndpointServiceConfigurationRequest < Struct.new( :dry_run, :service_id, :private_dns_name, :remove_private_dns_name, :acceptance_required, :add_network_load_balancer_arns, :remove_network_load_balancer_arns, :add_gateway_load_balancer_arns, :remove_gateway_load_balancer_arns, :add_supported_ip_address_types, :remove_supported_ip_address_types, :add_supported_regions, :remove_supported_regions) SENSITIVE = [] include Aws::Structure end |
#add_supported_ip_address_types ⇒ Array<String>
The IP address types to add to the service configuration.
66109 66110 66111 66112 66113 66114 66115 66116 66117 66118 66119 66120 66121 66122 66123 66124 66125 |
# File 'lib/aws-sdk-ec2/types.rb', line 66109 class ModifyVpcEndpointServiceConfigurationRequest < Struct.new( :dry_run, :service_id, :private_dns_name, :remove_private_dns_name, :acceptance_required, :add_network_load_balancer_arns, :remove_network_load_balancer_arns, :add_gateway_load_balancer_arns, :remove_gateway_load_balancer_arns, :add_supported_ip_address_types, :remove_supported_ip_address_types, :add_supported_regions, :remove_supported_regions) SENSITIVE = [] include Aws::Structure end |
#add_supported_regions ⇒ Array<String>
The supported Regions to add to the service configuration.
66109 66110 66111 66112 66113 66114 66115 66116 66117 66118 66119 66120 66121 66122 66123 66124 66125 |
# File 'lib/aws-sdk-ec2/types.rb', line 66109 class ModifyVpcEndpointServiceConfigurationRequest < Struct.new( :dry_run, :service_id, :private_dns_name, :remove_private_dns_name, :acceptance_required, :add_network_load_balancer_arns, :remove_network_load_balancer_arns, :add_gateway_load_balancer_arns, :remove_gateway_load_balancer_arns, :add_supported_ip_address_types, :remove_supported_ip_address_types, :add_supported_regions, :remove_supported_regions) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
66109 66110 66111 66112 66113 66114 66115 66116 66117 66118 66119 66120 66121 66122 66123 66124 66125 |
# File 'lib/aws-sdk-ec2/types.rb', line 66109 class ModifyVpcEndpointServiceConfigurationRequest < Struct.new( :dry_run, :service_id, :private_dns_name, :remove_private_dns_name, :acceptance_required, :add_network_load_balancer_arns, :remove_network_load_balancer_arns, :add_gateway_load_balancer_arns, :remove_gateway_load_balancer_arns, :add_supported_ip_address_types, :remove_supported_ip_address_types, :add_supported_regions, :remove_supported_regions) SENSITIVE = [] include Aws::Structure end |
#private_dns_name ⇒ String
(Interface endpoint configuration) The private DNS name to assign to the endpoint service.
66109 66110 66111 66112 66113 66114 66115 66116 66117 66118 66119 66120 66121 66122 66123 66124 66125 |
# File 'lib/aws-sdk-ec2/types.rb', line 66109 class ModifyVpcEndpointServiceConfigurationRequest < Struct.new( :dry_run, :service_id, :private_dns_name, :remove_private_dns_name, :acceptance_required, :add_network_load_balancer_arns, :remove_network_load_balancer_arns, :add_gateway_load_balancer_arns, :remove_gateway_load_balancer_arns, :add_supported_ip_address_types, :remove_supported_ip_address_types, :add_supported_regions, :remove_supported_regions) SENSITIVE = [] include Aws::Structure end |
#remove_gateway_load_balancer_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of Gateway Load Balancers to remove from the service configuration.
66109 66110 66111 66112 66113 66114 66115 66116 66117 66118 66119 66120 66121 66122 66123 66124 66125 |
# File 'lib/aws-sdk-ec2/types.rb', line 66109 class ModifyVpcEndpointServiceConfigurationRequest < Struct.new( :dry_run, :service_id, :private_dns_name, :remove_private_dns_name, :acceptance_required, :add_network_load_balancer_arns, :remove_network_load_balancer_arns, :add_gateway_load_balancer_arns, :remove_gateway_load_balancer_arns, :add_supported_ip_address_types, :remove_supported_ip_address_types, :add_supported_regions, :remove_supported_regions) SENSITIVE = [] include Aws::Structure end |
#remove_network_load_balancer_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of Network Load Balancers to remove from the service configuration.
66109 66110 66111 66112 66113 66114 66115 66116 66117 66118 66119 66120 66121 66122 66123 66124 66125 |
# File 'lib/aws-sdk-ec2/types.rb', line 66109 class ModifyVpcEndpointServiceConfigurationRequest < Struct.new( :dry_run, :service_id, :private_dns_name, :remove_private_dns_name, :acceptance_required, :add_network_load_balancer_arns, :remove_network_load_balancer_arns, :add_gateway_load_balancer_arns, :remove_gateway_load_balancer_arns, :add_supported_ip_address_types, :remove_supported_ip_address_types, :add_supported_regions, :remove_supported_regions) SENSITIVE = [] include Aws::Structure end |
#remove_private_dns_name ⇒ Boolean
(Interface endpoint configuration) Removes the private DNS name of the endpoint service.
66109 66110 66111 66112 66113 66114 66115 66116 66117 66118 66119 66120 66121 66122 66123 66124 66125 |
# File 'lib/aws-sdk-ec2/types.rb', line 66109 class ModifyVpcEndpointServiceConfigurationRequest < Struct.new( :dry_run, :service_id, :private_dns_name, :remove_private_dns_name, :acceptance_required, :add_network_load_balancer_arns, :remove_network_load_balancer_arns, :add_gateway_load_balancer_arns, :remove_gateway_load_balancer_arns, :add_supported_ip_address_types, :remove_supported_ip_address_types, :add_supported_regions, :remove_supported_regions) SENSITIVE = [] include Aws::Structure end |
#remove_supported_ip_address_types ⇒ Array<String>
The IP address types to remove from the service configuration.
66109 66110 66111 66112 66113 66114 66115 66116 66117 66118 66119 66120 66121 66122 66123 66124 66125 |
# File 'lib/aws-sdk-ec2/types.rb', line 66109 class ModifyVpcEndpointServiceConfigurationRequest < Struct.new( :dry_run, :service_id, :private_dns_name, :remove_private_dns_name, :acceptance_required, :add_network_load_balancer_arns, :remove_network_load_balancer_arns, :add_gateway_load_balancer_arns, :remove_gateway_load_balancer_arns, :add_supported_ip_address_types, :remove_supported_ip_address_types, :add_supported_regions, :remove_supported_regions) SENSITIVE = [] include Aws::Structure end |
#remove_supported_regions ⇒ Array<String>
The supported Regions to remove from the service configuration.
66109 66110 66111 66112 66113 66114 66115 66116 66117 66118 66119 66120 66121 66122 66123 66124 66125 |
# File 'lib/aws-sdk-ec2/types.rb', line 66109 class ModifyVpcEndpointServiceConfigurationRequest < Struct.new( :dry_run, :service_id, :private_dns_name, :remove_private_dns_name, :acceptance_required, :add_network_load_balancer_arns, :remove_network_load_balancer_arns, :add_gateway_load_balancer_arns, :remove_gateway_load_balancer_arns, :add_supported_ip_address_types, :remove_supported_ip_address_types, :add_supported_regions, :remove_supported_regions) SENSITIVE = [] include Aws::Structure end |
#service_id ⇒ String
The ID of the service.
66109 66110 66111 66112 66113 66114 66115 66116 66117 66118 66119 66120 66121 66122 66123 66124 66125 |
# File 'lib/aws-sdk-ec2/types.rb', line 66109 class ModifyVpcEndpointServiceConfigurationRequest < Struct.new( :dry_run, :service_id, :private_dns_name, :remove_private_dns_name, :acceptance_required, :add_network_load_balancer_arns, :remove_network_load_balancer_arns, :add_gateway_load_balancer_arns, :remove_gateway_load_balancer_arns, :add_supported_ip_address_types, :remove_supported_ip_address_types, :add_supported_regions, :remove_supported_regions) SENSITIVE = [] include Aws::Structure end |