Class: Aws::EC2::Types::ModifyVpcEndpointServiceConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#acceptance_requiredBoolean

Indicates whether requests to create an endpoint to the service must be accepted.

Returns:

  • (Boolean)


64969
64970
64971
64972
64973
64974
64975
64976
64977
64978
64979
64980
64981
64982
64983
64984
64985
# File 'lib/aws-sdk-ec2/types.rb', line 64969

class ModifyVpcEndpointServiceConfigurationRequest < Struct.new(
  :dry_run,
  :service_id,
  :private_dns_name,
  :remove_private_dns_name,
  :acceptance_required,
  :add_network_load_balancer_arns,
  :remove_network_load_balancer_arns,
  :add_gateway_load_balancer_arns,
  :remove_gateway_load_balancer_arns,
  :add_supported_ip_address_types,
  :remove_supported_ip_address_types,
  :add_supported_regions,
  :remove_supported_regions)
  SENSITIVE = []
  include Aws::Structure
end

#add_gateway_load_balancer_arnsArray<String>

The Amazon Resource Names (ARNs) of Gateway Load Balancers to add to the service configuration.

Returns:

  • (Array<String>)


64969
64970
64971
64972
64973
64974
64975
64976
64977
64978
64979
64980
64981
64982
64983
64984
64985
# File 'lib/aws-sdk-ec2/types.rb', line 64969

class ModifyVpcEndpointServiceConfigurationRequest < Struct.new(
  :dry_run,
  :service_id,
  :private_dns_name,
  :remove_private_dns_name,
  :acceptance_required,
  :add_network_load_balancer_arns,
  :remove_network_load_balancer_arns,
  :add_gateway_load_balancer_arns,
  :remove_gateway_load_balancer_arns,
  :add_supported_ip_address_types,
  :remove_supported_ip_address_types,
  :add_supported_regions,
  :remove_supported_regions)
  SENSITIVE = []
  include Aws::Structure
end

#add_network_load_balancer_arnsArray<String>

The Amazon Resource Names (ARNs) of Network Load Balancers to add to the service configuration.

Returns:

  • (Array<String>)


64969
64970
64971
64972
64973
64974
64975
64976
64977
64978
64979
64980
64981
64982
64983
64984
64985
# File 'lib/aws-sdk-ec2/types.rb', line 64969

class ModifyVpcEndpointServiceConfigurationRequest < Struct.new(
  :dry_run,
  :service_id,
  :private_dns_name,
  :remove_private_dns_name,
  :acceptance_required,
  :add_network_load_balancer_arns,
  :remove_network_load_balancer_arns,
  :add_gateway_load_balancer_arns,
  :remove_gateway_load_balancer_arns,
  :add_supported_ip_address_types,
  :remove_supported_ip_address_types,
  :add_supported_regions,
  :remove_supported_regions)
  SENSITIVE = []
  include Aws::Structure
end

#add_supported_ip_address_typesArray<String>

The IP address types to add to the service configuration.

Returns:

  • (Array<String>)


64969
64970
64971
64972
64973
64974
64975
64976
64977
64978
64979
64980
64981
64982
64983
64984
64985
# File 'lib/aws-sdk-ec2/types.rb', line 64969

class ModifyVpcEndpointServiceConfigurationRequest < Struct.new(
  :dry_run,
  :service_id,
  :private_dns_name,
  :remove_private_dns_name,
  :acceptance_required,
  :add_network_load_balancer_arns,
  :remove_network_load_balancer_arns,
  :add_gateway_load_balancer_arns,
  :remove_gateway_load_balancer_arns,
  :add_supported_ip_address_types,
  :remove_supported_ip_address_types,
  :add_supported_regions,
  :remove_supported_regions)
  SENSITIVE = []
  include Aws::Structure
end

#add_supported_regionsArray<String>

The supported Regions to add to the service configuration.

Returns:

  • (Array<String>)


64969
64970
64971
64972
64973
64974
64975
64976
64977
64978
64979
64980
64981
64982
64983
64984
64985
# File 'lib/aws-sdk-ec2/types.rb', line 64969

class ModifyVpcEndpointServiceConfigurationRequest < Struct.new(
  :dry_run,
  :service_id,
  :private_dns_name,
  :remove_private_dns_name,
  :acceptance_required,
  :add_network_load_balancer_arns,
  :remove_network_load_balancer_arns,
  :add_gateway_load_balancer_arns,
  :remove_gateway_load_balancer_arns,
  :add_supported_ip_address_types,
  :remove_supported_ip_address_types,
  :add_supported_regions,
  :remove_supported_regions)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


64969
64970
64971
64972
64973
64974
64975
64976
64977
64978
64979
64980
64981
64982
64983
64984
64985
# File 'lib/aws-sdk-ec2/types.rb', line 64969

class ModifyVpcEndpointServiceConfigurationRequest < Struct.new(
  :dry_run,
  :service_id,
  :private_dns_name,
  :remove_private_dns_name,
  :acceptance_required,
  :add_network_load_balancer_arns,
  :remove_network_load_balancer_arns,
  :add_gateway_load_balancer_arns,
  :remove_gateway_load_balancer_arns,
  :add_supported_ip_address_types,
  :remove_supported_ip_address_types,
  :add_supported_regions,
  :remove_supported_regions)
  SENSITIVE = []
  include Aws::Structure
end

#private_dns_nameString

(Interface endpoint configuration) The private DNS name to assign to the endpoint service.

Returns:

  • (String)


64969
64970
64971
64972
64973
64974
64975
64976
64977
64978
64979
64980
64981
64982
64983
64984
64985
# File 'lib/aws-sdk-ec2/types.rb', line 64969

class ModifyVpcEndpointServiceConfigurationRequest < Struct.new(
  :dry_run,
  :service_id,
  :private_dns_name,
  :remove_private_dns_name,
  :acceptance_required,
  :add_network_load_balancer_arns,
  :remove_network_load_balancer_arns,
  :add_gateway_load_balancer_arns,
  :remove_gateway_load_balancer_arns,
  :add_supported_ip_address_types,
  :remove_supported_ip_address_types,
  :add_supported_regions,
  :remove_supported_regions)
  SENSITIVE = []
  include Aws::Structure
end

#remove_gateway_load_balancer_arnsArray<String>

The Amazon Resource Names (ARNs) of Gateway Load Balancers to remove from the service configuration.

Returns:

  • (Array<String>)


64969
64970
64971
64972
64973
64974
64975
64976
64977
64978
64979
64980
64981
64982
64983
64984
64985
# File 'lib/aws-sdk-ec2/types.rb', line 64969

class ModifyVpcEndpointServiceConfigurationRequest < Struct.new(
  :dry_run,
  :service_id,
  :private_dns_name,
  :remove_private_dns_name,
  :acceptance_required,
  :add_network_load_balancer_arns,
  :remove_network_load_balancer_arns,
  :add_gateway_load_balancer_arns,
  :remove_gateway_load_balancer_arns,
  :add_supported_ip_address_types,
  :remove_supported_ip_address_types,
  :add_supported_regions,
  :remove_supported_regions)
  SENSITIVE = []
  include Aws::Structure
end

#remove_network_load_balancer_arnsArray<String>

The Amazon Resource Names (ARNs) of Network Load Balancers to remove from the service configuration.

Returns:

  • (Array<String>)


64969
64970
64971
64972
64973
64974
64975
64976
64977
64978
64979
64980
64981
64982
64983
64984
64985
# File 'lib/aws-sdk-ec2/types.rb', line 64969

class ModifyVpcEndpointServiceConfigurationRequest < Struct.new(
  :dry_run,
  :service_id,
  :private_dns_name,
  :remove_private_dns_name,
  :acceptance_required,
  :add_network_load_balancer_arns,
  :remove_network_load_balancer_arns,
  :add_gateway_load_balancer_arns,
  :remove_gateway_load_balancer_arns,
  :add_supported_ip_address_types,
  :remove_supported_ip_address_types,
  :add_supported_regions,
  :remove_supported_regions)
  SENSITIVE = []
  include Aws::Structure
end

#remove_private_dns_nameBoolean

(Interface endpoint configuration) Removes the private DNS name of the endpoint service.

Returns:

  • (Boolean)


64969
64970
64971
64972
64973
64974
64975
64976
64977
64978
64979
64980
64981
64982
64983
64984
64985
# File 'lib/aws-sdk-ec2/types.rb', line 64969

class ModifyVpcEndpointServiceConfigurationRequest < Struct.new(
  :dry_run,
  :service_id,
  :private_dns_name,
  :remove_private_dns_name,
  :acceptance_required,
  :add_network_load_balancer_arns,
  :remove_network_load_balancer_arns,
  :add_gateway_load_balancer_arns,
  :remove_gateway_load_balancer_arns,
  :add_supported_ip_address_types,
  :remove_supported_ip_address_types,
  :add_supported_regions,
  :remove_supported_regions)
  SENSITIVE = []
  include Aws::Structure
end

#remove_supported_ip_address_typesArray<String>

The IP address types to remove from the service configuration.

Returns:

  • (Array<String>)


64969
64970
64971
64972
64973
64974
64975
64976
64977
64978
64979
64980
64981
64982
64983
64984
64985
# File 'lib/aws-sdk-ec2/types.rb', line 64969

class ModifyVpcEndpointServiceConfigurationRequest < Struct.new(
  :dry_run,
  :service_id,
  :private_dns_name,
  :remove_private_dns_name,
  :acceptance_required,
  :add_network_load_balancer_arns,
  :remove_network_load_balancer_arns,
  :add_gateway_load_balancer_arns,
  :remove_gateway_load_balancer_arns,
  :add_supported_ip_address_types,
  :remove_supported_ip_address_types,
  :add_supported_regions,
  :remove_supported_regions)
  SENSITIVE = []
  include Aws::Structure
end

#remove_supported_regionsArray<String>

The supported Regions to remove from the service configuration.

Returns:

  • (Array<String>)


64969
64970
64971
64972
64973
64974
64975
64976
64977
64978
64979
64980
64981
64982
64983
64984
64985
# File 'lib/aws-sdk-ec2/types.rb', line 64969

class ModifyVpcEndpointServiceConfigurationRequest < Struct.new(
  :dry_run,
  :service_id,
  :private_dns_name,
  :remove_private_dns_name,
  :acceptance_required,
  :add_network_load_balancer_arns,
  :remove_network_load_balancer_arns,
  :add_gateway_load_balancer_arns,
  :remove_gateway_load_balancer_arns,
  :add_supported_ip_address_types,
  :remove_supported_ip_address_types,
  :add_supported_regions,
  :remove_supported_regions)
  SENSITIVE = []
  include Aws::Structure
end

#service_idString

The ID of the service.

Returns:

  • (String)


64969
64970
64971
64972
64973
64974
64975
64976
64977
64978
64979
64980
64981
64982
64983
64984
64985
# File 'lib/aws-sdk-ec2/types.rb', line 64969

class ModifyVpcEndpointServiceConfigurationRequest < Struct.new(
  :dry_run,
  :service_id,
  :private_dns_name,
  :remove_private_dns_name,
  :acceptance_required,
  :add_network_load_balancer_arns,
  :remove_network_load_balancer_arns,
  :add_gateway_load_balancer_arns,
  :remove_gateway_load_balancer_arns,
  :add_supported_ip_address_types,
  :remove_supported_ip_address_types,
  :add_supported_regions,
  :remove_supported_regions)
  SENSITIVE = []
  include Aws::Structure
end