Class: Aws::EC2::Types::ModifyVpcEndpointServicePayerResponsibilityRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyVpcEndpointServicePayerResponsibilityRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#payer_responsibility ⇒ String
The entity that is responsible for the endpoint costs.
-
#service_id ⇒ String
The ID of the service.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
66159 66160 66161 66162 66163 66164 66165 |
# File 'lib/aws-sdk-ec2/types.rb', line 66159 class ModifyVpcEndpointServicePayerResponsibilityRequest < Struct.new( :dry_run, :service_id, :payer_responsibility) SENSITIVE = [] include Aws::Structure end |
#payer_responsibility ⇒ String
The entity that is responsible for the endpoint costs. The default is the endpoint owner. If you set the payer responsibility to the service owner, you cannot set it back to the endpoint owner.
66159 66160 66161 66162 66163 66164 66165 |
# File 'lib/aws-sdk-ec2/types.rb', line 66159 class ModifyVpcEndpointServicePayerResponsibilityRequest < Struct.new( :dry_run, :service_id, :payer_responsibility) SENSITIVE = [] include Aws::Structure end |
#service_id ⇒ String
The ID of the service.
66159 66160 66161 66162 66163 66164 66165 |
# File 'lib/aws-sdk-ec2/types.rb', line 66159 class ModifyVpcEndpointServicePayerResponsibilityRequest < Struct.new( :dry_run, :service_id, :payer_responsibility) SENSITIVE = [] include Aws::Structure end |