Class: Aws::EC2::Types::ModifyVpcEndpointServicePayerResponsibilityRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


65489
65490
65491
65492
65493
65494
65495
# File 'lib/aws-sdk-ec2/types.rb', line 65489

class ModifyVpcEndpointServicePayerResponsibilityRequest < Struct.new(
  :dry_run,
  :service_id,
  :payer_responsibility)
  SENSITIVE = []
  include Aws::Structure
end

#payer_responsibilityString

The entity that is responsible for the endpoint costs. The default is the endpoint owner. If you set the payer responsibility to the service owner, you cannot set it back to the endpoint owner.

Returns:

  • (String)


65489
65490
65491
65492
65493
65494
65495
# File 'lib/aws-sdk-ec2/types.rb', line 65489

class ModifyVpcEndpointServicePayerResponsibilityRequest < Struct.new(
  :dry_run,
  :service_id,
  :payer_responsibility)
  SENSITIVE = []
  include Aws::Structure
end

#service_idString

The ID of the service.

Returns:

  • (String)


65489
65490
65491
65492
65493
65494
65495
# File 'lib/aws-sdk-ec2/types.rb', line 65489

class ModifyVpcEndpointServicePayerResponsibilityRequest < Struct.new(
  :dry_run,
  :service_id,
  :payer_responsibility)
  SENSITIVE = []
  include Aws::Structure
end