Class: Aws::EC2::Types::ModifyVpcEndpointServicePermissionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#add_allowed_principalsArray<String>

The Amazon Resource Names (ARN) of the principals. Permissions are granted to the principals in this list. To grant permissions to all principals, specify an asterisk (*).

Returns:

  • (Array<String>)


69697
69698
69699
69700
69701
69702
69703
69704
# File 'lib/aws-sdk-ec2/types.rb', line 69697

class ModifyVpcEndpointServicePermissionsRequest < Struct.new(
  :dry_run,
  :service_id,
  :add_allowed_principals,
  :remove_allowed_principals)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


69697
69698
69699
69700
69701
69702
69703
69704
# File 'lib/aws-sdk-ec2/types.rb', line 69697

class ModifyVpcEndpointServicePermissionsRequest < Struct.new(
  :dry_run,
  :service_id,
  :add_allowed_principals,
  :remove_allowed_principals)
  SENSITIVE = []
  include Aws::Structure
end

#remove_allowed_principalsArray<String>

The Amazon Resource Names (ARN) of the principals. Permissions are revoked for principals in this list.

Returns:

  • (Array<String>)


69697
69698
69699
69700
69701
69702
69703
69704
# File 'lib/aws-sdk-ec2/types.rb', line 69697

class ModifyVpcEndpointServicePermissionsRequest < Struct.new(
  :dry_run,
  :service_id,
  :add_allowed_principals,
  :remove_allowed_principals)
  SENSITIVE = []
  include Aws::Structure
end

#service_idString

The ID of the service.

Returns:

  • (String)


69697
69698
69699
69700
69701
69702
69703
69704
# File 'lib/aws-sdk-ec2/types.rb', line 69697

class ModifyVpcEndpointServicePermissionsRequest < Struct.new(
  :dry_run,
  :service_id,
  :add_allowed_principals,
  :remove_allowed_principals)
  SENSITIVE = []
  include Aws::Structure
end