Class: Aws::EC2::Types::ModifyVpcEndpointServicePermissionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyVpcEndpointServicePermissionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#add_allowed_principals ⇒ Array<String>
The Amazon Resource Names (ARN) of the principals.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#remove_allowed_principals ⇒ Array<String>
The Amazon Resource Names (ARN) of the principals.
-
#service_id ⇒ String
The ID of the service.
Instance Attribute Details
#add_allowed_principals ⇒ Array<String>
The Amazon Resource Names (ARN) of the principals. Permissions are granted to the principals in this list. To grant permissions to all principals, specify an asterisk (*).
66567 66568 66569 66570 66571 66572 66573 66574 |
# File 'lib/aws-sdk-ec2/types.rb', line 66567 class ModifyVpcEndpointServicePermissionsRequest < Struct.new( :dry_run, :service_id, :add_allowed_principals, :remove_allowed_principals) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
66567 66568 66569 66570 66571 66572 66573 66574 |
# File 'lib/aws-sdk-ec2/types.rb', line 66567 class ModifyVpcEndpointServicePermissionsRequest < Struct.new( :dry_run, :service_id, :add_allowed_principals, :remove_allowed_principals) SENSITIVE = [] include Aws::Structure end |
#remove_allowed_principals ⇒ Array<String>
The Amazon Resource Names (ARN) of the principals. Permissions are revoked for principals in this list.
66567 66568 66569 66570 66571 66572 66573 66574 |
# File 'lib/aws-sdk-ec2/types.rb', line 66567 class ModifyVpcEndpointServicePermissionsRequest < Struct.new( :dry_run, :service_id, :add_allowed_principals, :remove_allowed_principals) SENSITIVE = [] include Aws::Structure end |
#service_id ⇒ String
The ID of the service.
66567 66568 66569 66570 66571 66572 66573 66574 |
# File 'lib/aws-sdk-ec2/types.rb', line 66567 class ModifyVpcEndpointServicePermissionsRequest < Struct.new( :dry_run, :service_id, :add_allowed_principals, :remove_allowed_principals) SENSITIVE = [] include Aws::Structure end |