Class: Aws::EC2::Types::ModifyVpcPeeringConnectionOptionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#accepter_peering_connection_optionsTypes::PeeringConnectionOptionsRequest

The VPC peering connection options for the accepter VPC.



66629
66630
66631
66632
66633
66634
66635
66636
# File 'lib/aws-sdk-ec2/types.rb', line 66629

class ModifyVpcPeeringConnectionOptionsRequest < Struct.new(
  :accepter_peering_connection_options,
  :dry_run,
  :requester_peering_connection_options,
  :vpc_peering_connection_id)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


66629
66630
66631
66632
66633
66634
66635
66636
# File 'lib/aws-sdk-ec2/types.rb', line 66629

class ModifyVpcPeeringConnectionOptionsRequest < Struct.new(
  :accepter_peering_connection_options,
  :dry_run,
  :requester_peering_connection_options,
  :vpc_peering_connection_id)
  SENSITIVE = []
  include Aws::Structure
end

#requester_peering_connection_optionsTypes::PeeringConnectionOptionsRequest

The VPC peering connection options for the requester VPC.



66629
66630
66631
66632
66633
66634
66635
66636
# File 'lib/aws-sdk-ec2/types.rb', line 66629

class ModifyVpcPeeringConnectionOptionsRequest < Struct.new(
  :accepter_peering_connection_options,
  :dry_run,
  :requester_peering_connection_options,
  :vpc_peering_connection_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_peering_connection_idString

The ID of the VPC peering connection.

Returns:

  • (String)


66629
66630
66631
66632
66633
66634
66635
66636
# File 'lib/aws-sdk-ec2/types.rb', line 66629

class ModifyVpcPeeringConnectionOptionsRequest < Struct.new(
  :accepter_peering_connection_options,
  :dry_run,
  :requester_peering_connection_options,
  :vpc_peering_connection_id)
  SENSITIVE = []
  include Aws::Structure
end