Class: Aws::EC2::Types::ModifyVpcPeeringConnectionOptionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyVpcPeeringConnectionOptionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#accepter_peering_connection_options ⇒ Types::PeeringConnectionOptionsRequest
The VPC peering connection options for the accepter VPC.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#requester_peering_connection_options ⇒ Types::PeeringConnectionOptionsRequest
The VPC peering connection options for the requester VPC.
-
#vpc_peering_connection_id ⇒ String
The ID of the VPC peering connection.
Instance Attribute Details
#accepter_peering_connection_options ⇒ Types::PeeringConnectionOptionsRequest
The VPC peering connection options for the accepter VPC.
65582 65583 65584 65585 65586 65587 65588 65589 |
# File 'lib/aws-sdk-ec2/types.rb', line 65582 class ModifyVpcPeeringConnectionOptionsRequest < Struct.new( :accepter_peering_connection_options, :dry_run, :requester_peering_connection_options, :vpc_peering_connection_id) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
65582 65583 65584 65585 65586 65587 65588 65589 |
# File 'lib/aws-sdk-ec2/types.rb', line 65582 class ModifyVpcPeeringConnectionOptionsRequest < Struct.new( :accepter_peering_connection_options, :dry_run, :requester_peering_connection_options, :vpc_peering_connection_id) SENSITIVE = [] include Aws::Structure end |
#requester_peering_connection_options ⇒ Types::PeeringConnectionOptionsRequest
The VPC peering connection options for the requester VPC.
65582 65583 65584 65585 65586 65587 65588 65589 |
# File 'lib/aws-sdk-ec2/types.rb', line 65582 class ModifyVpcPeeringConnectionOptionsRequest < Struct.new( :accepter_peering_connection_options, :dry_run, :requester_peering_connection_options, :vpc_peering_connection_id) SENSITIVE = [] include Aws::Structure end |
#vpc_peering_connection_id ⇒ String
The ID of the VPC peering connection.
65582 65583 65584 65585 65586 65587 65588 65589 |
# File 'lib/aws-sdk-ec2/types.rb', line 65582 class ModifyVpcPeeringConnectionOptionsRequest < Struct.new( :accepter_peering_connection_options, :dry_run, :requester_peering_connection_options, :vpc_peering_connection_id) SENSITIVE = [] include Aws::Structure end |