Class: Aws::EC2::Types::ModifyVpcPeeringConnectionOptionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyVpcPeeringConnectionOptionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#accepter_peering_connection_options ⇒ Types::PeeringConnectionOptionsRequest
The VPC peering connection options for the accepter VPC.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#requester_peering_connection_options ⇒ Types::PeeringConnectionOptionsRequest
The VPC peering connection options for the requester VPC.
-
#vpc_peering_connection_id ⇒ String
The ID of the VPC peering connection.
Instance Attribute Details
#accepter_peering_connection_options ⇒ Types::PeeringConnectionOptionsRequest
The VPC peering connection options for the accepter VPC.
65425 65426 65427 65428 65429 65430 65431 65432 |
# File 'lib/aws-sdk-ec2/types.rb', line 65425 class ModifyVpcPeeringConnectionOptionsRequest < Struct.new( :accepter_peering_connection_options, :dry_run, :requester_peering_connection_options, :vpc_peering_connection_id) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
65425 65426 65427 65428 65429 65430 65431 65432 |
# File 'lib/aws-sdk-ec2/types.rb', line 65425 class ModifyVpcPeeringConnectionOptionsRequest < Struct.new( :accepter_peering_connection_options, :dry_run, :requester_peering_connection_options, :vpc_peering_connection_id) SENSITIVE = [] include Aws::Structure end |
#requester_peering_connection_options ⇒ Types::PeeringConnectionOptionsRequest
The VPC peering connection options for the requester VPC.
65425 65426 65427 65428 65429 65430 65431 65432 |
# File 'lib/aws-sdk-ec2/types.rb', line 65425 class ModifyVpcPeeringConnectionOptionsRequest < Struct.new( :accepter_peering_connection_options, :dry_run, :requester_peering_connection_options, :vpc_peering_connection_id) SENSITIVE = [] include Aws::Structure end |
#vpc_peering_connection_id ⇒ String
The ID of the VPC peering connection.
65425 65426 65427 65428 65429 65430 65431 65432 |
# File 'lib/aws-sdk-ec2/types.rb', line 65425 class ModifyVpcPeeringConnectionOptionsRequest < Struct.new( :accepter_peering_connection_options, :dry_run, :requester_peering_connection_options, :vpc_peering_connection_id) SENSITIVE = [] include Aws::Structure end |