Class: Aws::EC2::Types::ModifyVpcTenancyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


65470
65471
65472
65473
65474
65475
65476
# File 'lib/aws-sdk-ec2/types.rb', line 65470

class ModifyVpcTenancyRequest < Struct.new(
  :vpc_id,
  :instance_tenancy,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#instance_tenancyString

The instance tenancy attribute for the VPC.

Returns:

  • (String)


65470
65471
65472
65473
65474
65475
65476
# File 'lib/aws-sdk-ec2/types.rb', line 65470

class ModifyVpcTenancyRequest < Struct.new(
  :vpc_id,
  :instance_tenancy,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC.

Returns:

  • (String)


65470
65471
65472
65473
65474
65475
65476
# File 'lib/aws-sdk-ec2/types.rb', line 65470

class ModifyVpcTenancyRequest < Struct.new(
  :vpc_id,
  :instance_tenancy,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end