Class: Aws::EC2::Types::ModifyVpcTenancyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyVpcTenancyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#instance_tenancy ⇒ String
The instance tenancy attribute for the VPC.
-
#vpc_id ⇒ String
The ID of the VPC.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
65470 65471 65472 65473 65474 65475 65476 |
# File 'lib/aws-sdk-ec2/types.rb', line 65470 class ModifyVpcTenancyRequest < Struct.new( :vpc_id, :instance_tenancy, :dry_run) SENSITIVE = [] include Aws::Structure end |
#instance_tenancy ⇒ String
The instance tenancy attribute for the VPC.
65470 65471 65472 65473 65474 65475 65476 |
# File 'lib/aws-sdk-ec2/types.rb', line 65470 class ModifyVpcTenancyRequest < Struct.new( :vpc_id, :instance_tenancy, :dry_run) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC.
65470 65471 65472 65473 65474 65475 65476 |
# File 'lib/aws-sdk-ec2/types.rb', line 65470 class ModifyVpcTenancyRequest < Struct.new( :vpc_id, :instance_tenancy, :dry_run) SENSITIVE = [] include Aws::Structure end |