Class: Aws::EC2::Types::ModifyVpnConnectionOptionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


66741
66742
66743
66744
66745
66746
66747
66748
66749
66750
66751
# File 'lib/aws-sdk-ec2/types.rb', line 66741

class ModifyVpnConnectionOptionsRequest < Struct.new(
  :vpn_connection_id,
  :local_ipv_4_network_cidr,
  :remote_ipv_4_network_cidr,
  :local_ipv_6_network_cidr,
  :remote_ipv_6_network_cidr,
  :tunnel_bandwidth,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#local_ipv_4_network_cidrString

The IPv4 CIDR on the customer gateway (on-premises) side of the VPN connection.

Default: 0.0.0.0/0

Returns:

  • (String)


66741
66742
66743
66744
66745
66746
66747
66748
66749
66750
66751
# File 'lib/aws-sdk-ec2/types.rb', line 66741

class ModifyVpnConnectionOptionsRequest < Struct.new(
  :vpn_connection_id,
  :local_ipv_4_network_cidr,
  :remote_ipv_4_network_cidr,
  :local_ipv_6_network_cidr,
  :remote_ipv_6_network_cidr,
  :tunnel_bandwidth,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#local_ipv_6_network_cidrString

The IPv6 CIDR on the customer gateway (on-premises) side of the VPN connection.

Default: ::/0

Returns:

  • (String)


66741
66742
66743
66744
66745
66746
66747
66748
66749
66750
66751
# File 'lib/aws-sdk-ec2/types.rb', line 66741

class ModifyVpnConnectionOptionsRequest < Struct.new(
  :vpn_connection_id,
  :local_ipv_4_network_cidr,
  :remote_ipv_4_network_cidr,
  :local_ipv_6_network_cidr,
  :remote_ipv_6_network_cidr,
  :tunnel_bandwidth,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#remote_ipv_4_network_cidrString

The IPv4 CIDR on the Amazon Web Services side of the VPN connection.

Default: 0.0.0.0/0

Returns:

  • (String)


66741
66742
66743
66744
66745
66746
66747
66748
66749
66750
66751
# File 'lib/aws-sdk-ec2/types.rb', line 66741

class ModifyVpnConnectionOptionsRequest < Struct.new(
  :vpn_connection_id,
  :local_ipv_4_network_cidr,
  :remote_ipv_4_network_cidr,
  :local_ipv_6_network_cidr,
  :remote_ipv_6_network_cidr,
  :tunnel_bandwidth,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#remote_ipv_6_network_cidrString

The IPv6 CIDR on the Amazon Web Services side of the VPN connection.

Default: ::/0

Returns:

  • (String)


66741
66742
66743
66744
66745
66746
66747
66748
66749
66750
66751
# File 'lib/aws-sdk-ec2/types.rb', line 66741

class ModifyVpnConnectionOptionsRequest < Struct.new(
  :vpn_connection_id,
  :local_ipv_4_network_cidr,
  :remote_ipv_4_network_cidr,
  :local_ipv_6_network_cidr,
  :remote_ipv_6_network_cidr,
  :tunnel_bandwidth,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tunnel_bandwidthString

The desired bandwidth specification for the VPN connection. standard supports up to 1.25 Gbps per tunnel, while large supports up to 5 Gbps per tunnel. Large bandwidth is only available for VPN connections attached to a transit gateway or to Cloud WAN. The default value is standard.

Returns:

  • (String)


66741
66742
66743
66744
66745
66746
66747
66748
66749
66750
66751
# File 'lib/aws-sdk-ec2/types.rb', line 66741

class ModifyVpnConnectionOptionsRequest < Struct.new(
  :vpn_connection_id,
  :local_ipv_4_network_cidr,
  :remote_ipv_4_network_cidr,
  :local_ipv_6_network_cidr,
  :remote_ipv_6_network_cidr,
  :tunnel_bandwidth,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpn_connection_idString

The ID of the Site-to-Site VPN connection.

Returns:

  • (String)


66741
66742
66743
66744
66745
66746
66747
66748
66749
66750
66751
# File 'lib/aws-sdk-ec2/types.rb', line 66741

class ModifyVpnConnectionOptionsRequest < Struct.new(
  :vpn_connection_id,
  :local_ipv_4_network_cidr,
  :remote_ipv_4_network_cidr,
  :local_ipv_6_network_cidr,
  :remote_ipv_6_network_cidr,
  :tunnel_bandwidth,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end