Class: Aws::EC2::Types::ModifyVpnConnectionOptionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyVpnConnectionOptionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#local_ipv_4_network_cidr ⇒ String
The IPv4 CIDR on the customer gateway (on-premises) side of the VPN connection.
-
#local_ipv_6_network_cidr ⇒ String
The IPv6 CIDR on the customer gateway (on-premises) side of the VPN connection.
-
#remote_ipv_4_network_cidr ⇒ String
The IPv4 CIDR on the Amazon Web Services side of the VPN connection.
-
#remote_ipv_6_network_cidr ⇒ String
The IPv6 CIDR on the Amazon Web Services side of the VPN connection.
-
#vpn_connection_id ⇒ String
The ID of the Site-to-Site VPN connection.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
65529 65530 65531 65532 65533 65534 65535 65536 65537 65538 |
# File 'lib/aws-sdk-ec2/types.rb', line 65529 class ModifyVpnConnectionOptionsRequest < Struct.new( :vpn_connection_id, :local_ipv_4_network_cidr, :remote_ipv_4_network_cidr, :local_ipv_6_network_cidr, :remote_ipv_6_network_cidr, :dry_run) SENSITIVE = [] include Aws::Structure end |
#local_ipv_4_network_cidr ⇒ String
The IPv4 CIDR on the customer gateway (on-premises) side of the VPN connection.
Default: ‘0.0.0.0/0`
65529 65530 65531 65532 65533 65534 65535 65536 65537 65538 |
# File 'lib/aws-sdk-ec2/types.rb', line 65529 class ModifyVpnConnectionOptionsRequest < Struct.new( :vpn_connection_id, :local_ipv_4_network_cidr, :remote_ipv_4_network_cidr, :local_ipv_6_network_cidr, :remote_ipv_6_network_cidr, :dry_run) SENSITIVE = [] include Aws::Structure end |
#local_ipv_6_network_cidr ⇒ String
The IPv6 CIDR on the customer gateway (on-premises) side of the VPN connection.
Default: ‘::/0`
65529 65530 65531 65532 65533 65534 65535 65536 65537 65538 |
# File 'lib/aws-sdk-ec2/types.rb', line 65529 class ModifyVpnConnectionOptionsRequest < Struct.new( :vpn_connection_id, :local_ipv_4_network_cidr, :remote_ipv_4_network_cidr, :local_ipv_6_network_cidr, :remote_ipv_6_network_cidr, :dry_run) SENSITIVE = [] include Aws::Structure end |
#remote_ipv_4_network_cidr ⇒ String
The IPv4 CIDR on the Amazon Web Services side of the VPN connection.
Default: ‘0.0.0.0/0`
65529 65530 65531 65532 65533 65534 65535 65536 65537 65538 |
# File 'lib/aws-sdk-ec2/types.rb', line 65529 class ModifyVpnConnectionOptionsRequest < Struct.new( :vpn_connection_id, :local_ipv_4_network_cidr, :remote_ipv_4_network_cidr, :local_ipv_6_network_cidr, :remote_ipv_6_network_cidr, :dry_run) SENSITIVE = [] include Aws::Structure end |
#remote_ipv_6_network_cidr ⇒ String
The IPv6 CIDR on the Amazon Web Services side of the VPN connection.
Default: ‘::/0`
65529 65530 65531 65532 65533 65534 65535 65536 65537 65538 |
# File 'lib/aws-sdk-ec2/types.rb', line 65529 class ModifyVpnConnectionOptionsRequest < Struct.new( :vpn_connection_id, :local_ipv_4_network_cidr, :remote_ipv_4_network_cidr, :local_ipv_6_network_cidr, :remote_ipv_6_network_cidr, :dry_run) SENSITIVE = [] include Aws::Structure end |
#vpn_connection_id ⇒ String
The ID of the Site-to-Site VPN connection.
65529 65530 65531 65532 65533 65534 65535 65536 65537 65538 |
# File 'lib/aws-sdk-ec2/types.rb', line 65529 class ModifyVpnConnectionOptionsRequest < Struct.new( :vpn_connection_id, :local_ipv_4_network_cidr, :remote_ipv_4_network_cidr, :local_ipv_6_network_cidr, :remote_ipv_6_network_cidr, :dry_run) SENSITIVE = [] include Aws::Structure end |