Class: Aws::EC2::Types::ModifyVpnConnectionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#customer_gateway_idString

The ID of the customer gateway at your end of the VPN connection.

Returns:

  • (String)


69907
69908
69909
69910
69911
69912
69913
69914
69915
# File 'lib/aws-sdk-ec2/types.rb', line 69907

class ModifyVpnConnectionRequest < Struct.new(
  :vpn_connection_id,
  :transit_gateway_id,
  :customer_gateway_id,
  :vpn_gateway_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


69907
69908
69909
69910
69911
69912
69913
69914
69915
# File 'lib/aws-sdk-ec2/types.rb', line 69907

class ModifyVpnConnectionRequest < Struct.new(
  :vpn_connection_id,
  :transit_gateway_id,
  :customer_gateway_id,
  :vpn_gateway_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_idString

The ID of the transit gateway.

Returns:

  • (String)


69907
69908
69909
69910
69911
69912
69913
69914
69915
# File 'lib/aws-sdk-ec2/types.rb', line 69907

class ModifyVpnConnectionRequest < Struct.new(
  :vpn_connection_id,
  :transit_gateway_id,
  :customer_gateway_id,
  :vpn_gateway_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpn_connection_idString

The ID of the VPN connection.

Returns:

  • (String)


69907
69908
69909
69910
69911
69912
69913
69914
69915
# File 'lib/aws-sdk-ec2/types.rb', line 69907

class ModifyVpnConnectionRequest < Struct.new(
  :vpn_connection_id,
  :transit_gateway_id,
  :customer_gateway_id,
  :vpn_gateway_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpn_gateway_idString

The ID of the virtual private gateway at the Amazon Web Services side of the VPN connection.

Returns:

  • (String)


69907
69908
69909
69910
69911
69912
69913
69914
69915
# File 'lib/aws-sdk-ec2/types.rb', line 69907

class ModifyVpnConnectionRequest < Struct.new(
  :vpn_connection_id,
  :transit_gateway_id,
  :customer_gateway_id,
  :vpn_gateway_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end