Class: Aws::EC2::Types::ModifyVpnConnectionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyVpnConnectionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#customer_gateway_id ⇒ String
The ID of the customer gateway at your end of the VPN connection.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#transit_gateway_id ⇒ String
The ID of the transit gateway.
-
#vpn_connection_id ⇒ String
The ID of the VPN connection.
-
#vpn_gateway_id ⇒ String
The ID of the virtual private gateway at the Amazon Web Services side of the VPN connection.
Instance Attribute Details
#customer_gateway_id ⇒ String
The ID of the customer gateway at your end of the VPN connection.
67105 67106 67107 67108 67109 67110 67111 67112 67113 |
# File 'lib/aws-sdk-ec2/types.rb', line 67105 class ModifyVpnConnectionRequest < Struct.new( :vpn_connection_id, :transit_gateway_id, :customer_gateway_id, :vpn_gateway_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
67105 67106 67107 67108 67109 67110 67111 67112 67113 |
# File 'lib/aws-sdk-ec2/types.rb', line 67105 class ModifyVpnConnectionRequest < Struct.new( :vpn_connection_id, :transit_gateway_id, :customer_gateway_id, :vpn_gateway_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_id ⇒ String
The ID of the transit gateway.
67105 67106 67107 67108 67109 67110 67111 67112 67113 |
# File 'lib/aws-sdk-ec2/types.rb', line 67105 class ModifyVpnConnectionRequest < Struct.new( :vpn_connection_id, :transit_gateway_id, :customer_gateway_id, :vpn_gateway_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#vpn_connection_id ⇒ String
The ID of the VPN connection.
67105 67106 67107 67108 67109 67110 67111 67112 67113 |
# File 'lib/aws-sdk-ec2/types.rb', line 67105 class ModifyVpnConnectionRequest < Struct.new( :vpn_connection_id, :transit_gateway_id, :customer_gateway_id, :vpn_gateway_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#vpn_gateway_id ⇒ String
The ID of the virtual private gateway at the Amazon Web Services side of the VPN connection.
67105 67106 67107 67108 67109 67110 67111 67112 67113 |
# File 'lib/aws-sdk-ec2/types.rb', line 67105 class ModifyVpnConnectionRequest < Struct.new( :vpn_connection_id, :transit_gateway_id, :customer_gateway_id, :vpn_gateway_id, :dry_run) SENSITIVE = [] include Aws::Structure end |