Class: Aws::EC2::Types::ModifyVpnConnectionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#customer_gateway_idString

The ID of the customer gateway at your end of the VPN connection.

Returns:

  • (String)


66777
66778
66779
66780
66781
66782
66783
66784
66785
# File 'lib/aws-sdk-ec2/types.rb', line 66777

class ModifyVpnConnectionRequest < Struct.new(
  :vpn_connection_id,
  :transit_gateway_id,
  :customer_gateway_id,
  :vpn_gateway_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


66777
66778
66779
66780
66781
66782
66783
66784
66785
# File 'lib/aws-sdk-ec2/types.rb', line 66777

class ModifyVpnConnectionRequest < Struct.new(
  :vpn_connection_id,
  :transit_gateway_id,
  :customer_gateway_id,
  :vpn_gateway_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_idString

The ID of the transit gateway.

Returns:

  • (String)


66777
66778
66779
66780
66781
66782
66783
66784
66785
# File 'lib/aws-sdk-ec2/types.rb', line 66777

class ModifyVpnConnectionRequest < Struct.new(
  :vpn_connection_id,
  :transit_gateway_id,
  :customer_gateway_id,
  :vpn_gateway_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpn_connection_idString

The ID of the VPN connection.

Returns:

  • (String)


66777
66778
66779
66780
66781
66782
66783
66784
66785
# File 'lib/aws-sdk-ec2/types.rb', line 66777

class ModifyVpnConnectionRequest < Struct.new(
  :vpn_connection_id,
  :transit_gateway_id,
  :customer_gateway_id,
  :vpn_gateway_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpn_gateway_idString

The ID of the virtual private gateway at the Amazon Web Services side of the VPN connection.

Returns:

  • (String)


66777
66778
66779
66780
66781
66782
66783
66784
66785
# File 'lib/aws-sdk-ec2/types.rb', line 66777

class ModifyVpnConnectionRequest < Struct.new(
  :vpn_connection_id,
  :transit_gateway_id,
  :customer_gateway_id,
  :vpn_gateway_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end