Class: Aws::EC2::Types::ModifyVpnTunnelCertificateRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


69946
69947
69948
69949
69950
69951
69952
# File 'lib/aws-sdk-ec2/types.rb', line 69946

class ModifyVpnTunnelCertificateRequest < Struct.new(
  :vpn_connection_id,
  :vpn_tunnel_outside_ip_address,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpn_connection_idString

The ID of the Amazon Web Services Site-to-Site VPN connection.

Returns:

  • (String)


69946
69947
69948
69949
69950
69951
69952
# File 'lib/aws-sdk-ec2/types.rb', line 69946

class ModifyVpnTunnelCertificateRequest < Struct.new(
  :vpn_connection_id,
  :vpn_tunnel_outside_ip_address,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpn_tunnel_outside_ip_addressString

The external IP address of the VPN tunnel.

Returns:

  • (String)


69946
69947
69948
69949
69950
69951
69952
# File 'lib/aws-sdk-ec2/types.rb', line 69946

class ModifyVpnTunnelCertificateRequest < Struct.new(
  :vpn_connection_id,
  :vpn_tunnel_outside_ip_address,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end