Class: Aws::EC2::Types::ModifyVpnTunnelCertificateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyVpnTunnelCertificateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#vpn_connection_id ⇒ String
The ID of the Amazon Web Services Site-to-Site VPN connection.
-
#vpn_tunnel_outside_ip_address ⇒ String
The external IP address of the VPN tunnel.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
64353 64354 64355 64356 64357 64358 64359 |
# File 'lib/aws-sdk-ec2/types.rb', line 64353 class ModifyVpnTunnelCertificateRequest < Struct.new( :vpn_connection_id, :vpn_tunnel_outside_ip_address, :dry_run) SENSITIVE = [] include Aws::Structure end |
#vpn_connection_id ⇒ String
The ID of the Amazon Web Services Site-to-Site VPN connection.
64353 64354 64355 64356 64357 64358 64359 |
# File 'lib/aws-sdk-ec2/types.rb', line 64353 class ModifyVpnTunnelCertificateRequest < Struct.new( :vpn_connection_id, :vpn_tunnel_outside_ip_address, :dry_run) SENSITIVE = [] include Aws::Structure end |
#vpn_tunnel_outside_ip_address ⇒ String
The external IP address of the VPN tunnel.
64353 64354 64355 64356 64357 64358 64359 |
# File 'lib/aws-sdk-ec2/types.rb', line 64353 class ModifyVpnTunnelCertificateRequest < Struct.new( :vpn_connection_id, :vpn_tunnel_outside_ip_address, :dry_run) SENSITIVE = [] include Aws::Structure end |