Class: Aws::EC2::Types::ModifyVpnTunnelOptionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:tunnel_options]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


65672
65673
65674
65675
65676
65677
65678
65679
65680
65681
# File 'lib/aws-sdk-ec2/types.rb', line 65672

class ModifyVpnTunnelOptionsRequest < Struct.new(
  :vpn_connection_id,
  :vpn_tunnel_outside_ip_address,
  :tunnel_options,
  :dry_run,
  :skip_tunnel_replacement,
  :pre_shared_key_storage)
  SENSITIVE = [:tunnel_options]
  include Aws::Structure
end

#pre_shared_key_storageString

Specifies the storage mode for the pre-shared key (PSK). Valid values are ‘Standard` (stored in Site-to-Site VPN service) or `SecretsManager` (stored in Amazon Web Services Secrets Manager).

Returns:

  • (String)


65672
65673
65674
65675
65676
65677
65678
65679
65680
65681
# File 'lib/aws-sdk-ec2/types.rb', line 65672

class ModifyVpnTunnelOptionsRequest < Struct.new(
  :vpn_connection_id,
  :vpn_tunnel_outside_ip_address,
  :tunnel_options,
  :dry_run,
  :skip_tunnel_replacement,
  :pre_shared_key_storage)
  SENSITIVE = [:tunnel_options]
  include Aws::Structure
end

#skip_tunnel_replacementBoolean

Choose whether or not to trigger immediate tunnel replacement. This is only applicable when turning on or off ‘EnableTunnelLifecycleControl`.

Valid values: ‘True` | `False`

Returns:

  • (Boolean)


65672
65673
65674
65675
65676
65677
65678
65679
65680
65681
# File 'lib/aws-sdk-ec2/types.rb', line 65672

class ModifyVpnTunnelOptionsRequest < Struct.new(
  :vpn_connection_id,
  :vpn_tunnel_outside_ip_address,
  :tunnel_options,
  :dry_run,
  :skip_tunnel_replacement,
  :pre_shared_key_storage)
  SENSITIVE = [:tunnel_options]
  include Aws::Structure
end

#tunnel_optionsTypes::ModifyVpnTunnelOptionsSpecification

The tunnel options to modify.



65672
65673
65674
65675
65676
65677
65678
65679
65680
65681
# File 'lib/aws-sdk-ec2/types.rb', line 65672

class ModifyVpnTunnelOptionsRequest < Struct.new(
  :vpn_connection_id,
  :vpn_tunnel_outside_ip_address,
  :tunnel_options,
  :dry_run,
  :skip_tunnel_replacement,
  :pre_shared_key_storage)
  SENSITIVE = [:tunnel_options]
  include Aws::Structure
end

#vpn_connection_idString

The ID of the Amazon Web Services Site-to-Site VPN connection.

Returns:

  • (String)


65672
65673
65674
65675
65676
65677
65678
65679
65680
65681
# File 'lib/aws-sdk-ec2/types.rb', line 65672

class ModifyVpnTunnelOptionsRequest < Struct.new(
  :vpn_connection_id,
  :vpn_tunnel_outside_ip_address,
  :tunnel_options,
  :dry_run,
  :skip_tunnel_replacement,
  :pre_shared_key_storage)
  SENSITIVE = [:tunnel_options]
  include Aws::Structure
end

#vpn_tunnel_outside_ip_addressString

The external IP address of the VPN tunnel.

Returns:

  • (String)


65672
65673
65674
65675
65676
65677
65678
65679
65680
65681
# File 'lib/aws-sdk-ec2/types.rb', line 65672

class ModifyVpnTunnelOptionsRequest < Struct.new(
  :vpn_connection_id,
  :vpn_tunnel_outside_ip_address,
  :tunnel_options,
  :dry_run,
  :skip_tunnel_replacement,
  :pre_shared_key_storage)
  SENSITIVE = [:tunnel_options]
  include Aws::Structure
end