Class: Aws::EC2::Types::ModifyVpnTunnelOptionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ModifyVpnTunnelOptionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:tunnel_options]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#pre_shared_key_storage ⇒ String
Specifies the storage mode for the pre-shared key (PSK).
-
#skip_tunnel_replacement ⇒ Boolean
Choose whether or not to trigger immediate tunnel replacement.
-
#tunnel_options ⇒ Types::ModifyVpnTunnelOptionsSpecification
The tunnel options to modify.
-
#vpn_connection_id ⇒ String
The ID of the Amazon Web Services Site-to-Site VPN connection.
-
#vpn_tunnel_outside_ip_address ⇒ String
The external IP address of the VPN tunnel.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
64408 64409 64410 64411 64412 64413 64414 64415 64416 64417 |
# File 'lib/aws-sdk-ec2/types.rb', line 64408 class ModifyVpnTunnelOptionsRequest < Struct.new( :vpn_connection_id, :vpn_tunnel_outside_ip_address, :tunnel_options, :dry_run, :skip_tunnel_replacement, :pre_shared_key_storage) SENSITIVE = [:tunnel_options] include Aws::Structure end |
#pre_shared_key_storage ⇒ String
Specifies the storage mode for the pre-shared key (PSK). Valid values are ‘Standard` (stored in Site-to-Site VPN service) or `SecretsManager` (stored in Amazon Web Services Secrets Manager).
64408 64409 64410 64411 64412 64413 64414 64415 64416 64417 |
# File 'lib/aws-sdk-ec2/types.rb', line 64408 class ModifyVpnTunnelOptionsRequest < Struct.new( :vpn_connection_id, :vpn_tunnel_outside_ip_address, :tunnel_options, :dry_run, :skip_tunnel_replacement, :pre_shared_key_storage) SENSITIVE = [:tunnel_options] include Aws::Structure end |
#skip_tunnel_replacement ⇒ Boolean
Choose whether or not to trigger immediate tunnel replacement. This is only applicable when turning on or off ‘EnableTunnelLifecycleControl`.
Valid values: ‘True` | `False`
64408 64409 64410 64411 64412 64413 64414 64415 64416 64417 |
# File 'lib/aws-sdk-ec2/types.rb', line 64408 class ModifyVpnTunnelOptionsRequest < Struct.new( :vpn_connection_id, :vpn_tunnel_outside_ip_address, :tunnel_options, :dry_run, :skip_tunnel_replacement, :pre_shared_key_storage) SENSITIVE = [:tunnel_options] include Aws::Structure end |
#tunnel_options ⇒ Types::ModifyVpnTunnelOptionsSpecification
The tunnel options to modify.
64408 64409 64410 64411 64412 64413 64414 64415 64416 64417 |
# File 'lib/aws-sdk-ec2/types.rb', line 64408 class ModifyVpnTunnelOptionsRequest < Struct.new( :vpn_connection_id, :vpn_tunnel_outside_ip_address, :tunnel_options, :dry_run, :skip_tunnel_replacement, :pre_shared_key_storage) SENSITIVE = [:tunnel_options] include Aws::Structure end |
#vpn_connection_id ⇒ String
The ID of the Amazon Web Services Site-to-Site VPN connection.
64408 64409 64410 64411 64412 64413 64414 64415 64416 64417 |
# File 'lib/aws-sdk-ec2/types.rb', line 64408 class ModifyVpnTunnelOptionsRequest < Struct.new( :vpn_connection_id, :vpn_tunnel_outside_ip_address, :tunnel_options, :dry_run, :skip_tunnel_replacement, :pre_shared_key_storage) SENSITIVE = [:tunnel_options] include Aws::Structure end |
#vpn_tunnel_outside_ip_address ⇒ String
The external IP address of the VPN tunnel.
64408 64409 64410 64411 64412 64413 64414 64415 64416 64417 |
# File 'lib/aws-sdk-ec2/types.rb', line 64408 class ModifyVpnTunnelOptionsRequest < Struct.new( :vpn_connection_id, :vpn_tunnel_outside_ip_address, :tunnel_options, :dry_run, :skip_tunnel_replacement, :pre_shared_key_storage) SENSITIVE = [:tunnel_options] include Aws::Structure end |