Class: Aws::EC2::Types::MonitorInstancesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::MonitorInstancesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#instance_ids ⇒ Array<String>
The IDs of the instances.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
65600 65601 65602 65603 65604 65605 |
# File 'lib/aws-sdk-ec2/types.rb', line 65600 class MonitorInstancesRequest < Struct.new( :instance_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#instance_ids ⇒ Array<String>
The IDs of the instances.
65600 65601 65602 65603 65604 65605 |
# File 'lib/aws-sdk-ec2/types.rb', line 65600 class MonitorInstancesRequest < Struct.new( :instance_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |