Class: Aws::EC2::Types::MoveAddressToVpcRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


67310
67311
67312
67313
67314
67315
# File 'lib/aws-sdk-ec2/types.rb', line 67310

class MoveAddressToVpcRequest < Struct.new(
  :dry_run,
  :public_ip)
  SENSITIVE = []
  include Aws::Structure
end

#public_ipString

The Elastic IP address.

Returns:

  • (String)


67310
67311
67312
67313
67314
67315
# File 'lib/aws-sdk-ec2/types.rb', line 67310

class MoveAddressToVpcRequest < Struct.new(
  :dry_run,
  :public_ip)
  SENSITIVE = []
  include Aws::Structure
end