Class: Aws::EC2::Types::MoveAddressToVpcRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::MoveAddressToVpcRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#public_ip ⇒ String
The Elastic IP address.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
65647 65648 65649 65650 65651 65652 |
# File 'lib/aws-sdk-ec2/types.rb', line 65647 class MoveAddressToVpcRequest < Struct.new( :dry_run, :public_ip) SENSITIVE = [] include Aws::Structure end |
#public_ip ⇒ String
The Elastic IP address.
65647 65648 65649 65650 65651 65652 |
# File 'lib/aws-sdk-ec2/types.rb', line 65647 class MoveAddressToVpcRequest < Struct.new( :dry_run, :public_ip) SENSITIVE = [] include Aws::Structure end |