Class: Aws::EC2::Types::MoveByoipCidrToIpamRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::MoveByoipCidrToIpamRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cidr ⇒ String
The BYOIP CIDR.
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#ipam_pool_id ⇒ String
The IPAM pool ID.
-
#ipam_pool_owner ⇒ String
The Amazon Web Services account ID of the owner of the IPAM pool.
Instance Attribute Details
#cidr ⇒ String
The BYOIP CIDR.
67355 67356 67357 67358 67359 67360 67361 67362 |
# File 'lib/aws-sdk-ec2/types.rb', line 67355 class MoveByoipCidrToIpamRequest < Struct.new( :dry_run, :cidr, :ipam_pool_id, :ipam_pool_owner) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action
without actually making the request and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
67355 67356 67357 67358 67359 67360 67361 67362 |
# File 'lib/aws-sdk-ec2/types.rb', line 67355 class MoveByoipCidrToIpamRequest < Struct.new( :dry_run, :cidr, :ipam_pool_id, :ipam_pool_owner) SENSITIVE = [] include Aws::Structure end |
#ipam_pool_id ⇒ String
The IPAM pool ID.
67355 67356 67357 67358 67359 67360 67361 67362 |
# File 'lib/aws-sdk-ec2/types.rb', line 67355 class MoveByoipCidrToIpamRequest < Struct.new( :dry_run, :cidr, :ipam_pool_id, :ipam_pool_owner) SENSITIVE = [] include Aws::Structure end |
#ipam_pool_owner ⇒ String
The Amazon Web Services account ID of the owner of the IPAM pool.
67355 67356 67357 67358 67359 67360 67361 67362 |
# File 'lib/aws-sdk-ec2/types.rb', line 67355 class MoveByoipCidrToIpamRequest < Struct.new( :dry_run, :cidr, :ipam_pool_id, :ipam_pool_owner) SENSITIVE = [] include Aws::Structure end |