Class: Aws::EC2::Types::MoveByoipCidrToIpamRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cidrString

The BYOIP CIDR.

Returns:

  • (String)


66171
66172
66173
66174
66175
66176
66177
66178
# File 'lib/aws-sdk-ec2/types.rb', line 66171

class MoveByoipCidrToIpamRequest < Struct.new(
  :dry_run,
  :cidr,
  :ipam_pool_id,
  :ipam_pool_owner)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


66171
66172
66173
66174
66175
66176
66177
66178
# File 'lib/aws-sdk-ec2/types.rb', line 66171

class MoveByoipCidrToIpamRequest < Struct.new(
  :dry_run,
  :cidr,
  :ipam_pool_id,
  :ipam_pool_owner)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_pool_idString

The IPAM pool ID.

Returns:

  • (String)


66171
66172
66173
66174
66175
66176
66177
66178
# File 'lib/aws-sdk-ec2/types.rb', line 66171

class MoveByoipCidrToIpamRequest < Struct.new(
  :dry_run,
  :cidr,
  :ipam_pool_id,
  :ipam_pool_owner)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_pool_ownerString

The Amazon Web Services account ID of the owner of the IPAM pool.

Returns:

  • (String)


66171
66172
66173
66174
66175
66176
66177
66178
# File 'lib/aws-sdk-ec2/types.rb', line 66171

class MoveByoipCidrToIpamRequest < Struct.new(
  :dry_run,
  :cidr,
  :ipam_pool_id,
  :ipam_pool_owner)
  SENSITIVE = []
  include Aws::Structure
end