Class: Aws::EC2::Types::MoveCapacityReservationInstancesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensure Idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


68957
68958
68959
68960
68961
68962
68963
68964
68965
# File 'lib/aws-sdk-ec2/types.rb', line 68957

class MoveCapacityReservationInstancesRequest < Struct.new(
  :dry_run,
  :client_token,
  :source_capacity_reservation_id,
  :destination_capacity_reservation_id,
  :instance_count)
  SENSITIVE = []
  include Aws::Structure
end

#destination_capacity_reservation_idString

The ID of the Capacity Reservation that you want to move capacity into.

Returns:

  • (String)


68957
68958
68959
68960
68961
68962
68963
68964
68965
# File 'lib/aws-sdk-ec2/types.rb', line 68957

class MoveCapacityReservationInstancesRequest < Struct.new(
  :dry_run,
  :client_token,
  :source_capacity_reservation_id,
  :destination_capacity_reservation_id,
  :instance_count)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


68957
68958
68959
68960
68961
68962
68963
68964
68965
# File 'lib/aws-sdk-ec2/types.rb', line 68957

class MoveCapacityReservationInstancesRequest < Struct.new(
  :dry_run,
  :client_token,
  :source_capacity_reservation_id,
  :destination_capacity_reservation_id,
  :instance_count)
  SENSITIVE = []
  include Aws::Structure
end

#instance_countInteger

The number of instances that you want to move from the source Capacity Reservation.

Returns:

  • (Integer)


68957
68958
68959
68960
68961
68962
68963
68964
68965
# File 'lib/aws-sdk-ec2/types.rb', line 68957

class MoveCapacityReservationInstancesRequest < Struct.new(
  :dry_run,
  :client_token,
  :source_capacity_reservation_id,
  :destination_capacity_reservation_id,
  :instance_count)
  SENSITIVE = []
  include Aws::Structure
end

#source_capacity_reservation_idString

The ID of the Capacity Reservation from which you want to move capacity.

Returns:

  • (String)


68957
68958
68959
68960
68961
68962
68963
68964
68965
# File 'lib/aws-sdk-ec2/types.rb', line 68957

class MoveCapacityReservationInstancesRequest < Struct.new(
  :dry_run,
  :client_token,
  :source_capacity_reservation_id,
  :destination_capacity_reservation_id,
  :instance_count)
  SENSITIVE = []
  include Aws::Structure
end