Class: Aws::EC2::Types::MoveCapacityReservationInstancesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::MoveCapacityReservationInstancesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#destination_capacity_reservation_id ⇒ String
The ID of the Capacity Reservation that you want to move capacity into.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#instance_count ⇒ Integer
The number of instances that you want to move from the source Capacity Reservation.
-
#source_capacity_reservation_id ⇒ String
The ID of the Capacity Reservation from which you want to move capacity.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [Ensure Idempotency].
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html
66661 66662 66663 66664 66665 66666 66667 66668 66669 |
# File 'lib/aws-sdk-ec2/types.rb', line 66661 class MoveCapacityReservationInstancesRequest < Struct.new( :dry_run, :client_token, :source_capacity_reservation_id, :destination_capacity_reservation_id, :instance_count) SENSITIVE = [] include Aws::Structure end |
#destination_capacity_reservation_id ⇒ String
The ID of the Capacity Reservation that you want to move capacity into.
66661 66662 66663 66664 66665 66666 66667 66668 66669 |
# File 'lib/aws-sdk-ec2/types.rb', line 66661 class MoveCapacityReservationInstancesRequest < Struct.new( :dry_run, :client_token, :source_capacity_reservation_id, :destination_capacity_reservation_id, :instance_count) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
66661 66662 66663 66664 66665 66666 66667 66668 66669 |
# File 'lib/aws-sdk-ec2/types.rb', line 66661 class MoveCapacityReservationInstancesRequest < Struct.new( :dry_run, :client_token, :source_capacity_reservation_id, :destination_capacity_reservation_id, :instance_count) SENSITIVE = [] include Aws::Structure end |
#instance_count ⇒ Integer
The number of instances that you want to move from the source Capacity Reservation.
66661 66662 66663 66664 66665 66666 66667 66668 66669 |
# File 'lib/aws-sdk-ec2/types.rb', line 66661 class MoveCapacityReservationInstancesRequest < Struct.new( :dry_run, :client_token, :source_capacity_reservation_id, :destination_capacity_reservation_id, :instance_count) SENSITIVE = [] include Aws::Structure end |
#source_capacity_reservation_id ⇒ String
The ID of the Capacity Reservation from which you want to move capacity.
66661 66662 66663 66664 66665 66666 66667 66668 66669 |
# File 'lib/aws-sdk-ec2/types.rb', line 66661 class MoveCapacityReservationInstancesRequest < Struct.new( :dry_run, :client_token, :source_capacity_reservation_id, :destination_capacity_reservation_id, :instance_count) SENSITIVE = [] include Aws::Structure end |