Class: Aws::EC2::Types::MoveCapacityReservationInstancesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [Ensure Idempotency].

**A suitable default value is auto-generated.** You should normally not need to pass this option.

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html

Returns:

  • (String)


66063
66064
66065
66066
66067
66068
66069
66070
66071
# File 'lib/aws-sdk-ec2/types.rb', line 66063

class MoveCapacityReservationInstancesRequest < Struct.new(
  :dry_run,
  :client_token,
  :source_capacity_reservation_id,
  :destination_capacity_reservation_id,
  :instance_count)
  SENSITIVE = []
  include Aws::Structure
end

#destination_capacity_reservation_idString

The ID of the Capacity Reservation that you want to move capacity into.

Returns:

  • (String)


66063
66064
66065
66066
66067
66068
66069
66070
66071
# File 'lib/aws-sdk-ec2/types.rb', line 66063

class MoveCapacityReservationInstancesRequest < Struct.new(
  :dry_run,
  :client_token,
  :source_capacity_reservation_id,
  :destination_capacity_reservation_id,
  :instance_count)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


66063
66064
66065
66066
66067
66068
66069
66070
66071
# File 'lib/aws-sdk-ec2/types.rb', line 66063

class MoveCapacityReservationInstancesRequest < Struct.new(
  :dry_run,
  :client_token,
  :source_capacity_reservation_id,
  :destination_capacity_reservation_id,
  :instance_count)
  SENSITIVE = []
  include Aws::Structure
end

#instance_countInteger

The number of instances that you want to move from the source Capacity Reservation.

Returns:

  • (Integer)


66063
66064
66065
66066
66067
66068
66069
66070
66071
# File 'lib/aws-sdk-ec2/types.rb', line 66063

class MoveCapacityReservationInstancesRequest < Struct.new(
  :dry_run,
  :client_token,
  :source_capacity_reservation_id,
  :destination_capacity_reservation_id,
  :instance_count)
  SENSITIVE = []
  include Aws::Structure
end

#source_capacity_reservation_idString

The ID of the Capacity Reservation from which you want to move capacity.

Returns:

  • (String)


66063
66064
66065
66066
66067
66068
66069
66070
66071
# File 'lib/aws-sdk-ec2/types.rb', line 66063

class MoveCapacityReservationInstancesRequest < Struct.new(
  :dry_run,
  :client_token,
  :source_capacity_reservation_id,
  :destination_capacity_reservation_id,
  :instance_count)
  SENSITIVE = []
  include Aws::Structure
end