Class: Aws::EC2::Types::NatGatewayAddress
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::NatGatewayAddress
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the IP addresses and network interface associated with a NAT gateway.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allocation_id ⇒ String
[Public NAT gateway only] The allocation ID of the Elastic IP address that’s associated with the NAT gateway.
-
#association_id ⇒ String
[Public NAT gateway only] The association ID of the Elastic IP address that’s associated with the NAT gateway.
-
#availability_zone ⇒ String
The Availability Zone where this Elastic IP address (EIP) is being used to handle outbound NAT traffic.
-
#availability_zone_id ⇒ String
The ID of the Availability Zone where this Elastic IP address (EIP) is being used to handle outbound NAT traffic.
-
#failure_message ⇒ String
The address failure message.
-
#is_primary ⇒ Boolean
Defines if the IP address is the primary address.
-
#network_interface_id ⇒ String
The ID of the network interface associated with the NAT gateway.
-
#private_ip ⇒ String
The private IP address associated with the NAT gateway.
-
#public_ip ⇒ String
[Public NAT gateway only] The Elastic IP address associated with the NAT gateway.
-
#status ⇒ String
The address status.
Instance Attribute Details
#allocation_id ⇒ String
[Public NAT gateway only] The allocation ID of the Elastic IP address that’s associated with the NAT gateway.
66043 66044 66045 66046 66047 66048 66049 66050 66051 66052 66053 66054 66055 66056 |
# File 'lib/aws-sdk-ec2/types.rb', line 66043 class NatGatewayAddress < Struct.new( :allocation_id, :network_interface_id, :private_ip, :public_ip, :association_id, :is_primary, :failure_message, :status, :availability_zone, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#association_id ⇒ String
[Public NAT gateway only] The association ID of the Elastic IP address that’s associated with the NAT gateway.
66043 66044 66045 66046 66047 66048 66049 66050 66051 66052 66053 66054 66055 66056 |
# File 'lib/aws-sdk-ec2/types.rb', line 66043 class NatGatewayAddress < Struct.new( :allocation_id, :network_interface_id, :private_ip, :public_ip, :association_id, :is_primary, :failure_message, :status, :availability_zone, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#availability_zone ⇒ String
The Availability Zone where this Elastic IP address (EIP) is being used to handle outbound NAT traffic.
66043 66044 66045 66046 66047 66048 66049 66050 66051 66052 66053 66054 66055 66056 |
# File 'lib/aws-sdk-ec2/types.rb', line 66043 class NatGatewayAddress < Struct.new( :allocation_id, :network_interface_id, :private_ip, :public_ip, :association_id, :is_primary, :failure_message, :status, :availability_zone, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
The ID of the Availability Zone where this Elastic IP address (EIP) is being used to handle outbound NAT traffic. Use this instead of AvailabilityZone for consistent identification of AZs across Amazon Web Services Regions.
66043 66044 66045 66046 66047 66048 66049 66050 66051 66052 66053 66054 66055 66056 |
# File 'lib/aws-sdk-ec2/types.rb', line 66043 class NatGatewayAddress < Struct.new( :allocation_id, :network_interface_id, :private_ip, :public_ip, :association_id, :is_primary, :failure_message, :status, :availability_zone, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#failure_message ⇒ String
The address failure message.
66043 66044 66045 66046 66047 66048 66049 66050 66051 66052 66053 66054 66055 66056 |
# File 'lib/aws-sdk-ec2/types.rb', line 66043 class NatGatewayAddress < Struct.new( :allocation_id, :network_interface_id, :private_ip, :public_ip, :association_id, :is_primary, :failure_message, :status, :availability_zone, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#is_primary ⇒ Boolean
Defines if the IP address is the primary address.
66043 66044 66045 66046 66047 66048 66049 66050 66051 66052 66053 66054 66055 66056 |
# File 'lib/aws-sdk-ec2/types.rb', line 66043 class NatGatewayAddress < Struct.new( :allocation_id, :network_interface_id, :private_ip, :public_ip, :association_id, :is_primary, :failure_message, :status, :availability_zone, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#network_interface_id ⇒ String
The ID of the network interface associated with the NAT gateway.
66043 66044 66045 66046 66047 66048 66049 66050 66051 66052 66053 66054 66055 66056 |
# File 'lib/aws-sdk-ec2/types.rb', line 66043 class NatGatewayAddress < Struct.new( :allocation_id, :network_interface_id, :private_ip, :public_ip, :association_id, :is_primary, :failure_message, :status, :availability_zone, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#private_ip ⇒ String
The private IP address associated with the NAT gateway.
66043 66044 66045 66046 66047 66048 66049 66050 66051 66052 66053 66054 66055 66056 |
# File 'lib/aws-sdk-ec2/types.rb', line 66043 class NatGatewayAddress < Struct.new( :allocation_id, :network_interface_id, :private_ip, :public_ip, :association_id, :is_primary, :failure_message, :status, :availability_zone, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#public_ip ⇒ String
[Public NAT gateway only] The Elastic IP address associated with the NAT gateway.
66043 66044 66045 66046 66047 66048 66049 66050 66051 66052 66053 66054 66055 66056 |
# File 'lib/aws-sdk-ec2/types.rb', line 66043 class NatGatewayAddress < Struct.new( :allocation_id, :network_interface_id, :private_ip, :public_ip, :association_id, :is_primary, :failure_message, :status, :availability_zone, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The address status.
66043 66044 66045 66046 66047 66048 66049 66050 66051 66052 66053 66054 66055 66056 |
# File 'lib/aws-sdk-ec2/types.rb', line 66043 class NatGatewayAddress < Struct.new( :allocation_id, :network_interface_id, :private_ip, :public_ip, :association_id, :is_primary, :failure_message, :status, :availability_zone, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |