Class: Aws::EC2::Types::NetworkCardInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::NetworkCardInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the network card support of the instance type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_flexible_network_interfaces ⇒ Integer
The number of additional network interfaces that can be attached to an instance when using flexible Elastic Network Adapter (ENA) queues.
-
#baseline_bandwidth_in_gbps ⇒ Float
The baseline network performance of the network card, in Gbps.
-
#default_ena_queue_count_per_interface ⇒ Integer
The default number of the ENA queues for each interface.
-
#maximum_ena_queue_count ⇒ Integer
The maximum number of the ENA queues.
-
#maximum_ena_queue_count_per_interface ⇒ Integer
The maximum number of the ENA queues for each interface.
-
#maximum_network_interfaces ⇒ Integer
The maximum number of network interfaces for the network card.
-
#network_card_index ⇒ Integer
The index of the network card.
-
#network_performance ⇒ String
The network performance of the network card.
-
#peak_bandwidth_in_gbps ⇒ Float
The peak (burst) network performance of the network card, in Gbps.
Instance Attribute Details
#additional_flexible_network_interfaces ⇒ Integer
The number of additional network interfaces that can be attached to
an instance when using flexible Elastic Network Adapter (ENA)
queues. This number is in addition to the base number specified by
maximumNetworkInterfaces.
71051 71052 71053 71054 71055 71056 71057 71058 71059 71060 71061 71062 71063 |
# File 'lib/aws-sdk-ec2/types.rb', line 71051 class NetworkCardInfo < Struct.new( :network_card_index, :network_performance, :maximum_network_interfaces, :additional_flexible_network_interfaces, :baseline_bandwidth_in_gbps, :peak_bandwidth_in_gbps, :default_ena_queue_count_per_interface, :maximum_ena_queue_count, :maximum_ena_queue_count_per_interface) SENSITIVE = [] include Aws::Structure end |
#baseline_bandwidth_in_gbps ⇒ Float
The baseline network performance of the network card, in Gbps.
71051 71052 71053 71054 71055 71056 71057 71058 71059 71060 71061 71062 71063 |
# File 'lib/aws-sdk-ec2/types.rb', line 71051 class NetworkCardInfo < Struct.new( :network_card_index, :network_performance, :maximum_network_interfaces, :additional_flexible_network_interfaces, :baseline_bandwidth_in_gbps, :peak_bandwidth_in_gbps, :default_ena_queue_count_per_interface, :maximum_ena_queue_count, :maximum_ena_queue_count_per_interface) SENSITIVE = [] include Aws::Structure end |
#default_ena_queue_count_per_interface ⇒ Integer
The default number of the ENA queues for each interface.
71051 71052 71053 71054 71055 71056 71057 71058 71059 71060 71061 71062 71063 |
# File 'lib/aws-sdk-ec2/types.rb', line 71051 class NetworkCardInfo < Struct.new( :network_card_index, :network_performance, :maximum_network_interfaces, :additional_flexible_network_interfaces, :baseline_bandwidth_in_gbps, :peak_bandwidth_in_gbps, :default_ena_queue_count_per_interface, :maximum_ena_queue_count, :maximum_ena_queue_count_per_interface) SENSITIVE = [] include Aws::Structure end |
#maximum_ena_queue_count ⇒ Integer
The maximum number of the ENA queues.
71051 71052 71053 71054 71055 71056 71057 71058 71059 71060 71061 71062 71063 |
# File 'lib/aws-sdk-ec2/types.rb', line 71051 class NetworkCardInfo < Struct.new( :network_card_index, :network_performance, :maximum_network_interfaces, :additional_flexible_network_interfaces, :baseline_bandwidth_in_gbps, :peak_bandwidth_in_gbps, :default_ena_queue_count_per_interface, :maximum_ena_queue_count, :maximum_ena_queue_count_per_interface) SENSITIVE = [] include Aws::Structure end |
#maximum_ena_queue_count_per_interface ⇒ Integer
The maximum number of the ENA queues for each interface.
71051 71052 71053 71054 71055 71056 71057 71058 71059 71060 71061 71062 71063 |
# File 'lib/aws-sdk-ec2/types.rb', line 71051 class NetworkCardInfo < Struct.new( :network_card_index, :network_performance, :maximum_network_interfaces, :additional_flexible_network_interfaces, :baseline_bandwidth_in_gbps, :peak_bandwidth_in_gbps, :default_ena_queue_count_per_interface, :maximum_ena_queue_count, :maximum_ena_queue_count_per_interface) SENSITIVE = [] include Aws::Structure end |
#maximum_network_interfaces ⇒ Integer
The maximum number of network interfaces for the network card.
71051 71052 71053 71054 71055 71056 71057 71058 71059 71060 71061 71062 71063 |
# File 'lib/aws-sdk-ec2/types.rb', line 71051 class NetworkCardInfo < Struct.new( :network_card_index, :network_performance, :maximum_network_interfaces, :additional_flexible_network_interfaces, :baseline_bandwidth_in_gbps, :peak_bandwidth_in_gbps, :default_ena_queue_count_per_interface, :maximum_ena_queue_count, :maximum_ena_queue_count_per_interface) SENSITIVE = [] include Aws::Structure end |
#network_card_index ⇒ Integer
The index of the network card.
71051 71052 71053 71054 71055 71056 71057 71058 71059 71060 71061 71062 71063 |
# File 'lib/aws-sdk-ec2/types.rb', line 71051 class NetworkCardInfo < Struct.new( :network_card_index, :network_performance, :maximum_network_interfaces, :additional_flexible_network_interfaces, :baseline_bandwidth_in_gbps, :peak_bandwidth_in_gbps, :default_ena_queue_count_per_interface, :maximum_ena_queue_count, :maximum_ena_queue_count_per_interface) SENSITIVE = [] include Aws::Structure end |
#network_performance ⇒ String
The network performance of the network card.
71051 71052 71053 71054 71055 71056 71057 71058 71059 71060 71061 71062 71063 |
# File 'lib/aws-sdk-ec2/types.rb', line 71051 class NetworkCardInfo < Struct.new( :network_card_index, :network_performance, :maximum_network_interfaces, :additional_flexible_network_interfaces, :baseline_bandwidth_in_gbps, :peak_bandwidth_in_gbps, :default_ena_queue_count_per_interface, :maximum_ena_queue_count, :maximum_ena_queue_count_per_interface) SENSITIVE = [] include Aws::Structure end |
#peak_bandwidth_in_gbps ⇒ Float
The peak (burst) network performance of the network card, in Gbps.
71051 71052 71053 71054 71055 71056 71057 71058 71059 71060 71061 71062 71063 |
# File 'lib/aws-sdk-ec2/types.rb', line 71051 class NetworkCardInfo < Struct.new( :network_card_index, :network_performance, :maximum_network_interfaces, :additional_flexible_network_interfaces, :baseline_bandwidth_in_gbps, :peak_bandwidth_in_gbps, :default_ena_queue_count_per_interface, :maximum_ena_queue_count, :maximum_ena_queue_count_per_interface) SENSITIVE = [] include Aws::Structure end |