Class: Aws::EC2::Types::NetworkCardInfo

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes the network card support of the instance type.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_flexible_network_interfacesInteger

The number of additional network interfaces that can be attached to an instance when using flexible Elastic Network Adapter (ENA) queues. This number is in addition to the base number specified by maximumNetworkInterfaces.

Returns:

  • (Integer)


67912
67913
67914
67915
67916
67917
67918
67919
67920
67921
67922
67923
67924
# File 'lib/aws-sdk-ec2/types.rb', line 67912

class NetworkCardInfo < Struct.new(
  :network_card_index,
  :network_performance,
  :maximum_network_interfaces,
  :additional_flexible_network_interfaces,
  :baseline_bandwidth_in_gbps,
  :peak_bandwidth_in_gbps,
  :default_ena_queue_count_per_interface,
  :maximum_ena_queue_count,
  :maximum_ena_queue_count_per_interface)
  SENSITIVE = []
  include Aws::Structure
end

#baseline_bandwidth_in_gbpsFloat

The baseline network performance of the network card, in Gbps.

Returns:

  • (Float)


67912
67913
67914
67915
67916
67917
67918
67919
67920
67921
67922
67923
67924
# File 'lib/aws-sdk-ec2/types.rb', line 67912

class NetworkCardInfo < Struct.new(
  :network_card_index,
  :network_performance,
  :maximum_network_interfaces,
  :additional_flexible_network_interfaces,
  :baseline_bandwidth_in_gbps,
  :peak_bandwidth_in_gbps,
  :default_ena_queue_count_per_interface,
  :maximum_ena_queue_count,
  :maximum_ena_queue_count_per_interface)
  SENSITIVE = []
  include Aws::Structure
end

#default_ena_queue_count_per_interfaceInteger

The default number of the ENA queues for each interface.

Returns:

  • (Integer)


67912
67913
67914
67915
67916
67917
67918
67919
67920
67921
67922
67923
67924
# File 'lib/aws-sdk-ec2/types.rb', line 67912

class NetworkCardInfo < Struct.new(
  :network_card_index,
  :network_performance,
  :maximum_network_interfaces,
  :additional_flexible_network_interfaces,
  :baseline_bandwidth_in_gbps,
  :peak_bandwidth_in_gbps,
  :default_ena_queue_count_per_interface,
  :maximum_ena_queue_count,
  :maximum_ena_queue_count_per_interface)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_ena_queue_countInteger

The maximum number of the ENA queues.

Returns:

  • (Integer)


67912
67913
67914
67915
67916
67917
67918
67919
67920
67921
67922
67923
67924
# File 'lib/aws-sdk-ec2/types.rb', line 67912

class NetworkCardInfo < Struct.new(
  :network_card_index,
  :network_performance,
  :maximum_network_interfaces,
  :additional_flexible_network_interfaces,
  :baseline_bandwidth_in_gbps,
  :peak_bandwidth_in_gbps,
  :default_ena_queue_count_per_interface,
  :maximum_ena_queue_count,
  :maximum_ena_queue_count_per_interface)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_ena_queue_count_per_interfaceInteger

The maximum number of the ENA queues for each interface.

Returns:

  • (Integer)


67912
67913
67914
67915
67916
67917
67918
67919
67920
67921
67922
67923
67924
# File 'lib/aws-sdk-ec2/types.rb', line 67912

class NetworkCardInfo < Struct.new(
  :network_card_index,
  :network_performance,
  :maximum_network_interfaces,
  :additional_flexible_network_interfaces,
  :baseline_bandwidth_in_gbps,
  :peak_bandwidth_in_gbps,
  :default_ena_queue_count_per_interface,
  :maximum_ena_queue_count,
  :maximum_ena_queue_count_per_interface)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_network_interfacesInteger

The maximum number of network interfaces for the network card.

Returns:

  • (Integer)


67912
67913
67914
67915
67916
67917
67918
67919
67920
67921
67922
67923
67924
# File 'lib/aws-sdk-ec2/types.rb', line 67912

class NetworkCardInfo < Struct.new(
  :network_card_index,
  :network_performance,
  :maximum_network_interfaces,
  :additional_flexible_network_interfaces,
  :baseline_bandwidth_in_gbps,
  :peak_bandwidth_in_gbps,
  :default_ena_queue_count_per_interface,
  :maximum_ena_queue_count,
  :maximum_ena_queue_count_per_interface)
  SENSITIVE = []
  include Aws::Structure
end

#network_card_indexInteger

The index of the network card.

Returns:

  • (Integer)


67912
67913
67914
67915
67916
67917
67918
67919
67920
67921
67922
67923
67924
# File 'lib/aws-sdk-ec2/types.rb', line 67912

class NetworkCardInfo < Struct.new(
  :network_card_index,
  :network_performance,
  :maximum_network_interfaces,
  :additional_flexible_network_interfaces,
  :baseline_bandwidth_in_gbps,
  :peak_bandwidth_in_gbps,
  :default_ena_queue_count_per_interface,
  :maximum_ena_queue_count,
  :maximum_ena_queue_count_per_interface)
  SENSITIVE = []
  include Aws::Structure
end

#network_performanceString

The network performance of the network card.

Returns:

  • (String)


67912
67913
67914
67915
67916
67917
67918
67919
67920
67921
67922
67923
67924
# File 'lib/aws-sdk-ec2/types.rb', line 67912

class NetworkCardInfo < Struct.new(
  :network_card_index,
  :network_performance,
  :maximum_network_interfaces,
  :additional_flexible_network_interfaces,
  :baseline_bandwidth_in_gbps,
  :peak_bandwidth_in_gbps,
  :default_ena_queue_count_per_interface,
  :maximum_ena_queue_count,
  :maximum_ena_queue_count_per_interface)
  SENSITIVE = []
  include Aws::Structure
end

#peak_bandwidth_in_gbpsFloat

The peak (burst) network performance of the network card, in Gbps.

Returns:

  • (Float)


67912
67913
67914
67915
67916
67917
67918
67919
67920
67921
67922
67923
67924
# File 'lib/aws-sdk-ec2/types.rb', line 67912

class NetworkCardInfo < Struct.new(
  :network_card_index,
  :network_performance,
  :maximum_network_interfaces,
  :additional_flexible_network_interfaces,
  :baseline_bandwidth_in_gbps,
  :peak_bandwidth_in_gbps,
  :default_ena_queue_count_per_interface,
  :maximum_ena_queue_count,
  :maximum_ena_queue_count_per_interface)
  SENSITIVE = []
  include Aws::Structure
end