Class: Aws::EC2::Types::NetworkInfo

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes the networking features of the instance type.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bandwidth_weightingsArray<String>

A list of valid settings for configurable bandwidth weighting for the instance type, if supported.

Returns:

  • (Array<String>)


66966
66967
66968
66969
66970
66971
66972
66973
66974
66975
66976
66977
66978
66979
66980
66981
66982
66983
66984
66985
66986
66987
66988
# File 'lib/aws-sdk-ec2/types.rb', line 66966

class NetworkInfo < Struct.new(
  :network_performance,
  :maximum_network_interfaces,
  :maximum_network_cards,
  :default_network_card_index,
  :network_cards,
  :ipv_4_addresses_per_interface,
  :ipv_6_addresses_per_interface,
  :ipv_6_supported,
  :ena_support,
  :efa_supported,
  :efa_info,
  :encryption_in_transit_supported,
  :ena_srd_supported,
  :bandwidth_weightings,
  :flexible_ena_queues_support,
  :connection_tracking_configuration,
  :secondary_network_supported,
  :maximum_secondary_network_interfaces,
  :ipv_4_addresses_per_secondary_interface)
  SENSITIVE = []
  include Aws::Structure
end

#connection_tracking_configurationTypes::DefaultConnectionTrackingConfiguration

Indicates conntrack information for the instance type



66966
66967
66968
66969
66970
66971
66972
66973
66974
66975
66976
66977
66978
66979
66980
66981
66982
66983
66984
66985
66986
66987
66988
# File 'lib/aws-sdk-ec2/types.rb', line 66966

class NetworkInfo < Struct.new(
  :network_performance,
  :maximum_network_interfaces,
  :maximum_network_cards,
  :default_network_card_index,
  :network_cards,
  :ipv_4_addresses_per_interface,
  :ipv_6_addresses_per_interface,
  :ipv_6_supported,
  :ena_support,
  :efa_supported,
  :efa_info,
  :encryption_in_transit_supported,
  :ena_srd_supported,
  :bandwidth_weightings,
  :flexible_ena_queues_support,
  :connection_tracking_configuration,
  :secondary_network_supported,
  :maximum_secondary_network_interfaces,
  :ipv_4_addresses_per_secondary_interface)
  SENSITIVE = []
  include Aws::Structure
end

#default_network_card_indexInteger

The index of the default network card, starting at 0.

Returns:

  • (Integer)


66966
66967
66968
66969
66970
66971
66972
66973
66974
66975
66976
66977
66978
66979
66980
66981
66982
66983
66984
66985
66986
66987
66988
# File 'lib/aws-sdk-ec2/types.rb', line 66966

class NetworkInfo < Struct.new(
  :network_performance,
  :maximum_network_interfaces,
  :maximum_network_cards,
  :default_network_card_index,
  :network_cards,
  :ipv_4_addresses_per_interface,
  :ipv_6_addresses_per_interface,
  :ipv_6_supported,
  :ena_support,
  :efa_supported,
  :efa_info,
  :encryption_in_transit_supported,
  :ena_srd_supported,
  :bandwidth_weightings,
  :flexible_ena_queues_support,
  :connection_tracking_configuration,
  :secondary_network_supported,
  :maximum_secondary_network_interfaces,
  :ipv_4_addresses_per_secondary_interface)
  SENSITIVE = []
  include Aws::Structure
end

#efa_infoTypes::EfaInfo

Describes the Elastic Fabric Adapters for the instance type.

Returns:



66966
66967
66968
66969
66970
66971
66972
66973
66974
66975
66976
66977
66978
66979
66980
66981
66982
66983
66984
66985
66986
66987
66988
# File 'lib/aws-sdk-ec2/types.rb', line 66966

class NetworkInfo < Struct.new(
  :network_performance,
  :maximum_network_interfaces,
  :maximum_network_cards,
  :default_network_card_index,
  :network_cards,
  :ipv_4_addresses_per_interface,
  :ipv_6_addresses_per_interface,
  :ipv_6_supported,
  :ena_support,
  :efa_supported,
  :efa_info,
  :encryption_in_transit_supported,
  :ena_srd_supported,
  :bandwidth_weightings,
  :flexible_ena_queues_support,
  :connection_tracking_configuration,
  :secondary_network_supported,
  :maximum_secondary_network_interfaces,
  :ipv_4_addresses_per_secondary_interface)
  SENSITIVE = []
  include Aws::Structure
end

#efa_supportedBoolean

Indicates whether Elastic Fabric Adapter (EFA) is supported.

Returns:

  • (Boolean)


66966
66967
66968
66969
66970
66971
66972
66973
66974
66975
66976
66977
66978
66979
66980
66981
66982
66983
66984
66985
66986
66987
66988
# File 'lib/aws-sdk-ec2/types.rb', line 66966

class NetworkInfo < Struct.new(
  :network_performance,
  :maximum_network_interfaces,
  :maximum_network_cards,
  :default_network_card_index,
  :network_cards,
  :ipv_4_addresses_per_interface,
  :ipv_6_addresses_per_interface,
  :ipv_6_supported,
  :ena_support,
  :efa_supported,
  :efa_info,
  :encryption_in_transit_supported,
  :ena_srd_supported,
  :bandwidth_weightings,
  :flexible_ena_queues_support,
  :connection_tracking_configuration,
  :secondary_network_supported,
  :maximum_secondary_network_interfaces,
  :ipv_4_addresses_per_secondary_interface)
  SENSITIVE = []
  include Aws::Structure
end

#ena_srd_supportedBoolean

Indicates whether the instance type supports ENA Express. ENA Express uses Amazon Web Services Scalable Reliable Datagram (SRD) technology to increase the maximum bandwidth used per stream and minimize tail latency of network traffic between EC2 instances.

Returns:

  • (Boolean)


66966
66967
66968
66969
66970
66971
66972
66973
66974
66975
66976
66977
66978
66979
66980
66981
66982
66983
66984
66985
66986
66987
66988
# File 'lib/aws-sdk-ec2/types.rb', line 66966

class NetworkInfo < Struct.new(
  :network_performance,
  :maximum_network_interfaces,
  :maximum_network_cards,
  :default_network_card_index,
  :network_cards,
  :ipv_4_addresses_per_interface,
  :ipv_6_addresses_per_interface,
  :ipv_6_supported,
  :ena_support,
  :efa_supported,
  :efa_info,
  :encryption_in_transit_supported,
  :ena_srd_supported,
  :bandwidth_weightings,
  :flexible_ena_queues_support,
  :connection_tracking_configuration,
  :secondary_network_supported,
  :maximum_secondary_network_interfaces,
  :ipv_4_addresses_per_secondary_interface)
  SENSITIVE = []
  include Aws::Structure
end

#ena_supportString

Indicates whether Elastic Network Adapter (ENA) is supported.

Returns:

  • (String)


66966
66967
66968
66969
66970
66971
66972
66973
66974
66975
66976
66977
66978
66979
66980
66981
66982
66983
66984
66985
66986
66987
66988
# File 'lib/aws-sdk-ec2/types.rb', line 66966

class NetworkInfo < Struct.new(
  :network_performance,
  :maximum_network_interfaces,
  :maximum_network_cards,
  :default_network_card_index,
  :network_cards,
  :ipv_4_addresses_per_interface,
  :ipv_6_addresses_per_interface,
  :ipv_6_supported,
  :ena_support,
  :efa_supported,
  :efa_info,
  :encryption_in_transit_supported,
  :ena_srd_supported,
  :bandwidth_weightings,
  :flexible_ena_queues_support,
  :connection_tracking_configuration,
  :secondary_network_supported,
  :maximum_secondary_network_interfaces,
  :ipv_4_addresses_per_secondary_interface)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_in_transit_supportedBoolean

Indicates whether the instance type automatically encrypts in-transit traffic between instances.

Returns:

  • (Boolean)


66966
66967
66968
66969
66970
66971
66972
66973
66974
66975
66976
66977
66978
66979
66980
66981
66982
66983
66984
66985
66986
66987
66988
# File 'lib/aws-sdk-ec2/types.rb', line 66966

class NetworkInfo < Struct.new(
  :network_performance,
  :maximum_network_interfaces,
  :maximum_network_cards,
  :default_network_card_index,
  :network_cards,
  :ipv_4_addresses_per_interface,
  :ipv_6_addresses_per_interface,
  :ipv_6_supported,
  :ena_support,
  :efa_supported,
  :efa_info,
  :encryption_in_transit_supported,
  :ena_srd_supported,
  :bandwidth_weightings,
  :flexible_ena_queues_support,
  :connection_tracking_configuration,
  :secondary_network_supported,
  :maximum_secondary_network_interfaces,
  :ipv_4_addresses_per_secondary_interface)
  SENSITIVE = []
  include Aws::Structure
end

#flexible_ena_queues_supportString

Indicates whether changing the number of ENA queues is supported.

Returns:

  • (String)


66966
66967
66968
66969
66970
66971
66972
66973
66974
66975
66976
66977
66978
66979
66980
66981
66982
66983
66984
66985
66986
66987
66988
# File 'lib/aws-sdk-ec2/types.rb', line 66966

class NetworkInfo < Struct.new(
  :network_performance,
  :maximum_network_interfaces,
  :maximum_network_cards,
  :default_network_card_index,
  :network_cards,
  :ipv_4_addresses_per_interface,
  :ipv_6_addresses_per_interface,
  :ipv_6_supported,
  :ena_support,
  :efa_supported,
  :efa_info,
  :encryption_in_transit_supported,
  :ena_srd_supported,
  :bandwidth_weightings,
  :flexible_ena_queues_support,
  :connection_tracking_configuration,
  :secondary_network_supported,
  :maximum_secondary_network_interfaces,
  :ipv_4_addresses_per_secondary_interface)
  SENSITIVE = []
  include Aws::Structure
end

#ipv_4_addresses_per_interfaceInteger

The maximum number of IPv4 addresses per network interface.

Returns:

  • (Integer)


66966
66967
66968
66969
66970
66971
66972
66973
66974
66975
66976
66977
66978
66979
66980
66981
66982
66983
66984
66985
66986
66987
66988
# File 'lib/aws-sdk-ec2/types.rb', line 66966

class NetworkInfo < Struct.new(
  :network_performance,
  :maximum_network_interfaces,
  :maximum_network_cards,
  :default_network_card_index,
  :network_cards,
  :ipv_4_addresses_per_interface,
  :ipv_6_addresses_per_interface,
  :ipv_6_supported,
  :ena_support,
  :efa_supported,
  :efa_info,
  :encryption_in_transit_supported,
  :ena_srd_supported,
  :bandwidth_weightings,
  :flexible_ena_queues_support,
  :connection_tracking_configuration,
  :secondary_network_supported,
  :maximum_secondary_network_interfaces,
  :ipv_4_addresses_per_secondary_interface)
  SENSITIVE = []
  include Aws::Structure
end

#ipv_4_addresses_per_secondary_interfaceInteger

The maximum number of IPv4 addresses per secondary interface.

Returns:

  • (Integer)


66966
66967
66968
66969
66970
66971
66972
66973
66974
66975
66976
66977
66978
66979
66980
66981
66982
66983
66984
66985
66986
66987
66988
# File 'lib/aws-sdk-ec2/types.rb', line 66966

class NetworkInfo < Struct.new(
  :network_performance,
  :maximum_network_interfaces,
  :maximum_network_cards,
  :default_network_card_index,
  :network_cards,
  :ipv_4_addresses_per_interface,
  :ipv_6_addresses_per_interface,
  :ipv_6_supported,
  :ena_support,
  :efa_supported,
  :efa_info,
  :encryption_in_transit_supported,
  :ena_srd_supported,
  :bandwidth_weightings,
  :flexible_ena_queues_support,
  :connection_tracking_configuration,
  :secondary_network_supported,
  :maximum_secondary_network_interfaces,
  :ipv_4_addresses_per_secondary_interface)
  SENSITIVE = []
  include Aws::Structure
end

#ipv_6_addresses_per_interfaceInteger

The maximum number of IPv6 addresses per network interface.

Returns:

  • (Integer)


66966
66967
66968
66969
66970
66971
66972
66973
66974
66975
66976
66977
66978
66979
66980
66981
66982
66983
66984
66985
66986
66987
66988
# File 'lib/aws-sdk-ec2/types.rb', line 66966

class NetworkInfo < Struct.new(
  :network_performance,
  :maximum_network_interfaces,
  :maximum_network_cards,
  :default_network_card_index,
  :network_cards,
  :ipv_4_addresses_per_interface,
  :ipv_6_addresses_per_interface,
  :ipv_6_supported,
  :ena_support,
  :efa_supported,
  :efa_info,
  :encryption_in_transit_supported,
  :ena_srd_supported,
  :bandwidth_weightings,
  :flexible_ena_queues_support,
  :connection_tracking_configuration,
  :secondary_network_supported,
  :maximum_secondary_network_interfaces,
  :ipv_4_addresses_per_secondary_interface)
  SENSITIVE = []
  include Aws::Structure
end

#ipv_6_supportedBoolean

Indicates whether IPv6 is supported.

Returns:

  • (Boolean)


66966
66967
66968
66969
66970
66971
66972
66973
66974
66975
66976
66977
66978
66979
66980
66981
66982
66983
66984
66985
66986
66987
66988
# File 'lib/aws-sdk-ec2/types.rb', line 66966

class NetworkInfo < Struct.new(
  :network_performance,
  :maximum_network_interfaces,
  :maximum_network_cards,
  :default_network_card_index,
  :network_cards,
  :ipv_4_addresses_per_interface,
  :ipv_6_addresses_per_interface,
  :ipv_6_supported,
  :ena_support,
  :efa_supported,
  :efa_info,
  :encryption_in_transit_supported,
  :ena_srd_supported,
  :bandwidth_weightings,
  :flexible_ena_queues_support,
  :connection_tracking_configuration,
  :secondary_network_supported,
  :maximum_secondary_network_interfaces,
  :ipv_4_addresses_per_secondary_interface)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_network_cardsInteger

The maximum number of physical network cards that can be allocated to the instance.

Returns:

  • (Integer)


66966
66967
66968
66969
66970
66971
66972
66973
66974
66975
66976
66977
66978
66979
66980
66981
66982
66983
66984
66985
66986
66987
66988
# File 'lib/aws-sdk-ec2/types.rb', line 66966

class NetworkInfo < Struct.new(
  :network_performance,
  :maximum_network_interfaces,
  :maximum_network_cards,
  :default_network_card_index,
  :network_cards,
  :ipv_4_addresses_per_interface,
  :ipv_6_addresses_per_interface,
  :ipv_6_supported,
  :ena_support,
  :efa_supported,
  :efa_info,
  :encryption_in_transit_supported,
  :ena_srd_supported,
  :bandwidth_weightings,
  :flexible_ena_queues_support,
  :connection_tracking_configuration,
  :secondary_network_supported,
  :maximum_secondary_network_interfaces,
  :ipv_4_addresses_per_secondary_interface)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_network_interfacesInteger

The maximum number of network interfaces for the instance type.

Returns:

  • (Integer)


66966
66967
66968
66969
66970
66971
66972
66973
66974
66975
66976
66977
66978
66979
66980
66981
66982
66983
66984
66985
66986
66987
66988
# File 'lib/aws-sdk-ec2/types.rb', line 66966

class NetworkInfo < Struct.new(
  :network_performance,
  :maximum_network_interfaces,
  :maximum_network_cards,
  :default_network_card_index,
  :network_cards,
  :ipv_4_addresses_per_interface,
  :ipv_6_addresses_per_interface,
  :ipv_6_supported,
  :ena_support,
  :efa_supported,
  :efa_info,
  :encryption_in_transit_supported,
  :ena_srd_supported,
  :bandwidth_weightings,
  :flexible_ena_queues_support,
  :connection_tracking_configuration,
  :secondary_network_supported,
  :maximum_secondary_network_interfaces,
  :ipv_4_addresses_per_secondary_interface)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_secondary_network_interfacesInteger

The maximum number of secondary interfaces for the instance type.

Returns:

  • (Integer)


66966
66967
66968
66969
66970
66971
66972
66973
66974
66975
66976
66977
66978
66979
66980
66981
66982
66983
66984
66985
66986
66987
66988
# File 'lib/aws-sdk-ec2/types.rb', line 66966

class NetworkInfo < Struct.new(
  :network_performance,
  :maximum_network_interfaces,
  :maximum_network_cards,
  :default_network_card_index,
  :network_cards,
  :ipv_4_addresses_per_interface,
  :ipv_6_addresses_per_interface,
  :ipv_6_supported,
  :ena_support,
  :efa_supported,
  :efa_info,
  :encryption_in_transit_supported,
  :ena_srd_supported,
  :bandwidth_weightings,
  :flexible_ena_queues_support,
  :connection_tracking_configuration,
  :secondary_network_supported,
  :maximum_secondary_network_interfaces,
  :ipv_4_addresses_per_secondary_interface)
  SENSITIVE = []
  include Aws::Structure
end

#network_cardsArray<Types::NetworkCardInfo>

Describes the network cards for the instance type.

Returns:



66966
66967
66968
66969
66970
66971
66972
66973
66974
66975
66976
66977
66978
66979
66980
66981
66982
66983
66984
66985
66986
66987
66988
# File 'lib/aws-sdk-ec2/types.rb', line 66966

class NetworkInfo < Struct.new(
  :network_performance,
  :maximum_network_interfaces,
  :maximum_network_cards,
  :default_network_card_index,
  :network_cards,
  :ipv_4_addresses_per_interface,
  :ipv_6_addresses_per_interface,
  :ipv_6_supported,
  :ena_support,
  :efa_supported,
  :efa_info,
  :encryption_in_transit_supported,
  :ena_srd_supported,
  :bandwidth_weightings,
  :flexible_ena_queues_support,
  :connection_tracking_configuration,
  :secondary_network_supported,
  :maximum_secondary_network_interfaces,
  :ipv_4_addresses_per_secondary_interface)
  SENSITIVE = []
  include Aws::Structure
end

#network_performanceString

The network performance.

Returns:

  • (String)


66966
66967
66968
66969
66970
66971
66972
66973
66974
66975
66976
66977
66978
66979
66980
66981
66982
66983
66984
66985
66986
66987
66988
# File 'lib/aws-sdk-ec2/types.rb', line 66966

class NetworkInfo < Struct.new(
  :network_performance,
  :maximum_network_interfaces,
  :maximum_network_cards,
  :default_network_card_index,
  :network_cards,
  :ipv_4_addresses_per_interface,
  :ipv_6_addresses_per_interface,
  :ipv_6_supported,
  :ena_support,
  :efa_supported,
  :efa_info,
  :encryption_in_transit_supported,
  :ena_srd_supported,
  :bandwidth_weightings,
  :flexible_ena_queues_support,
  :connection_tracking_configuration,
  :secondary_network_supported,
  :maximum_secondary_network_interfaces,
  :ipv_4_addresses_per_secondary_interface)
  SENSITIVE = []
  include Aws::Structure
end

#secondary_network_supportedBoolean

Indicates whether secondary interface attachments from secondary network are supported.

Returns:

  • (Boolean)


66966
66967
66968
66969
66970
66971
66972
66973
66974
66975
66976
66977
66978
66979
66980
66981
66982
66983
66984
66985
66986
66987
66988
# File 'lib/aws-sdk-ec2/types.rb', line 66966

class NetworkInfo < Struct.new(
  :network_performance,
  :maximum_network_interfaces,
  :maximum_network_cards,
  :default_network_card_index,
  :network_cards,
  :ipv_4_addresses_per_interface,
  :ipv_6_addresses_per_interface,
  :ipv_6_supported,
  :ena_support,
  :efa_supported,
  :efa_info,
  :encryption_in_transit_supported,
  :ena_srd_supported,
  :bandwidth_weightings,
  :flexible_ena_queues_support,
  :connection_tracking_configuration,
  :secondary_network_supported,
  :maximum_secondary_network_interfaces,
  :ipv_4_addresses_per_secondary_interface)
  SENSITIVE = []
  include Aws::Structure
end