Class: Aws::EC2::Types::NetworkInsightsAnalysis

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes a network insights analysis.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_accountsArray<String>

The member accounts that contain resources that the path can traverse.

Returns:

  • (Array<String>)


68192
68193
68194
68195
68196
68197
68198
68199
68200
68201
68202
68203
68204
68205
68206
68207
68208
68209
68210
68211
68212
# File 'lib/aws-sdk-ec2/types.rb', line 68192

class NetworkInsightsAnalysis < Struct.new(
  :network_insights_analysis_id,
  :network_insights_analysis_arn,
  :network_insights_path_id,
  :additional_accounts,
  :filter_in_arns,
  :filter_out_arns,
  :start_date,
  :status,
  :status_message,
  :warning_message,
  :network_path_found,
  :forward_path_components,
  :return_path_components,
  :explanations,
  :alternate_path_hints,
  :suggested_accounts,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#alternate_path_hintsArray<Types::AlternatePathHint>

Potential intermediate components.

Returns:



68192
68193
68194
68195
68196
68197
68198
68199
68200
68201
68202
68203
68204
68205
68206
68207
68208
68209
68210
68211
68212
# File 'lib/aws-sdk-ec2/types.rb', line 68192

class NetworkInsightsAnalysis < Struct.new(
  :network_insights_analysis_id,
  :network_insights_analysis_arn,
  :network_insights_path_id,
  :additional_accounts,
  :filter_in_arns,
  :filter_out_arns,
  :start_date,
  :status,
  :status_message,
  :warning_message,
  :network_path_found,
  :forward_path_components,
  :return_path_components,
  :explanations,
  :alternate_path_hints,
  :suggested_accounts,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#explanationsArray<Types::Explanation>

The explanations. For more information, see Reachability Analyzer explanation codes.

Returns:



68192
68193
68194
68195
68196
68197
68198
68199
68200
68201
68202
68203
68204
68205
68206
68207
68208
68209
68210
68211
68212
# File 'lib/aws-sdk-ec2/types.rb', line 68192

class NetworkInsightsAnalysis < Struct.new(
  :network_insights_analysis_id,
  :network_insights_analysis_arn,
  :network_insights_path_id,
  :additional_accounts,
  :filter_in_arns,
  :filter_out_arns,
  :start_date,
  :status,
  :status_message,
  :warning_message,
  :network_path_found,
  :forward_path_components,
  :return_path_components,
  :explanations,
  :alternate_path_hints,
  :suggested_accounts,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#filter_in_arnsArray<String>

The Amazon Resource Names (ARN) of the resources that the path must traverse.

Returns:

  • (Array<String>)


68192
68193
68194
68195
68196
68197
68198
68199
68200
68201
68202
68203
68204
68205
68206
68207
68208
68209
68210
68211
68212
# File 'lib/aws-sdk-ec2/types.rb', line 68192

class NetworkInsightsAnalysis < Struct.new(
  :network_insights_analysis_id,
  :network_insights_analysis_arn,
  :network_insights_path_id,
  :additional_accounts,
  :filter_in_arns,
  :filter_out_arns,
  :start_date,
  :status,
  :status_message,
  :warning_message,
  :network_path_found,
  :forward_path_components,
  :return_path_components,
  :explanations,
  :alternate_path_hints,
  :suggested_accounts,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#filter_out_arnsArray<String>

The Amazon Resource Names (ARN) of the resources that the path must ignore.

Returns:

  • (Array<String>)


68192
68193
68194
68195
68196
68197
68198
68199
68200
68201
68202
68203
68204
68205
68206
68207
68208
68209
68210
68211
68212
# File 'lib/aws-sdk-ec2/types.rb', line 68192

class NetworkInsightsAnalysis < Struct.new(
  :network_insights_analysis_id,
  :network_insights_analysis_arn,
  :network_insights_path_id,
  :additional_accounts,
  :filter_in_arns,
  :filter_out_arns,
  :start_date,
  :status,
  :status_message,
  :warning_message,
  :network_path_found,
  :forward_path_components,
  :return_path_components,
  :explanations,
  :alternate_path_hints,
  :suggested_accounts,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#forward_path_componentsArray<Types::PathComponent>

The components in the path from source to destination.

Returns:



68192
68193
68194
68195
68196
68197
68198
68199
68200
68201
68202
68203
68204
68205
68206
68207
68208
68209
68210
68211
68212
# File 'lib/aws-sdk-ec2/types.rb', line 68192

class NetworkInsightsAnalysis < Struct.new(
  :network_insights_analysis_id,
  :network_insights_analysis_arn,
  :network_insights_path_id,
  :additional_accounts,
  :filter_in_arns,
  :filter_out_arns,
  :start_date,
  :status,
  :status_message,
  :warning_message,
  :network_path_found,
  :forward_path_components,
  :return_path_components,
  :explanations,
  :alternate_path_hints,
  :suggested_accounts,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#network_insights_analysis_arnString

The Amazon Resource Name (ARN) of the network insights analysis.

Returns:

  • (String)


68192
68193
68194
68195
68196
68197
68198
68199
68200
68201
68202
68203
68204
68205
68206
68207
68208
68209
68210
68211
68212
# File 'lib/aws-sdk-ec2/types.rb', line 68192

class NetworkInsightsAnalysis < Struct.new(
  :network_insights_analysis_id,
  :network_insights_analysis_arn,
  :network_insights_path_id,
  :additional_accounts,
  :filter_in_arns,
  :filter_out_arns,
  :start_date,
  :status,
  :status_message,
  :warning_message,
  :network_path_found,
  :forward_path_components,
  :return_path_components,
  :explanations,
  :alternate_path_hints,
  :suggested_accounts,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#network_insights_analysis_idString

The ID of the network insights analysis.

Returns:

  • (String)


68192
68193
68194
68195
68196
68197
68198
68199
68200
68201
68202
68203
68204
68205
68206
68207
68208
68209
68210
68211
68212
# File 'lib/aws-sdk-ec2/types.rb', line 68192

class NetworkInsightsAnalysis < Struct.new(
  :network_insights_analysis_id,
  :network_insights_analysis_arn,
  :network_insights_path_id,
  :additional_accounts,
  :filter_in_arns,
  :filter_out_arns,
  :start_date,
  :status,
  :status_message,
  :warning_message,
  :network_path_found,
  :forward_path_components,
  :return_path_components,
  :explanations,
  :alternate_path_hints,
  :suggested_accounts,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#network_insights_path_idString

The ID of the path.

Returns:

  • (String)


68192
68193
68194
68195
68196
68197
68198
68199
68200
68201
68202
68203
68204
68205
68206
68207
68208
68209
68210
68211
68212
# File 'lib/aws-sdk-ec2/types.rb', line 68192

class NetworkInsightsAnalysis < Struct.new(
  :network_insights_analysis_id,
  :network_insights_analysis_arn,
  :network_insights_path_id,
  :additional_accounts,
  :filter_in_arns,
  :filter_out_arns,
  :start_date,
  :status,
  :status_message,
  :warning_message,
  :network_path_found,
  :forward_path_components,
  :return_path_components,
  :explanations,
  :alternate_path_hints,
  :suggested_accounts,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#network_path_foundBoolean

Indicates whether the destination is reachable from the source.

Returns:

  • (Boolean)


68192
68193
68194
68195
68196
68197
68198
68199
68200
68201
68202
68203
68204
68205
68206
68207
68208
68209
68210
68211
68212
# File 'lib/aws-sdk-ec2/types.rb', line 68192

class NetworkInsightsAnalysis < Struct.new(
  :network_insights_analysis_id,
  :network_insights_analysis_arn,
  :network_insights_path_id,
  :additional_accounts,
  :filter_in_arns,
  :filter_out_arns,
  :start_date,
  :status,
  :status_message,
  :warning_message,
  :network_path_found,
  :forward_path_components,
  :return_path_components,
  :explanations,
  :alternate_path_hints,
  :suggested_accounts,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#return_path_componentsArray<Types::PathComponent>

The components in the path from destination to source.

Returns:



68192
68193
68194
68195
68196
68197
68198
68199
68200
68201
68202
68203
68204
68205
68206
68207
68208
68209
68210
68211
68212
# File 'lib/aws-sdk-ec2/types.rb', line 68192

class NetworkInsightsAnalysis < Struct.new(
  :network_insights_analysis_id,
  :network_insights_analysis_arn,
  :network_insights_path_id,
  :additional_accounts,
  :filter_in_arns,
  :filter_out_arns,
  :start_date,
  :status,
  :status_message,
  :warning_message,
  :network_path_found,
  :forward_path_components,
  :return_path_components,
  :explanations,
  :alternate_path_hints,
  :suggested_accounts,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#start_dateTime

The time the analysis started.

Returns:

  • (Time)


68192
68193
68194
68195
68196
68197
68198
68199
68200
68201
68202
68203
68204
68205
68206
68207
68208
68209
68210
68211
68212
# File 'lib/aws-sdk-ec2/types.rb', line 68192

class NetworkInsightsAnalysis < Struct.new(
  :network_insights_analysis_id,
  :network_insights_analysis_arn,
  :network_insights_path_id,
  :additional_accounts,
  :filter_in_arns,
  :filter_out_arns,
  :start_date,
  :status,
  :status_message,
  :warning_message,
  :network_path_found,
  :forward_path_components,
  :return_path_components,
  :explanations,
  :alternate_path_hints,
  :suggested_accounts,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the network insights analysis.

Returns:

  • (String)


68192
68193
68194
68195
68196
68197
68198
68199
68200
68201
68202
68203
68204
68205
68206
68207
68208
68209
68210
68211
68212
# File 'lib/aws-sdk-ec2/types.rb', line 68192

class NetworkInsightsAnalysis < Struct.new(
  :network_insights_analysis_id,
  :network_insights_analysis_arn,
  :network_insights_path_id,
  :additional_accounts,
  :filter_in_arns,
  :filter_out_arns,
  :start_date,
  :status,
  :status_message,
  :warning_message,
  :network_path_found,
  :forward_path_components,
  :return_path_components,
  :explanations,
  :alternate_path_hints,
  :suggested_accounts,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#status_messageString

The status message, if the status is failed.

Returns:

  • (String)


68192
68193
68194
68195
68196
68197
68198
68199
68200
68201
68202
68203
68204
68205
68206
68207
68208
68209
68210
68211
68212
# File 'lib/aws-sdk-ec2/types.rb', line 68192

class NetworkInsightsAnalysis < Struct.new(
  :network_insights_analysis_id,
  :network_insights_analysis_arn,
  :network_insights_path_id,
  :additional_accounts,
  :filter_in_arns,
  :filter_out_arns,
  :start_date,
  :status,
  :status_message,
  :warning_message,
  :network_path_found,
  :forward_path_components,
  :return_path_components,
  :explanations,
  :alternate_path_hints,
  :suggested_accounts,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#suggested_accountsArray<String>

Potential intermediate accounts.

Returns:

  • (Array<String>)


68192
68193
68194
68195
68196
68197
68198
68199
68200
68201
68202
68203
68204
68205
68206
68207
68208
68209
68210
68211
68212
# File 'lib/aws-sdk-ec2/types.rb', line 68192

class NetworkInsightsAnalysis < Struct.new(
  :network_insights_analysis_id,
  :network_insights_analysis_arn,
  :network_insights_path_id,
  :additional_accounts,
  :filter_in_arns,
  :filter_out_arns,
  :start_date,
  :status,
  :status_message,
  :warning_message,
  :network_path_found,
  :forward_path_components,
  :return_path_components,
  :explanations,
  :alternate_path_hints,
  :suggested_accounts,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The tags.

Returns:



68192
68193
68194
68195
68196
68197
68198
68199
68200
68201
68202
68203
68204
68205
68206
68207
68208
68209
68210
68211
68212
# File 'lib/aws-sdk-ec2/types.rb', line 68192

class NetworkInsightsAnalysis < Struct.new(
  :network_insights_analysis_id,
  :network_insights_analysis_arn,
  :network_insights_path_id,
  :additional_accounts,
  :filter_in_arns,
  :filter_out_arns,
  :start_date,
  :status,
  :status_message,
  :warning_message,
  :network_path_found,
  :forward_path_components,
  :return_path_components,
  :explanations,
  :alternate_path_hints,
  :suggested_accounts,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#warning_messageString

The warning message.

Returns:

  • (String)


68192
68193
68194
68195
68196
68197
68198
68199
68200
68201
68202
68203
68204
68205
68206
68207
68208
68209
68210
68211
68212
# File 'lib/aws-sdk-ec2/types.rb', line 68192

class NetworkInsightsAnalysis < Struct.new(
  :network_insights_analysis_id,
  :network_insights_analysis_arn,
  :network_insights_path_id,
  :additional_accounts,
  :filter_in_arns,
  :filter_out_arns,
  :start_date,
  :status,
  :status_message,
  :warning_message,
  :network_path_found,
  :forward_path_components,
  :return_path_components,
  :explanations,
  :alternate_path_hints,
  :suggested_accounts,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end