Class: Aws::EC2::Types::NetworkInsightsAnalysis
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::NetworkInsightsAnalysis
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a network insights analysis.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_accounts ⇒ Array<String>
The member accounts that contain resources that the path can traverse.
-
#alternate_path_hints ⇒ Array<Types::AlternatePathHint>
Potential intermediate components.
-
#explanations ⇒ Array<Types::Explanation>
The explanations.
-
#filter_in_arns ⇒ Array<String>
The Amazon Resource Names (ARN) of the resources that the path must traverse.
-
#filter_out_arns ⇒ Array<String>
The Amazon Resource Names (ARN) of the resources that the path must ignore.
-
#forward_path_components ⇒ Array<Types::PathComponent>
The components in the path from source to destination.
-
#network_insights_analysis_arn ⇒ String
The Amazon Resource Name (ARN) of the network insights analysis.
-
#network_insights_analysis_id ⇒ String
The ID of the network insights analysis.
-
#network_insights_path_id ⇒ String
The ID of the path.
-
#network_path_found ⇒ Boolean
Indicates whether the destination is reachable from the source.
-
#return_path_components ⇒ Array<Types::PathComponent>
The components in the path from destination to source.
-
#start_date ⇒ Time
The time the analysis started.
-
#status ⇒ String
The status of the network insights analysis.
-
#status_message ⇒ String
The status message, if the status is ‘failed`.
-
#suggested_accounts ⇒ Array<String>
Potential intermediate accounts.
-
#tags ⇒ Array<Types::Tag>
The tags.
-
#warning_message ⇒ String
The warning message.
Instance Attribute Details
#additional_accounts ⇒ Array<String>
The member accounts that contain resources that the path can traverse.
67192 67193 67194 67195 67196 67197 67198 67199 67200 67201 67202 67203 67204 67205 67206 67207 67208 67209 67210 67211 67212 |
# File 'lib/aws-sdk-ec2/types.rb', line 67192 class NetworkInsightsAnalysis < Struct.new( :network_insights_analysis_id, :network_insights_analysis_arn, :network_insights_path_id, :additional_accounts, :filter_in_arns, :filter_out_arns, :start_date, :status, :status_message, :warning_message, :network_path_found, :forward_path_components, :return_path_components, :explanations, :alternate_path_hints, :suggested_accounts, :tags) SENSITIVE = [] include Aws::Structure end |
#alternate_path_hints ⇒ Array<Types::AlternatePathHint>
Potential intermediate components.
67192 67193 67194 67195 67196 67197 67198 67199 67200 67201 67202 67203 67204 67205 67206 67207 67208 67209 67210 67211 67212 |
# File 'lib/aws-sdk-ec2/types.rb', line 67192 class NetworkInsightsAnalysis < Struct.new( :network_insights_analysis_id, :network_insights_analysis_arn, :network_insights_path_id, :additional_accounts, :filter_in_arns, :filter_out_arns, :start_date, :status, :status_message, :warning_message, :network_path_found, :forward_path_components, :return_path_components, :explanations, :alternate_path_hints, :suggested_accounts, :tags) SENSITIVE = [] include Aws::Structure end |
#explanations ⇒ Array<Types::Explanation>
The explanations. For more information, see [Reachability Analyzer explanation codes].
[1]: docs.aws.amazon.com/vpc/latest/reachability/explanation-codes.html
67192 67193 67194 67195 67196 67197 67198 67199 67200 67201 67202 67203 67204 67205 67206 67207 67208 67209 67210 67211 67212 |
# File 'lib/aws-sdk-ec2/types.rb', line 67192 class NetworkInsightsAnalysis < Struct.new( :network_insights_analysis_id, :network_insights_analysis_arn, :network_insights_path_id, :additional_accounts, :filter_in_arns, :filter_out_arns, :start_date, :status, :status_message, :warning_message, :network_path_found, :forward_path_components, :return_path_components, :explanations, :alternate_path_hints, :suggested_accounts, :tags) SENSITIVE = [] include Aws::Structure end |
#filter_in_arns ⇒ Array<String>
The Amazon Resource Names (ARN) of the resources that the path must traverse.
67192 67193 67194 67195 67196 67197 67198 67199 67200 67201 67202 67203 67204 67205 67206 67207 67208 67209 67210 67211 67212 |
# File 'lib/aws-sdk-ec2/types.rb', line 67192 class NetworkInsightsAnalysis < Struct.new( :network_insights_analysis_id, :network_insights_analysis_arn, :network_insights_path_id, :additional_accounts, :filter_in_arns, :filter_out_arns, :start_date, :status, :status_message, :warning_message, :network_path_found, :forward_path_components, :return_path_components, :explanations, :alternate_path_hints, :suggested_accounts, :tags) SENSITIVE = [] include Aws::Structure end |
#filter_out_arns ⇒ Array<String>
The Amazon Resource Names (ARN) of the resources that the path must ignore.
67192 67193 67194 67195 67196 67197 67198 67199 67200 67201 67202 67203 67204 67205 67206 67207 67208 67209 67210 67211 67212 |
# File 'lib/aws-sdk-ec2/types.rb', line 67192 class NetworkInsightsAnalysis < Struct.new( :network_insights_analysis_id, :network_insights_analysis_arn, :network_insights_path_id, :additional_accounts, :filter_in_arns, :filter_out_arns, :start_date, :status, :status_message, :warning_message, :network_path_found, :forward_path_components, :return_path_components, :explanations, :alternate_path_hints, :suggested_accounts, :tags) SENSITIVE = [] include Aws::Structure end |
#forward_path_components ⇒ Array<Types::PathComponent>
The components in the path from source to destination.
67192 67193 67194 67195 67196 67197 67198 67199 67200 67201 67202 67203 67204 67205 67206 67207 67208 67209 67210 67211 67212 |
# File 'lib/aws-sdk-ec2/types.rb', line 67192 class NetworkInsightsAnalysis < Struct.new( :network_insights_analysis_id, :network_insights_analysis_arn, :network_insights_path_id, :additional_accounts, :filter_in_arns, :filter_out_arns, :start_date, :status, :status_message, :warning_message, :network_path_found, :forward_path_components, :return_path_components, :explanations, :alternate_path_hints, :suggested_accounts, :tags) SENSITIVE = [] include Aws::Structure end |
#network_insights_analysis_arn ⇒ String
The Amazon Resource Name (ARN) of the network insights analysis.
67192 67193 67194 67195 67196 67197 67198 67199 67200 67201 67202 67203 67204 67205 67206 67207 67208 67209 67210 67211 67212 |
# File 'lib/aws-sdk-ec2/types.rb', line 67192 class NetworkInsightsAnalysis < Struct.new( :network_insights_analysis_id, :network_insights_analysis_arn, :network_insights_path_id, :additional_accounts, :filter_in_arns, :filter_out_arns, :start_date, :status, :status_message, :warning_message, :network_path_found, :forward_path_components, :return_path_components, :explanations, :alternate_path_hints, :suggested_accounts, :tags) SENSITIVE = [] include Aws::Structure end |
#network_insights_analysis_id ⇒ String
The ID of the network insights analysis.
67192 67193 67194 67195 67196 67197 67198 67199 67200 67201 67202 67203 67204 67205 67206 67207 67208 67209 67210 67211 67212 |
# File 'lib/aws-sdk-ec2/types.rb', line 67192 class NetworkInsightsAnalysis < Struct.new( :network_insights_analysis_id, :network_insights_analysis_arn, :network_insights_path_id, :additional_accounts, :filter_in_arns, :filter_out_arns, :start_date, :status, :status_message, :warning_message, :network_path_found, :forward_path_components, :return_path_components, :explanations, :alternate_path_hints, :suggested_accounts, :tags) SENSITIVE = [] include Aws::Structure end |
#network_insights_path_id ⇒ String
The ID of the path.
67192 67193 67194 67195 67196 67197 67198 67199 67200 67201 67202 67203 67204 67205 67206 67207 67208 67209 67210 67211 67212 |
# File 'lib/aws-sdk-ec2/types.rb', line 67192 class NetworkInsightsAnalysis < Struct.new( :network_insights_analysis_id, :network_insights_analysis_arn, :network_insights_path_id, :additional_accounts, :filter_in_arns, :filter_out_arns, :start_date, :status, :status_message, :warning_message, :network_path_found, :forward_path_components, :return_path_components, :explanations, :alternate_path_hints, :suggested_accounts, :tags) SENSITIVE = [] include Aws::Structure end |
#network_path_found ⇒ Boolean
Indicates whether the destination is reachable from the source.
67192 67193 67194 67195 67196 67197 67198 67199 67200 67201 67202 67203 67204 67205 67206 67207 67208 67209 67210 67211 67212 |
# File 'lib/aws-sdk-ec2/types.rb', line 67192 class NetworkInsightsAnalysis < Struct.new( :network_insights_analysis_id, :network_insights_analysis_arn, :network_insights_path_id, :additional_accounts, :filter_in_arns, :filter_out_arns, :start_date, :status, :status_message, :warning_message, :network_path_found, :forward_path_components, :return_path_components, :explanations, :alternate_path_hints, :suggested_accounts, :tags) SENSITIVE = [] include Aws::Structure end |
#return_path_components ⇒ Array<Types::PathComponent>
The components in the path from destination to source.
67192 67193 67194 67195 67196 67197 67198 67199 67200 67201 67202 67203 67204 67205 67206 67207 67208 67209 67210 67211 67212 |
# File 'lib/aws-sdk-ec2/types.rb', line 67192 class NetworkInsightsAnalysis < Struct.new( :network_insights_analysis_id, :network_insights_analysis_arn, :network_insights_path_id, :additional_accounts, :filter_in_arns, :filter_out_arns, :start_date, :status, :status_message, :warning_message, :network_path_found, :forward_path_components, :return_path_components, :explanations, :alternate_path_hints, :suggested_accounts, :tags) SENSITIVE = [] include Aws::Structure end |
#start_date ⇒ Time
The time the analysis started.
67192 67193 67194 67195 67196 67197 67198 67199 67200 67201 67202 67203 67204 67205 67206 67207 67208 67209 67210 67211 67212 |
# File 'lib/aws-sdk-ec2/types.rb', line 67192 class NetworkInsightsAnalysis < Struct.new( :network_insights_analysis_id, :network_insights_analysis_arn, :network_insights_path_id, :additional_accounts, :filter_in_arns, :filter_out_arns, :start_date, :status, :status_message, :warning_message, :network_path_found, :forward_path_components, :return_path_components, :explanations, :alternate_path_hints, :suggested_accounts, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the network insights analysis.
67192 67193 67194 67195 67196 67197 67198 67199 67200 67201 67202 67203 67204 67205 67206 67207 67208 67209 67210 67211 67212 |
# File 'lib/aws-sdk-ec2/types.rb', line 67192 class NetworkInsightsAnalysis < Struct.new( :network_insights_analysis_id, :network_insights_analysis_arn, :network_insights_path_id, :additional_accounts, :filter_in_arns, :filter_out_arns, :start_date, :status, :status_message, :warning_message, :network_path_found, :forward_path_components, :return_path_components, :explanations, :alternate_path_hints, :suggested_accounts, :tags) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
The status message, if the status is ‘failed`.
67192 67193 67194 67195 67196 67197 67198 67199 67200 67201 67202 67203 67204 67205 67206 67207 67208 67209 67210 67211 67212 |
# File 'lib/aws-sdk-ec2/types.rb', line 67192 class NetworkInsightsAnalysis < Struct.new( :network_insights_analysis_id, :network_insights_analysis_arn, :network_insights_path_id, :additional_accounts, :filter_in_arns, :filter_out_arns, :start_date, :status, :status_message, :warning_message, :network_path_found, :forward_path_components, :return_path_components, :explanations, :alternate_path_hints, :suggested_accounts, :tags) SENSITIVE = [] include Aws::Structure end |
#suggested_accounts ⇒ Array<String>
Potential intermediate accounts.
67192 67193 67194 67195 67196 67197 67198 67199 67200 67201 67202 67203 67204 67205 67206 67207 67208 67209 67210 67211 67212 |
# File 'lib/aws-sdk-ec2/types.rb', line 67192 class NetworkInsightsAnalysis < Struct.new( :network_insights_analysis_id, :network_insights_analysis_arn, :network_insights_path_id, :additional_accounts, :filter_in_arns, :filter_out_arns, :start_date, :status, :status_message, :warning_message, :network_path_found, :forward_path_components, :return_path_components, :explanations, :alternate_path_hints, :suggested_accounts, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags.
67192 67193 67194 67195 67196 67197 67198 67199 67200 67201 67202 67203 67204 67205 67206 67207 67208 67209 67210 67211 67212 |
# File 'lib/aws-sdk-ec2/types.rb', line 67192 class NetworkInsightsAnalysis < Struct.new( :network_insights_analysis_id, :network_insights_analysis_arn, :network_insights_path_id, :additional_accounts, :filter_in_arns, :filter_out_arns, :start_date, :status, :status_message, :warning_message, :network_path_found, :forward_path_components, :return_path_components, :explanations, :alternate_path_hints, :suggested_accounts, :tags) SENSITIVE = [] include Aws::Structure end |
#warning_message ⇒ String
The warning message.
67192 67193 67194 67195 67196 67197 67198 67199 67200 67201 67202 67203 67204 67205 67206 67207 67208 67209 67210 67211 67212 |
# File 'lib/aws-sdk-ec2/types.rb', line 67192 class NetworkInsightsAnalysis < Struct.new( :network_insights_analysis_id, :network_insights_analysis_arn, :network_insights_path_id, :additional_accounts, :filter_in_arns, :filter_out_arns, :start_date, :status, :status_message, :warning_message, :network_path_found, :forward_path_components, :return_path_components, :explanations, :alternate_path_hints, :suggested_accounts, :tags) SENSITIVE = [] include Aws::Structure end |