Class: Aws::EC2::Types::NetworkInsightsPath

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes a path.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_dateTime

The time stamp when the path was created.

Returns:

  • (Time)


70004
70005
70006
70007
70008
70009
70010
70011
70012
70013
70014
70015
70016
70017
70018
70019
70020
70021
# File 'lib/aws-sdk-ec2/types.rb', line 70004

class NetworkInsightsPath < Struct.new(
  :network_insights_path_id,
  :network_insights_path_arn,
  :created_date,
  :source,
  :destination,
  :source_arn,
  :destination_arn,
  :source_ip,
  :destination_ip,
  :protocol,
  :destination_port,
  :tags,
  :filter_at_source,
  :filter_at_destination)
  SENSITIVE = []
  include Aws::Structure
end

#destinationString

The ID of the destination.

Returns:

  • (String)


70004
70005
70006
70007
70008
70009
70010
70011
70012
70013
70014
70015
70016
70017
70018
70019
70020
70021
# File 'lib/aws-sdk-ec2/types.rb', line 70004

class NetworkInsightsPath < Struct.new(
  :network_insights_path_id,
  :network_insights_path_arn,
  :created_date,
  :source,
  :destination,
  :source_arn,
  :destination_arn,
  :source_ip,
  :destination_ip,
  :protocol,
  :destination_port,
  :tags,
  :filter_at_source,
  :filter_at_destination)
  SENSITIVE = []
  include Aws::Structure
end

#destination_arnString

The Amazon Resource Name (ARN) of the destination.

Returns:

  • (String)


70004
70005
70006
70007
70008
70009
70010
70011
70012
70013
70014
70015
70016
70017
70018
70019
70020
70021
# File 'lib/aws-sdk-ec2/types.rb', line 70004

class NetworkInsightsPath < Struct.new(
  :network_insights_path_id,
  :network_insights_path_arn,
  :created_date,
  :source,
  :destination,
  :source_arn,
  :destination_arn,
  :source_ip,
  :destination_ip,
  :protocol,
  :destination_port,
  :tags,
  :filter_at_source,
  :filter_at_destination)
  SENSITIVE = []
  include Aws::Structure
end

#destination_ipString

The IP address of the destination.

Returns:

  • (String)


70004
70005
70006
70007
70008
70009
70010
70011
70012
70013
70014
70015
70016
70017
70018
70019
70020
70021
# File 'lib/aws-sdk-ec2/types.rb', line 70004

class NetworkInsightsPath < Struct.new(
  :network_insights_path_id,
  :network_insights_path_arn,
  :created_date,
  :source,
  :destination,
  :source_arn,
  :destination_arn,
  :source_ip,
  :destination_ip,
  :protocol,
  :destination_port,
  :tags,
  :filter_at_source,
  :filter_at_destination)
  SENSITIVE = []
  include Aws::Structure
end

#destination_portInteger

The destination port.

Returns:

  • (Integer)


70004
70005
70006
70007
70008
70009
70010
70011
70012
70013
70014
70015
70016
70017
70018
70019
70020
70021
# File 'lib/aws-sdk-ec2/types.rb', line 70004

class NetworkInsightsPath < Struct.new(
  :network_insights_path_id,
  :network_insights_path_arn,
  :created_date,
  :source,
  :destination,
  :source_arn,
  :destination_arn,
  :source_ip,
  :destination_ip,
  :protocol,
  :destination_port,
  :tags,
  :filter_at_source,
  :filter_at_destination)
  SENSITIVE = []
  include Aws::Structure
end

#filter_at_destinationTypes::PathFilter

Scopes the analysis to network paths that match specific filters at the destination.

Returns:



70004
70005
70006
70007
70008
70009
70010
70011
70012
70013
70014
70015
70016
70017
70018
70019
70020
70021
# File 'lib/aws-sdk-ec2/types.rb', line 70004

class NetworkInsightsPath < Struct.new(
  :network_insights_path_id,
  :network_insights_path_arn,
  :created_date,
  :source,
  :destination,
  :source_arn,
  :destination_arn,
  :source_ip,
  :destination_ip,
  :protocol,
  :destination_port,
  :tags,
  :filter_at_source,
  :filter_at_destination)
  SENSITIVE = []
  include Aws::Structure
end

#filter_at_sourceTypes::PathFilter

Scopes the analysis to network paths that match specific filters at the source.

Returns:



70004
70005
70006
70007
70008
70009
70010
70011
70012
70013
70014
70015
70016
70017
70018
70019
70020
70021
# File 'lib/aws-sdk-ec2/types.rb', line 70004

class NetworkInsightsPath < Struct.new(
  :network_insights_path_id,
  :network_insights_path_arn,
  :created_date,
  :source,
  :destination,
  :source_arn,
  :destination_arn,
  :source_ip,
  :destination_ip,
  :protocol,
  :destination_port,
  :tags,
  :filter_at_source,
  :filter_at_destination)
  SENSITIVE = []
  include Aws::Structure
end

#network_insights_path_arnString

The Amazon Resource Name (ARN) of the path.

Returns:

  • (String)


70004
70005
70006
70007
70008
70009
70010
70011
70012
70013
70014
70015
70016
70017
70018
70019
70020
70021
# File 'lib/aws-sdk-ec2/types.rb', line 70004

class NetworkInsightsPath < Struct.new(
  :network_insights_path_id,
  :network_insights_path_arn,
  :created_date,
  :source,
  :destination,
  :source_arn,
  :destination_arn,
  :source_ip,
  :destination_ip,
  :protocol,
  :destination_port,
  :tags,
  :filter_at_source,
  :filter_at_destination)
  SENSITIVE = []
  include Aws::Structure
end

#network_insights_path_idString

The ID of the path.

Returns:

  • (String)


70004
70005
70006
70007
70008
70009
70010
70011
70012
70013
70014
70015
70016
70017
70018
70019
70020
70021
# File 'lib/aws-sdk-ec2/types.rb', line 70004

class NetworkInsightsPath < Struct.new(
  :network_insights_path_id,
  :network_insights_path_arn,
  :created_date,
  :source,
  :destination,
  :source_arn,
  :destination_arn,
  :source_ip,
  :destination_ip,
  :protocol,
  :destination_port,
  :tags,
  :filter_at_source,
  :filter_at_destination)
  SENSITIVE = []
  include Aws::Structure
end

#protocolString

The protocol.

Returns:

  • (String)


70004
70005
70006
70007
70008
70009
70010
70011
70012
70013
70014
70015
70016
70017
70018
70019
70020
70021
# File 'lib/aws-sdk-ec2/types.rb', line 70004

class NetworkInsightsPath < Struct.new(
  :network_insights_path_id,
  :network_insights_path_arn,
  :created_date,
  :source,
  :destination,
  :source_arn,
  :destination_arn,
  :source_ip,
  :destination_ip,
  :protocol,
  :destination_port,
  :tags,
  :filter_at_source,
  :filter_at_destination)
  SENSITIVE = []
  include Aws::Structure
end

#sourceString

The ID of the source.

Returns:

  • (String)


70004
70005
70006
70007
70008
70009
70010
70011
70012
70013
70014
70015
70016
70017
70018
70019
70020
70021
# File 'lib/aws-sdk-ec2/types.rb', line 70004

class NetworkInsightsPath < Struct.new(
  :network_insights_path_id,
  :network_insights_path_arn,
  :created_date,
  :source,
  :destination,
  :source_arn,
  :destination_arn,
  :source_ip,
  :destination_ip,
  :protocol,
  :destination_port,
  :tags,
  :filter_at_source,
  :filter_at_destination)
  SENSITIVE = []
  include Aws::Structure
end

#source_arnString

The Amazon Resource Name (ARN) of the source.

Returns:

  • (String)


70004
70005
70006
70007
70008
70009
70010
70011
70012
70013
70014
70015
70016
70017
70018
70019
70020
70021
# File 'lib/aws-sdk-ec2/types.rb', line 70004

class NetworkInsightsPath < Struct.new(
  :network_insights_path_id,
  :network_insights_path_arn,
  :created_date,
  :source,
  :destination,
  :source_arn,
  :destination_arn,
  :source_ip,
  :destination_ip,
  :protocol,
  :destination_port,
  :tags,
  :filter_at_source,
  :filter_at_destination)
  SENSITIVE = []
  include Aws::Structure
end

#source_ipString

The IP address of the source.

Returns:

  • (String)


70004
70005
70006
70007
70008
70009
70010
70011
70012
70013
70014
70015
70016
70017
70018
70019
70020
70021
# File 'lib/aws-sdk-ec2/types.rb', line 70004

class NetworkInsightsPath < Struct.new(
  :network_insights_path_id,
  :network_insights_path_arn,
  :created_date,
  :source,
  :destination,
  :source_arn,
  :destination_arn,
  :source_ip,
  :destination_ip,
  :protocol,
  :destination_port,
  :tags,
  :filter_at_source,
  :filter_at_destination)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The tags associated with the path.

Returns:



70004
70005
70006
70007
70008
70009
70010
70011
70012
70013
70014
70015
70016
70017
70018
70019
70020
70021
# File 'lib/aws-sdk-ec2/types.rb', line 70004

class NetworkInsightsPath < Struct.new(
  :network_insights_path_id,
  :network_insights_path_arn,
  :created_date,
  :source,
  :destination,
  :source_arn,
  :destination_arn,
  :source_ip,
  :destination_ip,
  :protocol,
  :destination_port,
  :tags,
  :filter_at_source,
  :filter_at_destination)
  SENSITIVE = []
  include Aws::Structure
end