Class: Aws::EC2::Types::NetworkInsightsPath
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::NetworkInsightsPath
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a path.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_date ⇒ Time
The time stamp when the path was created.
-
#destination ⇒ String
The ID of the destination.
-
#destination_arn ⇒ String
The Amazon Resource Name (ARN) of the destination.
-
#destination_ip ⇒ String
The IP address of the destination.
-
#destination_port ⇒ Integer
The destination port.
-
#filter_at_destination ⇒ Types::PathFilter
Scopes the analysis to network paths that match specific filters at the destination.
-
#filter_at_source ⇒ Types::PathFilter
Scopes the analysis to network paths that match specific filters at the source.
-
#network_insights_path_arn ⇒ String
The Amazon Resource Name (ARN) of the path.
-
#network_insights_path_id ⇒ String
The ID of the path.
-
#protocol ⇒ String
The protocol.
-
#source ⇒ String
The ID of the source.
-
#source_arn ⇒ String
The Amazon Resource Name (ARN) of the source.
-
#source_ip ⇒ String
The IP address of the source.
-
#tags ⇒ Array<Types::Tag>
The tags associated with the path.
Instance Attribute Details
#created_date ⇒ Time
The time stamp when the path was created.
68637 68638 68639 68640 68641 68642 68643 68644 68645 68646 68647 68648 68649 68650 68651 68652 68653 68654 |
# File 'lib/aws-sdk-ec2/types.rb', line 68637 class NetworkInsightsPath < Struct.new( :network_insights_path_id, :network_insights_path_arn, :created_date, :source, :destination, :source_arn, :destination_arn, :source_ip, :destination_ip, :protocol, :destination_port, :tags, :filter_at_source, :filter_at_destination) SENSITIVE = [] include Aws::Structure end |
#destination ⇒ String
The ID of the destination.
68637 68638 68639 68640 68641 68642 68643 68644 68645 68646 68647 68648 68649 68650 68651 68652 68653 68654 |
# File 'lib/aws-sdk-ec2/types.rb', line 68637 class NetworkInsightsPath < Struct.new( :network_insights_path_id, :network_insights_path_arn, :created_date, :source, :destination, :source_arn, :destination_arn, :source_ip, :destination_ip, :protocol, :destination_port, :tags, :filter_at_source, :filter_at_destination) SENSITIVE = [] include Aws::Structure end |
#destination_arn ⇒ String
The Amazon Resource Name (ARN) of the destination.
68637 68638 68639 68640 68641 68642 68643 68644 68645 68646 68647 68648 68649 68650 68651 68652 68653 68654 |
# File 'lib/aws-sdk-ec2/types.rb', line 68637 class NetworkInsightsPath < Struct.new( :network_insights_path_id, :network_insights_path_arn, :created_date, :source, :destination, :source_arn, :destination_arn, :source_ip, :destination_ip, :protocol, :destination_port, :tags, :filter_at_source, :filter_at_destination) SENSITIVE = [] include Aws::Structure end |
#destination_ip ⇒ String
The IP address of the destination.
68637 68638 68639 68640 68641 68642 68643 68644 68645 68646 68647 68648 68649 68650 68651 68652 68653 68654 |
# File 'lib/aws-sdk-ec2/types.rb', line 68637 class NetworkInsightsPath < Struct.new( :network_insights_path_id, :network_insights_path_arn, :created_date, :source, :destination, :source_arn, :destination_arn, :source_ip, :destination_ip, :protocol, :destination_port, :tags, :filter_at_source, :filter_at_destination) SENSITIVE = [] include Aws::Structure end |
#destination_port ⇒ Integer
The destination port.
68637 68638 68639 68640 68641 68642 68643 68644 68645 68646 68647 68648 68649 68650 68651 68652 68653 68654 |
# File 'lib/aws-sdk-ec2/types.rb', line 68637 class NetworkInsightsPath < Struct.new( :network_insights_path_id, :network_insights_path_arn, :created_date, :source, :destination, :source_arn, :destination_arn, :source_ip, :destination_ip, :protocol, :destination_port, :tags, :filter_at_source, :filter_at_destination) SENSITIVE = [] include Aws::Structure end |
#filter_at_destination ⇒ Types::PathFilter
Scopes the analysis to network paths that match specific filters at the destination.
68637 68638 68639 68640 68641 68642 68643 68644 68645 68646 68647 68648 68649 68650 68651 68652 68653 68654 |
# File 'lib/aws-sdk-ec2/types.rb', line 68637 class NetworkInsightsPath < Struct.new( :network_insights_path_id, :network_insights_path_arn, :created_date, :source, :destination, :source_arn, :destination_arn, :source_ip, :destination_ip, :protocol, :destination_port, :tags, :filter_at_source, :filter_at_destination) SENSITIVE = [] include Aws::Structure end |
#filter_at_source ⇒ Types::PathFilter
Scopes the analysis to network paths that match specific filters at the source.
68637 68638 68639 68640 68641 68642 68643 68644 68645 68646 68647 68648 68649 68650 68651 68652 68653 68654 |
# File 'lib/aws-sdk-ec2/types.rb', line 68637 class NetworkInsightsPath < Struct.new( :network_insights_path_id, :network_insights_path_arn, :created_date, :source, :destination, :source_arn, :destination_arn, :source_ip, :destination_ip, :protocol, :destination_port, :tags, :filter_at_source, :filter_at_destination) SENSITIVE = [] include Aws::Structure end |
#network_insights_path_arn ⇒ String
The Amazon Resource Name (ARN) of the path.
68637 68638 68639 68640 68641 68642 68643 68644 68645 68646 68647 68648 68649 68650 68651 68652 68653 68654 |
# File 'lib/aws-sdk-ec2/types.rb', line 68637 class NetworkInsightsPath < Struct.new( :network_insights_path_id, :network_insights_path_arn, :created_date, :source, :destination, :source_arn, :destination_arn, :source_ip, :destination_ip, :protocol, :destination_port, :tags, :filter_at_source, :filter_at_destination) SENSITIVE = [] include Aws::Structure end |
#network_insights_path_id ⇒ String
The ID of the path.
68637 68638 68639 68640 68641 68642 68643 68644 68645 68646 68647 68648 68649 68650 68651 68652 68653 68654 |
# File 'lib/aws-sdk-ec2/types.rb', line 68637 class NetworkInsightsPath < Struct.new( :network_insights_path_id, :network_insights_path_arn, :created_date, :source, :destination, :source_arn, :destination_arn, :source_ip, :destination_ip, :protocol, :destination_port, :tags, :filter_at_source, :filter_at_destination) SENSITIVE = [] include Aws::Structure end |
#protocol ⇒ String
The protocol.
68637 68638 68639 68640 68641 68642 68643 68644 68645 68646 68647 68648 68649 68650 68651 68652 68653 68654 |
# File 'lib/aws-sdk-ec2/types.rb', line 68637 class NetworkInsightsPath < Struct.new( :network_insights_path_id, :network_insights_path_arn, :created_date, :source, :destination, :source_arn, :destination_arn, :source_ip, :destination_ip, :protocol, :destination_port, :tags, :filter_at_source, :filter_at_destination) SENSITIVE = [] include Aws::Structure end |
#source ⇒ String
The ID of the source.
68637 68638 68639 68640 68641 68642 68643 68644 68645 68646 68647 68648 68649 68650 68651 68652 68653 68654 |
# File 'lib/aws-sdk-ec2/types.rb', line 68637 class NetworkInsightsPath < Struct.new( :network_insights_path_id, :network_insights_path_arn, :created_date, :source, :destination, :source_arn, :destination_arn, :source_ip, :destination_ip, :protocol, :destination_port, :tags, :filter_at_source, :filter_at_destination) SENSITIVE = [] include Aws::Structure end |
#source_arn ⇒ String
The Amazon Resource Name (ARN) of the source.
68637 68638 68639 68640 68641 68642 68643 68644 68645 68646 68647 68648 68649 68650 68651 68652 68653 68654 |
# File 'lib/aws-sdk-ec2/types.rb', line 68637 class NetworkInsightsPath < Struct.new( :network_insights_path_id, :network_insights_path_arn, :created_date, :source, :destination, :source_arn, :destination_arn, :source_ip, :destination_ip, :protocol, :destination_port, :tags, :filter_at_source, :filter_at_destination) SENSITIVE = [] include Aws::Structure end |
#source_ip ⇒ String
The IP address of the source.
68637 68638 68639 68640 68641 68642 68643 68644 68645 68646 68647 68648 68649 68650 68651 68652 68653 68654 |
# File 'lib/aws-sdk-ec2/types.rb', line 68637 class NetworkInsightsPath < Struct.new( :network_insights_path_id, :network_insights_path_arn, :created_date, :source, :destination, :source_arn, :destination_arn, :source_ip, :destination_ip, :protocol, :destination_port, :tags, :filter_at_source, :filter_at_destination) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags associated with the path.
68637 68638 68639 68640 68641 68642 68643 68644 68645 68646 68647 68648 68649 68650 68651 68652 68653 68654 |
# File 'lib/aws-sdk-ec2/types.rb', line 68637 class NetworkInsightsPath < Struct.new( :network_insights_path_id, :network_insights_path_arn, :created_date, :source, :destination, :source_arn, :destination_arn, :source_ip, :destination_ip, :protocol, :destination_port, :tags, :filter_at_source, :filter_at_destination) SENSITIVE = [] include Aws::Structure end |