Class: Aws::EC2::Types::NetworkInterface
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::NetworkInterface
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a network interface.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#associated_subnets ⇒ Array<String>
The subnets associated with this network interface.
-
#association ⇒ Types::NetworkInterfaceAssociation
The association information for an Elastic IP address (IPv4) associated with the network interface.
-
#attachment ⇒ Types::NetworkInterfaceAttachment
The network interface attachment.
-
#availability_zone ⇒ String
The Availability Zone.
-
#availability_zone_id ⇒ String
The ID of the Availability Zone.
-
#connection_tracking_configuration ⇒ Types::ConnectionTrackingConfiguration
A security group connection tracking configuration that enables you to set the timeout for connection tracking on an Elastic network interface.
-
#deny_all_igw_traffic ⇒ Boolean
Indicates whether a network interface with an IPv6 address is unreachable from the public internet.
-
#description ⇒ String
A description.
-
#groups ⇒ Array<Types::GroupIdentifier>
Any security groups for the network interface.
-
#interface_type ⇒ String
The type of network interface.
-
#ipv_4_prefixes ⇒ Array<Types::Ipv4PrefixSpecification>
The IPv4 prefixes that are assigned to the network interface.
-
#ipv_6_address ⇒ String
The IPv6 globally unique address associated with the network interface.
-
#ipv_6_addresses ⇒ Array<Types::NetworkInterfaceIpv6Address>
The IPv6 addresses associated with the network interface.
-
#ipv_6_native ⇒ Boolean
Indicates whether this is an IPv6 only network interface.
-
#ipv_6_prefixes ⇒ Array<Types::Ipv6PrefixSpecification>
The IPv6 prefixes that are assigned to the network interface.
-
#mac_address ⇒ String
The MAC address.
-
#network_interface_id ⇒ String
The ID of the network interface.
-
#operator ⇒ Types::OperatorResponse
The service provider that manages the network interface.
-
#outpost_arn ⇒ String
The Amazon Resource Name (ARN) of the Outpost.
-
#owner_id ⇒ String
The Amazon Web Services account ID of the owner of the network interface.
-
#private_dns_name ⇒ String
The private hostname.
-
#private_ip_address ⇒ String
The IPv4 address of the network interface within the subnet.
-
#private_ip_addresses ⇒ Array<Types::NetworkInterfacePrivateIpAddress>
The private IPv4 addresses associated with the network interface.
-
#public_dns_name ⇒ String
A public hostname.
-
#public_ip_dns_name_options ⇒ Types::PublicIpDnsNameOptions
Public hostname type options.
-
#requester_id ⇒ String
The alias or Amazon Web Services account ID of the principal or service that created the network interface.
-
#requester_managed ⇒ Boolean
Indicates whether the network interface is being managed by Amazon Web Services.
-
#source_dest_check ⇒ Boolean
Indicates whether source/destination checking is enabled.
-
#status ⇒ String
The status of the network interface.
-
#subnet_id ⇒ String
The ID of the subnet.
-
#tag_set ⇒ Array<Types::Tag>
Any tags assigned to the network interface.
-
#vpc_id ⇒ String
The ID of the VPC.
Instance Attribute Details
#associated_subnets ⇒ Array<String>
The subnets associated with this network interface.
67440 67441 67442 67443 67444 67445 67446 67447 67448 67449 67450 67451 67452 67453 67454 67455 67456 67457 67458 67459 67460 67461 67462 67463 67464 67465 67466 67467 67468 67469 67470 67471 67472 67473 67474 67475 |
# File 'lib/aws-sdk-ec2/types.rb', line 67440 class NetworkInterface < Struct.new( :association, :attachment, :availability_zone, :connection_tracking_configuration, :description, :groups, :interface_type, :ipv_6_addresses, :mac_address, :network_interface_id, :outpost_arn, :owner_id, :private_dns_name, :public_dns_name, :public_ip_dns_name_options, :private_ip_address, :private_ip_addresses, :ipv_4_prefixes, :ipv_6_prefixes, :requester_id, :requester_managed, :source_dest_check, :status, :subnet_id, :tag_set, :vpc_id, :deny_all_igw_traffic, :ipv_6_native, :ipv_6_address, :operator, :associated_subnets, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#association ⇒ Types::NetworkInterfaceAssociation
The association information for an Elastic IP address (IPv4) associated with the network interface.
67440 67441 67442 67443 67444 67445 67446 67447 67448 67449 67450 67451 67452 67453 67454 67455 67456 67457 67458 67459 67460 67461 67462 67463 67464 67465 67466 67467 67468 67469 67470 67471 67472 67473 67474 67475 |
# File 'lib/aws-sdk-ec2/types.rb', line 67440 class NetworkInterface < Struct.new( :association, :attachment, :availability_zone, :connection_tracking_configuration, :description, :groups, :interface_type, :ipv_6_addresses, :mac_address, :network_interface_id, :outpost_arn, :owner_id, :private_dns_name, :public_dns_name, :public_ip_dns_name_options, :private_ip_address, :private_ip_addresses, :ipv_4_prefixes, :ipv_6_prefixes, :requester_id, :requester_managed, :source_dest_check, :status, :subnet_id, :tag_set, :vpc_id, :deny_all_igw_traffic, :ipv_6_native, :ipv_6_address, :operator, :associated_subnets, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#attachment ⇒ Types::NetworkInterfaceAttachment
The network interface attachment.
67440 67441 67442 67443 67444 67445 67446 67447 67448 67449 67450 67451 67452 67453 67454 67455 67456 67457 67458 67459 67460 67461 67462 67463 67464 67465 67466 67467 67468 67469 67470 67471 67472 67473 67474 67475 |
# File 'lib/aws-sdk-ec2/types.rb', line 67440 class NetworkInterface < Struct.new( :association, :attachment, :availability_zone, :connection_tracking_configuration, :description, :groups, :interface_type, :ipv_6_addresses, :mac_address, :network_interface_id, :outpost_arn, :owner_id, :private_dns_name, :public_dns_name, :public_ip_dns_name_options, :private_ip_address, :private_ip_addresses, :ipv_4_prefixes, :ipv_6_prefixes, :requester_id, :requester_managed, :source_dest_check, :status, :subnet_id, :tag_set, :vpc_id, :deny_all_igw_traffic, :ipv_6_native, :ipv_6_address, :operator, :associated_subnets, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#availability_zone ⇒ String
The Availability Zone.
67440 67441 67442 67443 67444 67445 67446 67447 67448 67449 67450 67451 67452 67453 67454 67455 67456 67457 67458 67459 67460 67461 67462 67463 67464 67465 67466 67467 67468 67469 67470 67471 67472 67473 67474 67475 |
# File 'lib/aws-sdk-ec2/types.rb', line 67440 class NetworkInterface < Struct.new( :association, :attachment, :availability_zone, :connection_tracking_configuration, :description, :groups, :interface_type, :ipv_6_addresses, :mac_address, :network_interface_id, :outpost_arn, :owner_id, :private_dns_name, :public_dns_name, :public_ip_dns_name_options, :private_ip_address, :private_ip_addresses, :ipv_4_prefixes, :ipv_6_prefixes, :requester_id, :requester_managed, :source_dest_check, :status, :subnet_id, :tag_set, :vpc_id, :deny_all_igw_traffic, :ipv_6_native, :ipv_6_address, :operator, :associated_subnets, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
The ID of the Availability Zone.
67440 67441 67442 67443 67444 67445 67446 67447 67448 67449 67450 67451 67452 67453 67454 67455 67456 67457 67458 67459 67460 67461 67462 67463 67464 67465 67466 67467 67468 67469 67470 67471 67472 67473 67474 67475 |
# File 'lib/aws-sdk-ec2/types.rb', line 67440 class NetworkInterface < Struct.new( :association, :attachment, :availability_zone, :connection_tracking_configuration, :description, :groups, :interface_type, :ipv_6_addresses, :mac_address, :network_interface_id, :outpost_arn, :owner_id, :private_dns_name, :public_dns_name, :public_ip_dns_name_options, :private_ip_address, :private_ip_addresses, :ipv_4_prefixes, :ipv_6_prefixes, :requester_id, :requester_managed, :source_dest_check, :status, :subnet_id, :tag_set, :vpc_id, :deny_all_igw_traffic, :ipv_6_native, :ipv_6_address, :operator, :associated_subnets, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#connection_tracking_configuration ⇒ Types::ConnectionTrackingConfiguration
A security group connection tracking configuration that enables you to set the timeout for connection tracking on an Elastic network interface. For more information, see [Connection tracking timeouts] in the *Amazon EC2 User Guide*.
67440 67441 67442 67443 67444 67445 67446 67447 67448 67449 67450 67451 67452 67453 67454 67455 67456 67457 67458 67459 67460 67461 67462 67463 67464 67465 67466 67467 67468 67469 67470 67471 67472 67473 67474 67475 |
# File 'lib/aws-sdk-ec2/types.rb', line 67440 class NetworkInterface < Struct.new( :association, :attachment, :availability_zone, :connection_tracking_configuration, :description, :groups, :interface_type, :ipv_6_addresses, :mac_address, :network_interface_id, :outpost_arn, :owner_id, :private_dns_name, :public_dns_name, :public_ip_dns_name_options, :private_ip_address, :private_ip_addresses, :ipv_4_prefixes, :ipv_6_prefixes, :requester_id, :requester_managed, :source_dest_check, :status, :subnet_id, :tag_set, :vpc_id, :deny_all_igw_traffic, :ipv_6_native, :ipv_6_address, :operator, :associated_subnets, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#deny_all_igw_traffic ⇒ Boolean
Indicates whether a network interface with an IPv6 address is unreachable from the public internet. If the value is ‘true`, inbound traffic from the internet is dropped and you cannot assign an elastic IP address to the network interface. The network interface is reachable from peered VPCs and resources connected through a transit gateway, including on-premises networks.
67440 67441 67442 67443 67444 67445 67446 67447 67448 67449 67450 67451 67452 67453 67454 67455 67456 67457 67458 67459 67460 67461 67462 67463 67464 67465 67466 67467 67468 67469 67470 67471 67472 67473 67474 67475 |
# File 'lib/aws-sdk-ec2/types.rb', line 67440 class NetworkInterface < Struct.new( :association, :attachment, :availability_zone, :connection_tracking_configuration, :description, :groups, :interface_type, :ipv_6_addresses, :mac_address, :network_interface_id, :outpost_arn, :owner_id, :private_dns_name, :public_dns_name, :public_ip_dns_name_options, :private_ip_address, :private_ip_addresses, :ipv_4_prefixes, :ipv_6_prefixes, :requester_id, :requester_managed, :source_dest_check, :status, :subnet_id, :tag_set, :vpc_id, :deny_all_igw_traffic, :ipv_6_native, :ipv_6_address, :operator, :associated_subnets, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description.
67440 67441 67442 67443 67444 67445 67446 67447 67448 67449 67450 67451 67452 67453 67454 67455 67456 67457 67458 67459 67460 67461 67462 67463 67464 67465 67466 67467 67468 67469 67470 67471 67472 67473 67474 67475 |
# File 'lib/aws-sdk-ec2/types.rb', line 67440 class NetworkInterface < Struct.new( :association, :attachment, :availability_zone, :connection_tracking_configuration, :description, :groups, :interface_type, :ipv_6_addresses, :mac_address, :network_interface_id, :outpost_arn, :owner_id, :private_dns_name, :public_dns_name, :public_ip_dns_name_options, :private_ip_address, :private_ip_addresses, :ipv_4_prefixes, :ipv_6_prefixes, :requester_id, :requester_managed, :source_dest_check, :status, :subnet_id, :tag_set, :vpc_id, :deny_all_igw_traffic, :ipv_6_native, :ipv_6_address, :operator, :associated_subnets, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#groups ⇒ Array<Types::GroupIdentifier>
Any security groups for the network interface.
67440 67441 67442 67443 67444 67445 67446 67447 67448 67449 67450 67451 67452 67453 67454 67455 67456 67457 67458 67459 67460 67461 67462 67463 67464 67465 67466 67467 67468 67469 67470 67471 67472 67473 67474 67475 |
# File 'lib/aws-sdk-ec2/types.rb', line 67440 class NetworkInterface < Struct.new( :association, :attachment, :availability_zone, :connection_tracking_configuration, :description, :groups, :interface_type, :ipv_6_addresses, :mac_address, :network_interface_id, :outpost_arn, :owner_id, :private_dns_name, :public_dns_name, :public_ip_dns_name_options, :private_ip_address, :private_ip_addresses, :ipv_4_prefixes, :ipv_6_prefixes, :requester_id, :requester_managed, :source_dest_check, :status, :subnet_id, :tag_set, :vpc_id, :deny_all_igw_traffic, :ipv_6_native, :ipv_6_address, :operator, :associated_subnets, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#interface_type ⇒ String
The type of network interface.
67440 67441 67442 67443 67444 67445 67446 67447 67448 67449 67450 67451 67452 67453 67454 67455 67456 67457 67458 67459 67460 67461 67462 67463 67464 67465 67466 67467 67468 67469 67470 67471 67472 67473 67474 67475 |
# File 'lib/aws-sdk-ec2/types.rb', line 67440 class NetworkInterface < Struct.new( :association, :attachment, :availability_zone, :connection_tracking_configuration, :description, :groups, :interface_type, :ipv_6_addresses, :mac_address, :network_interface_id, :outpost_arn, :owner_id, :private_dns_name, :public_dns_name, :public_ip_dns_name_options, :private_ip_address, :private_ip_addresses, :ipv_4_prefixes, :ipv_6_prefixes, :requester_id, :requester_managed, :source_dest_check, :status, :subnet_id, :tag_set, :vpc_id, :deny_all_igw_traffic, :ipv_6_native, :ipv_6_address, :operator, :associated_subnets, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#ipv_4_prefixes ⇒ Array<Types::Ipv4PrefixSpecification>
The IPv4 prefixes that are assigned to the network interface.
67440 67441 67442 67443 67444 67445 67446 67447 67448 67449 67450 67451 67452 67453 67454 67455 67456 67457 67458 67459 67460 67461 67462 67463 67464 67465 67466 67467 67468 67469 67470 67471 67472 67473 67474 67475 |
# File 'lib/aws-sdk-ec2/types.rb', line 67440 class NetworkInterface < Struct.new( :association, :attachment, :availability_zone, :connection_tracking_configuration, :description, :groups, :interface_type, :ipv_6_addresses, :mac_address, :network_interface_id, :outpost_arn, :owner_id, :private_dns_name, :public_dns_name, :public_ip_dns_name_options, :private_ip_address, :private_ip_addresses, :ipv_4_prefixes, :ipv_6_prefixes, :requester_id, :requester_managed, :source_dest_check, :status, :subnet_id, :tag_set, :vpc_id, :deny_all_igw_traffic, :ipv_6_native, :ipv_6_address, :operator, :associated_subnets, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#ipv_6_address ⇒ String
The IPv6 globally unique address associated with the network interface.
67440 67441 67442 67443 67444 67445 67446 67447 67448 67449 67450 67451 67452 67453 67454 67455 67456 67457 67458 67459 67460 67461 67462 67463 67464 67465 67466 67467 67468 67469 67470 67471 67472 67473 67474 67475 |
# File 'lib/aws-sdk-ec2/types.rb', line 67440 class NetworkInterface < Struct.new( :association, :attachment, :availability_zone, :connection_tracking_configuration, :description, :groups, :interface_type, :ipv_6_addresses, :mac_address, :network_interface_id, :outpost_arn, :owner_id, :private_dns_name, :public_dns_name, :public_ip_dns_name_options, :private_ip_address, :private_ip_addresses, :ipv_4_prefixes, :ipv_6_prefixes, :requester_id, :requester_managed, :source_dest_check, :status, :subnet_id, :tag_set, :vpc_id, :deny_all_igw_traffic, :ipv_6_native, :ipv_6_address, :operator, :associated_subnets, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#ipv_6_addresses ⇒ Array<Types::NetworkInterfaceIpv6Address>
The IPv6 addresses associated with the network interface.
67440 67441 67442 67443 67444 67445 67446 67447 67448 67449 67450 67451 67452 67453 67454 67455 67456 67457 67458 67459 67460 67461 67462 67463 67464 67465 67466 67467 67468 67469 67470 67471 67472 67473 67474 67475 |
# File 'lib/aws-sdk-ec2/types.rb', line 67440 class NetworkInterface < Struct.new( :association, :attachment, :availability_zone, :connection_tracking_configuration, :description, :groups, :interface_type, :ipv_6_addresses, :mac_address, :network_interface_id, :outpost_arn, :owner_id, :private_dns_name, :public_dns_name, :public_ip_dns_name_options, :private_ip_address, :private_ip_addresses, :ipv_4_prefixes, :ipv_6_prefixes, :requester_id, :requester_managed, :source_dest_check, :status, :subnet_id, :tag_set, :vpc_id, :deny_all_igw_traffic, :ipv_6_native, :ipv_6_address, :operator, :associated_subnets, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#ipv_6_native ⇒ Boolean
Indicates whether this is an IPv6 only network interface.
67440 67441 67442 67443 67444 67445 67446 67447 67448 67449 67450 67451 67452 67453 67454 67455 67456 67457 67458 67459 67460 67461 67462 67463 67464 67465 67466 67467 67468 67469 67470 67471 67472 67473 67474 67475 |
# File 'lib/aws-sdk-ec2/types.rb', line 67440 class NetworkInterface < Struct.new( :association, :attachment, :availability_zone, :connection_tracking_configuration, :description, :groups, :interface_type, :ipv_6_addresses, :mac_address, :network_interface_id, :outpost_arn, :owner_id, :private_dns_name, :public_dns_name, :public_ip_dns_name_options, :private_ip_address, :private_ip_addresses, :ipv_4_prefixes, :ipv_6_prefixes, :requester_id, :requester_managed, :source_dest_check, :status, :subnet_id, :tag_set, :vpc_id, :deny_all_igw_traffic, :ipv_6_native, :ipv_6_address, :operator, :associated_subnets, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#ipv_6_prefixes ⇒ Array<Types::Ipv6PrefixSpecification>
The IPv6 prefixes that are assigned to the network interface.
67440 67441 67442 67443 67444 67445 67446 67447 67448 67449 67450 67451 67452 67453 67454 67455 67456 67457 67458 67459 67460 67461 67462 67463 67464 67465 67466 67467 67468 67469 67470 67471 67472 67473 67474 67475 |
# File 'lib/aws-sdk-ec2/types.rb', line 67440 class NetworkInterface < Struct.new( :association, :attachment, :availability_zone, :connection_tracking_configuration, :description, :groups, :interface_type, :ipv_6_addresses, :mac_address, :network_interface_id, :outpost_arn, :owner_id, :private_dns_name, :public_dns_name, :public_ip_dns_name_options, :private_ip_address, :private_ip_addresses, :ipv_4_prefixes, :ipv_6_prefixes, :requester_id, :requester_managed, :source_dest_check, :status, :subnet_id, :tag_set, :vpc_id, :deny_all_igw_traffic, :ipv_6_native, :ipv_6_address, :operator, :associated_subnets, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#mac_address ⇒ String
The MAC address.
67440 67441 67442 67443 67444 67445 67446 67447 67448 67449 67450 67451 67452 67453 67454 67455 67456 67457 67458 67459 67460 67461 67462 67463 67464 67465 67466 67467 67468 67469 67470 67471 67472 67473 67474 67475 |
# File 'lib/aws-sdk-ec2/types.rb', line 67440 class NetworkInterface < Struct.new( :association, :attachment, :availability_zone, :connection_tracking_configuration, :description, :groups, :interface_type, :ipv_6_addresses, :mac_address, :network_interface_id, :outpost_arn, :owner_id, :private_dns_name, :public_dns_name, :public_ip_dns_name_options, :private_ip_address, :private_ip_addresses, :ipv_4_prefixes, :ipv_6_prefixes, :requester_id, :requester_managed, :source_dest_check, :status, :subnet_id, :tag_set, :vpc_id, :deny_all_igw_traffic, :ipv_6_native, :ipv_6_address, :operator, :associated_subnets, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#network_interface_id ⇒ String
The ID of the network interface.
67440 67441 67442 67443 67444 67445 67446 67447 67448 67449 67450 67451 67452 67453 67454 67455 67456 67457 67458 67459 67460 67461 67462 67463 67464 67465 67466 67467 67468 67469 67470 67471 67472 67473 67474 67475 |
# File 'lib/aws-sdk-ec2/types.rb', line 67440 class NetworkInterface < Struct.new( :association, :attachment, :availability_zone, :connection_tracking_configuration, :description, :groups, :interface_type, :ipv_6_addresses, :mac_address, :network_interface_id, :outpost_arn, :owner_id, :private_dns_name, :public_dns_name, :public_ip_dns_name_options, :private_ip_address, :private_ip_addresses, :ipv_4_prefixes, :ipv_6_prefixes, :requester_id, :requester_managed, :source_dest_check, :status, :subnet_id, :tag_set, :vpc_id, :deny_all_igw_traffic, :ipv_6_native, :ipv_6_address, :operator, :associated_subnets, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#operator ⇒ Types::OperatorResponse
The service provider that manages the network interface.
67440 67441 67442 67443 67444 67445 67446 67447 67448 67449 67450 67451 67452 67453 67454 67455 67456 67457 67458 67459 67460 67461 67462 67463 67464 67465 67466 67467 67468 67469 67470 67471 67472 67473 67474 67475 |
# File 'lib/aws-sdk-ec2/types.rb', line 67440 class NetworkInterface < Struct.new( :association, :attachment, :availability_zone, :connection_tracking_configuration, :description, :groups, :interface_type, :ipv_6_addresses, :mac_address, :network_interface_id, :outpost_arn, :owner_id, :private_dns_name, :public_dns_name, :public_ip_dns_name_options, :private_ip_address, :private_ip_addresses, :ipv_4_prefixes, :ipv_6_prefixes, :requester_id, :requester_managed, :source_dest_check, :status, :subnet_id, :tag_set, :vpc_id, :deny_all_igw_traffic, :ipv_6_native, :ipv_6_address, :operator, :associated_subnets, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#outpost_arn ⇒ String
The Amazon Resource Name (ARN) of the Outpost.
67440 67441 67442 67443 67444 67445 67446 67447 67448 67449 67450 67451 67452 67453 67454 67455 67456 67457 67458 67459 67460 67461 67462 67463 67464 67465 67466 67467 67468 67469 67470 67471 67472 67473 67474 67475 |
# File 'lib/aws-sdk-ec2/types.rb', line 67440 class NetworkInterface < Struct.new( :association, :attachment, :availability_zone, :connection_tracking_configuration, :description, :groups, :interface_type, :ipv_6_addresses, :mac_address, :network_interface_id, :outpost_arn, :owner_id, :private_dns_name, :public_dns_name, :public_ip_dns_name_options, :private_ip_address, :private_ip_addresses, :ipv_4_prefixes, :ipv_6_prefixes, :requester_id, :requester_managed, :source_dest_check, :status, :subnet_id, :tag_set, :vpc_id, :deny_all_igw_traffic, :ipv_6_native, :ipv_6_address, :operator, :associated_subnets, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
The Amazon Web Services account ID of the owner of the network interface.
67440 67441 67442 67443 67444 67445 67446 67447 67448 67449 67450 67451 67452 67453 67454 67455 67456 67457 67458 67459 67460 67461 67462 67463 67464 67465 67466 67467 67468 67469 67470 67471 67472 67473 67474 67475 |
# File 'lib/aws-sdk-ec2/types.rb', line 67440 class NetworkInterface < Struct.new( :association, :attachment, :availability_zone, :connection_tracking_configuration, :description, :groups, :interface_type, :ipv_6_addresses, :mac_address, :network_interface_id, :outpost_arn, :owner_id, :private_dns_name, :public_dns_name, :public_ip_dns_name_options, :private_ip_address, :private_ip_addresses, :ipv_4_prefixes, :ipv_6_prefixes, :requester_id, :requester_managed, :source_dest_check, :status, :subnet_id, :tag_set, :vpc_id, :deny_all_igw_traffic, :ipv_6_native, :ipv_6_address, :operator, :associated_subnets, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#private_dns_name ⇒ String
The private hostname. For more information, see [EC2 instance hostnames, DNS names, and domains] in the *Amazon EC2 User Guide*.
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-instance-naming.html
67440 67441 67442 67443 67444 67445 67446 67447 67448 67449 67450 67451 67452 67453 67454 67455 67456 67457 67458 67459 67460 67461 67462 67463 67464 67465 67466 67467 67468 67469 67470 67471 67472 67473 67474 67475 |
# File 'lib/aws-sdk-ec2/types.rb', line 67440 class NetworkInterface < Struct.new( :association, :attachment, :availability_zone, :connection_tracking_configuration, :description, :groups, :interface_type, :ipv_6_addresses, :mac_address, :network_interface_id, :outpost_arn, :owner_id, :private_dns_name, :public_dns_name, :public_ip_dns_name_options, :private_ip_address, :private_ip_addresses, :ipv_4_prefixes, :ipv_6_prefixes, :requester_id, :requester_managed, :source_dest_check, :status, :subnet_id, :tag_set, :vpc_id, :deny_all_igw_traffic, :ipv_6_native, :ipv_6_address, :operator, :associated_subnets, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#private_ip_address ⇒ String
The IPv4 address of the network interface within the subnet.
67440 67441 67442 67443 67444 67445 67446 67447 67448 67449 67450 67451 67452 67453 67454 67455 67456 67457 67458 67459 67460 67461 67462 67463 67464 67465 67466 67467 67468 67469 67470 67471 67472 67473 67474 67475 |
# File 'lib/aws-sdk-ec2/types.rb', line 67440 class NetworkInterface < Struct.new( :association, :attachment, :availability_zone, :connection_tracking_configuration, :description, :groups, :interface_type, :ipv_6_addresses, :mac_address, :network_interface_id, :outpost_arn, :owner_id, :private_dns_name, :public_dns_name, :public_ip_dns_name_options, :private_ip_address, :private_ip_addresses, :ipv_4_prefixes, :ipv_6_prefixes, :requester_id, :requester_managed, :source_dest_check, :status, :subnet_id, :tag_set, :vpc_id, :deny_all_igw_traffic, :ipv_6_native, :ipv_6_address, :operator, :associated_subnets, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#private_ip_addresses ⇒ Array<Types::NetworkInterfacePrivateIpAddress>
The private IPv4 addresses associated with the network interface.
67440 67441 67442 67443 67444 67445 67446 67447 67448 67449 67450 67451 67452 67453 67454 67455 67456 67457 67458 67459 67460 67461 67462 67463 67464 67465 67466 67467 67468 67469 67470 67471 67472 67473 67474 67475 |
# File 'lib/aws-sdk-ec2/types.rb', line 67440 class NetworkInterface < Struct.new( :association, :attachment, :availability_zone, :connection_tracking_configuration, :description, :groups, :interface_type, :ipv_6_addresses, :mac_address, :network_interface_id, :outpost_arn, :owner_id, :private_dns_name, :public_dns_name, :public_ip_dns_name_options, :private_ip_address, :private_ip_addresses, :ipv_4_prefixes, :ipv_6_prefixes, :requester_id, :requester_managed, :source_dest_check, :status, :subnet_id, :tag_set, :vpc_id, :deny_all_igw_traffic, :ipv_6_native, :ipv_6_address, :operator, :associated_subnets, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#public_dns_name ⇒ String
A public hostname. For more information, see [EC2 instance hostnames, DNS names, and domains] in the *Amazon EC2 User Guide*.
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-instance-naming.html
67440 67441 67442 67443 67444 67445 67446 67447 67448 67449 67450 67451 67452 67453 67454 67455 67456 67457 67458 67459 67460 67461 67462 67463 67464 67465 67466 67467 67468 67469 67470 67471 67472 67473 67474 67475 |
# File 'lib/aws-sdk-ec2/types.rb', line 67440 class NetworkInterface < Struct.new( :association, :attachment, :availability_zone, :connection_tracking_configuration, :description, :groups, :interface_type, :ipv_6_addresses, :mac_address, :network_interface_id, :outpost_arn, :owner_id, :private_dns_name, :public_dns_name, :public_ip_dns_name_options, :private_ip_address, :private_ip_addresses, :ipv_4_prefixes, :ipv_6_prefixes, :requester_id, :requester_managed, :source_dest_check, :status, :subnet_id, :tag_set, :vpc_id, :deny_all_igw_traffic, :ipv_6_native, :ipv_6_address, :operator, :associated_subnets, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#public_ip_dns_name_options ⇒ Types::PublicIpDnsNameOptions
Public hostname type options. For more information, see [EC2 instance hostnames, DNS names, and domains] in the *Amazon EC2 User Guide*.
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-instance-naming.html
67440 67441 67442 67443 67444 67445 67446 67447 67448 67449 67450 67451 67452 67453 67454 67455 67456 67457 67458 67459 67460 67461 67462 67463 67464 67465 67466 67467 67468 67469 67470 67471 67472 67473 67474 67475 |
# File 'lib/aws-sdk-ec2/types.rb', line 67440 class NetworkInterface < Struct.new( :association, :attachment, :availability_zone, :connection_tracking_configuration, :description, :groups, :interface_type, :ipv_6_addresses, :mac_address, :network_interface_id, :outpost_arn, :owner_id, :private_dns_name, :public_dns_name, :public_ip_dns_name_options, :private_ip_address, :private_ip_addresses, :ipv_4_prefixes, :ipv_6_prefixes, :requester_id, :requester_managed, :source_dest_check, :status, :subnet_id, :tag_set, :vpc_id, :deny_all_igw_traffic, :ipv_6_native, :ipv_6_address, :operator, :associated_subnets, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#requester_id ⇒ String
The alias or Amazon Web Services account ID of the principal or service that created the network interface.
67440 67441 67442 67443 67444 67445 67446 67447 67448 67449 67450 67451 67452 67453 67454 67455 67456 67457 67458 67459 67460 67461 67462 67463 67464 67465 67466 67467 67468 67469 67470 67471 67472 67473 67474 67475 |
# File 'lib/aws-sdk-ec2/types.rb', line 67440 class NetworkInterface < Struct.new( :association, :attachment, :availability_zone, :connection_tracking_configuration, :description, :groups, :interface_type, :ipv_6_addresses, :mac_address, :network_interface_id, :outpost_arn, :owner_id, :private_dns_name, :public_dns_name, :public_ip_dns_name_options, :private_ip_address, :private_ip_addresses, :ipv_4_prefixes, :ipv_6_prefixes, :requester_id, :requester_managed, :source_dest_check, :status, :subnet_id, :tag_set, :vpc_id, :deny_all_igw_traffic, :ipv_6_native, :ipv_6_address, :operator, :associated_subnets, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#requester_managed ⇒ Boolean
Indicates whether the network interface is being managed by Amazon Web Services.
67440 67441 67442 67443 67444 67445 67446 67447 67448 67449 67450 67451 67452 67453 67454 67455 67456 67457 67458 67459 67460 67461 67462 67463 67464 67465 67466 67467 67468 67469 67470 67471 67472 67473 67474 67475 |
# File 'lib/aws-sdk-ec2/types.rb', line 67440 class NetworkInterface < Struct.new( :association, :attachment, :availability_zone, :connection_tracking_configuration, :description, :groups, :interface_type, :ipv_6_addresses, :mac_address, :network_interface_id, :outpost_arn, :owner_id, :private_dns_name, :public_dns_name, :public_ip_dns_name_options, :private_ip_address, :private_ip_addresses, :ipv_4_prefixes, :ipv_6_prefixes, :requester_id, :requester_managed, :source_dest_check, :status, :subnet_id, :tag_set, :vpc_id, :deny_all_igw_traffic, :ipv_6_native, :ipv_6_address, :operator, :associated_subnets, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#source_dest_check ⇒ Boolean
Indicates whether source/destination checking is enabled.
67440 67441 67442 67443 67444 67445 67446 67447 67448 67449 67450 67451 67452 67453 67454 67455 67456 67457 67458 67459 67460 67461 67462 67463 67464 67465 67466 67467 67468 67469 67470 67471 67472 67473 67474 67475 |
# File 'lib/aws-sdk-ec2/types.rb', line 67440 class NetworkInterface < Struct.new( :association, :attachment, :availability_zone, :connection_tracking_configuration, :description, :groups, :interface_type, :ipv_6_addresses, :mac_address, :network_interface_id, :outpost_arn, :owner_id, :private_dns_name, :public_dns_name, :public_ip_dns_name_options, :private_ip_address, :private_ip_addresses, :ipv_4_prefixes, :ipv_6_prefixes, :requester_id, :requester_managed, :source_dest_check, :status, :subnet_id, :tag_set, :vpc_id, :deny_all_igw_traffic, :ipv_6_native, :ipv_6_address, :operator, :associated_subnets, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the network interface.
67440 67441 67442 67443 67444 67445 67446 67447 67448 67449 67450 67451 67452 67453 67454 67455 67456 67457 67458 67459 67460 67461 67462 67463 67464 67465 67466 67467 67468 67469 67470 67471 67472 67473 67474 67475 |
# File 'lib/aws-sdk-ec2/types.rb', line 67440 class NetworkInterface < Struct.new( :association, :attachment, :availability_zone, :connection_tracking_configuration, :description, :groups, :interface_type, :ipv_6_addresses, :mac_address, :network_interface_id, :outpost_arn, :owner_id, :private_dns_name, :public_dns_name, :public_ip_dns_name_options, :private_ip_address, :private_ip_addresses, :ipv_4_prefixes, :ipv_6_prefixes, :requester_id, :requester_managed, :source_dest_check, :status, :subnet_id, :tag_set, :vpc_id, :deny_all_igw_traffic, :ipv_6_native, :ipv_6_address, :operator, :associated_subnets, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#subnet_id ⇒ String
The ID of the subnet.
67440 67441 67442 67443 67444 67445 67446 67447 67448 67449 67450 67451 67452 67453 67454 67455 67456 67457 67458 67459 67460 67461 67462 67463 67464 67465 67466 67467 67468 67469 67470 67471 67472 67473 67474 67475 |
# File 'lib/aws-sdk-ec2/types.rb', line 67440 class NetworkInterface < Struct.new( :association, :attachment, :availability_zone, :connection_tracking_configuration, :description, :groups, :interface_type, :ipv_6_addresses, :mac_address, :network_interface_id, :outpost_arn, :owner_id, :private_dns_name, :public_dns_name, :public_ip_dns_name_options, :private_ip_address, :private_ip_addresses, :ipv_4_prefixes, :ipv_6_prefixes, :requester_id, :requester_managed, :source_dest_check, :status, :subnet_id, :tag_set, :vpc_id, :deny_all_igw_traffic, :ipv_6_native, :ipv_6_address, :operator, :associated_subnets, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#tag_set ⇒ Array<Types::Tag>
Any tags assigned to the network interface.
67440 67441 67442 67443 67444 67445 67446 67447 67448 67449 67450 67451 67452 67453 67454 67455 67456 67457 67458 67459 67460 67461 67462 67463 67464 67465 67466 67467 67468 67469 67470 67471 67472 67473 67474 67475 |
# File 'lib/aws-sdk-ec2/types.rb', line 67440 class NetworkInterface < Struct.new( :association, :attachment, :availability_zone, :connection_tracking_configuration, :description, :groups, :interface_type, :ipv_6_addresses, :mac_address, :network_interface_id, :outpost_arn, :owner_id, :private_dns_name, :public_dns_name, :public_ip_dns_name_options, :private_ip_address, :private_ip_addresses, :ipv_4_prefixes, :ipv_6_prefixes, :requester_id, :requester_managed, :source_dest_check, :status, :subnet_id, :tag_set, :vpc_id, :deny_all_igw_traffic, :ipv_6_native, :ipv_6_address, :operator, :associated_subnets, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC.
67440 67441 67442 67443 67444 67445 67446 67447 67448 67449 67450 67451 67452 67453 67454 67455 67456 67457 67458 67459 67460 67461 67462 67463 67464 67465 67466 67467 67468 67469 67470 67471 67472 67473 67474 67475 |
# File 'lib/aws-sdk-ec2/types.rb', line 67440 class NetworkInterface < Struct.new( :association, :attachment, :availability_zone, :connection_tracking_configuration, :description, :groups, :interface_type, :ipv_6_addresses, :mac_address, :network_interface_id, :outpost_arn, :owner_id, :private_dns_name, :public_dns_name, :public_ip_dns_name_options, :private_ip_address, :private_ip_addresses, :ipv_4_prefixes, :ipv_6_prefixes, :requester_id, :requester_managed, :source_dest_check, :status, :subnet_id, :tag_set, :vpc_id, :deny_all_igw_traffic, :ipv_6_native, :ipv_6_address, :operator, :associated_subnets, :availability_zone_id) SENSITIVE = [] include Aws::Structure end |