Class: Aws::EC2::Types::OperatorResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::OperatorResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes whether the resource is managed by a service provider and, if so, describes the service provider that manages it.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#hidden_by_default ⇒ Boolean
If ‘true`, the resource is hidden by default based on the managed resource visibility settings for the account.
-
#managed ⇒ Boolean
If ‘true`, the resource is managed by a service provider.
-
#principal ⇒ String
If ‘managed` is `true`, then the principal is returned.
Instance Attribute Details
#hidden_by_default ⇒ Boolean
If ‘true`, the resource is hidden by default based on the managed resource visibility settings for the account.
68142 68143 68144 68145 68146 68147 68148 |
# File 'lib/aws-sdk-ec2/types.rb', line 68142 class OperatorResponse < Struct.new( :managed, :principal, :hidden_by_default) SENSITIVE = [] include Aws::Structure end |
#managed ⇒ Boolean
If ‘true`, the resource is managed by a service provider.
68142 68143 68144 68145 68146 68147 68148 |
# File 'lib/aws-sdk-ec2/types.rb', line 68142 class OperatorResponse < Struct.new( :managed, :principal, :hidden_by_default) SENSITIVE = [] include Aws::Structure end |
#principal ⇒ String
If ‘managed` is `true`, then the principal is returned. The principal is the service provider that manages the resource.
68142 68143 68144 68145 68146 68147 68148 |
# File 'lib/aws-sdk-ec2/types.rb', line 68142 class OperatorResponse < Struct.new( :managed, :principal, :hidden_by_default) SENSITIVE = [] include Aws::Structure end |