Class: Aws::EC2::Types::PeeringConnectionOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::PeeringConnectionOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the VPC peering connection options.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allow_dns_resolution_from_remote_vpc ⇒ Boolean
If true, the public DNS hostnames of instances in the specified VPC resolve to private IP addresses when queried from instances in the peer VPC.
-
#allow_egress_from_local_classic_link_to_remote_vpc ⇒ Boolean
Deprecated.
-
#allow_egress_from_local_vpc_to_remote_classic_link ⇒ Boolean
Deprecated.
Instance Attribute Details
#allow_dns_resolution_from_remote_vpc ⇒ Boolean
If true, the public DNS hostnames of instances in the specified VPC resolve to private IP addresses when queried from instances in the peer VPC.
69144 69145 69146 69147 69148 69149 69150 |
# File 'lib/aws-sdk-ec2/types.rb', line 69144 class PeeringConnectionOptions < Struct.new( :allow_dns_resolution_from_remote_vpc, :allow_egress_from_local_classic_link_to_remote_vpc, :allow_egress_from_local_vpc_to_remote_classic_link) SENSITIVE = [] include Aws::Structure end |
#allow_egress_from_local_classic_link_to_remote_vpc ⇒ Boolean
Deprecated.
69144 69145 69146 69147 69148 69149 69150 |
# File 'lib/aws-sdk-ec2/types.rb', line 69144 class PeeringConnectionOptions < Struct.new( :allow_dns_resolution_from_remote_vpc, :allow_egress_from_local_classic_link_to_remote_vpc, :allow_egress_from_local_vpc_to_remote_classic_link) SENSITIVE = [] include Aws::Structure end |
#allow_egress_from_local_vpc_to_remote_classic_link ⇒ Boolean
Deprecated.
69144 69145 69146 69147 69148 69149 69150 |
# File 'lib/aws-sdk-ec2/types.rb', line 69144 class PeeringConnectionOptions < Struct.new( :allow_dns_resolution_from_remote_vpc, :allow_egress_from_local_classic_link_to_remote_vpc, :allow_egress_from_local_vpc_to_remote_classic_link) SENSITIVE = [] include Aws::Structure end |