Class: Aws::EC2::Types::Placement

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes the placement of an instance.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#affinityString

The affinity setting for the instance on the Dedicated Host.

This parameter is not supported for [CreateFleet] or [ImportInstance].

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateFleet [2]: docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ImportInstance.html

Returns:

  • (String)


69488
69489
69490
69491
69492
69493
69494
69495
69496
69497
69498
69499
69500
69501
# File 'lib/aws-sdk-ec2/types.rb', line 69488

class Placement < Struct.new(
  :availability_zone_id,
  :affinity,
  :group_name,
  :partition_number,
  :host_id,
  :tenancy,
  :spread_domain,
  :host_resource_group_arn,
  :group_id,
  :availability_zone)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zoneString

The Availability Zone of the instance.

On input, you can specify ‘AvailabilityZone` or `AvailabilityZoneId`, but not both. If you specify neither one, Amazon EC2 automatically selects an Availability Zone for you.

This parameter is not supported for [CreateFleet].

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateFleet

Returns:

  • (String)


69488
69489
69490
69491
69492
69493
69494
69495
69496
69497
69498
69499
69500
69501
# File 'lib/aws-sdk-ec2/types.rb', line 69488

class Placement < Struct.new(
  :availability_zone_id,
  :affinity,
  :group_name,
  :partition_number,
  :host_id,
  :tenancy,
  :spread_domain,
  :host_resource_group_arn,
  :group_id,
  :availability_zone)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zone_idString

The ID of the Availability Zone of the instance.

On input, you can specify ‘AvailabilityZone` or `AvailabilityZoneId`, but not both. If you specify neither one, Amazon EC2 automatically selects an Availability Zone for you.

This parameter is not supported for [CreateFleet].

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateFleet

Returns:

  • (String)


69488
69489
69490
69491
69492
69493
69494
69495
69496
69497
69498
69499
69500
69501
# File 'lib/aws-sdk-ec2/types.rb', line 69488

class Placement < Struct.new(
  :availability_zone_id,
  :affinity,
  :group_name,
  :partition_number,
  :host_id,
  :tenancy,
  :spread_domain,
  :host_resource_group_arn,
  :group_id,
  :availability_zone)
  SENSITIVE = []
  include Aws::Structure
end

#group_idString

The ID of the placement group that the instance is in.

On input, you can specify ‘GroupId` or `GroupName`, but not both.

Returns:

  • (String)


69488
69489
69490
69491
69492
69493
69494
69495
69496
69497
69498
69499
69500
69501
# File 'lib/aws-sdk-ec2/types.rb', line 69488

class Placement < Struct.new(
  :availability_zone_id,
  :affinity,
  :group_name,
  :partition_number,
  :host_id,
  :tenancy,
  :spread_domain,
  :host_resource_group_arn,
  :group_id,
  :availability_zone)
  SENSITIVE = []
  include Aws::Structure
end

#group_nameString

The name of the placement group that the instance is in.

On input, you can specify ‘GroupId` or `GroupName`, but not both.

Returns:

  • (String)


69488
69489
69490
69491
69492
69493
69494
69495
69496
69497
69498
69499
69500
69501
# File 'lib/aws-sdk-ec2/types.rb', line 69488

class Placement < Struct.new(
  :availability_zone_id,
  :affinity,
  :group_name,
  :partition_number,
  :host_id,
  :tenancy,
  :spread_domain,
  :host_resource_group_arn,
  :group_id,
  :availability_zone)
  SENSITIVE = []
  include Aws::Structure
end

#host_idString

The ID of the Dedicated Host on which the instance resides.

This parameter is not supported for [CreateFleet] or [ImportInstance].

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateFleet [2]: docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ImportInstance.html

Returns:

  • (String)


69488
69489
69490
69491
69492
69493
69494
69495
69496
69497
69498
69499
69500
69501
# File 'lib/aws-sdk-ec2/types.rb', line 69488

class Placement < Struct.new(
  :availability_zone_id,
  :affinity,
  :group_name,
  :partition_number,
  :host_id,
  :tenancy,
  :spread_domain,
  :host_resource_group_arn,
  :group_id,
  :availability_zone)
  SENSITIVE = []
  include Aws::Structure
end

#host_resource_group_arnString

The ARN of the host resource group in which to launch the instances.

On input, if you specify this parameter, either omit the Tenancy parameter or set it to ‘host`.

This parameter is not supported for [CreateFleet].

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateFleet

Returns:

  • (String)


69488
69489
69490
69491
69492
69493
69494
69495
69496
69497
69498
69499
69500
69501
# File 'lib/aws-sdk-ec2/types.rb', line 69488

class Placement < Struct.new(
  :availability_zone_id,
  :affinity,
  :group_name,
  :partition_number,
  :host_id,
  :tenancy,
  :spread_domain,
  :host_resource_group_arn,
  :group_id,
  :availability_zone)
  SENSITIVE = []
  include Aws::Structure
end

#partition_numberInteger

The number of the partition that the instance is in. Valid only if the placement group strategy is set to ‘partition`.

This parameter is not supported for [CreateFleet].

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateFleet

Returns:

  • (Integer)


69488
69489
69490
69491
69492
69493
69494
69495
69496
69497
69498
69499
69500
69501
# File 'lib/aws-sdk-ec2/types.rb', line 69488

class Placement < Struct.new(
  :availability_zone_id,
  :affinity,
  :group_name,
  :partition_number,
  :host_id,
  :tenancy,
  :spread_domain,
  :host_resource_group_arn,
  :group_id,
  :availability_zone)
  SENSITIVE = []
  include Aws::Structure
end

#spread_domainString

Reserved for future use.

Returns:

  • (String)


69488
69489
69490
69491
69492
69493
69494
69495
69496
69497
69498
69499
69500
69501
# File 'lib/aws-sdk-ec2/types.rb', line 69488

class Placement < Struct.new(
  :availability_zone_id,
  :affinity,
  :group_name,
  :partition_number,
  :host_id,
  :tenancy,
  :spread_domain,
  :host_resource_group_arn,
  :group_id,
  :availability_zone)
  SENSITIVE = []
  include Aws::Structure
end

#tenancyString

The tenancy of the instance. An instance with a tenancy of ‘dedicated` runs on single-tenant hardware.

This parameter is not supported for [CreateFleet]. The ‘host` tenancy is not supported for [ImportInstance] or for T3 instances that are configured for the `unlimited` CPU credit option.

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateFleet [2]: docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ImportInstance.html

Returns:

  • (String)


69488
69489
69490
69491
69492
69493
69494
69495
69496
69497
69498
69499
69500
69501
# File 'lib/aws-sdk-ec2/types.rb', line 69488

class Placement < Struct.new(
  :availability_zone_id,
  :affinity,
  :group_name,
  :partition_number,
  :host_id,
  :tenancy,
  :spread_domain,
  :host_resource_group_arn,
  :group_id,
  :availability_zone)
  SENSITIVE = []
  include Aws::Structure
end