Class: Aws::EC2::Types::PrivateDnsNameConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::PrivateDnsNameConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Information about the private DNS name for the service endpoint.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the record subdomain the service provider needs to create.
-
#state ⇒ String
The verification state of the VPC endpoint service.
-
#type ⇒ String
The endpoint service verification type, for example TXT.
-
#value ⇒ String
The value the service provider adds to the private DNS name domain record before verification.
Instance Attribute Details
#name ⇒ String
The name of the record subdomain the service provider needs to
create. The service provider adds the value text to the name.
72188 72189 72190 72191 72192 72193 72194 72195 |
# File 'lib/aws-sdk-ec2/types.rb', line 72188 class PrivateDnsNameConfiguration < Struct.new( :state, :type, :value, :name) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The verification state of the VPC endpoint service.
Consumers of the endpoint service can use the private name only when
the state is verified.
72188 72189 72190 72191 72192 72193 72194 72195 |
# File 'lib/aws-sdk-ec2/types.rb', line 72188 class PrivateDnsNameConfiguration < Struct.new( :state, :type, :value, :name) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The endpoint service verification type, for example TXT.
72188 72189 72190 72191 72192 72193 72194 72195 |
# File 'lib/aws-sdk-ec2/types.rb', line 72188 class PrivateDnsNameConfiguration < Struct.new( :state, :type, :value, :name) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
The value the service provider adds to the private DNS name domain record before verification.
72188 72189 72190 72191 72192 72193 72194 72195 |
# File 'lib/aws-sdk-ec2/types.rb', line 72188 class PrivateDnsNameConfiguration < Struct.new( :state, :type, :value, :name) SENSITIVE = [] include Aws::Structure end |