Class: Aws::EC2::Types::ProvisionIpamByoasnRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ProvisionIpamByoasnRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asn ⇒ String
A public 2-byte or 4-byte ASN.
-
#asn_authorization_context ⇒ Types::AsnAuthorizationContext
An ASN authorization context.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#ipam_id ⇒ String
An IPAM ID.
Instance Attribute Details
#asn ⇒ String
A public 2-byte or 4-byte ASN.
70757 70758 70759 70760 70761 70762 70763 70764 |
# File 'lib/aws-sdk-ec2/types.rb', line 70757 class ProvisionIpamByoasnRequest < Struct.new( :dry_run, :ipam_id, :asn, :asn_authorization_context) SENSITIVE = [] include Aws::Structure end |
#asn_authorization_context ⇒ Types::AsnAuthorizationContext
An ASN authorization context.
70757 70758 70759 70760 70761 70762 70763 70764 |
# File 'lib/aws-sdk-ec2/types.rb', line 70757 class ProvisionIpamByoasnRequest < Struct.new( :dry_run, :ipam_id, :asn, :asn_authorization_context) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
70757 70758 70759 70760 70761 70762 70763 70764 |
# File 'lib/aws-sdk-ec2/types.rb', line 70757 class ProvisionIpamByoasnRequest < Struct.new( :dry_run, :ipam_id, :asn, :asn_authorization_context) SENSITIVE = [] include Aws::Structure end |
#ipam_id ⇒ String
An IPAM ID.
70757 70758 70759 70760 70761 70762 70763 70764 |
# File 'lib/aws-sdk-ec2/types.rb', line 70757 class ProvisionIpamByoasnRequest < Struct.new( :dry_run, :ipam_id, :asn, :asn_authorization_context) SENSITIVE = [] include Aws::Structure end |