Class: Aws::EC2::Types::ProvisionIpamByoasnRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#asnString

A public 2-byte or 4-byte ASN.

Returns:

  • (String)


69733
69734
69735
69736
69737
69738
69739
69740
# File 'lib/aws-sdk-ec2/types.rb', line 69733

class ProvisionIpamByoasnRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :asn,
  :asn_authorization_context)
  SENSITIVE = []
  include Aws::Structure
end

#asn_authorization_contextTypes::AsnAuthorizationContext

An ASN authorization context.



69733
69734
69735
69736
69737
69738
69739
69740
# File 'lib/aws-sdk-ec2/types.rb', line 69733

class ProvisionIpamByoasnRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :asn,
  :asn_authorization_context)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


69733
69734
69735
69736
69737
69738
69739
69740
# File 'lib/aws-sdk-ec2/types.rb', line 69733

class ProvisionIpamByoasnRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :asn,
  :asn_authorization_context)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_idString

An IPAM ID.

Returns:

  • (String)


69733
69734
69735
69736
69737
69738
69739
69740
# File 'lib/aws-sdk-ec2/types.rb', line 69733

class ProvisionIpamByoasnRequest < Struct.new(
  :dry_run,
  :ipam_id,
  :asn,
  :asn_authorization_context)
  SENSITIVE = []
  include Aws::Structure
end