Class: Aws::EC2::Types::ProvisionIpamPoolCidrRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cidrString

The CIDR you want to assign to the IPAM pool. Either "NetmaskLength" or "Cidr" is required. This value will be null if you specify "NetmaskLength" and will be filled in during the provisioning process.

Returns:

  • (String)


71197
71198
71199
71200
71201
71202
71203
71204
71205
71206
71207
71208
# File 'lib/aws-sdk-ec2/types.rb', line 71197

class ProvisionIpamPoolCidrRequest < Struct.new(
  :dry_run,
  :ipam_pool_id,
  :cidr,
  :cidr_authorization_context,
  :netmask_length,
  :client_token,
  :verification_method,
  :ipam_external_resource_verification_token_id)
  SENSITIVE = []
  include Aws::Structure
end

#cidr_authorization_contextTypes::IpamCidrAuthorizationContext

A signed document that proves that you are authorized to bring a specified IP address range to Amazon using BYOIP. This option only applies to IPv4 and IPv6 pools in the public scope.



71197
71198
71199
71200
71201
71202
71203
71204
71205
71206
71207
71208
# File 'lib/aws-sdk-ec2/types.rb', line 71197

class ProvisionIpamPoolCidrRequest < Struct.new(
  :dry_run,
  :ipam_pool_id,
  :cidr,
  :cidr_authorization_context,
  :netmask_length,
  :client_token,
  :verification_method,
  :ipam_external_resource_verification_token_id)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


71197
71198
71199
71200
71201
71202
71203
71204
71205
71206
71207
71208
# File 'lib/aws-sdk-ec2/types.rb', line 71197

class ProvisionIpamPoolCidrRequest < Struct.new(
  :dry_run,
  :ipam_pool_id,
  :cidr,
  :cidr_authorization_context,
  :netmask_length,
  :client_token,
  :verification_method,
  :ipam_external_resource_verification_token_id)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


71197
71198
71199
71200
71201
71202
71203
71204
71205
71206
71207
71208
# File 'lib/aws-sdk-ec2/types.rb', line 71197

class ProvisionIpamPoolCidrRequest < Struct.new(
  :dry_run,
  :ipam_pool_id,
  :cidr,
  :cidr_authorization_context,
  :netmask_length,
  :client_token,
  :verification_method,
  :ipam_external_resource_verification_token_id)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_external_resource_verification_token_idString

Verification token ID. This option only applies to IPv4 and IPv6 pools in the public scope.

Returns:

  • (String)


71197
71198
71199
71200
71201
71202
71203
71204
71205
71206
71207
71208
# File 'lib/aws-sdk-ec2/types.rb', line 71197

class ProvisionIpamPoolCidrRequest < Struct.new(
  :dry_run,
  :ipam_pool_id,
  :cidr,
  :cidr_authorization_context,
  :netmask_length,
  :client_token,
  :verification_method,
  :ipam_external_resource_verification_token_id)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_pool_idString

The ID of the IPAM pool to which you want to assign a CIDR.

Returns:

  • (String)


71197
71198
71199
71200
71201
71202
71203
71204
71205
71206
71207
71208
# File 'lib/aws-sdk-ec2/types.rb', line 71197

class ProvisionIpamPoolCidrRequest < Struct.new(
  :dry_run,
  :ipam_pool_id,
  :cidr,
  :cidr_authorization_context,
  :netmask_length,
  :client_token,
  :verification_method,
  :ipam_external_resource_verification_token_id)
  SENSITIVE = []
  include Aws::Structure
end

#netmask_lengthInteger

The netmask length of the CIDR you'd like to provision to a pool. Can be used for provisioning Amazon-provided IPv6 CIDRs to top-level pools and for provisioning CIDRs to pools with source pools. Cannot be used to provision BYOIP CIDRs to top-level pools. Either "NetmaskLength" or "Cidr" is required.

Returns:

  • (Integer)


71197
71198
71199
71200
71201
71202
71203
71204
71205
71206
71207
71208
# File 'lib/aws-sdk-ec2/types.rb', line 71197

class ProvisionIpamPoolCidrRequest < Struct.new(
  :dry_run,
  :ipam_pool_id,
  :cidr,
  :cidr_authorization_context,
  :netmask_length,
  :client_token,
  :verification_method,
  :ipam_external_resource_verification_token_id)
  SENSITIVE = []
  include Aws::Structure
end

#verification_methodString

The method for verifying control of a public IP address range. Defaults to remarks-x509 if not specified. This option only applies to IPv4 and IPv6 pools in the public scope.

Returns:

  • (String)


71197
71198
71199
71200
71201
71202
71203
71204
71205
71206
71207
71208
# File 'lib/aws-sdk-ec2/types.rb', line 71197

class ProvisionIpamPoolCidrRequest < Struct.new(
  :dry_run,
  :ipam_pool_id,
  :cidr,
  :cidr_authorization_context,
  :netmask_length,
  :client_token,
  :verification_method,
  :ipam_external_resource_verification_token_id)
  SENSITIVE = []
  include Aws::Structure
end