Class: Aws::EC2::Types::ProvisionIpamPoolCidrRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ProvisionIpamPoolCidrRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cidr ⇒ String
The CIDR you want to assign to the IPAM pool.
-
#cidr_authorization_context ⇒ Types::IpamCidrAuthorizationContext
A signed document that proves that you are authorized to bring a specified IP address range to Amazon using BYOIP.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#ipam_external_resource_verification_token_id ⇒ String
Verification token ID.
-
#ipam_pool_id ⇒ String
The ID of the IPAM pool to which you want to assign a CIDR.
-
#netmask_length ⇒ Integer
The netmask length of the CIDR you’d like to provision to a pool.
-
#verification_method ⇒ String
The method for verifying control of a public IP address range.
Instance Attribute Details
#cidr ⇒ String
The CIDR you want to assign to the IPAM pool. Either “NetmaskLength” or “Cidr” is required. This value will be null if you specify “NetmaskLength” and will be filled in during the provisioning process.
69799 69800 69801 69802 69803 69804 69805 69806 69807 69808 69809 69810 |
# File 'lib/aws-sdk-ec2/types.rb', line 69799 class ProvisionIpamPoolCidrRequest < Struct.new( :dry_run, :ipam_pool_id, :cidr, :cidr_authorization_context, :netmask_length, :client_token, :verification_method, :ipam_external_resource_verification_token_id) SENSITIVE = [] include Aws::Structure end |
#cidr_authorization_context ⇒ Types::IpamCidrAuthorizationContext
A signed document that proves that you are authorized to bring a specified IP address range to Amazon using BYOIP. This option only applies to IPv4 and IPv6 pools in the public scope.
69799 69800 69801 69802 69803 69804 69805 69806 69807 69808 69809 69810 |
# File 'lib/aws-sdk-ec2/types.rb', line 69799 class ProvisionIpamPoolCidrRequest < Struct.new( :dry_run, :ipam_pool_id, :cidr, :cidr_authorization_context, :netmask_length, :client_token, :verification_method, :ipam_external_resource_verification_token_id) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [Ensuring idempotency].
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html
69799 69800 69801 69802 69803 69804 69805 69806 69807 69808 69809 69810 |
# File 'lib/aws-sdk-ec2/types.rb', line 69799 class ProvisionIpamPoolCidrRequest < Struct.new( :dry_run, :ipam_pool_id, :cidr, :cidr_authorization_context, :netmask_length, :client_token, :verification_method, :ipam_external_resource_verification_token_id) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
69799 69800 69801 69802 69803 69804 69805 69806 69807 69808 69809 69810 |
# File 'lib/aws-sdk-ec2/types.rb', line 69799 class ProvisionIpamPoolCidrRequest < Struct.new( :dry_run, :ipam_pool_id, :cidr, :cidr_authorization_context, :netmask_length, :client_token, :verification_method, :ipam_external_resource_verification_token_id) SENSITIVE = [] include Aws::Structure end |
#ipam_external_resource_verification_token_id ⇒ String
Verification token ID. This option only applies to IPv4 and IPv6 pools in the public scope.
69799 69800 69801 69802 69803 69804 69805 69806 69807 69808 69809 69810 |
# File 'lib/aws-sdk-ec2/types.rb', line 69799 class ProvisionIpamPoolCidrRequest < Struct.new( :dry_run, :ipam_pool_id, :cidr, :cidr_authorization_context, :netmask_length, :client_token, :verification_method, :ipam_external_resource_verification_token_id) SENSITIVE = [] include Aws::Structure end |
#ipam_pool_id ⇒ String
The ID of the IPAM pool to which you want to assign a CIDR.
69799 69800 69801 69802 69803 69804 69805 69806 69807 69808 69809 69810 |
# File 'lib/aws-sdk-ec2/types.rb', line 69799 class ProvisionIpamPoolCidrRequest < Struct.new( :dry_run, :ipam_pool_id, :cidr, :cidr_authorization_context, :netmask_length, :client_token, :verification_method, :ipam_external_resource_verification_token_id) SENSITIVE = [] include Aws::Structure end |
#netmask_length ⇒ Integer
The netmask length of the CIDR you’d like to provision to a pool. Can be used for provisioning Amazon-provided IPv6 CIDRs to top-level pools and for provisioning CIDRs to pools with source pools. Cannot be used to provision BYOIP CIDRs to top-level pools. Either “NetmaskLength” or “Cidr” is required.
69799 69800 69801 69802 69803 69804 69805 69806 69807 69808 69809 69810 |
# File 'lib/aws-sdk-ec2/types.rb', line 69799 class ProvisionIpamPoolCidrRequest < Struct.new( :dry_run, :ipam_pool_id, :cidr, :cidr_authorization_context, :netmask_length, :client_token, :verification_method, :ipam_external_resource_verification_token_id) SENSITIVE = [] include Aws::Structure end |
#verification_method ⇒ String
The method for verifying control of a public IP address range. Defaults to ‘remarks-x509` if not specified. This option only applies to IPv4 and IPv6 pools in the public scope.
69799 69800 69801 69802 69803 69804 69805 69806 69807 69808 69809 69810 |
# File 'lib/aws-sdk-ec2/types.rb', line 69799 class ProvisionIpamPoolCidrRequest < Struct.new( :dry_run, :ipam_pool_id, :cidr, :cidr_authorization_context, :netmask_length, :client_token, :verification_method, :ipam_external_resource_verification_token_id) SENSITIVE = [] include Aws::Structure end |