Class: Aws::EC2::Types::ProvisionPublicIpv4PoolCidrRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ProvisionPublicIpv4PoolCidrRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#ipam_pool_id ⇒ String
The ID of the IPAM pool you would like to use to allocate this CIDR.
-
#netmask_length ⇒ Integer
The netmask length of the CIDR you would like to allocate to the public IPv4 pool.
-
#network_border_group ⇒ String
The Availability Zone (AZ) or Local Zone (LZ) network border group that the resource that the IP address is assigned to is in.
-
#pool_id ⇒ String
The ID of the public IPv4 pool you would like to use for this CIDR.
Instance Attribute Details
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action
without actually making the request and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
74082 74083 74084 74085 74086 74087 74088 74089 74090 |
# File 'lib/aws-sdk-ec2/types.rb', line 74082 class ProvisionPublicIpv4PoolCidrRequest < Struct.new( :dry_run, :ipam_pool_id, :pool_id, :netmask_length, :network_border_group) SENSITIVE = [] include Aws::Structure end |
#ipam_pool_id ⇒ String
The ID of the IPAM pool you would like to use to allocate this CIDR.
74082 74083 74084 74085 74086 74087 74088 74089 74090 |
# File 'lib/aws-sdk-ec2/types.rb', line 74082 class ProvisionPublicIpv4PoolCidrRequest < Struct.new( :dry_run, :ipam_pool_id, :pool_id, :netmask_length, :network_border_group) SENSITIVE = [] include Aws::Structure end |
#netmask_length ⇒ Integer
The netmask length of the CIDR you would like to allocate to the public IPv4 pool. The least specific netmask length you can define is 24.
74082 74083 74084 74085 74086 74087 74088 74089 74090 |
# File 'lib/aws-sdk-ec2/types.rb', line 74082 class ProvisionPublicIpv4PoolCidrRequest < Struct.new( :dry_run, :ipam_pool_id, :pool_id, :netmask_length, :network_border_group) SENSITIVE = [] include Aws::Structure end |
#network_border_group ⇒ String
The Availability Zone (AZ) or Local Zone (LZ) network border group that the resource that the IP address is assigned to is in. Defaults to an AZ network border group. For more information on available Local Zones, see Local Zone availability in the Amazon EC2 User Guide.
74082 74083 74084 74085 74086 74087 74088 74089 74090 |
# File 'lib/aws-sdk-ec2/types.rb', line 74082 class ProvisionPublicIpv4PoolCidrRequest < Struct.new( :dry_run, :ipam_pool_id, :pool_id, :netmask_length, :network_border_group) SENSITIVE = [] include Aws::Structure end |
#pool_id ⇒ String
The ID of the public IPv4 pool you would like to use for this CIDR.
74082 74083 74084 74085 74086 74087 74088 74089 74090 |
# File 'lib/aws-sdk-ec2/types.rb', line 74082 class ProvisionPublicIpv4PoolCidrRequest < Struct.new( :dry_run, :ipam_pool_id, :pool_id, :netmask_length, :network_border_group) SENSITIVE = [] include Aws::Structure end |