Class: Aws::EC2::Types::PublicIpDnsNameOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::PublicIpDnsNameOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Public hostname type options. For more information, see [EC2 instance hostnames, DNS names, and domains] in the *Amazon EC2 User Guide*.
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-instance-naming.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dns_hostname_type ⇒ String
The public hostname type.
-
#public_dual_stack_dns_name ⇒ String
A dual-stack public hostname for a network interface.
-
#public_ipv_4_dns_name ⇒ String
An IPv4-enabled public hostname for a network interface.
-
#public_ipv_6_dns_name ⇒ String
An IPv6-enabled public hostname for a network interface.
Instance Attribute Details
#dns_hostname_type ⇒ String
The public hostname type. For more information, see [EC2 instance hostnames, DNS names, and domains] in the *Amazon EC2 User Guide*.
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-instance-naming.html
68541 68542 68543 68544 68545 68546 68547 68548 |
# File 'lib/aws-sdk-ec2/types.rb', line 68541 class PublicIpDnsNameOptions < Struct.new( :dns_hostname_type, :public_ipv_4_dns_name, :public_ipv_6_dns_name, :public_dual_stack_dns_name) SENSITIVE = [] include Aws::Structure end |
#public_dual_stack_dns_name ⇒ String
A dual-stack public hostname for a network interface. Requests from within the VPC resolve to both the private IPv4 address and the IPv6 Global Unicast Address of the network interface. Requests from the internet resolve to both the public IPv4 and the IPv6 GUA address of the network interface.
68541 68542 68543 68544 68545 68546 68547 68548 |
# File 'lib/aws-sdk-ec2/types.rb', line 68541 class PublicIpDnsNameOptions < Struct.new( :dns_hostname_type, :public_ipv_4_dns_name, :public_ipv_6_dns_name, :public_dual_stack_dns_name) SENSITIVE = [] include Aws::Structure end |
#public_ipv_4_dns_name ⇒ String
An IPv4-enabled public hostname for a network interface. Requests from within the VPC resolve to the private primary IPv4 address of the network interface. Requests from the internet resolve to the public IPv4 address of the network interface.
68541 68542 68543 68544 68545 68546 68547 68548 |
# File 'lib/aws-sdk-ec2/types.rb', line 68541 class PublicIpDnsNameOptions < Struct.new( :dns_hostname_type, :public_ipv_4_dns_name, :public_ipv_6_dns_name, :public_dual_stack_dns_name) SENSITIVE = [] include Aws::Structure end |
#public_ipv_6_dns_name ⇒ String
An IPv6-enabled public hostname for a network interface. Requests from within the VPC or from the internet resolve to the IPv6 GUA of the network interface.
68541 68542 68543 68544 68545 68546 68547 68548 |
# File 'lib/aws-sdk-ec2/types.rb', line 68541 class PublicIpDnsNameOptions < Struct.new( :dns_hostname_type, :public_ipv_4_dns_name, :public_ipv_6_dns_name, :public_dual_stack_dns_name) SENSITIVE = [] include Aws::Structure end |