Class: Aws::EC2::Types::PurchaseCapacityBlockExtensionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_block_extension_offering_idString

The ID of the Capacity Block extension offering to purchase.

Returns:

  • (String)


72908
72909
72910
72911
72912
72913
72914
# File 'lib/aws-sdk-ec2/types.rb', line 72908

class PurchaseCapacityBlockExtensionRequest < Struct.new(
  :capacity_block_extension_offering_id,
  :capacity_reservation_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#capacity_reservation_idString

The ID of the Capacity reservation to be extended.

Returns:

  • (String)


72908
72909
72910
72911
72912
72913
72914
# File 'lib/aws-sdk-ec2/types.rb', line 72908

class PurchaseCapacityBlockExtensionRequest < Struct.new(
  :capacity_block_extension_offering_id,
  :capacity_reservation_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


72908
72909
72910
72911
72912
72913
72914
# File 'lib/aws-sdk-ec2/types.rb', line 72908

class PurchaseCapacityBlockExtensionRequest < Struct.new(
  :capacity_block_extension_offering_id,
  :capacity_reservation_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end