Class: Aws::EC2::Types::PurchaseCapacityBlockExtensionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::PurchaseCapacityBlockExtensionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_block_extension_offering_id ⇒ String
The ID of the Capacity Block extension offering to purchase.
-
#capacity_reservation_id ⇒ String
The ID of the Capacity reservation to be extended.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#capacity_block_extension_offering_id ⇒ String
The ID of the Capacity Block extension offering to purchase.
70720 70721 70722 70723 70724 70725 70726 |
# File 'lib/aws-sdk-ec2/types.rb', line 70720 class PurchaseCapacityBlockExtensionRequest < Struct.new( :capacity_block_extension_offering_id, :capacity_reservation_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#capacity_reservation_id ⇒ String
The ID of the Capacity reservation to be extended.
70720 70721 70722 70723 70724 70725 70726 |
# File 'lib/aws-sdk-ec2/types.rb', line 70720 class PurchaseCapacityBlockExtensionRequest < Struct.new( :capacity_block_extension_offering_id, :capacity_reservation_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
70720 70721 70722 70723 70724 70725 70726 |
# File 'lib/aws-sdk-ec2/types.rb', line 70720 class PurchaseCapacityBlockExtensionRequest < Struct.new( :capacity_block_extension_offering_id, :capacity_reservation_id, :dry_run) SENSITIVE = [] include Aws::Structure end |