Class: Aws::EC2::Types::PurchaseCapacityBlockRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::PurchaseCapacityBlockRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_block_offering_id ⇒ String
The ID of the Capacity Block offering.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#instance_platform ⇒ String
The type of operating system for which to reserve capacity.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the Capacity Block during launch.
Instance Attribute Details
#capacity_block_offering_id ⇒ String
The ID of the Capacity Block offering.
74407 74408 74409 74410 74411 74412 74413 74414 |
# File 'lib/aws-sdk-ec2/types.rb', line 74407 class PurchaseCapacityBlockRequest < Struct.new( :dry_run, :tag_specifications, :capacity_block_offering_id, :instance_platform) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
74407 74408 74409 74410 74411 74412 74413 74414 |
# File 'lib/aws-sdk-ec2/types.rb', line 74407 class PurchaseCapacityBlockRequest < Struct.new( :dry_run, :tag_specifications, :capacity_block_offering_id, :instance_platform) SENSITIVE = [] include Aws::Structure end |
#instance_platform ⇒ String
The type of operating system for which to reserve capacity.
74407 74408 74409 74410 74411 74412 74413 74414 |
# File 'lib/aws-sdk-ec2/types.rb', line 74407 class PurchaseCapacityBlockRequest < Struct.new( :dry_run, :tag_specifications, :capacity_block_offering_id, :instance_platform) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the Capacity Block during launch.
74407 74408 74409 74410 74411 74412 74413 74414 |
# File 'lib/aws-sdk-ec2/types.rb', line 74407 class PurchaseCapacityBlockRequest < Struct.new( :dry_run, :tag_specifications, :capacity_block_offering_id, :instance_platform) SENSITIVE = [] include Aws::Structure end |