Class: Aws::EC2::Types::PurchaseCapacityBlockRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_block_offering_idString

The ID of the Capacity Block offering.

Returns:

  • (String)


70761
70762
70763
70764
70765
70766
70767
70768
# File 'lib/aws-sdk-ec2/types.rb', line 70761

class PurchaseCapacityBlockRequest < Struct.new(
  :dry_run,
  :tag_specifications,
  :capacity_block_offering_id,
  :instance_platform)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


70761
70762
70763
70764
70765
70766
70767
70768
# File 'lib/aws-sdk-ec2/types.rb', line 70761

class PurchaseCapacityBlockRequest < Struct.new(
  :dry_run,
  :tag_specifications,
  :capacity_block_offering_id,
  :instance_platform)
  SENSITIVE = []
  include Aws::Structure
end

#instance_platformString

The type of operating system for which to reserve capacity.

Returns:

  • (String)


70761
70762
70763
70764
70765
70766
70767
70768
# File 'lib/aws-sdk-ec2/types.rb', line 70761

class PurchaseCapacityBlockRequest < Struct.new(
  :dry_run,
  :tag_specifications,
  :capacity_block_offering_id,
  :instance_platform)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the Capacity Block during launch.

Returns:



70761
70762
70763
70764
70765
70766
70767
70768
# File 'lib/aws-sdk-ec2/types.rb', line 70761

class PurchaseCapacityBlockRequest < Struct.new(
  :dry_run,
  :tag_specifications,
  :capacity_block_offering_id,
  :instance_platform)
  SENSITIVE = []
  include Aws::Structure
end