Class: Aws::EC2::Types::PurchaseCapacityBlockRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::PurchaseCapacityBlockRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_block_offering_id ⇒ String
The ID of the Capacity Block offering.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#instance_platform ⇒ String
The type of operating system for which to reserve capacity.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the Capacity Block during launch.
Instance Attribute Details
#capacity_block_offering_id ⇒ String
The ID of the Capacity Block offering.
70175 70176 70177 70178 70179 70180 70181 70182 |
# File 'lib/aws-sdk-ec2/types.rb', line 70175 class PurchaseCapacityBlockRequest < Struct.new( :dry_run, :tag_specifications, :capacity_block_offering_id, :instance_platform) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
70175 70176 70177 70178 70179 70180 70181 70182 |
# File 'lib/aws-sdk-ec2/types.rb', line 70175 class PurchaseCapacityBlockRequest < Struct.new( :dry_run, :tag_specifications, :capacity_block_offering_id, :instance_platform) SENSITIVE = [] include Aws::Structure end |
#instance_platform ⇒ String
The type of operating system for which to reserve capacity.
70175 70176 70177 70178 70179 70180 70181 70182 |
# File 'lib/aws-sdk-ec2/types.rb', line 70175 class PurchaseCapacityBlockRequest < Struct.new( :dry_run, :tag_specifications, :capacity_block_offering_id, :instance_platform) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the Capacity Block during launch.
70175 70176 70177 70178 70179 70180 70181 70182 |
# File 'lib/aws-sdk-ec2/types.rb', line 70175 class PurchaseCapacityBlockRequest < Struct.new( :dry_run, :tag_specifications, :capacity_block_offering_id, :instance_platform) SENSITIVE = [] include Aws::Structure end |