Class: Aws::EC2::Types::PurchaseHostReservationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [Ensuring Idempotency].

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html

Returns:

  • (String)


69774
69775
69776
69777
69778
69779
69780
69781
69782
69783
# File 'lib/aws-sdk-ec2/types.rb', line 69774

class PurchaseHostReservationRequest < Struct.new(
  :client_token,
  :currency_code,
  :host_id_set,
  :limit_price,
  :offering_id,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#currency_codeString

The currency in which the ‘totalUpfrontPrice`, `LimitPrice`, and `totalHourlyPrice` amounts are specified. At this time, the only supported currency is `USD`.

Returns:

  • (String)


69774
69775
69776
69777
69778
69779
69780
69781
69782
69783
# File 'lib/aws-sdk-ec2/types.rb', line 69774

class PurchaseHostReservationRequest < Struct.new(
  :client_token,
  :currency_code,
  :host_id_set,
  :limit_price,
  :offering_id,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#host_id_setArray<String>

The IDs of the Dedicated Hosts with which the reservation will be associated.

Returns:

  • (Array<String>)


69774
69775
69776
69777
69778
69779
69780
69781
69782
69783
# File 'lib/aws-sdk-ec2/types.rb', line 69774

class PurchaseHostReservationRequest < Struct.new(
  :client_token,
  :currency_code,
  :host_id_set,
  :limit_price,
  :offering_id,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#limit_priceString

The specified limit is checked against the total upfront cost of the reservation (calculated as the offering’s upfront cost multiplied by the host count). If the total upfront cost is greater than the specified price limit, the request fails. This is used to ensure that the purchase does not exceed the expected upfront cost of the purchase. At this time, the only supported currency is ‘USD`. For example, to indicate a limit price of USD 100, specify 100.00.

Returns:

  • (String)


69774
69775
69776
69777
69778
69779
69780
69781
69782
69783
# File 'lib/aws-sdk-ec2/types.rb', line 69774

class PurchaseHostReservationRequest < Struct.new(
  :client_token,
  :currency_code,
  :host_id_set,
  :limit_price,
  :offering_id,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#offering_idString

The ID of the offering.

Returns:

  • (String)


69774
69775
69776
69777
69778
69779
69780
69781
69782
69783
# File 'lib/aws-sdk-ec2/types.rb', line 69774

class PurchaseHostReservationRequest < Struct.new(
  :client_token,
  :currency_code,
  :host_id_set,
  :limit_price,
  :offering_id,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply to the Dedicated Host Reservation during purchase.

Returns:



69774
69775
69776
69777
69778
69779
69780
69781
69782
69783
# File 'lib/aws-sdk-ec2/types.rb', line 69774

class PurchaseHostReservationRequest < Struct.new(
  :client_token,
  :currency_code,
  :host_id_set,
  :limit_price,
  :offering_id,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end