Class: Aws::EC2::Types::PurchaseHostReservationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::PurchaseHostReservationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#currency_code ⇒ String
The currency in which the ‘totalUpfrontPrice`, `LimitPrice`, and `totalHourlyPrice` amounts are specified.
-
#host_id_set ⇒ Array<String>
The IDs of the Dedicated Hosts with which the reservation will be associated.
-
#limit_price ⇒ String
The specified limit is checked against the total upfront cost of the reservation (calculated as the offering’s upfront cost multiplied by the host count).
-
#offering_id ⇒ String
The ID of the offering.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the Dedicated Host Reservation during purchase.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [Ensuring Idempotency].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html
68802 68803 68804 68805 68806 68807 68808 68809 68810 68811 |
# File 'lib/aws-sdk-ec2/types.rb', line 68802 class PurchaseHostReservationRequest < Struct.new( :client_token, :currency_code, :host_id_set, :limit_price, :offering_id, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#currency_code ⇒ String
The currency in which the ‘totalUpfrontPrice`, `LimitPrice`, and `totalHourlyPrice` amounts are specified. At this time, the only supported currency is `USD`.
68802 68803 68804 68805 68806 68807 68808 68809 68810 68811 |
# File 'lib/aws-sdk-ec2/types.rb', line 68802 class PurchaseHostReservationRequest < Struct.new( :client_token, :currency_code, :host_id_set, :limit_price, :offering_id, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#host_id_set ⇒ Array<String>
The IDs of the Dedicated Hosts with which the reservation will be associated.
68802 68803 68804 68805 68806 68807 68808 68809 68810 68811 |
# File 'lib/aws-sdk-ec2/types.rb', line 68802 class PurchaseHostReservationRequest < Struct.new( :client_token, :currency_code, :host_id_set, :limit_price, :offering_id, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#limit_price ⇒ String
The specified limit is checked against the total upfront cost of the reservation (calculated as the offering’s upfront cost multiplied by the host count). If the total upfront cost is greater than the specified price limit, the request fails. This is used to ensure that the purchase does not exceed the expected upfront cost of the purchase. At this time, the only supported currency is ‘USD`. For example, to indicate a limit price of USD 100, specify 100.00.
68802 68803 68804 68805 68806 68807 68808 68809 68810 68811 |
# File 'lib/aws-sdk-ec2/types.rb', line 68802 class PurchaseHostReservationRequest < Struct.new( :client_token, :currency_code, :host_id_set, :limit_price, :offering_id, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#offering_id ⇒ String
The ID of the offering.
68802 68803 68804 68805 68806 68807 68808 68809 68810 68811 |
# File 'lib/aws-sdk-ec2/types.rb', line 68802 class PurchaseHostReservationRequest < Struct.new( :client_token, :currency_code, :host_id_set, :limit_price, :offering_id, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply to the Dedicated Host Reservation during purchase.
68802 68803 68804 68805 68806 68807 68808 68809 68810 68811 |
# File 'lib/aws-sdk-ec2/types.rb', line 68802 class PurchaseHostReservationRequest < Struct.new( :client_token, :currency_code, :host_id_set, :limit_price, :offering_id, :tag_specifications) SENSITIVE = [] include Aws::Structure end |