Class: Aws::EC2::Types::PurchaseReservedInstancesOfferingRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for PurchaseReservedInstancesOffering.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


74552
74553
74554
74555
74556
74557
74558
74559
74560
# File 'lib/aws-sdk-ec2/types.rb', line 74552

class PurchaseReservedInstancesOfferingRequest < Struct.new(
  :instance_count,
  :reserved_instances_offering_id,
  :purchase_time,
  :dry_run,
  :limit_price)
  SENSITIVE = []
  include Aws::Structure
end

#instance_countInteger

The number of Reserved Instances to purchase.

Returns:

  • (Integer)


74552
74553
74554
74555
74556
74557
74558
74559
74560
# File 'lib/aws-sdk-ec2/types.rb', line 74552

class PurchaseReservedInstancesOfferingRequest < Struct.new(
  :instance_count,
  :reserved_instances_offering_id,
  :purchase_time,
  :dry_run,
  :limit_price)
  SENSITIVE = []
  include Aws::Structure
end

#limit_priceTypes::ReservedInstanceLimitPrice

Specified for Reserved Instance Marketplace offerings to limit the total order and ensure that the Reserved Instances are not purchased at unexpected prices.



74552
74553
74554
74555
74556
74557
74558
74559
74560
# File 'lib/aws-sdk-ec2/types.rb', line 74552

class PurchaseReservedInstancesOfferingRequest < Struct.new(
  :instance_count,
  :reserved_instances_offering_id,
  :purchase_time,
  :dry_run,
  :limit_price)
  SENSITIVE = []
  include Aws::Structure
end

#purchase_timeTime

The time at which to purchase the Reserved Instance, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ).

Returns:

  • (Time)


74552
74553
74554
74555
74556
74557
74558
74559
74560
# File 'lib/aws-sdk-ec2/types.rb', line 74552

class PurchaseReservedInstancesOfferingRequest < Struct.new(
  :instance_count,
  :reserved_instances_offering_id,
  :purchase_time,
  :dry_run,
  :limit_price)
  SENSITIVE = []
  include Aws::Structure
end

#reserved_instances_offering_idString

The ID of the Reserved Instance offering to purchase.

Returns:

  • (String)


74552
74553
74554
74555
74556
74557
74558
74559
74560
# File 'lib/aws-sdk-ec2/types.rb', line 74552

class PurchaseReservedInstancesOfferingRequest < Struct.new(
  :instance_count,
  :reserved_instances_offering_id,
  :purchase_time,
  :dry_run,
  :limit_price)
  SENSITIVE = []
  include Aws::Structure
end