Class: Aws::EC2::Types::PurchaseReservedInstancesOfferingResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the output of PurchaseReservedInstancesOffering.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#reserved_instances_idString

The IDs of the purchased Reserved Instances. If your purchase crosses into a discounted pricing tier, the final Reserved Instances IDs might change. For more information, see Crossing pricing tiers in the Amazon EC2 User Guide.

Returns:

  • (String)


71071
71072
71073
71074
71075
# File 'lib/aws-sdk-ec2/types.rb', line 71071

class PurchaseReservedInstancesOfferingResult < Struct.new(
  :reserved_instances_id)
  SENSITIVE = []
  include Aws::Structure
end