Class: Aws::EC2::Types::PurchaseScheduledInstancesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for PurchaseScheduledInstances.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier that ensures the idempotency of the request. For more information, see [Ensuring Idempotency].

**A suitable default value is auto-generated.** You should normally not need to pass this option.

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html

Returns:

  • (String)


68961
68962
68963
68964
68965
68966
68967
# File 'lib/aws-sdk-ec2/types.rb', line 68961

class PurchaseScheduledInstancesRequest < Struct.new(
  :client_token,
  :dry_run,
  :purchase_requests)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


68961
68962
68963
68964
68965
68966
68967
# File 'lib/aws-sdk-ec2/types.rb', line 68961

class PurchaseScheduledInstancesRequest < Struct.new(
  :client_token,
  :dry_run,
  :purchase_requests)
  SENSITIVE = []
  include Aws::Structure
end

#purchase_requestsArray<Types::PurchaseRequest>

The purchase requests.

Returns:



68961
68962
68963
68964
68965
68966
68967
# File 'lib/aws-sdk-ec2/types.rb', line 68961

class PurchaseScheduledInstancesRequest < Struct.new(
  :client_token,
  :dry_run,
  :purchase_requests)
  SENSITIVE = []
  include Aws::Structure
end