Class: Aws::EC2::Types::RebootInstancesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::RebootInstancesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#instance_ids ⇒ Array<String>
The instance IDs.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
71515 71516 71517 71518 71519 71520 |
# File 'lib/aws-sdk-ec2/types.rb', line 71515 class RebootInstancesRequest < Struct.new( :instance_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#instance_ids ⇒ Array<String>
The instance IDs.
71515 71516 71517 71518 71519 71520 |
# File 'lib/aws-sdk-ec2/types.rb', line 71515 class RebootInstancesRequest < Struct.new( :instance_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |