Class: Aws::EC2::Types::RebootInstancesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::RebootInstancesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#instance_ids ⇒ Array<String>
The instance IDs.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
71139 71140 71141 71142 71143 71144 |
# File 'lib/aws-sdk-ec2/types.rb', line 71139 class RebootInstancesRequest < Struct.new( :instance_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#instance_ids ⇒ Array<String>
The instance IDs.
71139 71140 71141 71142 71143 71144 |
# File 'lib/aws-sdk-ec2/types.rb', line 71139 class RebootInstancesRequest < Struct.new( :instance_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |