Class: Aws::EC2::Types::RebootInstancesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


70878
70879
70880
70881
70882
70883
# File 'lib/aws-sdk-ec2/types.rb', line 70878

class RebootInstancesRequest < Struct.new(
  :instance_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idsArray<String>

The instance IDs.

Returns:

  • (Array<String>)


70878
70879
70880
70881
70882
70883
# File 'lib/aws-sdk-ec2/types.rb', line 70878

class RebootInstancesRequest < Struct.new(
  :instance_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end