Class: Aws::EC2::Types::RebootInstancesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


70458
70459
70460
70461
70462
70463
# File 'lib/aws-sdk-ec2/types.rb', line 70458

class RebootInstancesRequest < Struct.new(
  :instance_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idsArray<String>

The instance IDs.

Returns:

  • (Array<String>)


70458
70459
70460
70461
70462
70463
# File 'lib/aws-sdk-ec2/types.rb', line 70458

class RebootInstancesRequest < Struct.new(
  :instance_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end