Class: Aws::EC2::Types::RebootInstancesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::RebootInstancesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#instance_ids ⇒ Array<String>
The instance IDs.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
70436 70437 70438 70439 70440 70441 |
# File 'lib/aws-sdk-ec2/types.rb', line 70436 class RebootInstancesRequest < Struct.new( :instance_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#instance_ids ⇒ Array<String>
The instance IDs.
70436 70437 70438 70439 70440 70441 |
# File 'lib/aws-sdk-ec2/types.rb', line 70436 class RebootInstancesRequest < Struct.new( :instance_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |