Class: Aws::EC2::Types::RejectCapacityReservationBillingOwnershipRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_reservation_idString

The ID of the Capacity Reservation for which to reject the request.

Returns:

  • (String)


75230
75231
75232
75233
75234
75235
# File 'lib/aws-sdk-ec2/types.rb', line 75230

class RejectCapacityReservationBillingOwnershipRequest < Struct.new(
  :dry_run,
  :capacity_reservation_id)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


75230
75231
75232
75233
75234
75235
# File 'lib/aws-sdk-ec2/types.rb', line 75230

class RejectCapacityReservationBillingOwnershipRequest < Struct.new(
  :dry_run,
  :capacity_reservation_id)
  SENSITIVE = []
  include Aws::Structure
end