Class: Aws::EC2::Types::RejectCapacityReservationBillingOwnershipRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_reservation_idString

The ID of the Capacity Reservation for which to reject the request.

Returns:

  • (String)


70871
70872
70873
70874
70875
70876
# File 'lib/aws-sdk-ec2/types.rb', line 70871

class RejectCapacityReservationBillingOwnershipRequest < Struct.new(
  :dry_run,
  :capacity_reservation_id)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


70871
70872
70873
70874
70875
70876
# File 'lib/aws-sdk-ec2/types.rb', line 70871

class RejectCapacityReservationBillingOwnershipRequest < Struct.new(
  :dry_run,
  :capacity_reservation_id)
  SENSITIVE = []
  include Aws::Structure
end