Class: Aws::EC2::Types::RejectCapacityReservationBillingOwnershipRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::RejectCapacityReservationBillingOwnershipRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_reservation_id ⇒ String
The ID of the Capacity Reservation for which to reject the request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#capacity_reservation_id ⇒ String
The ID of the Capacity Reservation for which to reject the request.
70553 70554 70555 70556 70557 70558 |
# File 'lib/aws-sdk-ec2/types.rb', line 70553 class RejectCapacityReservationBillingOwnershipRequest < Struct.new( :dry_run, :capacity_reservation_id) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
70553 70554 70555 70556 70557 70558 |
# File 'lib/aws-sdk-ec2/types.rb', line 70553 class RejectCapacityReservationBillingOwnershipRequest < Struct.new( :dry_run, :capacity_reservation_id) SENSITIVE = [] include Aws::Structure end |