Class: Aws::EC2::Types::RejectTransitGatewayClientVpnAttachmentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::RejectTransitGatewayClientVpnAttachmentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#transit_gateway_attachment_id ⇒ String
The ID of the Transit Gateway attachment.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
75272 75273 75274 75275 75276 75277 |
# File 'lib/aws-sdk-ec2/types.rb', line 75272 class RejectTransitGatewayClientVpnAttachmentRequest < Struct.new( :transit_gateway_attachment_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_attachment_id ⇒ String
The ID of the Transit Gateway attachment.
75272 75273 75274 75275 75276 75277 |
# File 'lib/aws-sdk-ec2/types.rb', line 75272 class RejectTransitGatewayClientVpnAttachmentRequest < Struct.new( :transit_gateway_attachment_id, :dry_run) SENSITIVE = [] include Aws::Structure end |