Class: Aws::EC2::Types::RejectTransitGatewayClientVpnAttachmentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::RejectTransitGatewayClientVpnAttachmentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#transit_gateway_attachment_id ⇒ String
The ID of the Transit Gateway attachment.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
71063 71064 71065 71066 71067 71068 |
# File 'lib/aws-sdk-ec2/types.rb', line 71063 class RejectTransitGatewayClientVpnAttachmentRequest < Struct.new( :transit_gateway_attachment_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_attachment_id ⇒ String
The ID of the Transit Gateway attachment.
71063 71064 71065 71066 71067 71068 |
# File 'lib/aws-sdk-ec2/types.rb', line 71063 class RejectTransitGatewayClientVpnAttachmentRequest < Struct.new( :transit_gateway_attachment_id, :dry_run) SENSITIVE = [] include Aws::Structure end |