Class: Aws::EC2::Types::RejectTransitGatewayMulticastDomainAssociationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::RejectTransitGatewayMulticastDomainAssociationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#subnet_ids ⇒ Array<String>
The IDs of the subnets to associate with the transit gateway multicast domain.
-
#transit_gateway_attachment_id ⇒ String
The ID of the transit gateway attachment.
-
#transit_gateway_multicast_domain_id ⇒ String
The ID of the transit gateway multicast domain.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
71537 71538 71539 71540 71541 71542 71543 71544 |
# File 'lib/aws-sdk-ec2/types.rb', line 71537 class RejectTransitGatewayMulticastDomainAssociationsRequest < Struct.new( :transit_gateway_multicast_domain_id, :transit_gateway_attachment_id, :subnet_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#subnet_ids ⇒ Array<String>
The IDs of the subnets to associate with the transit gateway multicast domain.
71537 71538 71539 71540 71541 71542 71543 71544 |
# File 'lib/aws-sdk-ec2/types.rb', line 71537 class RejectTransitGatewayMulticastDomainAssociationsRequest < Struct.new( :transit_gateway_multicast_domain_id, :transit_gateway_attachment_id, :subnet_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_attachment_id ⇒ String
The ID of the transit gateway attachment.
71537 71538 71539 71540 71541 71542 71543 71544 |
# File 'lib/aws-sdk-ec2/types.rb', line 71537 class RejectTransitGatewayMulticastDomainAssociationsRequest < Struct.new( :transit_gateway_multicast_domain_id, :transit_gateway_attachment_id, :subnet_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_multicast_domain_id ⇒ String
The ID of the transit gateway multicast domain.
71537 71538 71539 71540 71541 71542 71543 71544 |
# File 'lib/aws-sdk-ec2/types.rb', line 71537 class RejectTransitGatewayMulticastDomainAssociationsRequest < Struct.new( :transit_gateway_multicast_domain_id, :transit_gateway_attachment_id, :subnet_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |