Class: Aws::EC2::Types::RejectTransitGatewayPeeringAttachmentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::RejectTransitGatewayPeeringAttachmentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#transit_gateway_attachment_id ⇒ String
The ID of the transit gateway peering attachment.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
73903 73904 73905 73906 73907 73908 |
# File 'lib/aws-sdk-ec2/types.rb', line 73903 class RejectTransitGatewayPeeringAttachmentRequest < Struct.new( :transit_gateway_attachment_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_attachment_id ⇒ String
The ID of the transit gateway peering attachment.
73903 73904 73905 73906 73907 73908 |
# File 'lib/aws-sdk-ec2/types.rb', line 73903 class RejectTransitGatewayPeeringAttachmentRequest < Struct.new( :transit_gateway_attachment_id, :dry_run) SENSITIVE = [] include Aws::Structure end |