Class: Aws::EC2::Types::RejectTransitGatewayPeeringAttachmentRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


72222
72223
72224
72225
72226
72227
# File 'lib/aws-sdk-ec2/types.rb', line 72222

class RejectTransitGatewayPeeringAttachmentRequest < Struct.new(
  :transit_gateway_attachment_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_attachment_idString

The ID of the transit gateway peering attachment.

Returns:

  • (String)


72222
72223
72224
72225
72226
72227
# File 'lib/aws-sdk-ec2/types.rb', line 72222

class RejectTransitGatewayPeeringAttachmentRequest < Struct.new(
  :transit_gateway_attachment_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end