Class: Aws::EC2::Types::RejectVpcEndpointConnectionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::RejectVpcEndpointConnectionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#service_id ⇒ String
The ID of the service.
-
#vpc_endpoint_ids ⇒ Array<String>
The IDs of the VPC endpoints.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
71889 71890 71891 71892 71893 71894 71895 |
# File 'lib/aws-sdk-ec2/types.rb', line 71889 class RejectVpcEndpointConnectionsRequest < Struct.new( :dry_run, :service_id, :vpc_endpoint_ids) SENSITIVE = [] include Aws::Structure end |
#service_id ⇒ String
The ID of the service.
71889 71890 71891 71892 71893 71894 71895 |
# File 'lib/aws-sdk-ec2/types.rb', line 71889 class RejectVpcEndpointConnectionsRequest < Struct.new( :dry_run, :service_id, :vpc_endpoint_ids) SENSITIVE = [] include Aws::Structure end |
#vpc_endpoint_ids ⇒ Array<String>
The IDs of the VPC endpoints.
71889 71890 71891 71892 71893 71894 71895 |
# File 'lib/aws-sdk-ec2/types.rb', line 71889 class RejectVpcEndpointConnectionsRequest < Struct.new( :dry_run, :service_id, :vpc_endpoint_ids) SENSITIVE = [] include Aws::Structure end |