Class: Aws::EC2::Types::RejectVpcEndpointConnectionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


71639
71640
71641
71642
71643
71644
71645
# File 'lib/aws-sdk-ec2/types.rb', line 71639

class RejectVpcEndpointConnectionsRequest < Struct.new(
  :dry_run,
  :service_id,
  :vpc_endpoint_ids)
  SENSITIVE = []
  include Aws::Structure
end

#service_idString

The ID of the service.

Returns:

  • (String)


71639
71640
71641
71642
71643
71644
71645
# File 'lib/aws-sdk-ec2/types.rb', line 71639

class RejectVpcEndpointConnectionsRequest < Struct.new(
  :dry_run,
  :service_id,
  :vpc_endpoint_ids)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_endpoint_idsArray<String>

The IDs of the VPC endpoints.

Returns:

  • (Array<String>)


71639
71640
71641
71642
71643
71644
71645
# File 'lib/aws-sdk-ec2/types.rb', line 71639

class RejectVpcEndpointConnectionsRequest < Struct.new(
  :dry_run,
  :service_id,
  :vpc_endpoint_ids)
  SENSITIVE = []
  include Aws::Structure
end