Class: Aws::EC2::Types::RejectVpcPeeringConnectionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::RejectVpcPeeringConnectionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#vpc_peering_connection_id ⇒ String
The ID of the VPC peering connection.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
75493 75494 75495 75496 75497 75498 |
# File 'lib/aws-sdk-ec2/types.rb', line 75493 class RejectVpcPeeringConnectionRequest < Struct.new( :dry_run, :vpc_peering_connection_id) SENSITIVE = [] include Aws::Structure end |
#vpc_peering_connection_id ⇒ String
The ID of the VPC peering connection.
75493 75494 75495 75496 75497 75498 |
# File 'lib/aws-sdk-ec2/types.rb', line 75493 class RejectVpcPeeringConnectionRequest < Struct.new( :dry_run, :vpc_peering_connection_id) SENSITIVE = [] include Aws::Structure end |