Class: Aws::EC2::Types::ReleaseAddressRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ReleaseAddressRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allocation_id ⇒ String
The allocation ID.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#network_border_group ⇒ String
The set of Availability Zones, Local Zones, or Wavelength Zones from which Amazon Web Services advertises IP addresses.
-
#public_ip ⇒ String
Deprecated.
Instance Attribute Details
#allocation_id ⇒ String
The allocation ID. This parameter is required.
72369 72370 72371 72372 72373 72374 72375 72376 |
# File 'lib/aws-sdk-ec2/types.rb', line 72369 class ReleaseAddressRequest < Struct.new( :allocation_id, :public_ip, :network_border_group, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
72369 72370 72371 72372 72373 72374 72375 72376 |
# File 'lib/aws-sdk-ec2/types.rb', line 72369 class ReleaseAddressRequest < Struct.new( :allocation_id, :public_ip, :network_border_group, :dry_run) SENSITIVE = [] include Aws::Structure end |
#network_border_group ⇒ String
The set of Availability Zones, Local Zones, or Wavelength Zones from which Amazon Web Services advertises IP addresses.
If you provide an incorrect network border group, you receive an
InvalidAddress.NotFound error.
72369 72370 72371 72372 72373 72374 72375 72376 |
# File 'lib/aws-sdk-ec2/types.rb', line 72369 class ReleaseAddressRequest < Struct.new( :allocation_id, :public_ip, :network_border_group, :dry_run) SENSITIVE = [] include Aws::Structure end |
#public_ip ⇒ String
Deprecated.
72369 72370 72371 72372 72373 72374 72375 72376 |
# File 'lib/aws-sdk-ec2/types.rb', line 72369 class ReleaseAddressRequest < Struct.new( :allocation_id, :public_ip, :network_border_group, :dry_run) SENSITIVE = [] include Aws::Structure end |