Class: Aws::EC2::Types::ReleaseAddressRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allocation_idString

The allocation ID. This parameter is required.

Returns:

  • (String)


72322
72323
72324
72325
72326
72327
72328
72329
# File 'lib/aws-sdk-ec2/types.rb', line 72322

class ReleaseAddressRequest < Struct.new(
  :allocation_id,
  :public_ip,
  :network_border_group,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


72322
72323
72324
72325
72326
72327
72328
72329
# File 'lib/aws-sdk-ec2/types.rb', line 72322

class ReleaseAddressRequest < Struct.new(
  :allocation_id,
  :public_ip,
  :network_border_group,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#network_border_groupString

The set of Availability Zones, Local Zones, or Wavelength Zones from which Amazon Web Services advertises IP addresses.

If you provide an incorrect network border group, you receive an InvalidAddress.NotFound error.

Returns:

  • (String)


72322
72323
72324
72325
72326
72327
72328
72329
# File 'lib/aws-sdk-ec2/types.rb', line 72322

class ReleaseAddressRequest < Struct.new(
  :allocation_id,
  :public_ip,
  :network_border_group,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#public_ipString

Deprecated.

Returns:

  • (String)


72322
72323
72324
72325
72326
72327
72328
72329
# File 'lib/aws-sdk-ec2/types.rb', line 72322

class ReleaseAddressRequest < Struct.new(
  :allocation_id,
  :public_ip,
  :network_border_group,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end