Class: Aws::EC2::Types::ReleaseAddressRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allocation_idString

The allocation ID. This parameter is required.

Returns:

  • (String)


69784
69785
69786
69787
69788
69789
69790
69791
# File 'lib/aws-sdk-ec2/types.rb', line 69784

class ReleaseAddressRequest < Struct.new(
  :allocation_id,
  :public_ip,
  :network_border_group,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


69784
69785
69786
69787
69788
69789
69790
69791
# File 'lib/aws-sdk-ec2/types.rb', line 69784

class ReleaseAddressRequest < Struct.new(
  :allocation_id,
  :public_ip,
  :network_border_group,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#network_border_groupString

The set of Availability Zones, Local Zones, or Wavelength Zones from which Amazon Web Services advertises IP addresses.

If you provide an incorrect network border group, you receive an ‘InvalidAddress.NotFound` error.

Returns:

  • (String)


69784
69785
69786
69787
69788
69789
69790
69791
# File 'lib/aws-sdk-ec2/types.rb', line 69784

class ReleaseAddressRequest < Struct.new(
  :allocation_id,
  :public_ip,
  :network_border_group,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#public_ipString

Deprecated.

Returns:

  • (String)


69784
69785
69786
69787
69788
69789
69790
69791
# File 'lib/aws-sdk-ec2/types.rb', line 69784

class ReleaseAddressRequest < Struct.new(
  :allocation_id,
  :public_ip,
  :network_border_group,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end