Class: Aws::EC2::Types::ReleaseIpamPoolAllocationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cidrString

The CIDR of the allocation you want to release.

Returns:

  • (String)


75546
75547
75548
75549
75550
75551
75552
75553
# File 'lib/aws-sdk-ec2/types.rb', line 75546

class ReleaseIpamPoolAllocationRequest < Struct.new(
  :dry_run,
  :ipam_pool_id,
  :cidr,
  :ipam_pool_allocation_id)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


75546
75547
75548
75549
75550
75551
75552
75553
# File 'lib/aws-sdk-ec2/types.rb', line 75546

class ReleaseIpamPoolAllocationRequest < Struct.new(
  :dry_run,
  :ipam_pool_id,
  :cidr,
  :ipam_pool_allocation_id)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_pool_allocation_idString

The ID of the allocation.

Returns:

  • (String)


75546
75547
75548
75549
75550
75551
75552
75553
# File 'lib/aws-sdk-ec2/types.rb', line 75546

class ReleaseIpamPoolAllocationRequest < Struct.new(
  :dry_run,
  :ipam_pool_id,
  :cidr,
  :ipam_pool_allocation_id)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_pool_idString

The ID of the IPAM pool which contains the allocation you want to release.

Returns:

  • (String)


75546
75547
75548
75549
75550
75551
75552
75553
# File 'lib/aws-sdk-ec2/types.rb', line 75546

class ReleaseIpamPoolAllocationRequest < Struct.new(
  :dry_run,
  :ipam_pool_id,
  :cidr,
  :ipam_pool_allocation_id)
  SENSITIVE = []
  include Aws::Structure
end