Class: Aws::EC2::Types::ReleaseIpamPoolAllocationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ReleaseIpamPoolAllocationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cidr ⇒ String
The CIDR of the allocation you want to release.
-
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response.
-
#ipam_pool_allocation_id ⇒ String
The ID of the allocation.
-
#ipam_pool_id ⇒ String
The ID of the IPAM pool which contains the allocation you want to release.
Instance Attribute Details
#cidr ⇒ String
The CIDR of the allocation you want to release.
71791 71792 71793 71794 71795 71796 71797 71798 |
# File 'lib/aws-sdk-ec2/types.rb', line 71791 class ReleaseIpamPoolAllocationRequest < Struct.new( :dry_run, :ipam_pool_id, :cidr, :ipam_pool_allocation_id) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
71791 71792 71793 71794 71795 71796 71797 71798 |
# File 'lib/aws-sdk-ec2/types.rb', line 71791 class ReleaseIpamPoolAllocationRequest < Struct.new( :dry_run, :ipam_pool_id, :cidr, :ipam_pool_allocation_id) SENSITIVE = [] include Aws::Structure end |
#ipam_pool_allocation_id ⇒ String
The ID of the allocation.
71791 71792 71793 71794 71795 71796 71797 71798 |
# File 'lib/aws-sdk-ec2/types.rb', line 71791 class ReleaseIpamPoolAllocationRequest < Struct.new( :dry_run, :ipam_pool_id, :cidr, :ipam_pool_allocation_id) SENSITIVE = [] include Aws::Structure end |
#ipam_pool_id ⇒ String
The ID of the IPAM pool which contains the allocation you want to release.
71791 71792 71793 71794 71795 71796 71797 71798 |
# File 'lib/aws-sdk-ec2/types.rb', line 71791 class ReleaseIpamPoolAllocationRequest < Struct.new( :dry_run, :ipam_pool_id, :cidr, :ipam_pool_allocation_id) SENSITIVE = [] include Aws::Structure end |