Class: Aws::EC2::Types::ReleaseIpamPoolAllocationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cidrString

The CIDR of the allocation you want to release.

Returns:

  • (String)


71779
71780
71781
71782
71783
71784
71785
71786
# File 'lib/aws-sdk-ec2/types.rb', line 71779

class ReleaseIpamPoolAllocationRequest < Struct.new(
  :dry_run,
  :ipam_pool_id,
  :cidr,
  :ipam_pool_allocation_id)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


71779
71780
71781
71782
71783
71784
71785
71786
# File 'lib/aws-sdk-ec2/types.rb', line 71779

class ReleaseIpamPoolAllocationRequest < Struct.new(
  :dry_run,
  :ipam_pool_id,
  :cidr,
  :ipam_pool_allocation_id)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_pool_allocation_idString

The ID of the allocation.

Returns:

  • (String)


71779
71780
71781
71782
71783
71784
71785
71786
# File 'lib/aws-sdk-ec2/types.rb', line 71779

class ReleaseIpamPoolAllocationRequest < Struct.new(
  :dry_run,
  :ipam_pool_id,
  :cidr,
  :ipam_pool_allocation_id)
  SENSITIVE = []
  include Aws::Structure
end

#ipam_pool_idString

The ID of the IPAM pool which contains the allocation you want to release.

Returns:

  • (String)


71779
71780
71781
71782
71783
71784
71785
71786
# File 'lib/aws-sdk-ec2/types.rb', line 71779

class ReleaseIpamPoolAllocationRequest < Struct.new(
  :dry_run,
  :ipam_pool_id,
  :cidr,
  :ipam_pool_allocation_id)
  SENSITIVE = []
  include Aws::Structure
end