Class: Aws::EC2::Types::ReplaceImageCriteriaInAllowedImagesSettingsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


72900
72901
72902
72903
72904
72905
# File 'lib/aws-sdk-ec2/types.rb', line 72900

class ReplaceImageCriteriaInAllowedImagesSettingsRequest < Struct.new(
  :image_criteria,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#image_criteriaArray<Types::ImageCriterionRequest>

The list of criteria that are evaluated to determine whether AMIs are discoverable and usable in the account in the specified Amazon Web Services Region.

Returns:



72900
72901
72902
72903
72904
72905
# File 'lib/aws-sdk-ec2/types.rb', line 72900

class ReplaceImageCriteriaInAllowedImagesSettingsRequest < Struct.new(
  :image_criteria,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end