Class: Aws::EC2::Types::ReplaceImageCriteriaInAllowedImagesSettingsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ReplaceImageCriteriaInAllowedImagesSettingsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#image_criteria ⇒ Array<Types::ImageCriterionRequest>
The list of criteria that are evaluated to determine whether AMIs are discoverable and usable in the account in the specified Amazon Web Services Region.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
70001 70002 70003 70004 70005 70006 |
# File 'lib/aws-sdk-ec2/types.rb', line 70001 class ReplaceImageCriteriaInAllowedImagesSettingsRequest < Struct.new( :image_criteria, :dry_run) SENSITIVE = [] include Aws::Structure end |
#image_criteria ⇒ Array<Types::ImageCriterionRequest>
The list of criteria that are evaluated to determine whether AMIs are discoverable and usable in the account in the specified Amazon Web Services Region.
70001 70002 70003 70004 70005 70006 |
# File 'lib/aws-sdk-ec2/types.rb', line 70001 class ReplaceImageCriteriaInAllowedImagesSettingsRequest < Struct.new( :image_criteria, :dry_run) SENSITIVE = [] include Aws::Structure end |