Class: Aws::EC2::Types::ReplaceNetworkAclAssociationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ReplaceNetworkAclAssociationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#association_id ⇒ String
The ID of the current association between the original network ACL and the subnet.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#network_acl_id ⇒ String
The ID of the new network ACL to associate with the subnet.
Instance Attribute Details
#association_id ⇒ String
The ID of the current association between the original network ACL and the subnet.
71702 71703 71704 71705 71706 71707 71708 |
# File 'lib/aws-sdk-ec2/types.rb', line 71702 class ReplaceNetworkAclAssociationRequest < Struct.new( :dry_run, :association_id, :network_acl_id) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
71702 71703 71704 71705 71706 71707 71708 |
# File 'lib/aws-sdk-ec2/types.rb', line 71702 class ReplaceNetworkAclAssociationRequest < Struct.new( :dry_run, :association_id, :network_acl_id) SENSITIVE = [] include Aws::Structure end |
#network_acl_id ⇒ String
The ID of the new network ACL to associate with the subnet.
71702 71703 71704 71705 71706 71707 71708 |
# File 'lib/aws-sdk-ec2/types.rb', line 71702 class ReplaceNetworkAclAssociationRequest < Struct.new( :dry_run, :association_id, :network_acl_id) SENSITIVE = [] include Aws::Structure end |