Class: Aws::EC2::Types::ReplaceNetworkAclAssociationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#association_idString

The ID of the current association between the original network ACL and the subnet.

Returns:

  • (String)


69923
69924
69925
69926
69927
69928
69929
# File 'lib/aws-sdk-ec2/types.rb', line 69923

class ReplaceNetworkAclAssociationRequest < Struct.new(
  :dry_run,
  :association_id,
  :network_acl_id)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


69923
69924
69925
69926
69927
69928
69929
# File 'lib/aws-sdk-ec2/types.rb', line 69923

class ReplaceNetworkAclAssociationRequest < Struct.new(
  :dry_run,
  :association_id,
  :network_acl_id)
  SENSITIVE = []
  include Aws::Structure
end

#network_acl_idString

The ID of the new network ACL to associate with the subnet.

Returns:

  • (String)


69923
69924
69925
69926
69927
69928
69929
# File 'lib/aws-sdk-ec2/types.rb', line 69923

class ReplaceNetworkAclAssociationRequest < Struct.new(
  :dry_run,
  :association_id,
  :network_acl_id)
  SENSITIVE = []
  include Aws::Structure
end