Class: Aws::EC2::Types::ReplaceNetworkAclEntryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ReplaceNetworkAclEntryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cidr_block ⇒ String
The IPv4 network range to allow or deny, in CIDR notation (for example ‘172.16.0.0/24`).
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#egress ⇒ Boolean
Indicates whether to replace the egress rule.
-
#icmp_type_code ⇒ Types::IcmpTypeCode
ICMP protocol: The ICMP or ICMPv6 type and code.
-
#ipv_6_cidr_block ⇒ String
The IPv6 network range to allow or deny, in CIDR notation (for example ‘2001:bd8:1234:1a00::/64`).
-
#network_acl_id ⇒ String
The ID of the ACL.
-
#port_range ⇒ Types::PortRange
TCP or UDP protocols: The range of ports the rule applies to.
-
#protocol ⇒ String
The protocol number.
-
#rule_action ⇒ String
Indicates whether to allow or deny the traffic that matches the rule.
-
#rule_number ⇒ Integer
The rule number of the entry to replace.
Instance Attribute Details
#cidr_block ⇒ String
The IPv4 network range to allow or deny, in CIDR notation (for example ‘172.16.0.0/24`).
72065 72066 72067 72068 72069 72070 72071 72072 72073 72074 72075 72076 72077 72078 |
# File 'lib/aws-sdk-ec2/types.rb', line 72065 class ReplaceNetworkAclEntryRequest < Struct.new( :dry_run, :network_acl_id, :rule_number, :protocol, :rule_action, :egress, :cidr_block, :ipv_6_cidr_block, :icmp_type_code, :port_range) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
72065 72066 72067 72068 72069 72070 72071 72072 72073 72074 72075 72076 72077 72078 |
# File 'lib/aws-sdk-ec2/types.rb', line 72065 class ReplaceNetworkAclEntryRequest < Struct.new( :dry_run, :network_acl_id, :rule_number, :protocol, :rule_action, :egress, :cidr_block, :ipv_6_cidr_block, :icmp_type_code, :port_range) SENSITIVE = [] include Aws::Structure end |
#egress ⇒ Boolean
Indicates whether to replace the egress rule.
Default: If no value is specified, we replace the ingress rule.
72065 72066 72067 72068 72069 72070 72071 72072 72073 72074 72075 72076 72077 72078 |
# File 'lib/aws-sdk-ec2/types.rb', line 72065 class ReplaceNetworkAclEntryRequest < Struct.new( :dry_run, :network_acl_id, :rule_number, :protocol, :rule_action, :egress, :cidr_block, :ipv_6_cidr_block, :icmp_type_code, :port_range) SENSITIVE = [] include Aws::Structure end |
#icmp_type_code ⇒ Types::IcmpTypeCode
ICMP protocol: The ICMP or ICMPv6 type and code. Required if specifying protocol 1 (ICMP) or protocol 58 (ICMPv6) with an IPv6 CIDR block.
72065 72066 72067 72068 72069 72070 72071 72072 72073 72074 72075 72076 72077 72078 |
# File 'lib/aws-sdk-ec2/types.rb', line 72065 class ReplaceNetworkAclEntryRequest < Struct.new( :dry_run, :network_acl_id, :rule_number, :protocol, :rule_action, :egress, :cidr_block, :ipv_6_cidr_block, :icmp_type_code, :port_range) SENSITIVE = [] include Aws::Structure end |
#ipv_6_cidr_block ⇒ String
The IPv6 network range to allow or deny, in CIDR notation (for example ‘2001:bd8:1234:1a00::/64`).
72065 72066 72067 72068 72069 72070 72071 72072 72073 72074 72075 72076 72077 72078 |
# File 'lib/aws-sdk-ec2/types.rb', line 72065 class ReplaceNetworkAclEntryRequest < Struct.new( :dry_run, :network_acl_id, :rule_number, :protocol, :rule_action, :egress, :cidr_block, :ipv_6_cidr_block, :icmp_type_code, :port_range) SENSITIVE = [] include Aws::Structure end |
#network_acl_id ⇒ String
The ID of the ACL.
72065 72066 72067 72068 72069 72070 72071 72072 72073 72074 72075 72076 72077 72078 |
# File 'lib/aws-sdk-ec2/types.rb', line 72065 class ReplaceNetworkAclEntryRequest < Struct.new( :dry_run, :network_acl_id, :rule_number, :protocol, :rule_action, :egress, :cidr_block, :ipv_6_cidr_block, :icmp_type_code, :port_range) SENSITIVE = [] include Aws::Structure end |
#port_range ⇒ Types::PortRange
TCP or UDP protocols: The range of ports the rule applies to. Required if specifying protocol 6 (TCP) or 17 (UDP).
72065 72066 72067 72068 72069 72070 72071 72072 72073 72074 72075 72076 72077 72078 |
# File 'lib/aws-sdk-ec2/types.rb', line 72065 class ReplaceNetworkAclEntryRequest < Struct.new( :dry_run, :network_acl_id, :rule_number, :protocol, :rule_action, :egress, :cidr_block, :ipv_6_cidr_block, :icmp_type_code, :port_range) SENSITIVE = [] include Aws::Structure end |
#protocol ⇒ String
The protocol number. A value of “-1” means all protocols. If you specify “-1” or a protocol number other than “6” (TCP), “17” (UDP), or “1” (ICMP), traffic on all ports is allowed, regardless of any ports or ICMP types or codes that you specify. If you specify protocol “58” (ICMPv6) and specify an IPv4 CIDR block, traffic for all ICMP types and codes allowed, regardless of any that you specify. If you specify protocol “58” (ICMPv6) and specify an IPv6 CIDR block, you must specify an ICMP type and code.
72065 72066 72067 72068 72069 72070 72071 72072 72073 72074 72075 72076 72077 72078 |
# File 'lib/aws-sdk-ec2/types.rb', line 72065 class ReplaceNetworkAclEntryRequest < Struct.new( :dry_run, :network_acl_id, :rule_number, :protocol, :rule_action, :egress, :cidr_block, :ipv_6_cidr_block, :icmp_type_code, :port_range) SENSITIVE = [] include Aws::Structure end |
#rule_action ⇒ String
Indicates whether to allow or deny the traffic that matches the rule.
72065 72066 72067 72068 72069 72070 72071 72072 72073 72074 72075 72076 72077 72078 |
# File 'lib/aws-sdk-ec2/types.rb', line 72065 class ReplaceNetworkAclEntryRequest < Struct.new( :dry_run, :network_acl_id, :rule_number, :protocol, :rule_action, :egress, :cidr_block, :ipv_6_cidr_block, :icmp_type_code, :port_range) SENSITIVE = [] include Aws::Structure end |
#rule_number ⇒ Integer
The rule number of the entry to replace.
72065 72066 72067 72068 72069 72070 72071 72072 72073 72074 72075 72076 72077 72078 |
# File 'lib/aws-sdk-ec2/types.rb', line 72065 class ReplaceNetworkAclEntryRequest < Struct.new( :dry_run, :network_acl_id, :rule_number, :protocol, :rule_action, :egress, :cidr_block, :ipv_6_cidr_block, :icmp_type_code, :port_range) SENSITIVE = [] include Aws::Structure end |