Class: Aws::EC2::Types::ReplaceRouteRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#carrier_gateway_idString

[IPv4 traffic only] The ID of a carrier gateway.

Returns:

  • (String)


76003
76004
76005
76006
76007
76008
76009
76010
76011
76012
76013
76014
76015
76016
76017
76018
76019
76020
76021
76022
76023
76024
# File 'lib/aws-sdk-ec2/types.rb', line 76003

class ReplaceRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :vpc_endpoint_id,
  :local_target,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :core_network_arn,
  :odb_network_arn,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :gateway_id,
  :destination_ipv_6_cidr_block,
  :egress_only_internet_gateway_id,
  :instance_id,
  :network_interface_id,
  :vpc_peering_connection_id,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end

#core_network_arnString

The Amazon Resource Name (ARN) of the core network.

Returns:

  • (String)


76003
76004
76005
76006
76007
76008
76009
76010
76011
76012
76013
76014
76015
76016
76017
76018
76019
76020
76021
76022
76023
76024
# File 'lib/aws-sdk-ec2/types.rb', line 76003

class ReplaceRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :vpc_endpoint_id,
  :local_target,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :core_network_arn,
  :odb_network_arn,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :gateway_id,
  :destination_ipv_6_cidr_block,
  :egress_only_internet_gateway_id,
  :instance_id,
  :network_interface_id,
  :vpc_peering_connection_id,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end

#destination_cidr_blockString

The IPv4 CIDR address block used for the destination match. The value that you provide must match the CIDR of an existing route in the table.

Returns:

  • (String)


76003
76004
76005
76006
76007
76008
76009
76010
76011
76012
76013
76014
76015
76016
76017
76018
76019
76020
76021
76022
76023
76024
# File 'lib/aws-sdk-ec2/types.rb', line 76003

class ReplaceRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :vpc_endpoint_id,
  :local_target,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :core_network_arn,
  :odb_network_arn,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :gateway_id,
  :destination_ipv_6_cidr_block,
  :egress_only_internet_gateway_id,
  :instance_id,
  :network_interface_id,
  :vpc_peering_connection_id,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end

#destination_ipv_6_cidr_blockString

The IPv6 CIDR address block used for the destination match. The value that you provide must match the CIDR of an existing route in the table.

Returns:

  • (String)


76003
76004
76005
76006
76007
76008
76009
76010
76011
76012
76013
76014
76015
76016
76017
76018
76019
76020
76021
76022
76023
76024
# File 'lib/aws-sdk-ec2/types.rb', line 76003

class ReplaceRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :vpc_endpoint_id,
  :local_target,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :core_network_arn,
  :odb_network_arn,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :gateway_id,
  :destination_ipv_6_cidr_block,
  :egress_only_internet_gateway_id,
  :instance_id,
  :network_interface_id,
  :vpc_peering_connection_id,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end

#destination_prefix_list_idString

The ID of the prefix list for the route.

Returns:

  • (String)


76003
76004
76005
76006
76007
76008
76009
76010
76011
76012
76013
76014
76015
76016
76017
76018
76019
76020
76021
76022
76023
76024
# File 'lib/aws-sdk-ec2/types.rb', line 76003

class ReplaceRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :vpc_endpoint_id,
  :local_target,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :core_network_arn,
  :odb_network_arn,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :gateway_id,
  :destination_ipv_6_cidr_block,
  :egress_only_internet_gateway_id,
  :instance_id,
  :network_interface_id,
  :vpc_peering_connection_id,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


76003
76004
76005
76006
76007
76008
76009
76010
76011
76012
76013
76014
76015
76016
76017
76018
76019
76020
76021
76022
76023
76024
# File 'lib/aws-sdk-ec2/types.rb', line 76003

class ReplaceRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :vpc_endpoint_id,
  :local_target,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :core_network_arn,
  :odb_network_arn,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :gateway_id,
  :destination_ipv_6_cidr_block,
  :egress_only_internet_gateway_id,
  :instance_id,
  :network_interface_id,
  :vpc_peering_connection_id,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end

#egress_only_internet_gateway_idString

[IPv6 traffic only] The ID of an egress-only internet gateway.

Returns:

  • (String)


76003
76004
76005
76006
76007
76008
76009
76010
76011
76012
76013
76014
76015
76016
76017
76018
76019
76020
76021
76022
76023
76024
# File 'lib/aws-sdk-ec2/types.rb', line 76003

class ReplaceRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :vpc_endpoint_id,
  :local_target,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :core_network_arn,
  :odb_network_arn,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :gateway_id,
  :destination_ipv_6_cidr_block,
  :egress_only_internet_gateway_id,
  :instance_id,
  :network_interface_id,
  :vpc_peering_connection_id,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end

#gateway_idString

The ID of an internet gateway or virtual private gateway.

Returns:

  • (String)


76003
76004
76005
76006
76007
76008
76009
76010
76011
76012
76013
76014
76015
76016
76017
76018
76019
76020
76021
76022
76023
76024
# File 'lib/aws-sdk-ec2/types.rb', line 76003

class ReplaceRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :vpc_endpoint_id,
  :local_target,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :core_network_arn,
  :odb_network_arn,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :gateway_id,
  :destination_ipv_6_cidr_block,
  :egress_only_internet_gateway_id,
  :instance_id,
  :network_interface_id,
  :vpc_peering_connection_id,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The ID of a NAT instance in your VPC.

Returns:

  • (String)


76003
76004
76005
76006
76007
76008
76009
76010
76011
76012
76013
76014
76015
76016
76017
76018
76019
76020
76021
76022
76023
76024
# File 'lib/aws-sdk-ec2/types.rb', line 76003

class ReplaceRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :vpc_endpoint_id,
  :local_target,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :core_network_arn,
  :odb_network_arn,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :gateway_id,
  :destination_ipv_6_cidr_block,
  :egress_only_internet_gateway_id,
  :instance_id,
  :network_interface_id,
  :vpc_peering_connection_id,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end

#local_gateway_idString

The ID of the local gateway.

Returns:

  • (String)


76003
76004
76005
76006
76007
76008
76009
76010
76011
76012
76013
76014
76015
76016
76017
76018
76019
76020
76021
76022
76023
76024
# File 'lib/aws-sdk-ec2/types.rb', line 76003

class ReplaceRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :vpc_endpoint_id,
  :local_target,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :core_network_arn,
  :odb_network_arn,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :gateway_id,
  :destination_ipv_6_cidr_block,
  :egress_only_internet_gateway_id,
  :instance_id,
  :network_interface_id,
  :vpc_peering_connection_id,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end

#local_targetBoolean

Specifies whether to reset the local route to its default target (local).

Returns:

  • (Boolean)


76003
76004
76005
76006
76007
76008
76009
76010
76011
76012
76013
76014
76015
76016
76017
76018
76019
76020
76021
76022
76023
76024
# File 'lib/aws-sdk-ec2/types.rb', line 76003

class ReplaceRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :vpc_endpoint_id,
  :local_target,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :core_network_arn,
  :odb_network_arn,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :gateway_id,
  :destination_ipv_6_cidr_block,
  :egress_only_internet_gateway_id,
  :instance_id,
  :network_interface_id,
  :vpc_peering_connection_id,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end

#nat_gateway_idString

[IPv4 traffic only] The ID of a NAT gateway.

Returns:

  • (String)


76003
76004
76005
76006
76007
76008
76009
76010
76011
76012
76013
76014
76015
76016
76017
76018
76019
76020
76021
76022
76023
76024
# File 'lib/aws-sdk-ec2/types.rb', line 76003

class ReplaceRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :vpc_endpoint_id,
  :local_target,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :core_network_arn,
  :odb_network_arn,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :gateway_id,
  :destination_ipv_6_cidr_block,
  :egress_only_internet_gateway_id,
  :instance_id,
  :network_interface_id,
  :vpc_peering_connection_id,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end

#network_interface_idString

The ID of a network interface.

Returns:

  • (String)


76003
76004
76005
76006
76007
76008
76009
76010
76011
76012
76013
76014
76015
76016
76017
76018
76019
76020
76021
76022
76023
76024
# File 'lib/aws-sdk-ec2/types.rb', line 76003

class ReplaceRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :vpc_endpoint_id,
  :local_target,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :core_network_arn,
  :odb_network_arn,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :gateway_id,
  :destination_ipv_6_cidr_block,
  :egress_only_internet_gateway_id,
  :instance_id,
  :network_interface_id,
  :vpc_peering_connection_id,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end

#odb_network_arnString

The Amazon Resource Name (ARN) of the ODB network.

Returns:

  • (String)


76003
76004
76005
76006
76007
76008
76009
76010
76011
76012
76013
76014
76015
76016
76017
76018
76019
76020
76021
76022
76023
76024
# File 'lib/aws-sdk-ec2/types.rb', line 76003

class ReplaceRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :vpc_endpoint_id,
  :local_target,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :core_network_arn,
  :odb_network_arn,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :gateway_id,
  :destination_ipv_6_cidr_block,
  :egress_only_internet_gateway_id,
  :instance_id,
  :network_interface_id,
  :vpc_peering_connection_id,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end

#route_table_idString

The ID of the route table.

Returns:

  • (String)


76003
76004
76005
76006
76007
76008
76009
76010
76011
76012
76013
76014
76015
76016
76017
76018
76019
76020
76021
76022
76023
76024
# File 'lib/aws-sdk-ec2/types.rb', line 76003

class ReplaceRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :vpc_endpoint_id,
  :local_target,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :core_network_arn,
  :odb_network_arn,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :gateway_id,
  :destination_ipv_6_cidr_block,
  :egress_only_internet_gateway_id,
  :instance_id,
  :network_interface_id,
  :vpc_peering_connection_id,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_idString

The ID of a transit gateway.

Returns:

  • (String)


76003
76004
76005
76006
76007
76008
76009
76010
76011
76012
76013
76014
76015
76016
76017
76018
76019
76020
76021
76022
76023
76024
# File 'lib/aws-sdk-ec2/types.rb', line 76003

class ReplaceRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :vpc_endpoint_id,
  :local_target,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :core_network_arn,
  :odb_network_arn,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :gateway_id,
  :destination_ipv_6_cidr_block,
  :egress_only_internet_gateway_id,
  :instance_id,
  :network_interface_id,
  :vpc_peering_connection_id,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_endpoint_idString

The ID of a VPC endpoint. Supported for Gateway Load Balancer endpoints only.

Returns:

  • (String)


76003
76004
76005
76006
76007
76008
76009
76010
76011
76012
76013
76014
76015
76016
76017
76018
76019
76020
76021
76022
76023
76024
# File 'lib/aws-sdk-ec2/types.rb', line 76003

class ReplaceRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :vpc_endpoint_id,
  :local_target,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :core_network_arn,
  :odb_network_arn,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :gateway_id,
  :destination_ipv_6_cidr_block,
  :egress_only_internet_gateway_id,
  :instance_id,
  :network_interface_id,
  :vpc_peering_connection_id,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_peering_connection_idString

The ID of a VPC peering connection.

Returns:

  • (String)


76003
76004
76005
76006
76007
76008
76009
76010
76011
76012
76013
76014
76015
76016
76017
76018
76019
76020
76021
76022
76023
76024
# File 'lib/aws-sdk-ec2/types.rb', line 76003

class ReplaceRouteRequest < Struct.new(
  :destination_prefix_list_id,
  :vpc_endpoint_id,
  :local_target,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :core_network_arn,
  :odb_network_arn,
  :dry_run,
  :route_table_id,
  :destination_cidr_block,
  :gateway_id,
  :destination_ipv_6_cidr_block,
  :egress_only_internet_gateway_id,
  :instance_id,
  :network_interface_id,
  :vpc_peering_connection_id,
  :nat_gateway_id)
  SENSITIVE = []
  include Aws::Structure
end