Class: Aws::EC2::Types::ReplaceRouteRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ReplaceRouteRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#carrier_gateway_id ⇒ String
[IPv4 traffic only] The ID of a carrier gateway.
-
#core_network_arn ⇒ String
The Amazon Resource Name (ARN) of the core network.
-
#destination_cidr_block ⇒ String
The IPv4 CIDR address block used for the destination match.
-
#destination_ipv_6_cidr_block ⇒ String
The IPv6 CIDR address block used for the destination match.
-
#destination_prefix_list_id ⇒ String
The ID of the prefix list for the route.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#egress_only_internet_gateway_id ⇒ String
[IPv6 traffic only] The ID of an egress-only internet gateway.
-
#gateway_id ⇒ String
The ID of an internet gateway or virtual private gateway.
-
#instance_id ⇒ String
The ID of a NAT instance in your VPC.
-
#local_gateway_id ⇒ String
The ID of the local gateway.
-
#local_target ⇒ Boolean
Specifies whether to reset the local route to its default target (
local). -
#nat_gateway_id ⇒ String
[IPv4 traffic only] The ID of a NAT gateway.
-
#network_interface_id ⇒ String
The ID of a network interface.
-
#odb_network_arn ⇒ String
The Amazon Resource Name (ARN) of the ODB network.
-
#route_table_id ⇒ String
The ID of the route table.
-
#transit_gateway_id ⇒ String
The ID of a transit gateway.
-
#vpc_endpoint_id ⇒ String
The ID of a VPC endpoint.
-
#vpc_peering_connection_id ⇒ String
The ID of a VPC peering connection.
Instance Attribute Details
#carrier_gateway_id ⇒ String
[IPv4 traffic only] The ID of a carrier gateway.
76003 76004 76005 76006 76007 76008 76009 76010 76011 76012 76013 76014 76015 76016 76017 76018 76019 76020 76021 76022 76023 76024 |
# File 'lib/aws-sdk-ec2/types.rb', line 76003 class ReplaceRouteRequest < Struct.new( :destination_prefix_list_id, :vpc_endpoint_id, :local_target, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :core_network_arn, :odb_network_arn, :dry_run, :route_table_id, :destination_cidr_block, :gateway_id, :destination_ipv_6_cidr_block, :egress_only_internet_gateway_id, :instance_id, :network_interface_id, :vpc_peering_connection_id, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |
#core_network_arn ⇒ String
The Amazon Resource Name (ARN) of the core network.
76003 76004 76005 76006 76007 76008 76009 76010 76011 76012 76013 76014 76015 76016 76017 76018 76019 76020 76021 76022 76023 76024 |
# File 'lib/aws-sdk-ec2/types.rb', line 76003 class ReplaceRouteRequest < Struct.new( :destination_prefix_list_id, :vpc_endpoint_id, :local_target, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :core_network_arn, :odb_network_arn, :dry_run, :route_table_id, :destination_cidr_block, :gateway_id, :destination_ipv_6_cidr_block, :egress_only_internet_gateway_id, :instance_id, :network_interface_id, :vpc_peering_connection_id, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |
#destination_cidr_block ⇒ String
The IPv4 CIDR address block used for the destination match. The value that you provide must match the CIDR of an existing route in the table.
76003 76004 76005 76006 76007 76008 76009 76010 76011 76012 76013 76014 76015 76016 76017 76018 76019 76020 76021 76022 76023 76024 |
# File 'lib/aws-sdk-ec2/types.rb', line 76003 class ReplaceRouteRequest < Struct.new( :destination_prefix_list_id, :vpc_endpoint_id, :local_target, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :core_network_arn, :odb_network_arn, :dry_run, :route_table_id, :destination_cidr_block, :gateway_id, :destination_ipv_6_cidr_block, :egress_only_internet_gateway_id, :instance_id, :network_interface_id, :vpc_peering_connection_id, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |
#destination_ipv_6_cidr_block ⇒ String
The IPv6 CIDR address block used for the destination match. The value that you provide must match the CIDR of an existing route in the table.
76003 76004 76005 76006 76007 76008 76009 76010 76011 76012 76013 76014 76015 76016 76017 76018 76019 76020 76021 76022 76023 76024 |
# File 'lib/aws-sdk-ec2/types.rb', line 76003 class ReplaceRouteRequest < Struct.new( :destination_prefix_list_id, :vpc_endpoint_id, :local_target, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :core_network_arn, :odb_network_arn, :dry_run, :route_table_id, :destination_cidr_block, :gateway_id, :destination_ipv_6_cidr_block, :egress_only_internet_gateway_id, :instance_id, :network_interface_id, :vpc_peering_connection_id, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |
#destination_prefix_list_id ⇒ String
The ID of the prefix list for the route.
76003 76004 76005 76006 76007 76008 76009 76010 76011 76012 76013 76014 76015 76016 76017 76018 76019 76020 76021 76022 76023 76024 |
# File 'lib/aws-sdk-ec2/types.rb', line 76003 class ReplaceRouteRequest < Struct.new( :destination_prefix_list_id, :vpc_endpoint_id, :local_target, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :core_network_arn, :odb_network_arn, :dry_run, :route_table_id, :destination_cidr_block, :gateway_id, :destination_ipv_6_cidr_block, :egress_only_internet_gateway_id, :instance_id, :network_interface_id, :vpc_peering_connection_id, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
76003 76004 76005 76006 76007 76008 76009 76010 76011 76012 76013 76014 76015 76016 76017 76018 76019 76020 76021 76022 76023 76024 |
# File 'lib/aws-sdk-ec2/types.rb', line 76003 class ReplaceRouteRequest < Struct.new( :destination_prefix_list_id, :vpc_endpoint_id, :local_target, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :core_network_arn, :odb_network_arn, :dry_run, :route_table_id, :destination_cidr_block, :gateway_id, :destination_ipv_6_cidr_block, :egress_only_internet_gateway_id, :instance_id, :network_interface_id, :vpc_peering_connection_id, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |
#egress_only_internet_gateway_id ⇒ String
[IPv6 traffic only] The ID of an egress-only internet gateway.
76003 76004 76005 76006 76007 76008 76009 76010 76011 76012 76013 76014 76015 76016 76017 76018 76019 76020 76021 76022 76023 76024 |
# File 'lib/aws-sdk-ec2/types.rb', line 76003 class ReplaceRouteRequest < Struct.new( :destination_prefix_list_id, :vpc_endpoint_id, :local_target, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :core_network_arn, :odb_network_arn, :dry_run, :route_table_id, :destination_cidr_block, :gateway_id, :destination_ipv_6_cidr_block, :egress_only_internet_gateway_id, :instance_id, :network_interface_id, :vpc_peering_connection_id, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |
#gateway_id ⇒ String
The ID of an internet gateway or virtual private gateway.
76003 76004 76005 76006 76007 76008 76009 76010 76011 76012 76013 76014 76015 76016 76017 76018 76019 76020 76021 76022 76023 76024 |
# File 'lib/aws-sdk-ec2/types.rb', line 76003 class ReplaceRouteRequest < Struct.new( :destination_prefix_list_id, :vpc_endpoint_id, :local_target, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :core_network_arn, :odb_network_arn, :dry_run, :route_table_id, :destination_cidr_block, :gateway_id, :destination_ipv_6_cidr_block, :egress_only_internet_gateway_id, :instance_id, :network_interface_id, :vpc_peering_connection_id, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of a NAT instance in your VPC.
76003 76004 76005 76006 76007 76008 76009 76010 76011 76012 76013 76014 76015 76016 76017 76018 76019 76020 76021 76022 76023 76024 |
# File 'lib/aws-sdk-ec2/types.rb', line 76003 class ReplaceRouteRequest < Struct.new( :destination_prefix_list_id, :vpc_endpoint_id, :local_target, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :core_network_arn, :odb_network_arn, :dry_run, :route_table_id, :destination_cidr_block, :gateway_id, :destination_ipv_6_cidr_block, :egress_only_internet_gateway_id, :instance_id, :network_interface_id, :vpc_peering_connection_id, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |
#local_gateway_id ⇒ String
The ID of the local gateway.
76003 76004 76005 76006 76007 76008 76009 76010 76011 76012 76013 76014 76015 76016 76017 76018 76019 76020 76021 76022 76023 76024 |
# File 'lib/aws-sdk-ec2/types.rb', line 76003 class ReplaceRouteRequest < Struct.new( :destination_prefix_list_id, :vpc_endpoint_id, :local_target, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :core_network_arn, :odb_network_arn, :dry_run, :route_table_id, :destination_cidr_block, :gateway_id, :destination_ipv_6_cidr_block, :egress_only_internet_gateway_id, :instance_id, :network_interface_id, :vpc_peering_connection_id, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |
#local_target ⇒ Boolean
Specifies whether to reset the local route to its default target
(local).
76003 76004 76005 76006 76007 76008 76009 76010 76011 76012 76013 76014 76015 76016 76017 76018 76019 76020 76021 76022 76023 76024 |
# File 'lib/aws-sdk-ec2/types.rb', line 76003 class ReplaceRouteRequest < Struct.new( :destination_prefix_list_id, :vpc_endpoint_id, :local_target, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :core_network_arn, :odb_network_arn, :dry_run, :route_table_id, :destination_cidr_block, :gateway_id, :destination_ipv_6_cidr_block, :egress_only_internet_gateway_id, :instance_id, :network_interface_id, :vpc_peering_connection_id, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |
#nat_gateway_id ⇒ String
[IPv4 traffic only] The ID of a NAT gateway.
76003 76004 76005 76006 76007 76008 76009 76010 76011 76012 76013 76014 76015 76016 76017 76018 76019 76020 76021 76022 76023 76024 |
# File 'lib/aws-sdk-ec2/types.rb', line 76003 class ReplaceRouteRequest < Struct.new( :destination_prefix_list_id, :vpc_endpoint_id, :local_target, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :core_network_arn, :odb_network_arn, :dry_run, :route_table_id, :destination_cidr_block, :gateway_id, :destination_ipv_6_cidr_block, :egress_only_internet_gateway_id, :instance_id, :network_interface_id, :vpc_peering_connection_id, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |
#network_interface_id ⇒ String
The ID of a network interface.
76003 76004 76005 76006 76007 76008 76009 76010 76011 76012 76013 76014 76015 76016 76017 76018 76019 76020 76021 76022 76023 76024 |
# File 'lib/aws-sdk-ec2/types.rb', line 76003 class ReplaceRouteRequest < Struct.new( :destination_prefix_list_id, :vpc_endpoint_id, :local_target, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :core_network_arn, :odb_network_arn, :dry_run, :route_table_id, :destination_cidr_block, :gateway_id, :destination_ipv_6_cidr_block, :egress_only_internet_gateway_id, :instance_id, :network_interface_id, :vpc_peering_connection_id, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |
#odb_network_arn ⇒ String
The Amazon Resource Name (ARN) of the ODB network.
76003 76004 76005 76006 76007 76008 76009 76010 76011 76012 76013 76014 76015 76016 76017 76018 76019 76020 76021 76022 76023 76024 |
# File 'lib/aws-sdk-ec2/types.rb', line 76003 class ReplaceRouteRequest < Struct.new( :destination_prefix_list_id, :vpc_endpoint_id, :local_target, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :core_network_arn, :odb_network_arn, :dry_run, :route_table_id, :destination_cidr_block, :gateway_id, :destination_ipv_6_cidr_block, :egress_only_internet_gateway_id, :instance_id, :network_interface_id, :vpc_peering_connection_id, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |
#route_table_id ⇒ String
The ID of the route table.
76003 76004 76005 76006 76007 76008 76009 76010 76011 76012 76013 76014 76015 76016 76017 76018 76019 76020 76021 76022 76023 76024 |
# File 'lib/aws-sdk-ec2/types.rb', line 76003 class ReplaceRouteRequest < Struct.new( :destination_prefix_list_id, :vpc_endpoint_id, :local_target, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :core_network_arn, :odb_network_arn, :dry_run, :route_table_id, :destination_cidr_block, :gateway_id, :destination_ipv_6_cidr_block, :egress_only_internet_gateway_id, :instance_id, :network_interface_id, :vpc_peering_connection_id, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_id ⇒ String
The ID of a transit gateway.
76003 76004 76005 76006 76007 76008 76009 76010 76011 76012 76013 76014 76015 76016 76017 76018 76019 76020 76021 76022 76023 76024 |
# File 'lib/aws-sdk-ec2/types.rb', line 76003 class ReplaceRouteRequest < Struct.new( :destination_prefix_list_id, :vpc_endpoint_id, :local_target, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :core_network_arn, :odb_network_arn, :dry_run, :route_table_id, :destination_cidr_block, :gateway_id, :destination_ipv_6_cidr_block, :egress_only_internet_gateway_id, :instance_id, :network_interface_id, :vpc_peering_connection_id, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |
#vpc_endpoint_id ⇒ String
The ID of a VPC endpoint. Supported for Gateway Load Balancer endpoints only.
76003 76004 76005 76006 76007 76008 76009 76010 76011 76012 76013 76014 76015 76016 76017 76018 76019 76020 76021 76022 76023 76024 |
# File 'lib/aws-sdk-ec2/types.rb', line 76003 class ReplaceRouteRequest < Struct.new( :destination_prefix_list_id, :vpc_endpoint_id, :local_target, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :core_network_arn, :odb_network_arn, :dry_run, :route_table_id, :destination_cidr_block, :gateway_id, :destination_ipv_6_cidr_block, :egress_only_internet_gateway_id, :instance_id, :network_interface_id, :vpc_peering_connection_id, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |
#vpc_peering_connection_id ⇒ String
The ID of a VPC peering connection.
76003 76004 76005 76006 76007 76008 76009 76010 76011 76012 76013 76014 76015 76016 76017 76018 76019 76020 76021 76022 76023 76024 |
# File 'lib/aws-sdk-ec2/types.rb', line 76003 class ReplaceRouteRequest < Struct.new( :destination_prefix_list_id, :vpc_endpoint_id, :local_target, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :core_network_arn, :odb_network_arn, :dry_run, :route_table_id, :destination_cidr_block, :gateway_id, :destination_ipv_6_cidr_block, :egress_only_internet_gateway_id, :instance_id, :network_interface_id, :vpc_peering_connection_id, :nat_gateway_id) SENSITIVE = [] include Aws::Structure end |