Class: Aws::EC2::Types::ReplaceRouteTableAssociationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#association_idString

The association ID.

Returns:

  • (String)


72918
72919
72920
72921
72922
72923
72924
# File 'lib/aws-sdk-ec2/types.rb', line 72918

class ReplaceRouteTableAssociationRequest < Struct.new(
  :dry_run,
  :association_id,
  :route_table_id)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


72918
72919
72920
72921
72922
72923
72924
# File 'lib/aws-sdk-ec2/types.rb', line 72918

class ReplaceRouteTableAssociationRequest < Struct.new(
  :dry_run,
  :association_id,
  :route_table_id)
  SENSITIVE = []
  include Aws::Structure
end

#route_table_idString

The ID of the new route table to associate with the subnet.

Returns:

  • (String)


72918
72919
72920
72921
72922
72923
72924
# File 'lib/aws-sdk-ec2/types.rb', line 72918

class ReplaceRouteTableAssociationRequest < Struct.new(
  :dry_run,
  :association_id,
  :route_table_id)
  SENSITIVE = []
  include Aws::Structure
end