Class: Aws::EC2::Types::ReplaceRouteTableAssociationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ReplaceRouteTableAssociationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#association_id ⇒ String
The association ID.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#route_table_id ⇒ String
The ID of the new route table to associate with the subnet.
Instance Attribute Details
#association_id ⇒ String
The association ID.
72528 72529 72530 72531 72532 72533 72534 |
# File 'lib/aws-sdk-ec2/types.rb', line 72528 class ReplaceRouteTableAssociationRequest < Struct.new( :dry_run, :association_id, :route_table_id) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
72528 72529 72530 72531 72532 72533 72534 |
# File 'lib/aws-sdk-ec2/types.rb', line 72528 class ReplaceRouteTableAssociationRequest < Struct.new( :dry_run, :association_id, :route_table_id) SENSITIVE = [] include Aws::Structure end |
#route_table_id ⇒ String
The ID of the new route table to associate with the subnet.
72528 72529 72530 72531 72532 72533 72534 |
# File 'lib/aws-sdk-ec2/types.rb', line 72528 class ReplaceRouteTableAssociationRequest < Struct.new( :dry_run, :association_id, :route_table_id) SENSITIVE = [] include Aws::Structure end |