Class: Aws::EC2::Types::ReplaceRouteTableAssociationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#association_idString

The association ID.

Returns:

  • (String)


72517
72518
72519
72520
72521
72522
72523
# File 'lib/aws-sdk-ec2/types.rb', line 72517

class ReplaceRouteTableAssociationRequest < Struct.new(
  :dry_run,
  :association_id,
  :route_table_id)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


72517
72518
72519
72520
72521
72522
72523
# File 'lib/aws-sdk-ec2/types.rb', line 72517

class ReplaceRouteTableAssociationRequest < Struct.new(
  :dry_run,
  :association_id,
  :route_table_id)
  SENSITIVE = []
  include Aws::Structure
end

#route_table_idString

The ID of the new route table to associate with the subnet.

Returns:

  • (String)


72517
72518
72519
72520
72521
72522
72523
# File 'lib/aws-sdk-ec2/types.rb', line 72517

class ReplaceRouteTableAssociationRequest < Struct.new(
  :dry_run,
  :association_id,
  :route_table_id)
  SENSITIVE = []
  include Aws::Structure
end