Class: Aws::EC2::Types::ReplaceRouteTableAssociationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#association_idString

The association ID.

Returns:

  • (String)


72267
72268
72269
72270
72271
72272
72273
# File 'lib/aws-sdk-ec2/types.rb', line 72267

class ReplaceRouteTableAssociationRequest < Struct.new(
  :dry_run,
  :association_id,
  :route_table_id)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


72267
72268
72269
72270
72271
72272
72273
# File 'lib/aws-sdk-ec2/types.rb', line 72267

class ReplaceRouteTableAssociationRequest < Struct.new(
  :dry_run,
  :association_id,
  :route_table_id)
  SENSITIVE = []
  include Aws::Structure
end

#route_table_idString

The ID of the new route table to associate with the subnet.

Returns:

  • (String)


72267
72268
72269
72270
72271
72272
72273
# File 'lib/aws-sdk-ec2/types.rb', line 72267

class ReplaceRouteTableAssociationRequest < Struct.new(
  :dry_run,
  :association_id,
  :route_table_id)
  SENSITIVE = []
  include Aws::Structure
end