Class: Aws::EC2::Types::ReplaceTransitGatewayRouteRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ReplaceTransitGatewayRouteRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#blackhole ⇒ Boolean
Indicates whether traffic matching this route is to be dropped.
-
#destination_cidr_block ⇒ String
The CIDR range used for the destination match.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#transit_gateway_attachment_id ⇒ String
The ID of the attachment.
-
#transit_gateway_route_table_id ⇒ String
The ID of the route table.
Instance Attribute Details
#blackhole ⇒ Boolean
Indicates whether traffic matching this route is to be dropped.
71876 71877 71878 71879 71880 71881 71882 71883 71884 |
# File 'lib/aws-sdk-ec2/types.rb', line 71876 class ReplaceTransitGatewayRouteRequest < Struct.new( :destination_cidr_block, :transit_gateway_route_table_id, :transit_gateway_attachment_id, :blackhole, :dry_run) SENSITIVE = [] include Aws::Structure end |
#destination_cidr_block ⇒ String
The CIDR range used for the destination match. Routing decisions are based on the most specific match.
71876 71877 71878 71879 71880 71881 71882 71883 71884 |
# File 'lib/aws-sdk-ec2/types.rb', line 71876 class ReplaceTransitGatewayRouteRequest < Struct.new( :destination_cidr_block, :transit_gateway_route_table_id, :transit_gateway_attachment_id, :blackhole, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
71876 71877 71878 71879 71880 71881 71882 71883 71884 |
# File 'lib/aws-sdk-ec2/types.rb', line 71876 class ReplaceTransitGatewayRouteRequest < Struct.new( :destination_cidr_block, :transit_gateway_route_table_id, :transit_gateway_attachment_id, :blackhole, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_attachment_id ⇒ String
The ID of the attachment.
71876 71877 71878 71879 71880 71881 71882 71883 71884 |
# File 'lib/aws-sdk-ec2/types.rb', line 71876 class ReplaceTransitGatewayRouteRequest < Struct.new( :destination_cidr_block, :transit_gateway_route_table_id, :transit_gateway_attachment_id, :blackhole, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_route_table_id ⇒ String
The ID of the route table.
71876 71877 71878 71879 71880 71881 71882 71883 71884 |
# File 'lib/aws-sdk-ec2/types.rb', line 71876 class ReplaceTransitGatewayRouteRequest < Struct.new( :destination_cidr_block, :transit_gateway_route_table_id, :transit_gateway_attachment_id, :blackhole, :dry_run) SENSITIVE = [] include Aws::Structure end |