Class: Aws::EC2::Types::ReplaceTransitGatewayRouteRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#blackholeBoolean

Indicates whether traffic matching this route is to be dropped.

Returns:

  • (Boolean)


71726
71727
71728
71729
71730
71731
71732
71733
71734
# File 'lib/aws-sdk-ec2/types.rb', line 71726

class ReplaceTransitGatewayRouteRequest < Struct.new(
  :destination_cidr_block,
  :transit_gateway_route_table_id,
  :transit_gateway_attachment_id,
  :blackhole,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#destination_cidr_blockString

The CIDR range used for the destination match. Routing decisions are based on the most specific match.

Returns:

  • (String)


71726
71727
71728
71729
71730
71731
71732
71733
71734
# File 'lib/aws-sdk-ec2/types.rb', line 71726

class ReplaceTransitGatewayRouteRequest < Struct.new(
  :destination_cidr_block,
  :transit_gateway_route_table_id,
  :transit_gateway_attachment_id,
  :blackhole,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


71726
71727
71728
71729
71730
71731
71732
71733
71734
# File 'lib/aws-sdk-ec2/types.rb', line 71726

class ReplaceTransitGatewayRouteRequest < Struct.new(
  :destination_cidr_block,
  :transit_gateway_route_table_id,
  :transit_gateway_attachment_id,
  :blackhole,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_attachment_idString

The ID of the attachment.

Returns:

  • (String)


71726
71727
71728
71729
71730
71731
71732
71733
71734
# File 'lib/aws-sdk-ec2/types.rb', line 71726

class ReplaceTransitGatewayRouteRequest < Struct.new(
  :destination_cidr_block,
  :transit_gateway_route_table_id,
  :transit_gateway_attachment_id,
  :blackhole,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_route_table_idString

The ID of the route table.

Returns:

  • (String)


71726
71727
71728
71729
71730
71731
71732
71733
71734
# File 'lib/aws-sdk-ec2/types.rb', line 71726

class ReplaceTransitGatewayRouteRequest < Struct.new(
  :destination_cidr_block,
  :transit_gateway_route_table_id,
  :transit_gateway_attachment_id,
  :blackhole,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end