Class: Aws::EC2::Types::ReplaceVpnTunnelRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#apply_pending_maintenanceBoolean

Trigger pending tunnel endpoint maintenance.

Returns:

  • (Boolean)


76151
76152
76153
76154
76155
76156
76157
76158
# File 'lib/aws-sdk-ec2/types.rb', line 76151

class ReplaceVpnTunnelRequest < Struct.new(
  :vpn_connection_id,
  :vpn_tunnel_outside_ip_address,
  :apply_pending_maintenance,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


76151
76152
76153
76154
76155
76156
76157
76158
# File 'lib/aws-sdk-ec2/types.rb', line 76151

class ReplaceVpnTunnelRequest < Struct.new(
  :vpn_connection_id,
  :vpn_tunnel_outside_ip_address,
  :apply_pending_maintenance,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpn_connection_idString

The ID of the Site-to-Site VPN connection.

Returns:

  • (String)


76151
76152
76153
76154
76155
76156
76157
76158
# File 'lib/aws-sdk-ec2/types.rb', line 76151

class ReplaceVpnTunnelRequest < Struct.new(
  :vpn_connection_id,
  :vpn_tunnel_outside_ip_address,
  :apply_pending_maintenance,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#vpn_tunnel_outside_ip_addressString

The external IP address of the VPN tunnel.

Returns:

  • (String)


76151
76152
76153
76154
76155
76156
76157
76158
# File 'lib/aws-sdk-ec2/types.rb', line 76151

class ReplaceVpnTunnelRequest < Struct.new(
  :vpn_connection_id,
  :vpn_tunnel_outside_ip_address,
  :apply_pending_maintenance,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end