Class: Aws::EC2::Types::ReplaceVpnTunnelRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ReplaceVpnTunnelRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#apply_pending_maintenance ⇒ Boolean
Trigger pending tunnel endpoint maintenance.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#vpn_connection_id ⇒ String
The ID of the Site-to-Site VPN connection.
-
#vpn_tunnel_outside_ip_address ⇒ String
The external IP address of the VPN tunnel.
Instance Attribute Details
#apply_pending_maintenance ⇒ Boolean
Trigger pending tunnel endpoint maintenance.
71919 71920 71921 71922 71923 71924 71925 71926 |
# File 'lib/aws-sdk-ec2/types.rb', line 71919 class ReplaceVpnTunnelRequest < Struct.new( :vpn_connection_id, :vpn_tunnel_outside_ip_address, :apply_pending_maintenance, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
71919 71920 71921 71922 71923 71924 71925 71926 |
# File 'lib/aws-sdk-ec2/types.rb', line 71919 class ReplaceVpnTunnelRequest < Struct.new( :vpn_connection_id, :vpn_tunnel_outside_ip_address, :apply_pending_maintenance, :dry_run) SENSITIVE = [] include Aws::Structure end |
#vpn_connection_id ⇒ String
The ID of the Site-to-Site VPN connection.
71919 71920 71921 71922 71923 71924 71925 71926 |
# File 'lib/aws-sdk-ec2/types.rb', line 71919 class ReplaceVpnTunnelRequest < Struct.new( :vpn_connection_id, :vpn_tunnel_outside_ip_address, :apply_pending_maintenance, :dry_run) SENSITIVE = [] include Aws::Structure end |
#vpn_tunnel_outside_ip_address ⇒ String
The external IP address of the VPN tunnel.
71919 71920 71921 71922 71923 71924 71925 71926 |
# File 'lib/aws-sdk-ec2/types.rb', line 71919 class ReplaceVpnTunnelRequest < Struct.new( :vpn_connection_id, :vpn_tunnel_outside_ip_address, :apply_pending_maintenance, :dry_run) SENSITIVE = [] include Aws::Structure end |