Class: Aws::EC2::Types::ReportInstanceStatusRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ReportInstanceStatusRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#description ⇒ String
Descriptive text about the health state of your instance.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#end_time ⇒ Time
The time at which the reported instance health state ended.
-
#instances ⇒ Array<String>
The instances.
-
#reason_codes ⇒ Array<String>
The reason codes that describe the health state of your instance.
-
#start_time ⇒ Time
The time at which the reported instance health state began.
-
#status ⇒ String
The status of all instances listed.
Instance Attribute Details
#description ⇒ String
Descriptive text about the health state of your instance.
76260 76261 76262 76263 76264 76265 76266 76267 76268 76269 76270 |
# File 'lib/aws-sdk-ec2/types.rb', line 76260 class ReportInstanceStatusRequest < Struct.new( :dry_run, :instances, :status, :start_time, :end_time, :reason_codes, :description) SENSITIVE = [:description] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
76260 76261 76262 76263 76264 76265 76266 76267 76268 76269 76270 |
# File 'lib/aws-sdk-ec2/types.rb', line 76260 class ReportInstanceStatusRequest < Struct.new( :dry_run, :instances, :status, :start_time, :end_time, :reason_codes, :description) SENSITIVE = [:description] include Aws::Structure end |
#end_time ⇒ Time
The time at which the reported instance health state ended.
76260 76261 76262 76263 76264 76265 76266 76267 76268 76269 76270 |
# File 'lib/aws-sdk-ec2/types.rb', line 76260 class ReportInstanceStatusRequest < Struct.new( :dry_run, :instances, :status, :start_time, :end_time, :reason_codes, :description) SENSITIVE = [:description] include Aws::Structure end |
#instances ⇒ Array<String>
The instances.
76260 76261 76262 76263 76264 76265 76266 76267 76268 76269 76270 |
# File 'lib/aws-sdk-ec2/types.rb', line 76260 class ReportInstanceStatusRequest < Struct.new( :dry_run, :instances, :status, :start_time, :end_time, :reason_codes, :description) SENSITIVE = [:description] include Aws::Structure end |
#reason_codes ⇒ Array<String>
The reason codes that describe the health state of your instance.
-
instance-stuck-in-state: My instance is stuck in a state. -
unresponsive: My instance is unresponsive. -
not-accepting-credentials: My instance is not accepting my credentials. -
password-not-available: A password is not available for my instance. -
performance-network: My instance is experiencing performance problems that I believe are network related. -
performance-instance-store: My instance is experiencing performance problems that I believe are related to the instance stores. -
performance-ebs-volume: My instance is experiencing performance problems that I believe are related to an EBS volume. -
performance-other: My instance is experiencing performance problems. -
other: [explain using the description parameter]
76260 76261 76262 76263 76264 76265 76266 76267 76268 76269 76270 |
# File 'lib/aws-sdk-ec2/types.rb', line 76260 class ReportInstanceStatusRequest < Struct.new( :dry_run, :instances, :status, :start_time, :end_time, :reason_codes, :description) SENSITIVE = [:description] include Aws::Structure end |
#start_time ⇒ Time
The time at which the reported instance health state began.
76260 76261 76262 76263 76264 76265 76266 76267 76268 76269 76270 |
# File 'lib/aws-sdk-ec2/types.rb', line 76260 class ReportInstanceStatusRequest < Struct.new( :dry_run, :instances, :status, :start_time, :end_time, :reason_codes, :description) SENSITIVE = [:description] include Aws::Structure end |
#status ⇒ String
The status of all instances listed.
76260 76261 76262 76263 76264 76265 76266 76267 76268 76269 76270 |
# File 'lib/aws-sdk-ec2/types.rb', line 76260 class ReportInstanceStatusRequest < Struct.new( :dry_run, :instances, :status, :start_time, :end_time, :reason_codes, :description) SENSITIVE = [:description] include Aws::Structure end |