Class: Aws::EC2::Types::RequestSpotFleetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for RequestSpotFleet.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


73514
73515
73516
73517
73518
73519
# File 'lib/aws-sdk-ec2/types.rb', line 73514

class RequestSpotFleetRequest < Struct.new(
  :dry_run,
  :spot_fleet_request_config)
  SENSITIVE = []
  include Aws::Structure
end

#spot_fleet_request_configTypes::SpotFleetRequestConfigData

The configuration for the Spot Fleet request.



73514
73515
73516
73517
73518
73519
# File 'lib/aws-sdk-ec2/types.rb', line 73514

class RequestSpotFleetRequest < Struct.new(
  :dry_run,
  :spot_fleet_request_config)
  SENSITIVE = []
  include Aws::Structure
end