Class: Aws::EC2::Types::RequestSpotFleetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for RequestSpotFleet.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


73160
73161
73162
73163
73164
73165
# File 'lib/aws-sdk-ec2/types.rb', line 73160

class RequestSpotFleetRequest < Struct.new(
  :dry_run,
  :spot_fleet_request_config)
  SENSITIVE = []
  include Aws::Structure
end

#spot_fleet_request_configTypes::SpotFleetRequestConfigData

The configuration for the Spot Fleet request.



73160
73161
73162
73163
73164
73165
# File 'lib/aws-sdk-ec2/types.rb', line 73160

class RequestSpotFleetRequest < Struct.new(
  :dry_run,
  :spot_fleet_request_config)
  SENSITIVE = []
  include Aws::Structure
end