Class: Aws::EC2::Types::RequestSpotFleetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::RequestSpotFleetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for RequestSpotFleet.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#spot_fleet_request_config ⇒ Types::SpotFleetRequestConfigData
The configuration for the Spot Fleet request.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
72910 72911 72912 72913 72914 72915 |
# File 'lib/aws-sdk-ec2/types.rb', line 72910 class RequestSpotFleetRequest < Struct.new( :dry_run, :spot_fleet_request_config) SENSITIVE = [] include Aws::Structure end |
#spot_fleet_request_config ⇒ Types::SpotFleetRequestConfigData
The configuration for the Spot Fleet request.
72910 72911 72912 72913 72914 72915 |
# File 'lib/aws-sdk-ec2/types.rb', line 72910 class RequestSpotFleetRequest < Struct.new( :dry_run, :spot_fleet_request_config) SENSITIVE = [] include Aws::Structure end |