Class: Aws::EC2::Types::RequestSpotLaunchSpecification
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::RequestSpotLaunchSpecification
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the launch specification for an instance.
Constant Summary collapse
- SENSITIVE =
[:user_data]
Instance Attribute Summary collapse
-
#addressing_type ⇒ String
Deprecated.
-
#block_device_mappings ⇒ Array<Types::BlockDeviceMapping>
The block device mapping entries.
-
#ebs_optimized ⇒ Boolean
Indicates whether the instance is optimized for EBS I/O.
-
#iam_instance_profile ⇒ Types::IamInstanceProfileSpecification
The IAM instance profile.
-
#image_id ⇒ String
The ID of the AMI.
-
#instance_type ⇒ String
The instance type.
-
#kernel_id ⇒ String
The ID of the kernel.
-
#key_name ⇒ String
The name of the key pair.
-
#monitoring ⇒ Types::RunInstancesMonitoringEnabled
Indicates whether basic or detailed monitoring is enabled for the instance.
-
#network_interfaces ⇒ Array<Types::InstanceNetworkInterfaceSpecification>
The network interfaces.
-
#placement ⇒ Types::SpotPlacement
The placement information for the instance.
-
#ramdisk_id ⇒ String
The ID of the RAM disk.
-
#security_group_ids ⇒ Array<String>
The IDs of the security groups.
-
#security_groups ⇒ Array<String>
Not supported.
-
#subnet_id ⇒ String
The ID of the subnet in which to launch the instance.
-
#user_data ⇒ String
The base64-encoded user data that instances use when starting up.
Instance Attribute Details
#addressing_type ⇒ String
Deprecated.
73320 73321 73322 73323 73324 73325 73326 73327 73328 73329 73330 73331 73332 73333 73334 73335 73336 73337 73338 73339 |
# File 'lib/aws-sdk-ec2/types.rb', line 73320 class RequestSpotLaunchSpecification < Struct.new( :security_group_ids, :security_groups, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :monitoring, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :user_data) SENSITIVE = [:user_data] include Aws::Structure end |
#block_device_mappings ⇒ Array<Types::BlockDeviceMapping>
The block device mapping entries. You can’t specify both a snapshot ID and an encryption value. This is because only blank volumes can be encrypted on creation. If a snapshot is the basis for a volume, it is not blank and its encryption status is used for the volume encryption status.
73320 73321 73322 73323 73324 73325 73326 73327 73328 73329 73330 73331 73332 73333 73334 73335 73336 73337 73338 73339 |
# File 'lib/aws-sdk-ec2/types.rb', line 73320 class RequestSpotLaunchSpecification < Struct.new( :security_group_ids, :security_groups, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :monitoring, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :user_data) SENSITIVE = [:user_data] include Aws::Structure end |
#ebs_optimized ⇒ Boolean
Indicates whether the instance is optimized for EBS I/O. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal EBS I/O performance. This optimization isn’t available with all instance types. Additional usage charges apply when using an EBS Optimized instance.
Default: ‘false`
73320 73321 73322 73323 73324 73325 73326 73327 73328 73329 73330 73331 73332 73333 73334 73335 73336 73337 73338 73339 |
# File 'lib/aws-sdk-ec2/types.rb', line 73320 class RequestSpotLaunchSpecification < Struct.new( :security_group_ids, :security_groups, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :monitoring, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :user_data) SENSITIVE = [:user_data] include Aws::Structure end |
#iam_instance_profile ⇒ Types::IamInstanceProfileSpecification
The IAM instance profile.
73320 73321 73322 73323 73324 73325 73326 73327 73328 73329 73330 73331 73332 73333 73334 73335 73336 73337 73338 73339 |
# File 'lib/aws-sdk-ec2/types.rb', line 73320 class RequestSpotLaunchSpecification < Struct.new( :security_group_ids, :security_groups, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :monitoring, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :user_data) SENSITIVE = [:user_data] include Aws::Structure end |
#image_id ⇒ String
The ID of the AMI.
73320 73321 73322 73323 73324 73325 73326 73327 73328 73329 73330 73331 73332 73333 73334 73335 73336 73337 73338 73339 |
# File 'lib/aws-sdk-ec2/types.rb', line 73320 class RequestSpotLaunchSpecification < Struct.new( :security_group_ids, :security_groups, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :monitoring, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :user_data) SENSITIVE = [:user_data] include Aws::Structure end |
#instance_type ⇒ String
The instance type. Only one instance type can be specified.
73320 73321 73322 73323 73324 73325 73326 73327 73328 73329 73330 73331 73332 73333 73334 73335 73336 73337 73338 73339 |
# File 'lib/aws-sdk-ec2/types.rb', line 73320 class RequestSpotLaunchSpecification < Struct.new( :security_group_ids, :security_groups, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :monitoring, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :user_data) SENSITIVE = [:user_data] include Aws::Structure end |
#kernel_id ⇒ String
The ID of the kernel.
73320 73321 73322 73323 73324 73325 73326 73327 73328 73329 73330 73331 73332 73333 73334 73335 73336 73337 73338 73339 |
# File 'lib/aws-sdk-ec2/types.rb', line 73320 class RequestSpotLaunchSpecification < Struct.new( :security_group_ids, :security_groups, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :monitoring, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :user_data) SENSITIVE = [:user_data] include Aws::Structure end |
#key_name ⇒ String
The name of the key pair.
73320 73321 73322 73323 73324 73325 73326 73327 73328 73329 73330 73331 73332 73333 73334 73335 73336 73337 73338 73339 |
# File 'lib/aws-sdk-ec2/types.rb', line 73320 class RequestSpotLaunchSpecification < Struct.new( :security_group_ids, :security_groups, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :monitoring, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :user_data) SENSITIVE = [:user_data] include Aws::Structure end |
#monitoring ⇒ Types::RunInstancesMonitoringEnabled
Indicates whether basic or detailed monitoring is enabled for the instance.
Default: Disabled
73320 73321 73322 73323 73324 73325 73326 73327 73328 73329 73330 73331 73332 73333 73334 73335 73336 73337 73338 73339 |
# File 'lib/aws-sdk-ec2/types.rb', line 73320 class RequestSpotLaunchSpecification < Struct.new( :security_group_ids, :security_groups, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :monitoring, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :user_data) SENSITIVE = [:user_data] include Aws::Structure end |
#network_interfaces ⇒ Array<Types::InstanceNetworkInterfaceSpecification>
The network interfaces. If you specify a network interface, you must specify subnet IDs and security group IDs using the network interface.
73320 73321 73322 73323 73324 73325 73326 73327 73328 73329 73330 73331 73332 73333 73334 73335 73336 73337 73338 73339 |
# File 'lib/aws-sdk-ec2/types.rb', line 73320 class RequestSpotLaunchSpecification < Struct.new( :security_group_ids, :security_groups, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :monitoring, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :user_data) SENSITIVE = [:user_data] include Aws::Structure end |
#placement ⇒ Types::SpotPlacement
The placement information for the instance.
73320 73321 73322 73323 73324 73325 73326 73327 73328 73329 73330 73331 73332 73333 73334 73335 73336 73337 73338 73339 |
# File 'lib/aws-sdk-ec2/types.rb', line 73320 class RequestSpotLaunchSpecification < Struct.new( :security_group_ids, :security_groups, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :monitoring, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :user_data) SENSITIVE = [:user_data] include Aws::Structure end |
#ramdisk_id ⇒ String
The ID of the RAM disk.
73320 73321 73322 73323 73324 73325 73326 73327 73328 73329 73330 73331 73332 73333 73334 73335 73336 73337 73338 73339 |
# File 'lib/aws-sdk-ec2/types.rb', line 73320 class RequestSpotLaunchSpecification < Struct.new( :security_group_ids, :security_groups, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :monitoring, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :user_data) SENSITIVE = [:user_data] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
The IDs of the security groups.
73320 73321 73322 73323 73324 73325 73326 73327 73328 73329 73330 73331 73332 73333 73334 73335 73336 73337 73338 73339 |
# File 'lib/aws-sdk-ec2/types.rb', line 73320 class RequestSpotLaunchSpecification < Struct.new( :security_group_ids, :security_groups, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :monitoring, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :user_data) SENSITIVE = [:user_data] include Aws::Structure end |
#security_groups ⇒ Array<String>
Not supported.
73320 73321 73322 73323 73324 73325 73326 73327 73328 73329 73330 73331 73332 73333 73334 73335 73336 73337 73338 73339 |
# File 'lib/aws-sdk-ec2/types.rb', line 73320 class RequestSpotLaunchSpecification < Struct.new( :security_group_ids, :security_groups, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :monitoring, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :user_data) SENSITIVE = [:user_data] include Aws::Structure end |
#subnet_id ⇒ String
The ID of the subnet in which to launch the instance.
73320 73321 73322 73323 73324 73325 73326 73327 73328 73329 73330 73331 73332 73333 73334 73335 73336 73337 73338 73339 |
# File 'lib/aws-sdk-ec2/types.rb', line 73320 class RequestSpotLaunchSpecification < Struct.new( :security_group_ids, :security_groups, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :monitoring, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :user_data) SENSITIVE = [:user_data] include Aws::Structure end |
#user_data ⇒ String
The base64-encoded user data that instances use when starting up. User data is limited to 16 KB.
73320 73321 73322 73323 73324 73325 73326 73327 73328 73329 73330 73331 73332 73333 73334 73335 73336 73337 73338 73339 |
# File 'lib/aws-sdk-ec2/types.rb', line 73320 class RequestSpotLaunchSpecification < Struct.new( :security_group_ids, :security_groups, :addressing_type, :block_device_mappings, :ebs_optimized, :iam_instance_profile, :image_id, :instance_type, :kernel_id, :key_name, :monitoring, :network_interfaces, :placement, :ramdisk_id, :subnet_id, :user_data) SENSITIVE = [:user_data] include Aws::Structure end |