Class: Aws::EC2::Types::Reservation
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::Reservation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a launch request for one or more instances, and includes owner, requester, and security group information that applies to all instances in the launch request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#groups ⇒ Array<Types::GroupIdentifier>
Not supported.
-
#instances ⇒ Array<Types::Instance>
The instances.
-
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the reservation.
-
#requester_id ⇒ String
The ID of the requester that launched the instances on your behalf (for example, Amazon Web Services Management Console or Auto Scaling).
-
#reservation_id ⇒ String
The ID of the reservation.
Instance Attribute Details
#groups ⇒ Array<Types::GroupIdentifier>
Not supported.
76992 76993 76994 76995 76996 76997 76998 76999 77000 |
# File 'lib/aws-sdk-ec2/types.rb', line 76992 class Reservation < Struct.new( :reservation_id, :owner_id, :requester_id, :groups, :instances) SENSITIVE = [] include Aws::Structure end |
#instances ⇒ Array<Types::Instance>
The instances.
76992 76993 76994 76995 76996 76997 76998 76999 77000 |
# File 'lib/aws-sdk-ec2/types.rb', line 76992 class Reservation < Struct.new( :reservation_id, :owner_id, :requester_id, :groups, :instances) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the reservation.
76992 76993 76994 76995 76996 76997 76998 76999 77000 |
# File 'lib/aws-sdk-ec2/types.rb', line 76992 class Reservation < Struct.new( :reservation_id, :owner_id, :requester_id, :groups, :instances) SENSITIVE = [] include Aws::Structure end |
#requester_id ⇒ String
The ID of the requester that launched the instances on your behalf (for example, Amazon Web Services Management Console or Auto Scaling).
76992 76993 76994 76995 76996 76997 76998 76999 77000 |
# File 'lib/aws-sdk-ec2/types.rb', line 76992 class Reservation < Struct.new( :reservation_id, :owner_id, :requester_id, :groups, :instances) SENSITIVE = [] include Aws::Structure end |
#reservation_id ⇒ String
The ID of the reservation.
76992 76993 76994 76995 76996 76997 76998 76999 77000 |
# File 'lib/aws-sdk-ec2/types.rb', line 76992 class Reservation < Struct.new( :reservation_id, :owner_id, :requester_id, :groups, :instances) SENSITIVE = [] include Aws::Structure end |