Class: Aws::EC2::Types::ReservedCapacityOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ReservedCapacityOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Defines EC2 Fleet preferences for utilizing reserved capacity when
DefaultTargetCapacityType is set to reserved-capacity. EC2 Fleet
can fulfill reserved capacity using On-Demand Capacity Reservations,
Capacity Blocks for ML, and interruptible Capacity Reservations.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allocation_strategy ⇒ String
The strategy that determines the order in which EC2 Fleet launches instances across the reservation types that you specify.
-
#reservation_types ⇒ Array<String>
The types of Capacity Reservations used for fulfilling the EC2 Fleet request.
-
#reserved_capacity_fallback_options ⇒ Types::ReservedCapacityFallbackOptions
The fallback behavior for the EC2 Fleet when there is not enough reserved capacity available to meet the target capacity.
Instance Attribute Details
#allocation_strategy ⇒ String
The strategy that determines the order in which EC2 Fleet launches
instances across the reservation types that you specify. The only
supported value is prioritized, which launches instances in the
priority order that you specify in your launch template overrides.
If you don't specify an allocation strategy, instances are launched
in a random order.
77223 77224 77225 77226 77227 77228 77229 |
# File 'lib/aws-sdk-ec2/types.rb', line 77223 class ReservedCapacityOptions < Struct.new( :allocation_strategy, :reservation_types, :reserved_capacity_fallback_options) SENSITIVE = [] include Aws::Structure end |
#reservation_types ⇒ Array<String>
The types of Capacity Reservations used for fulfilling the EC2 Fleet request.
77223 77224 77225 77226 77227 77228 77229 |
# File 'lib/aws-sdk-ec2/types.rb', line 77223 class ReservedCapacityOptions < Struct.new( :allocation_strategy, :reservation_types, :reserved_capacity_fallback_options) SENSITIVE = [] include Aws::Structure end |
#reserved_capacity_fallback_options ⇒ Types::ReservedCapacityFallbackOptions
The fallback behavior for the EC2 Fleet when there is not enough reserved capacity available to meet the target capacity.
77223 77224 77225 77226 77227 77228 77229 |
# File 'lib/aws-sdk-ec2/types.rb', line 77223 class ReservedCapacityOptions < Struct.new( :allocation_strategy, :reservation_types, :reserved_capacity_fallback_options) SENSITIVE = [] include Aws::Structure end |