Class: Aws::EC2::Types::ReservedCapacityOptionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Defines EC2 Fleet preferences for utilizing reserved capacity when DefaultTargetCapacityType is set to ‘reserved-capacity`.

<note markdown=“1”> This configuration can only be used if the EC2 Fleet is of type ‘instant`.

</note>

When you specify ‘ReservedCapacityOptions`, you must also set `DefaultTargetCapacityType` to `reserved-capacity` in the `TargetCapacitySpecification`.

For more information about Interruptible Capacity Reservations, see

Launch instances into an Interruptible Capacity Reservation][1

in

the *Amazon EC2 User Guide*.

[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-fleet-launch-instances-interruptible-cr-walkthrough.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#reservation_typesArray<String>

The types of Capacity Reservations to use for fulfilling the EC2 Fleet request.

Returns:

  • (Array<String>)


72786
72787
72788
72789
72790
# File 'lib/aws-sdk-ec2/types.rb', line 72786

class ReservedCapacityOptionsRequest < Struct.new(
  :reservation_types)
  SENSITIVE = []
  include Aws::Structure
end