Class: Aws::EC2::Types::ReservedInstances
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ReservedInstances
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a Reserved Instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone ⇒ String
The Availability Zone in which the Reserved Instance can be used.
-
#availability_zone_id ⇒ String
The ID of the Availability Zone.
-
#currency_code ⇒ String
The currency of the Reserved Instance.
-
#duration ⇒ Integer
The duration of the Reserved Instance, in seconds.
-
#end ⇒ Time
The time when the Reserved Instance expires.
-
#fixed_price ⇒ Float
The purchase price of the Reserved Instance.
-
#instance_count ⇒ Integer
The number of reservations purchased.
-
#instance_tenancy ⇒ String
The tenancy of the instance.
-
#instance_type ⇒ String
The instance type on which the Reserved Instance can be used.
-
#offering_class ⇒ String
The offering class of the Reserved Instance.
-
#offering_type ⇒ String
The Reserved Instance offering type.
-
#product_description ⇒ String
The Reserved Instance product platform description.
-
#recurring_charges ⇒ Array<Types::RecurringCharge>
The recurring charge tag assigned to the resource.
-
#reserved_instances_id ⇒ String
The ID of the Reserved Instance.
-
#scope ⇒ String
The scope of the Reserved Instance.
-
#start ⇒ Time
The date and time the Reserved Instance started.
-
#state ⇒ String
The state of the Reserved Instance purchase.
-
#tags ⇒ Array<Types::Tag>
Any tags assigned to the resource.
-
#usage_price ⇒ Float
The usage price of the Reserved Instance, per hour.
Instance Attribute Details
#availability_zone ⇒ String
The Availability Zone in which the Reserved Instance can be used.
73651 73652 73653 73654 73655 73656 73657 73658 73659 73660 73661 73662 73663 73664 73665 73666 73667 73668 73669 73670 73671 73672 73673 |
# File 'lib/aws-sdk-ec2/types.rb', line 73651 class ReservedInstances < Struct.new( :currency_code, :instance_tenancy, :offering_class, :offering_type, :recurring_charges, :scope, :tags, :availability_zone_id, :reserved_instances_id, :instance_type, :availability_zone, :start, :end, :duration, :usage_price, :fixed_price, :instance_count, :product_description, :state) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
The ID of the Availability Zone.
73651 73652 73653 73654 73655 73656 73657 73658 73659 73660 73661 73662 73663 73664 73665 73666 73667 73668 73669 73670 73671 73672 73673 |
# File 'lib/aws-sdk-ec2/types.rb', line 73651 class ReservedInstances < Struct.new( :currency_code, :instance_tenancy, :offering_class, :offering_type, :recurring_charges, :scope, :tags, :availability_zone_id, :reserved_instances_id, :instance_type, :availability_zone, :start, :end, :duration, :usage_price, :fixed_price, :instance_count, :product_description, :state) SENSITIVE = [] include Aws::Structure end |
#currency_code ⇒ String
The currency of the Reserved Instance. It’s specified using ISO 4217 standard currency codes. At this time, the only supported currency is ‘USD`.
73651 73652 73653 73654 73655 73656 73657 73658 73659 73660 73661 73662 73663 73664 73665 73666 73667 73668 73669 73670 73671 73672 73673 |
# File 'lib/aws-sdk-ec2/types.rb', line 73651 class ReservedInstances < Struct.new( :currency_code, :instance_tenancy, :offering_class, :offering_type, :recurring_charges, :scope, :tags, :availability_zone_id, :reserved_instances_id, :instance_type, :availability_zone, :start, :end, :duration, :usage_price, :fixed_price, :instance_count, :product_description, :state) SENSITIVE = [] include Aws::Structure end |
#duration ⇒ Integer
The duration of the Reserved Instance, in seconds.
73651 73652 73653 73654 73655 73656 73657 73658 73659 73660 73661 73662 73663 73664 73665 73666 73667 73668 73669 73670 73671 73672 73673 |
# File 'lib/aws-sdk-ec2/types.rb', line 73651 class ReservedInstances < Struct.new( :currency_code, :instance_tenancy, :offering_class, :offering_type, :recurring_charges, :scope, :tags, :availability_zone_id, :reserved_instances_id, :instance_type, :availability_zone, :start, :end, :duration, :usage_price, :fixed_price, :instance_count, :product_description, :state) SENSITIVE = [] include Aws::Structure end |
#end ⇒ Time
The time when the Reserved Instance expires.
73651 73652 73653 73654 73655 73656 73657 73658 73659 73660 73661 73662 73663 73664 73665 73666 73667 73668 73669 73670 73671 73672 73673 |
# File 'lib/aws-sdk-ec2/types.rb', line 73651 class ReservedInstances < Struct.new( :currency_code, :instance_tenancy, :offering_class, :offering_type, :recurring_charges, :scope, :tags, :availability_zone_id, :reserved_instances_id, :instance_type, :availability_zone, :start, :end, :duration, :usage_price, :fixed_price, :instance_count, :product_description, :state) SENSITIVE = [] include Aws::Structure end |
#fixed_price ⇒ Float
The purchase price of the Reserved Instance.
73651 73652 73653 73654 73655 73656 73657 73658 73659 73660 73661 73662 73663 73664 73665 73666 73667 73668 73669 73670 73671 73672 73673 |
# File 'lib/aws-sdk-ec2/types.rb', line 73651 class ReservedInstances < Struct.new( :currency_code, :instance_tenancy, :offering_class, :offering_type, :recurring_charges, :scope, :tags, :availability_zone_id, :reserved_instances_id, :instance_type, :availability_zone, :start, :end, :duration, :usage_price, :fixed_price, :instance_count, :product_description, :state) SENSITIVE = [] include Aws::Structure end |
#instance_count ⇒ Integer
The number of reservations purchased.
73651 73652 73653 73654 73655 73656 73657 73658 73659 73660 73661 73662 73663 73664 73665 73666 73667 73668 73669 73670 73671 73672 73673 |
# File 'lib/aws-sdk-ec2/types.rb', line 73651 class ReservedInstances < Struct.new( :currency_code, :instance_tenancy, :offering_class, :offering_type, :recurring_charges, :scope, :tags, :availability_zone_id, :reserved_instances_id, :instance_type, :availability_zone, :start, :end, :duration, :usage_price, :fixed_price, :instance_count, :product_description, :state) SENSITIVE = [] include Aws::Structure end |
#instance_tenancy ⇒ String
The tenancy of the instance.
73651 73652 73653 73654 73655 73656 73657 73658 73659 73660 73661 73662 73663 73664 73665 73666 73667 73668 73669 73670 73671 73672 73673 |
# File 'lib/aws-sdk-ec2/types.rb', line 73651 class ReservedInstances < Struct.new( :currency_code, :instance_tenancy, :offering_class, :offering_type, :recurring_charges, :scope, :tags, :availability_zone_id, :reserved_instances_id, :instance_type, :availability_zone, :start, :end, :duration, :usage_price, :fixed_price, :instance_count, :product_description, :state) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The instance type on which the Reserved Instance can be used.
73651 73652 73653 73654 73655 73656 73657 73658 73659 73660 73661 73662 73663 73664 73665 73666 73667 73668 73669 73670 73671 73672 73673 |
# File 'lib/aws-sdk-ec2/types.rb', line 73651 class ReservedInstances < Struct.new( :currency_code, :instance_tenancy, :offering_class, :offering_type, :recurring_charges, :scope, :tags, :availability_zone_id, :reserved_instances_id, :instance_type, :availability_zone, :start, :end, :duration, :usage_price, :fixed_price, :instance_count, :product_description, :state) SENSITIVE = [] include Aws::Structure end |
#offering_class ⇒ String
The offering class of the Reserved Instance.
73651 73652 73653 73654 73655 73656 73657 73658 73659 73660 73661 73662 73663 73664 73665 73666 73667 73668 73669 73670 73671 73672 73673 |
# File 'lib/aws-sdk-ec2/types.rb', line 73651 class ReservedInstances < Struct.new( :currency_code, :instance_tenancy, :offering_class, :offering_type, :recurring_charges, :scope, :tags, :availability_zone_id, :reserved_instances_id, :instance_type, :availability_zone, :start, :end, :duration, :usage_price, :fixed_price, :instance_count, :product_description, :state) SENSITIVE = [] include Aws::Structure end |
#offering_type ⇒ String
The Reserved Instance offering type.
73651 73652 73653 73654 73655 73656 73657 73658 73659 73660 73661 73662 73663 73664 73665 73666 73667 73668 73669 73670 73671 73672 73673 |
# File 'lib/aws-sdk-ec2/types.rb', line 73651 class ReservedInstances < Struct.new( :currency_code, :instance_tenancy, :offering_class, :offering_type, :recurring_charges, :scope, :tags, :availability_zone_id, :reserved_instances_id, :instance_type, :availability_zone, :start, :end, :duration, :usage_price, :fixed_price, :instance_count, :product_description, :state) SENSITIVE = [] include Aws::Structure end |
#product_description ⇒ String
The Reserved Instance product platform description.
73651 73652 73653 73654 73655 73656 73657 73658 73659 73660 73661 73662 73663 73664 73665 73666 73667 73668 73669 73670 73671 73672 73673 |
# File 'lib/aws-sdk-ec2/types.rb', line 73651 class ReservedInstances < Struct.new( :currency_code, :instance_tenancy, :offering_class, :offering_type, :recurring_charges, :scope, :tags, :availability_zone_id, :reserved_instances_id, :instance_type, :availability_zone, :start, :end, :duration, :usage_price, :fixed_price, :instance_count, :product_description, :state) SENSITIVE = [] include Aws::Structure end |
#recurring_charges ⇒ Array<Types::RecurringCharge>
The recurring charge tag assigned to the resource.
73651 73652 73653 73654 73655 73656 73657 73658 73659 73660 73661 73662 73663 73664 73665 73666 73667 73668 73669 73670 73671 73672 73673 |
# File 'lib/aws-sdk-ec2/types.rb', line 73651 class ReservedInstances < Struct.new( :currency_code, :instance_tenancy, :offering_class, :offering_type, :recurring_charges, :scope, :tags, :availability_zone_id, :reserved_instances_id, :instance_type, :availability_zone, :start, :end, :duration, :usage_price, :fixed_price, :instance_count, :product_description, :state) SENSITIVE = [] include Aws::Structure end |
#reserved_instances_id ⇒ String
The ID of the Reserved Instance.
73651 73652 73653 73654 73655 73656 73657 73658 73659 73660 73661 73662 73663 73664 73665 73666 73667 73668 73669 73670 73671 73672 73673 |
# File 'lib/aws-sdk-ec2/types.rb', line 73651 class ReservedInstances < Struct.new( :currency_code, :instance_tenancy, :offering_class, :offering_type, :recurring_charges, :scope, :tags, :availability_zone_id, :reserved_instances_id, :instance_type, :availability_zone, :start, :end, :duration, :usage_price, :fixed_price, :instance_count, :product_description, :state) SENSITIVE = [] include Aws::Structure end |
#scope ⇒ String
The scope of the Reserved Instance.
73651 73652 73653 73654 73655 73656 73657 73658 73659 73660 73661 73662 73663 73664 73665 73666 73667 73668 73669 73670 73671 73672 73673 |
# File 'lib/aws-sdk-ec2/types.rb', line 73651 class ReservedInstances < Struct.new( :currency_code, :instance_tenancy, :offering_class, :offering_type, :recurring_charges, :scope, :tags, :availability_zone_id, :reserved_instances_id, :instance_type, :availability_zone, :start, :end, :duration, :usage_price, :fixed_price, :instance_count, :product_description, :state) SENSITIVE = [] include Aws::Structure end |
#start ⇒ Time
The date and time the Reserved Instance started.
73651 73652 73653 73654 73655 73656 73657 73658 73659 73660 73661 73662 73663 73664 73665 73666 73667 73668 73669 73670 73671 73672 73673 |
# File 'lib/aws-sdk-ec2/types.rb', line 73651 class ReservedInstances < Struct.new( :currency_code, :instance_tenancy, :offering_class, :offering_type, :recurring_charges, :scope, :tags, :availability_zone_id, :reserved_instances_id, :instance_type, :availability_zone, :start, :end, :duration, :usage_price, :fixed_price, :instance_count, :product_description, :state) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the Reserved Instance purchase.
73651 73652 73653 73654 73655 73656 73657 73658 73659 73660 73661 73662 73663 73664 73665 73666 73667 73668 73669 73670 73671 73672 73673 |
# File 'lib/aws-sdk-ec2/types.rb', line 73651 class ReservedInstances < Struct.new( :currency_code, :instance_tenancy, :offering_class, :offering_type, :recurring_charges, :scope, :tags, :availability_zone_id, :reserved_instances_id, :instance_type, :availability_zone, :start, :end, :duration, :usage_price, :fixed_price, :instance_count, :product_description, :state) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Any tags assigned to the resource.
73651 73652 73653 73654 73655 73656 73657 73658 73659 73660 73661 73662 73663 73664 73665 73666 73667 73668 73669 73670 73671 73672 73673 |
# File 'lib/aws-sdk-ec2/types.rb', line 73651 class ReservedInstances < Struct.new( :currency_code, :instance_tenancy, :offering_class, :offering_type, :recurring_charges, :scope, :tags, :availability_zone_id, :reserved_instances_id, :instance_type, :availability_zone, :start, :end, :duration, :usage_price, :fixed_price, :instance_count, :product_description, :state) SENSITIVE = [] include Aws::Structure end |
#usage_price ⇒ Float
The usage price of the Reserved Instance, per hour.
73651 73652 73653 73654 73655 73656 73657 73658 73659 73660 73661 73662 73663 73664 73665 73666 73667 73668 73669 73670 73671 73672 73673 |
# File 'lib/aws-sdk-ec2/types.rb', line 73651 class ReservedInstances < Struct.new( :currency_code, :instance_tenancy, :offering_class, :offering_type, :recurring_charges, :scope, :tags, :availability_zone_id, :reserved_instances_id, :instance_type, :availability_zone, :start, :end, :duration, :usage_price, :fixed_price, :instance_count, :product_description, :state) SENSITIVE = [] include Aws::Structure end |