Class: Aws::EC2::Types::ReservedInstancesModificationResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ReservedInstancesModificationResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the modification request/s.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#reserved_instances_id ⇒ String
The ID for the Reserved Instances that were created as part of the modification request.
-
#target_configuration ⇒ Types::ReservedInstancesConfiguration
The target Reserved Instances configurations supplied as part of the modification request.
Instance Attribute Details
#reserved_instances_id ⇒ String
The ID for the Reserved Instances that were created as part of the modification request. This field is only available when the modification is fulfilled.
71743 71744 71745 71746 71747 71748 |
# File 'lib/aws-sdk-ec2/types.rb', line 71743 class ReservedInstancesModificationResult < Struct.new( :reserved_instances_id, :target_configuration) SENSITIVE = [] include Aws::Structure end |
#target_configuration ⇒ Types::ReservedInstancesConfiguration
The target Reserved Instances configurations supplied as part of the modification request.
71743 71744 71745 71746 71747 71748 |
# File 'lib/aws-sdk-ec2/types.rb', line 71743 class ReservedInstancesModificationResult < Struct.new( :reserved_instances_id, :target_configuration) SENSITIVE = [] include Aws::Structure end |