Class: Aws::EC2::Types::ReservedInstancesOffering

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes a Reserved Instance offering.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_zoneString

The Availability Zone in which the Reserved Instance can be used.

Returns:

  • (String)


74781
74782
74783
74784
74785
74786
74787
74788
74789
74790
74791
74792
74793
74794
74795
74796
74797
74798
74799
74800
# File 'lib/aws-sdk-ec2/types.rb', line 74781

class ReservedInstancesOffering < Struct.new(
  :currency_code,
  :instance_tenancy,
  :marketplace,
  :offering_class,
  :offering_type,
  :pricing_details,
  :recurring_charges,
  :scope,
  :availability_zone_id,
  :reserved_instances_offering_id,
  :instance_type,
  :availability_zone,
  :duration,
  :usage_price,
  :fixed_price,
  :product_description)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zone_idString

The ID of the Availability Zone.

Returns:

  • (String)


74781
74782
74783
74784
74785
74786
74787
74788
74789
74790
74791
74792
74793
74794
74795
74796
74797
74798
74799
74800
# File 'lib/aws-sdk-ec2/types.rb', line 74781

class ReservedInstancesOffering < Struct.new(
  :currency_code,
  :instance_tenancy,
  :marketplace,
  :offering_class,
  :offering_type,
  :pricing_details,
  :recurring_charges,
  :scope,
  :availability_zone_id,
  :reserved_instances_offering_id,
  :instance_type,
  :availability_zone,
  :duration,
  :usage_price,
  :fixed_price,
  :product_description)
  SENSITIVE = []
  include Aws::Structure
end

#currency_codeString

The currency of the Reserved Instance offering you are purchasing. It's specified using ISO 4217 standard currency codes. At this time, the only supported currency is USD.

Returns:

  • (String)


74781
74782
74783
74784
74785
74786
74787
74788
74789
74790
74791
74792
74793
74794
74795
74796
74797
74798
74799
74800
# File 'lib/aws-sdk-ec2/types.rb', line 74781

class ReservedInstancesOffering < Struct.new(
  :currency_code,
  :instance_tenancy,
  :marketplace,
  :offering_class,
  :offering_type,
  :pricing_details,
  :recurring_charges,
  :scope,
  :availability_zone_id,
  :reserved_instances_offering_id,
  :instance_type,
  :availability_zone,
  :duration,
  :usage_price,
  :fixed_price,
  :product_description)
  SENSITIVE = []
  include Aws::Structure
end

#durationInteger

The duration of the Reserved Instance, in seconds.

Returns:

  • (Integer)


74781
74782
74783
74784
74785
74786
74787
74788
74789
74790
74791
74792
74793
74794
74795
74796
74797
74798
74799
74800
# File 'lib/aws-sdk-ec2/types.rb', line 74781

class ReservedInstancesOffering < Struct.new(
  :currency_code,
  :instance_tenancy,
  :marketplace,
  :offering_class,
  :offering_type,
  :pricing_details,
  :recurring_charges,
  :scope,
  :availability_zone_id,
  :reserved_instances_offering_id,
  :instance_type,
  :availability_zone,
  :duration,
  :usage_price,
  :fixed_price,
  :product_description)
  SENSITIVE = []
  include Aws::Structure
end

#fixed_priceFloat

The purchase price of the Reserved Instance.

Returns:

  • (Float)


74781
74782
74783
74784
74785
74786
74787
74788
74789
74790
74791
74792
74793
74794
74795
74796
74797
74798
74799
74800
# File 'lib/aws-sdk-ec2/types.rb', line 74781

class ReservedInstancesOffering < Struct.new(
  :currency_code,
  :instance_tenancy,
  :marketplace,
  :offering_class,
  :offering_type,
  :pricing_details,
  :recurring_charges,
  :scope,
  :availability_zone_id,
  :reserved_instances_offering_id,
  :instance_type,
  :availability_zone,
  :duration,
  :usage_price,
  :fixed_price,
  :product_description)
  SENSITIVE = []
  include Aws::Structure
end

#instance_tenancyString

The tenancy of the instance.

Returns:

  • (String)


74781
74782
74783
74784
74785
74786
74787
74788
74789
74790
74791
74792
74793
74794
74795
74796
74797
74798
74799
74800
# File 'lib/aws-sdk-ec2/types.rb', line 74781

class ReservedInstancesOffering < Struct.new(
  :currency_code,
  :instance_tenancy,
  :marketplace,
  :offering_class,
  :offering_type,
  :pricing_details,
  :recurring_charges,
  :scope,
  :availability_zone_id,
  :reserved_instances_offering_id,
  :instance_type,
  :availability_zone,
  :duration,
  :usage_price,
  :fixed_price,
  :product_description)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

The instance type on which the Reserved Instance can be used.

Returns:

  • (String)


74781
74782
74783
74784
74785
74786
74787
74788
74789
74790
74791
74792
74793
74794
74795
74796
74797
74798
74799
74800
# File 'lib/aws-sdk-ec2/types.rb', line 74781

class ReservedInstancesOffering < Struct.new(
  :currency_code,
  :instance_tenancy,
  :marketplace,
  :offering_class,
  :offering_type,
  :pricing_details,
  :recurring_charges,
  :scope,
  :availability_zone_id,
  :reserved_instances_offering_id,
  :instance_type,
  :availability_zone,
  :duration,
  :usage_price,
  :fixed_price,
  :product_description)
  SENSITIVE = []
  include Aws::Structure
end

#marketplaceBoolean

Indicates whether the offering is available through the Reserved Instance Marketplace (resale) or Amazon Web Services. If it's a Reserved Instance Marketplace offering, this is true.

Returns:

  • (Boolean)


74781
74782
74783
74784
74785
74786
74787
74788
74789
74790
74791
74792
74793
74794
74795
74796
74797
74798
74799
74800
# File 'lib/aws-sdk-ec2/types.rb', line 74781

class ReservedInstancesOffering < Struct.new(
  :currency_code,
  :instance_tenancy,
  :marketplace,
  :offering_class,
  :offering_type,
  :pricing_details,
  :recurring_charges,
  :scope,
  :availability_zone_id,
  :reserved_instances_offering_id,
  :instance_type,
  :availability_zone,
  :duration,
  :usage_price,
  :fixed_price,
  :product_description)
  SENSITIVE = []
  include Aws::Structure
end

#offering_classString

If convertible it can be exchanged for Reserved Instances of the same or higher monetary value, with different configurations. If standard, it is not possible to perform an exchange.

Returns:

  • (String)


74781
74782
74783
74784
74785
74786
74787
74788
74789
74790
74791
74792
74793
74794
74795
74796
74797
74798
74799
74800
# File 'lib/aws-sdk-ec2/types.rb', line 74781

class ReservedInstancesOffering < Struct.new(
  :currency_code,
  :instance_tenancy,
  :marketplace,
  :offering_class,
  :offering_type,
  :pricing_details,
  :recurring_charges,
  :scope,
  :availability_zone_id,
  :reserved_instances_offering_id,
  :instance_type,
  :availability_zone,
  :duration,
  :usage_price,
  :fixed_price,
  :product_description)
  SENSITIVE = []
  include Aws::Structure
end

#offering_typeString

The Reserved Instance offering type.

Returns:

  • (String)


74781
74782
74783
74784
74785
74786
74787
74788
74789
74790
74791
74792
74793
74794
74795
74796
74797
74798
74799
74800
# File 'lib/aws-sdk-ec2/types.rb', line 74781

class ReservedInstancesOffering < Struct.new(
  :currency_code,
  :instance_tenancy,
  :marketplace,
  :offering_class,
  :offering_type,
  :pricing_details,
  :recurring_charges,
  :scope,
  :availability_zone_id,
  :reserved_instances_offering_id,
  :instance_type,
  :availability_zone,
  :duration,
  :usage_price,
  :fixed_price,
  :product_description)
  SENSITIVE = []
  include Aws::Structure
end

#pricing_detailsArray<Types::PricingDetail>

The pricing details of the Reserved Instance offering.

Returns:



74781
74782
74783
74784
74785
74786
74787
74788
74789
74790
74791
74792
74793
74794
74795
74796
74797
74798
74799
74800
# File 'lib/aws-sdk-ec2/types.rb', line 74781

class ReservedInstancesOffering < Struct.new(
  :currency_code,
  :instance_tenancy,
  :marketplace,
  :offering_class,
  :offering_type,
  :pricing_details,
  :recurring_charges,
  :scope,
  :availability_zone_id,
  :reserved_instances_offering_id,
  :instance_type,
  :availability_zone,
  :duration,
  :usage_price,
  :fixed_price,
  :product_description)
  SENSITIVE = []
  include Aws::Structure
end

#product_descriptionString

The Reserved Instance product platform description.

Returns:

  • (String)


74781
74782
74783
74784
74785
74786
74787
74788
74789
74790
74791
74792
74793
74794
74795
74796
74797
74798
74799
74800
# File 'lib/aws-sdk-ec2/types.rb', line 74781

class ReservedInstancesOffering < Struct.new(
  :currency_code,
  :instance_tenancy,
  :marketplace,
  :offering_class,
  :offering_type,
  :pricing_details,
  :recurring_charges,
  :scope,
  :availability_zone_id,
  :reserved_instances_offering_id,
  :instance_type,
  :availability_zone,
  :duration,
  :usage_price,
  :fixed_price,
  :product_description)
  SENSITIVE = []
  include Aws::Structure
end

#recurring_chargesArray<Types::RecurringCharge>

The recurring charge tag assigned to the resource.

Returns:



74781
74782
74783
74784
74785
74786
74787
74788
74789
74790
74791
74792
74793
74794
74795
74796
74797
74798
74799
74800
# File 'lib/aws-sdk-ec2/types.rb', line 74781

class ReservedInstancesOffering < Struct.new(
  :currency_code,
  :instance_tenancy,
  :marketplace,
  :offering_class,
  :offering_type,
  :pricing_details,
  :recurring_charges,
  :scope,
  :availability_zone_id,
  :reserved_instances_offering_id,
  :instance_type,
  :availability_zone,
  :duration,
  :usage_price,
  :fixed_price,
  :product_description)
  SENSITIVE = []
  include Aws::Structure
end

#reserved_instances_offering_idString

The ID of the Reserved Instance offering. This is the offering ID used in GetReservedInstancesExchangeQuote to confirm that an exchange can be made.

Returns:

  • (String)


74781
74782
74783
74784
74785
74786
74787
74788
74789
74790
74791
74792
74793
74794
74795
74796
74797
74798
74799
74800
# File 'lib/aws-sdk-ec2/types.rb', line 74781

class ReservedInstancesOffering < Struct.new(
  :currency_code,
  :instance_tenancy,
  :marketplace,
  :offering_class,
  :offering_type,
  :pricing_details,
  :recurring_charges,
  :scope,
  :availability_zone_id,
  :reserved_instances_offering_id,
  :instance_type,
  :availability_zone,
  :duration,
  :usage_price,
  :fixed_price,
  :product_description)
  SENSITIVE = []
  include Aws::Structure
end

#scopeString

Whether the Reserved Instance is applied to instances in a Region or an Availability Zone.

Returns:

  • (String)


74781
74782
74783
74784
74785
74786
74787
74788
74789
74790
74791
74792
74793
74794
74795
74796
74797
74798
74799
74800
# File 'lib/aws-sdk-ec2/types.rb', line 74781

class ReservedInstancesOffering < Struct.new(
  :currency_code,
  :instance_tenancy,
  :marketplace,
  :offering_class,
  :offering_type,
  :pricing_details,
  :recurring_charges,
  :scope,
  :availability_zone_id,
  :reserved_instances_offering_id,
  :instance_type,
  :availability_zone,
  :duration,
  :usage_price,
  :fixed_price,
  :product_description)
  SENSITIVE = []
  include Aws::Structure
end

#usage_priceFloat

The usage price of the Reserved Instance, per hour.

Returns:

  • (Float)


74781
74782
74783
74784
74785
74786
74787
74788
74789
74790
74791
74792
74793
74794
74795
74796
74797
74798
74799
74800
# File 'lib/aws-sdk-ec2/types.rb', line 74781

class ReservedInstancesOffering < Struct.new(
  :currency_code,
  :instance_tenancy,
  :marketplace,
  :offering_class,
  :offering_type,
  :pricing_details,
  :recurring_charges,
  :scope,
  :availability_zone_id,
  :reserved_instances_offering_id,
  :instance_type,
  :availability_zone,
  :duration,
  :usage_price,
  :fixed_price,
  :product_description)
  SENSITIVE = []
  include Aws::Structure
end