Class: Aws::EC2::Types::ReservedInstancesOffering
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ReservedInstancesOffering
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a Reserved Instance offering.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone ⇒ String
The Availability Zone in which the Reserved Instance can be used.
-
#availability_zone_id ⇒ String
The ID of the Availability Zone.
-
#currency_code ⇒ String
The currency of the Reserved Instance offering you are purchasing.
-
#duration ⇒ Integer
The duration of the Reserved Instance, in seconds.
-
#fixed_price ⇒ Float
The purchase price of the Reserved Instance.
-
#instance_tenancy ⇒ String
The tenancy of the instance.
-
#instance_type ⇒ String
The instance type on which the Reserved Instance can be used.
-
#marketplace ⇒ Boolean
Indicates whether the offering is available through the Reserved Instance Marketplace (resale) or Amazon Web Services.
-
#offering_class ⇒ String
If
convertibleit can be exchanged for Reserved Instances of the same or higher monetary value, with different configurations. -
#offering_type ⇒ String
The Reserved Instance offering type.
-
#pricing_details ⇒ Array<Types::PricingDetail>
The pricing details of the Reserved Instance offering.
-
#product_description ⇒ String
The Reserved Instance product platform description.
-
#recurring_charges ⇒ Array<Types::RecurringCharge>
The recurring charge tag assigned to the resource.
-
#reserved_instances_offering_id ⇒ String
The ID of the Reserved Instance offering.
-
#scope ⇒ String
Whether the Reserved Instance is applied to instances in a Region or an Availability Zone.
-
#usage_price ⇒ Float
The usage price of the Reserved Instance, per hour.
Instance Attribute Details
#availability_zone ⇒ String
The Availability Zone in which the Reserved Instance can be used.
74781 74782 74783 74784 74785 74786 74787 74788 74789 74790 74791 74792 74793 74794 74795 74796 74797 74798 74799 74800 |
# File 'lib/aws-sdk-ec2/types.rb', line 74781 class ReservedInstancesOffering < Struct.new( :currency_code, :instance_tenancy, :marketplace, :offering_class, :offering_type, :pricing_details, :recurring_charges, :scope, :availability_zone_id, :reserved_instances_offering_id, :instance_type, :availability_zone, :duration, :usage_price, :fixed_price, :product_description) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
The ID of the Availability Zone.
74781 74782 74783 74784 74785 74786 74787 74788 74789 74790 74791 74792 74793 74794 74795 74796 74797 74798 74799 74800 |
# File 'lib/aws-sdk-ec2/types.rb', line 74781 class ReservedInstancesOffering < Struct.new( :currency_code, :instance_tenancy, :marketplace, :offering_class, :offering_type, :pricing_details, :recurring_charges, :scope, :availability_zone_id, :reserved_instances_offering_id, :instance_type, :availability_zone, :duration, :usage_price, :fixed_price, :product_description) SENSITIVE = [] include Aws::Structure end |
#currency_code ⇒ String
The currency of the Reserved Instance offering you are purchasing.
It's specified using ISO 4217 standard currency codes. At this
time, the only supported currency is USD.
74781 74782 74783 74784 74785 74786 74787 74788 74789 74790 74791 74792 74793 74794 74795 74796 74797 74798 74799 74800 |
# File 'lib/aws-sdk-ec2/types.rb', line 74781 class ReservedInstancesOffering < Struct.new( :currency_code, :instance_tenancy, :marketplace, :offering_class, :offering_type, :pricing_details, :recurring_charges, :scope, :availability_zone_id, :reserved_instances_offering_id, :instance_type, :availability_zone, :duration, :usage_price, :fixed_price, :product_description) SENSITIVE = [] include Aws::Structure end |
#duration ⇒ Integer
The duration of the Reserved Instance, in seconds.
74781 74782 74783 74784 74785 74786 74787 74788 74789 74790 74791 74792 74793 74794 74795 74796 74797 74798 74799 74800 |
# File 'lib/aws-sdk-ec2/types.rb', line 74781 class ReservedInstancesOffering < Struct.new( :currency_code, :instance_tenancy, :marketplace, :offering_class, :offering_type, :pricing_details, :recurring_charges, :scope, :availability_zone_id, :reserved_instances_offering_id, :instance_type, :availability_zone, :duration, :usage_price, :fixed_price, :product_description) SENSITIVE = [] include Aws::Structure end |
#fixed_price ⇒ Float
The purchase price of the Reserved Instance.
74781 74782 74783 74784 74785 74786 74787 74788 74789 74790 74791 74792 74793 74794 74795 74796 74797 74798 74799 74800 |
# File 'lib/aws-sdk-ec2/types.rb', line 74781 class ReservedInstancesOffering < Struct.new( :currency_code, :instance_tenancy, :marketplace, :offering_class, :offering_type, :pricing_details, :recurring_charges, :scope, :availability_zone_id, :reserved_instances_offering_id, :instance_type, :availability_zone, :duration, :usage_price, :fixed_price, :product_description) SENSITIVE = [] include Aws::Structure end |
#instance_tenancy ⇒ String
The tenancy of the instance.
74781 74782 74783 74784 74785 74786 74787 74788 74789 74790 74791 74792 74793 74794 74795 74796 74797 74798 74799 74800 |
# File 'lib/aws-sdk-ec2/types.rb', line 74781 class ReservedInstancesOffering < Struct.new( :currency_code, :instance_tenancy, :marketplace, :offering_class, :offering_type, :pricing_details, :recurring_charges, :scope, :availability_zone_id, :reserved_instances_offering_id, :instance_type, :availability_zone, :duration, :usage_price, :fixed_price, :product_description) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The instance type on which the Reserved Instance can be used.
74781 74782 74783 74784 74785 74786 74787 74788 74789 74790 74791 74792 74793 74794 74795 74796 74797 74798 74799 74800 |
# File 'lib/aws-sdk-ec2/types.rb', line 74781 class ReservedInstancesOffering < Struct.new( :currency_code, :instance_tenancy, :marketplace, :offering_class, :offering_type, :pricing_details, :recurring_charges, :scope, :availability_zone_id, :reserved_instances_offering_id, :instance_type, :availability_zone, :duration, :usage_price, :fixed_price, :product_description) SENSITIVE = [] include Aws::Structure end |
#marketplace ⇒ Boolean
Indicates whether the offering is available through the Reserved
Instance Marketplace (resale) or Amazon Web Services. If it's a
Reserved Instance Marketplace offering, this is true.
74781 74782 74783 74784 74785 74786 74787 74788 74789 74790 74791 74792 74793 74794 74795 74796 74797 74798 74799 74800 |
# File 'lib/aws-sdk-ec2/types.rb', line 74781 class ReservedInstancesOffering < Struct.new( :currency_code, :instance_tenancy, :marketplace, :offering_class, :offering_type, :pricing_details, :recurring_charges, :scope, :availability_zone_id, :reserved_instances_offering_id, :instance_type, :availability_zone, :duration, :usage_price, :fixed_price, :product_description) SENSITIVE = [] include Aws::Structure end |
#offering_class ⇒ String
If convertible it can be exchanged for Reserved Instances of the
same or higher monetary value, with different configurations. If
standard, it is not possible to perform an exchange.
74781 74782 74783 74784 74785 74786 74787 74788 74789 74790 74791 74792 74793 74794 74795 74796 74797 74798 74799 74800 |
# File 'lib/aws-sdk-ec2/types.rb', line 74781 class ReservedInstancesOffering < Struct.new( :currency_code, :instance_tenancy, :marketplace, :offering_class, :offering_type, :pricing_details, :recurring_charges, :scope, :availability_zone_id, :reserved_instances_offering_id, :instance_type, :availability_zone, :duration, :usage_price, :fixed_price, :product_description) SENSITIVE = [] include Aws::Structure end |
#offering_type ⇒ String
The Reserved Instance offering type.
74781 74782 74783 74784 74785 74786 74787 74788 74789 74790 74791 74792 74793 74794 74795 74796 74797 74798 74799 74800 |
# File 'lib/aws-sdk-ec2/types.rb', line 74781 class ReservedInstancesOffering < Struct.new( :currency_code, :instance_tenancy, :marketplace, :offering_class, :offering_type, :pricing_details, :recurring_charges, :scope, :availability_zone_id, :reserved_instances_offering_id, :instance_type, :availability_zone, :duration, :usage_price, :fixed_price, :product_description) SENSITIVE = [] include Aws::Structure end |
#pricing_details ⇒ Array<Types::PricingDetail>
The pricing details of the Reserved Instance offering.
74781 74782 74783 74784 74785 74786 74787 74788 74789 74790 74791 74792 74793 74794 74795 74796 74797 74798 74799 74800 |
# File 'lib/aws-sdk-ec2/types.rb', line 74781 class ReservedInstancesOffering < Struct.new( :currency_code, :instance_tenancy, :marketplace, :offering_class, :offering_type, :pricing_details, :recurring_charges, :scope, :availability_zone_id, :reserved_instances_offering_id, :instance_type, :availability_zone, :duration, :usage_price, :fixed_price, :product_description) SENSITIVE = [] include Aws::Structure end |
#product_description ⇒ String
The Reserved Instance product platform description.
74781 74782 74783 74784 74785 74786 74787 74788 74789 74790 74791 74792 74793 74794 74795 74796 74797 74798 74799 74800 |
# File 'lib/aws-sdk-ec2/types.rb', line 74781 class ReservedInstancesOffering < Struct.new( :currency_code, :instance_tenancy, :marketplace, :offering_class, :offering_type, :pricing_details, :recurring_charges, :scope, :availability_zone_id, :reserved_instances_offering_id, :instance_type, :availability_zone, :duration, :usage_price, :fixed_price, :product_description) SENSITIVE = [] include Aws::Structure end |
#recurring_charges ⇒ Array<Types::RecurringCharge>
The recurring charge tag assigned to the resource.
74781 74782 74783 74784 74785 74786 74787 74788 74789 74790 74791 74792 74793 74794 74795 74796 74797 74798 74799 74800 |
# File 'lib/aws-sdk-ec2/types.rb', line 74781 class ReservedInstancesOffering < Struct.new( :currency_code, :instance_tenancy, :marketplace, :offering_class, :offering_type, :pricing_details, :recurring_charges, :scope, :availability_zone_id, :reserved_instances_offering_id, :instance_type, :availability_zone, :duration, :usage_price, :fixed_price, :product_description) SENSITIVE = [] include Aws::Structure end |
#reserved_instances_offering_id ⇒ String
The ID of the Reserved Instance offering. This is the offering ID used in GetReservedInstancesExchangeQuote to confirm that an exchange can be made.
74781 74782 74783 74784 74785 74786 74787 74788 74789 74790 74791 74792 74793 74794 74795 74796 74797 74798 74799 74800 |
# File 'lib/aws-sdk-ec2/types.rb', line 74781 class ReservedInstancesOffering < Struct.new( :currency_code, :instance_tenancy, :marketplace, :offering_class, :offering_type, :pricing_details, :recurring_charges, :scope, :availability_zone_id, :reserved_instances_offering_id, :instance_type, :availability_zone, :duration, :usage_price, :fixed_price, :product_description) SENSITIVE = [] include Aws::Structure end |
#scope ⇒ String
Whether the Reserved Instance is applied to instances in a Region or an Availability Zone.
74781 74782 74783 74784 74785 74786 74787 74788 74789 74790 74791 74792 74793 74794 74795 74796 74797 74798 74799 74800 |
# File 'lib/aws-sdk-ec2/types.rb', line 74781 class ReservedInstancesOffering < Struct.new( :currency_code, :instance_tenancy, :marketplace, :offering_class, :offering_type, :pricing_details, :recurring_charges, :scope, :availability_zone_id, :reserved_instances_offering_id, :instance_type, :availability_zone, :duration, :usage_price, :fixed_price, :product_description) SENSITIVE = [] include Aws::Structure end |
#usage_price ⇒ Float
The usage price of the Reserved Instance, per hour.
74781 74782 74783 74784 74785 74786 74787 74788 74789 74790 74791 74792 74793 74794 74795 74796 74797 74798 74799 74800 |
# File 'lib/aws-sdk-ec2/types.rb', line 74781 class ReservedInstancesOffering < Struct.new( :currency_code, :instance_tenancy, :marketplace, :offering_class, :offering_type, :pricing_details, :recurring_charges, :scope, :availability_zone_id, :reserved_instances_offering_id, :instance_type, :availability_zone, :duration, :usage_price, :fixed_price, :product_description) SENSITIVE = [] include Aws::Structure end |