Class: Aws::EC2::Types::ReservedInstancesOffering
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ReservedInstancesOffering
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a Reserved Instance offering.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone ⇒ String
The Availability Zone in which the Reserved Instance can be used.
-
#availability_zone_id ⇒ String
The ID of the Availability Zone.
-
#currency_code ⇒ String
The currency of the Reserved Instance offering you are purchasing.
-
#duration ⇒ Integer
The duration of the Reserved Instance, in seconds.
-
#fixed_price ⇒ Float
The purchase price of the Reserved Instance.
-
#instance_tenancy ⇒ String
The tenancy of the instance.
-
#instance_type ⇒ String
The instance type on which the Reserved Instance can be used.
-
#marketplace ⇒ Boolean
Indicates whether the offering is available through the Reserved Instance Marketplace (resale) or Amazon Web Services.
-
#offering_class ⇒ String
If ‘convertible` it can be exchanged for Reserved Instances of the same or higher monetary value, with different configurations.
-
#offering_type ⇒ String
The Reserved Instance offering type.
-
#pricing_details ⇒ Array<Types::PricingDetail>
The pricing details of the Reserved Instance offering.
-
#product_description ⇒ String
The Reserved Instance product platform description.
-
#recurring_charges ⇒ Array<Types::RecurringCharge>
The recurring charge tag assigned to the resource.
-
#reserved_instances_offering_id ⇒ String
The ID of the Reserved Instance offering.
-
#scope ⇒ String
Whether the Reserved Instance is applied to instances in a Region or an Availability Zone.
-
#usage_price ⇒ Float
The usage price of the Reserved Instance, per hour.
Instance Attribute Details
#availability_zone ⇒ String
The Availability Zone in which the Reserved Instance can be used.
73960 73961 73962 73963 73964 73965 73966 73967 73968 73969 73970 73971 73972 73973 73974 73975 73976 73977 73978 73979 |
# File 'lib/aws-sdk-ec2/types.rb', line 73960 class ReservedInstancesOffering < Struct.new( :currency_code, :instance_tenancy, :marketplace, :offering_class, :offering_type, :pricing_details, :recurring_charges, :scope, :availability_zone_id, :reserved_instances_offering_id, :instance_type, :availability_zone, :duration, :usage_price, :fixed_price, :product_description) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
The ID of the Availability Zone.
73960 73961 73962 73963 73964 73965 73966 73967 73968 73969 73970 73971 73972 73973 73974 73975 73976 73977 73978 73979 |
# File 'lib/aws-sdk-ec2/types.rb', line 73960 class ReservedInstancesOffering < Struct.new( :currency_code, :instance_tenancy, :marketplace, :offering_class, :offering_type, :pricing_details, :recurring_charges, :scope, :availability_zone_id, :reserved_instances_offering_id, :instance_type, :availability_zone, :duration, :usage_price, :fixed_price, :product_description) SENSITIVE = [] include Aws::Structure end |
#currency_code ⇒ String
The currency of the Reserved Instance offering you are purchasing. It’s specified using ISO 4217 standard currency codes. At this time, the only supported currency is ‘USD`.
73960 73961 73962 73963 73964 73965 73966 73967 73968 73969 73970 73971 73972 73973 73974 73975 73976 73977 73978 73979 |
# File 'lib/aws-sdk-ec2/types.rb', line 73960 class ReservedInstancesOffering < Struct.new( :currency_code, :instance_tenancy, :marketplace, :offering_class, :offering_type, :pricing_details, :recurring_charges, :scope, :availability_zone_id, :reserved_instances_offering_id, :instance_type, :availability_zone, :duration, :usage_price, :fixed_price, :product_description) SENSITIVE = [] include Aws::Structure end |
#duration ⇒ Integer
The duration of the Reserved Instance, in seconds.
73960 73961 73962 73963 73964 73965 73966 73967 73968 73969 73970 73971 73972 73973 73974 73975 73976 73977 73978 73979 |
# File 'lib/aws-sdk-ec2/types.rb', line 73960 class ReservedInstancesOffering < Struct.new( :currency_code, :instance_tenancy, :marketplace, :offering_class, :offering_type, :pricing_details, :recurring_charges, :scope, :availability_zone_id, :reserved_instances_offering_id, :instance_type, :availability_zone, :duration, :usage_price, :fixed_price, :product_description) SENSITIVE = [] include Aws::Structure end |
#fixed_price ⇒ Float
The purchase price of the Reserved Instance.
73960 73961 73962 73963 73964 73965 73966 73967 73968 73969 73970 73971 73972 73973 73974 73975 73976 73977 73978 73979 |
# File 'lib/aws-sdk-ec2/types.rb', line 73960 class ReservedInstancesOffering < Struct.new( :currency_code, :instance_tenancy, :marketplace, :offering_class, :offering_type, :pricing_details, :recurring_charges, :scope, :availability_zone_id, :reserved_instances_offering_id, :instance_type, :availability_zone, :duration, :usage_price, :fixed_price, :product_description) SENSITIVE = [] include Aws::Structure end |
#instance_tenancy ⇒ String
The tenancy of the instance.
73960 73961 73962 73963 73964 73965 73966 73967 73968 73969 73970 73971 73972 73973 73974 73975 73976 73977 73978 73979 |
# File 'lib/aws-sdk-ec2/types.rb', line 73960 class ReservedInstancesOffering < Struct.new( :currency_code, :instance_tenancy, :marketplace, :offering_class, :offering_type, :pricing_details, :recurring_charges, :scope, :availability_zone_id, :reserved_instances_offering_id, :instance_type, :availability_zone, :duration, :usage_price, :fixed_price, :product_description) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The instance type on which the Reserved Instance can be used.
73960 73961 73962 73963 73964 73965 73966 73967 73968 73969 73970 73971 73972 73973 73974 73975 73976 73977 73978 73979 |
# File 'lib/aws-sdk-ec2/types.rb', line 73960 class ReservedInstancesOffering < Struct.new( :currency_code, :instance_tenancy, :marketplace, :offering_class, :offering_type, :pricing_details, :recurring_charges, :scope, :availability_zone_id, :reserved_instances_offering_id, :instance_type, :availability_zone, :duration, :usage_price, :fixed_price, :product_description) SENSITIVE = [] include Aws::Structure end |
#marketplace ⇒ Boolean
Indicates whether the offering is available through the Reserved Instance Marketplace (resale) or Amazon Web Services. If it’s a Reserved Instance Marketplace offering, this is ‘true`.
73960 73961 73962 73963 73964 73965 73966 73967 73968 73969 73970 73971 73972 73973 73974 73975 73976 73977 73978 73979 |
# File 'lib/aws-sdk-ec2/types.rb', line 73960 class ReservedInstancesOffering < Struct.new( :currency_code, :instance_tenancy, :marketplace, :offering_class, :offering_type, :pricing_details, :recurring_charges, :scope, :availability_zone_id, :reserved_instances_offering_id, :instance_type, :availability_zone, :duration, :usage_price, :fixed_price, :product_description) SENSITIVE = [] include Aws::Structure end |
#offering_class ⇒ String
If ‘convertible` it can be exchanged for Reserved Instances of the same or higher monetary value, with different configurations. If `standard`, it is not possible to perform an exchange.
73960 73961 73962 73963 73964 73965 73966 73967 73968 73969 73970 73971 73972 73973 73974 73975 73976 73977 73978 73979 |
# File 'lib/aws-sdk-ec2/types.rb', line 73960 class ReservedInstancesOffering < Struct.new( :currency_code, :instance_tenancy, :marketplace, :offering_class, :offering_type, :pricing_details, :recurring_charges, :scope, :availability_zone_id, :reserved_instances_offering_id, :instance_type, :availability_zone, :duration, :usage_price, :fixed_price, :product_description) SENSITIVE = [] include Aws::Structure end |
#offering_type ⇒ String
The Reserved Instance offering type.
73960 73961 73962 73963 73964 73965 73966 73967 73968 73969 73970 73971 73972 73973 73974 73975 73976 73977 73978 73979 |
# File 'lib/aws-sdk-ec2/types.rb', line 73960 class ReservedInstancesOffering < Struct.new( :currency_code, :instance_tenancy, :marketplace, :offering_class, :offering_type, :pricing_details, :recurring_charges, :scope, :availability_zone_id, :reserved_instances_offering_id, :instance_type, :availability_zone, :duration, :usage_price, :fixed_price, :product_description) SENSITIVE = [] include Aws::Structure end |
#pricing_details ⇒ Array<Types::PricingDetail>
The pricing details of the Reserved Instance offering.
73960 73961 73962 73963 73964 73965 73966 73967 73968 73969 73970 73971 73972 73973 73974 73975 73976 73977 73978 73979 |
# File 'lib/aws-sdk-ec2/types.rb', line 73960 class ReservedInstancesOffering < Struct.new( :currency_code, :instance_tenancy, :marketplace, :offering_class, :offering_type, :pricing_details, :recurring_charges, :scope, :availability_zone_id, :reserved_instances_offering_id, :instance_type, :availability_zone, :duration, :usage_price, :fixed_price, :product_description) SENSITIVE = [] include Aws::Structure end |
#product_description ⇒ String
The Reserved Instance product platform description.
73960 73961 73962 73963 73964 73965 73966 73967 73968 73969 73970 73971 73972 73973 73974 73975 73976 73977 73978 73979 |
# File 'lib/aws-sdk-ec2/types.rb', line 73960 class ReservedInstancesOffering < Struct.new( :currency_code, :instance_tenancy, :marketplace, :offering_class, :offering_type, :pricing_details, :recurring_charges, :scope, :availability_zone_id, :reserved_instances_offering_id, :instance_type, :availability_zone, :duration, :usage_price, :fixed_price, :product_description) SENSITIVE = [] include Aws::Structure end |
#recurring_charges ⇒ Array<Types::RecurringCharge>
The recurring charge tag assigned to the resource.
73960 73961 73962 73963 73964 73965 73966 73967 73968 73969 73970 73971 73972 73973 73974 73975 73976 73977 73978 73979 |
# File 'lib/aws-sdk-ec2/types.rb', line 73960 class ReservedInstancesOffering < Struct.new( :currency_code, :instance_tenancy, :marketplace, :offering_class, :offering_type, :pricing_details, :recurring_charges, :scope, :availability_zone_id, :reserved_instances_offering_id, :instance_type, :availability_zone, :duration, :usage_price, :fixed_price, :product_description) SENSITIVE = [] include Aws::Structure end |
#reserved_instances_offering_id ⇒ String
The ID of the Reserved Instance offering. This is the offering ID used in GetReservedInstancesExchangeQuote to confirm that an exchange can be made.
73960 73961 73962 73963 73964 73965 73966 73967 73968 73969 73970 73971 73972 73973 73974 73975 73976 73977 73978 73979 |
# File 'lib/aws-sdk-ec2/types.rb', line 73960 class ReservedInstancesOffering < Struct.new( :currency_code, :instance_tenancy, :marketplace, :offering_class, :offering_type, :pricing_details, :recurring_charges, :scope, :availability_zone_id, :reserved_instances_offering_id, :instance_type, :availability_zone, :duration, :usage_price, :fixed_price, :product_description) SENSITIVE = [] include Aws::Structure end |
#scope ⇒ String
Whether the Reserved Instance is applied to instances in a Region or an Availability Zone.
73960 73961 73962 73963 73964 73965 73966 73967 73968 73969 73970 73971 73972 73973 73974 73975 73976 73977 73978 73979 |
# File 'lib/aws-sdk-ec2/types.rb', line 73960 class ReservedInstancesOffering < Struct.new( :currency_code, :instance_tenancy, :marketplace, :offering_class, :offering_type, :pricing_details, :recurring_charges, :scope, :availability_zone_id, :reserved_instances_offering_id, :instance_type, :availability_zone, :duration, :usage_price, :fixed_price, :product_description) SENSITIVE = [] include Aws::Structure end |
#usage_price ⇒ Float
The usage price of the Reserved Instance, per hour.
73960 73961 73962 73963 73964 73965 73966 73967 73968 73969 73970 73971 73972 73973 73974 73975 73976 73977 73978 73979 |
# File 'lib/aws-sdk-ec2/types.rb', line 73960 class ReservedInstancesOffering < Struct.new( :currency_code, :instance_tenancy, :marketplace, :offering_class, :offering_type, :pricing_details, :recurring_charges, :scope, :availability_zone_id, :reserved_instances_offering_id, :instance_type, :availability_zone, :duration, :usage_price, :fixed_price, :product_description) SENSITIVE = [] include Aws::Structure end |