Class: Aws::EC2::Types::ResetAddressAttributeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ResetAddressAttributeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allocation_id ⇒ String
[EC2-VPC] The allocation ID.
-
#attribute ⇒ String
The attribute of the IP address.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#allocation_id ⇒ String
[EC2-VPC] The allocation ID.
74505 74506 74507 74508 74509 74510 74511 |
# File 'lib/aws-sdk-ec2/types.rb', line 74505 class ResetAddressAttributeRequest < Struct.new( :allocation_id, :attribute, :dry_run) SENSITIVE = [] include Aws::Structure end |
#attribute ⇒ String
The attribute of the IP address.
74505 74506 74507 74508 74509 74510 74511 |
# File 'lib/aws-sdk-ec2/types.rb', line 74505 class ResetAddressAttributeRequest < Struct.new( :allocation_id, :attribute, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
74505 74506 74507 74508 74509 74510 74511 |
# File 'lib/aws-sdk-ec2/types.rb', line 74505 class ResetAddressAttributeRequest < Struct.new( :allocation_id, :attribute, :dry_run) SENSITIVE = [] include Aws::Structure end |