Class: Aws::EC2::Types::ResetAddressAttributeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allocation_idString

[EC2-VPC] The allocation ID.

Returns:

  • (String)


73854
73855
73856
73857
73858
73859
73860
# File 'lib/aws-sdk-ec2/types.rb', line 73854

class ResetAddressAttributeRequest < Struct.new(
  :allocation_id,
  :attribute,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#attributeString

The attribute of the IP address.

Returns:

  • (String)


73854
73855
73856
73857
73858
73859
73860
# File 'lib/aws-sdk-ec2/types.rb', line 73854

class ResetAddressAttributeRequest < Struct.new(
  :allocation_id,
  :attribute,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


73854
73855
73856
73857
73858
73859
73860
# File 'lib/aws-sdk-ec2/types.rb', line 73854

class ResetAddressAttributeRequest < Struct.new(
  :allocation_id,
  :attribute,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end