Class: Aws::EC2::Types::ResetEbsDefaultKmsKeyIdRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ResetEbsDefaultKmsKeyIdRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
73895 73896 73897 73898 73899 |
# File 'lib/aws-sdk-ec2/types.rb', line 73895 class ResetEbsDefaultKmsKeyIdRequest < Struct.new( :dry_run) SENSITIVE = [] include Aws::Structure end |