Class: Aws::EC2::Types::ResetFpgaImageAttributeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributeString

The attribute.

Returns:

  • (String)


73477
73478
73479
73480
73481
73482
73483
# File 'lib/aws-sdk-ec2/types.rb', line 73477

class ResetFpgaImageAttributeRequest < Struct.new(
  :dry_run,
  :fpga_image_id,
  :attribute)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


73477
73478
73479
73480
73481
73482
73483
# File 'lib/aws-sdk-ec2/types.rb', line 73477

class ResetFpgaImageAttributeRequest < Struct.new(
  :dry_run,
  :fpga_image_id,
  :attribute)
  SENSITIVE = []
  include Aws::Structure
end

#fpga_image_idString

The ID of the AFI.

Returns:

  • (String)


73477
73478
73479
73480
73481
73482
73483
# File 'lib/aws-sdk-ec2/types.rb', line 73477

class ResetFpgaImageAttributeRequest < Struct.new(
  :dry_run,
  :fpga_image_id,
  :attribute)
  SENSITIVE = []
  include Aws::Structure
end