Class: Aws::EC2::Types::ResetFpgaImageAttributeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributeString

The attribute.

Returns:

  • (String)


71930
71931
71932
71933
71934
71935
71936
# File 'lib/aws-sdk-ec2/types.rb', line 71930

class ResetFpgaImageAttributeRequest < Struct.new(
  :dry_run,
  :fpga_image_id,
  :attribute)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


71930
71931
71932
71933
71934
71935
71936
# File 'lib/aws-sdk-ec2/types.rb', line 71930

class ResetFpgaImageAttributeRequest < Struct.new(
  :dry_run,
  :fpga_image_id,
  :attribute)
  SENSITIVE = []
  include Aws::Structure
end

#fpga_image_idString

The ID of the AFI.

Returns:

  • (String)


71930
71931
71932
71933
71934
71935
71936
# File 'lib/aws-sdk-ec2/types.rb', line 71930

class ResetFpgaImageAttributeRequest < Struct.new(
  :dry_run,
  :fpga_image_id,
  :attribute)
  SENSITIVE = []
  include Aws::Structure
end