Class: Aws::EC2::Types::ResetImageAttributeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ResetImageAttributeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for ResetImageAttribute.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute ⇒ String
The attribute to reset (currently you can only reset the launch permission attribute).
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#image_id ⇒ String
The ID of the AMI.
Instance Attribute Details
#attribute ⇒ String
The attribute to reset (currently you can only reset the launch permission attribute).
74610 74611 74612 74613 74614 74615 74616 |
# File 'lib/aws-sdk-ec2/types.rb', line 74610 class ResetImageAttributeRequest < Struct.new( :attribute, :image_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
74610 74611 74612 74613 74614 74615 74616 |
# File 'lib/aws-sdk-ec2/types.rb', line 74610 class ResetImageAttributeRequest < Struct.new( :attribute, :image_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#image_id ⇒ String
The ID of the AMI.
74610 74611 74612 74613 74614 74615 74616 |
# File 'lib/aws-sdk-ec2/types.rb', line 74610 class ResetImageAttributeRequest < Struct.new( :attribute, :image_id, :dry_run) SENSITIVE = [] include Aws::Structure end |