Class: Aws::EC2::Types::ResetImageAttributeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ResetImageAttributeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for ResetImageAttribute.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute ⇒ String
The attribute to reset (currently you can only reset the launch permission attribute).
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#image_id ⇒ String
The ID of the AMI.
Instance Attribute Details
#attribute ⇒ String
The attribute to reset (currently you can only reset the launch permission attribute).
73367 73368 73369 73370 73371 73372 73373 |
# File 'lib/aws-sdk-ec2/types.rb', line 73367 class ResetImageAttributeRequest < Struct.new( :attribute, :image_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
73367 73368 73369 73370 73371 73372 73373 |
# File 'lib/aws-sdk-ec2/types.rb', line 73367 class ResetImageAttributeRequest < Struct.new( :attribute, :image_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#image_id ⇒ String
The ID of the AMI.
73367 73368 73369 73370 73371 73372 73373 |
# File 'lib/aws-sdk-ec2/types.rb', line 73367 class ResetImageAttributeRequest < Struct.new( :attribute, :image_id, :dry_run) SENSITIVE = [] include Aws::Structure end |