Class: Aws::EC2::Types::ResetImageAttributeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for ResetImageAttribute.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributeString

The attribute to reset (currently you can only reset the launch permission attribute).

Returns:

  • (String)


72968
72969
72970
72971
72972
72973
72974
# File 'lib/aws-sdk-ec2/types.rb', line 72968

class ResetImageAttributeRequest < Struct.new(
  :attribute,
  :image_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


72968
72969
72970
72971
72972
72973
72974
# File 'lib/aws-sdk-ec2/types.rb', line 72968

class ResetImageAttributeRequest < Struct.new(
  :attribute,
  :image_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#image_idString

The ID of the AMI.

Returns:

  • (String)


72968
72969
72970
72971
72972
72973
72974
# File 'lib/aws-sdk-ec2/types.rb', line 72968

class ResetImageAttributeRequest < Struct.new(
  :attribute,
  :image_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end