Class: Aws::EC2::Types::ResetInstanceAttributeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributeString

The attribute to reset.

You can only reset the following attributes: kernel | ramdisk | sourceDestCheck.

Returns:

  • (String)


77777
77778
77779
77780
77781
77782
77783
# File 'lib/aws-sdk-ec2/types.rb', line 77777

class ResetInstanceAttributeRequest < Struct.new(
  :dry_run,
  :instance_id,
  :attribute)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


77777
77778
77779
77780
77781
77782
77783
# File 'lib/aws-sdk-ec2/types.rb', line 77777

class ResetInstanceAttributeRequest < Struct.new(
  :dry_run,
  :instance_id,
  :attribute)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The ID of the instance.

Returns:

  • (String)


77777
77778
77779
77780
77781
77782
77783
# File 'lib/aws-sdk-ec2/types.rb', line 77777

class ResetInstanceAttributeRequest < Struct.new(
  :dry_run,
  :instance_id,
  :attribute)
  SENSITIVE = []
  include Aws::Structure
end