Class: Aws::EC2::Types::ResetInstanceAttributeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ResetInstanceAttributeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute ⇒ String
The attribute to reset.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#instance_id ⇒ String
The ID of the instance.
Instance Attribute Details
#attribute ⇒ String
The attribute to reset.
You can only reset the following attributes: ‘kernel` | `ramdisk` | `sourceDestCheck`.
73554 73555 73556 73557 73558 73559 73560 |
# File 'lib/aws-sdk-ec2/types.rb', line 73554 class ResetInstanceAttributeRequest < Struct.new( :dry_run, :instance_id, :attribute) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
73554 73555 73556 73557 73558 73559 73560 |
# File 'lib/aws-sdk-ec2/types.rb', line 73554 class ResetInstanceAttributeRequest < Struct.new( :dry_run, :instance_id, :attribute) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the instance.
73554 73555 73556 73557 73558 73559 73560 |
# File 'lib/aws-sdk-ec2/types.rb', line 73554 class ResetInstanceAttributeRequest < Struct.new( :dry_run, :instance_id, :attribute) SENSITIVE = [] include Aws::Structure end |