Class: Aws::EC2::Types::ResetInstanceAttributeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributeString

The attribute to reset.

You can only reset the following attributes: ‘kernel` | `ramdisk` | `sourceDestCheck`.

Returns:

  • (String)


73545
73546
73547
73548
73549
73550
73551
# File 'lib/aws-sdk-ec2/types.rb', line 73545

class ResetInstanceAttributeRequest < Struct.new(
  :dry_run,
  :instance_id,
  :attribute)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


73545
73546
73547
73548
73549
73550
73551
# File 'lib/aws-sdk-ec2/types.rb', line 73545

class ResetInstanceAttributeRequest < Struct.new(
  :dry_run,
  :instance_id,
  :attribute)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The ID of the instance.

Returns:

  • (String)


73545
73546
73547
73548
73549
73550
73551
# File 'lib/aws-sdk-ec2/types.rb', line 73545

class ResetInstanceAttributeRequest < Struct.new(
  :dry_run,
  :instance_id,
  :attribute)
  SENSITIVE = []
  include Aws::Structure
end