Class: Aws::EC2::Types::ResetNetworkInterfaceAttributeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ResetNetworkInterfaceAttributeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Contains the parameters for ResetNetworkInterfaceAttribute.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#network_interface_id ⇒ String
The ID of the network interface.
-
#source_dest_check ⇒ String
The source/destination checking attribute.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
74619 74620 74621 74622 74623 74624 74625 |
# File 'lib/aws-sdk-ec2/types.rb', line 74619 class ResetNetworkInterfaceAttributeRequest < Struct.new( :dry_run, :network_interface_id, :source_dest_check) SENSITIVE = [] include Aws::Structure end |
#network_interface_id ⇒ String
The ID of the network interface.
74619 74620 74621 74622 74623 74624 74625 |
# File 'lib/aws-sdk-ec2/types.rb', line 74619 class ResetNetworkInterfaceAttributeRequest < Struct.new( :dry_run, :network_interface_id, :source_dest_check) SENSITIVE = [] include Aws::Structure end |
#source_dest_check ⇒ String
The source/destination checking attribute. Resets the value to
true.
74619 74620 74621 74622 74623 74624 74625 |
# File 'lib/aws-sdk-ec2/types.rb', line 74619 class ResetNetworkInterfaceAttributeRequest < Struct.new( :dry_run, :network_interface_id, :source_dest_check) SENSITIVE = [] include Aws::Structure end |