Class: Aws::EC2::Types::ResetNetworkInterfaceAttributeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Contains the parameters for ResetNetworkInterfaceAttribute.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


73024
73025
73026
73027
73028
73029
73030
# File 'lib/aws-sdk-ec2/types.rb', line 73024

class ResetNetworkInterfaceAttributeRequest < Struct.new(
  :dry_run,
  :network_interface_id,
  :source_dest_check)
  SENSITIVE = []
  include Aws::Structure
end

#network_interface_idString

The ID of the network interface.

Returns:

  • (String)


73024
73025
73026
73027
73028
73029
73030
# File 'lib/aws-sdk-ec2/types.rb', line 73024

class ResetNetworkInterfaceAttributeRequest < Struct.new(
  :dry_run,
  :network_interface_id,
  :source_dest_check)
  SENSITIVE = []
  include Aws::Structure
end

#source_dest_checkString

The source/destination checking attribute. Resets the value to ‘true`.

Returns:

  • (String)


73024
73025
73026
73027
73028
73029
73030
# File 'lib/aws-sdk-ec2/types.rb', line 73024

class ResetNetworkInterfaceAttributeRequest < Struct.new(
  :dry_run,
  :network_interface_id,
  :source_dest_check)
  SENSITIVE = []
  include Aws::Structure
end