Class: Aws::EC2::Types::ResetSnapshotAttributeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ResetSnapshotAttributeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute ⇒ String
The attribute to reset.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#snapshot_id ⇒ String
The ID of the snapshot.
Instance Attribute Details
#attribute ⇒ String
The attribute to reset. Currently, only the attribute for permission to create volumes can be reset.
77831 77832 77833 77834 77835 77836 77837 |
# File 'lib/aws-sdk-ec2/types.rb', line 77831 class ResetSnapshotAttributeRequest < Struct.new( :attribute, :snapshot_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
77831 77832 77833 77834 77835 77836 77837 |
# File 'lib/aws-sdk-ec2/types.rb', line 77831 class ResetSnapshotAttributeRequest < Struct.new( :attribute, :snapshot_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#snapshot_id ⇒ String
The ID of the snapshot.
77831 77832 77833 77834 77835 77836 77837 |
# File 'lib/aws-sdk-ec2/types.rb', line 77831 class ResetSnapshotAttributeRequest < Struct.new( :attribute, :snapshot_id, :dry_run) SENSITIVE = [] include Aws::Structure end |