Class: Aws::EC2::Types::ResetSnapshotAttributeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributeString

The attribute to reset. Currently, only the attribute for permission to create volumes can be reset.

Returns:

  • (String)


76373
76374
76375
76376
76377
76378
76379
# File 'lib/aws-sdk-ec2/types.rb', line 76373

class ResetSnapshotAttributeRequest < Struct.new(
  :attribute,
  :snapshot_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


76373
76374
76375
76376
76377
76378
76379
# File 'lib/aws-sdk-ec2/types.rb', line 76373

class ResetSnapshotAttributeRequest < Struct.new(
  :attribute,
  :snapshot_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_idString

The ID of the snapshot.

Returns:

  • (String)


76373
76374
76375
76376
76377
76378
76379
# File 'lib/aws-sdk-ec2/types.rb', line 76373

class ResetSnapshotAttributeRequest < Struct.new(
  :attribute,
  :snapshot_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end