Class: Aws::EC2::Types::ResetSnapshotAttributeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributeString

The attribute to reset. Currently, only the attribute for permission to create volumes can be reset.

Returns:

  • (String)


74829
74830
74831
74832
74833
74834
74835
# File 'lib/aws-sdk-ec2/types.rb', line 74829

class ResetSnapshotAttributeRequest < Struct.new(
  :attribute,
  :snapshot_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


74829
74830
74831
74832
74833
74834
74835
# File 'lib/aws-sdk-ec2/types.rb', line 74829

class ResetSnapshotAttributeRequest < Struct.new(
  :attribute,
  :snapshot_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_idString

The ID of the snapshot.

Returns:

  • (String)


74829
74830
74831
74832
74833
74834
74835
# File 'lib/aws-sdk-ec2/types.rb', line 74829

class ResetSnapshotAttributeRequest < Struct.new(
  :attribute,
  :snapshot_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end