Class: Aws::EC2::Types::ResetSnapshotAttributeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributeString

The attribute to reset. Currently, only the attribute for permission to create volumes can be reset.

Returns:

  • (String)


73050
73051
73052
73053
73054
73055
73056
# File 'lib/aws-sdk-ec2/types.rb', line 73050

class ResetSnapshotAttributeRequest < Struct.new(
  :attribute,
  :snapshot_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


73050
73051
73052
73053
73054
73055
73056
# File 'lib/aws-sdk-ec2/types.rb', line 73050

class ResetSnapshotAttributeRequest < Struct.new(
  :attribute,
  :snapshot_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_idString

The ID of the snapshot.

Returns:

  • (String)


73050
73051
73052
73053
73054
73055
73056
# File 'lib/aws-sdk-ec2/types.rb', line 73050

class ResetSnapshotAttributeRequest < Struct.new(
  :attribute,
  :snapshot_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end