Class: Aws::EC2::Types::ResourceTypeOption
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ResourceTypeOption
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
The options that affect the scope of the response.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#option_name ⇒ String
The name of the option.
-
#option_values ⇒ Array<String>
A value for the specified option.
Instance Attribute Details
#option_name ⇒ String
The name of the option.
-
For ‘ec2:Instance`:
Specify ‘state-name` - The current state of the EC2 instance.
-
For ‘ec2:LaunchTemplate`:
Specify ‘version-depth` - The number of launch template versions to check, starting from the most recent version.
72015 72016 72017 72018 72019 72020 |
# File 'lib/aws-sdk-ec2/types.rb', line 72015 class ResourceTypeOption < Struct.new( :option_name, :option_values) SENSITIVE = [] include Aws::Structure end |
#option_values ⇒ Array<String>
A value for the specified option.
-
For ‘state-name`:
-
Valid values: ‘pending` | `running` | `shutting-down` | `terminated` | `stopping` | `stopped`
-
Default: All states
-
-
For ‘version-depth`:
-
Valid values: Integers between ‘1` and `10000`
-
Default: ‘10`
-
72015 72016 72017 72018 72019 72020 |
# File 'lib/aws-sdk-ec2/types.rb', line 72015 class ResourceTypeOption < Struct.new( :option_name, :option_values) SENSITIVE = [] include Aws::Structure end |