Class: Aws::EC2::Types::ResourceTypeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ResourceTypeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
A resource type to check for image references. Associated options can also be specified if the resource type is an EC2 instance or launch template.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource_type ⇒ String
The resource type.
-
#resource_type_options ⇒ Array<Types::ResourceTypeOption>
The options that affect the scope of the response.
Instance Attribute Details
#resource_type ⇒ String
The resource type.
72037 72038 72039 72040 72041 72042 |
# File 'lib/aws-sdk-ec2/types.rb', line 72037 class ResourceTypeRequest < Struct.new( :resource_type, :resource_type_options) SENSITIVE = [] include Aws::Structure end |
#resource_type_options ⇒ Array<Types::ResourceTypeOption>
The options that affect the scope of the response. Valid only when ‘ResourceType` is `ec2:Instance` or `ec2:LaunchTemplate`.
72037 72038 72039 72040 72041 72042 |
# File 'lib/aws-sdk-ec2/types.rb', line 72037 class ResourceTypeRequest < Struct.new( :resource_type, :resource_type_options) SENSITIVE = [] include Aws::Structure end |