Class: Aws::EC2::Types::RestoreAddressToClassicRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


75220
75221
75222
75223
75224
75225
# File 'lib/aws-sdk-ec2/types.rb', line 75220

class RestoreAddressToClassicRequest < Struct.new(
  :dry_run,
  :public_ip)
  SENSITIVE = []
  include Aws::Structure
end

#public_ipString

The Elastic IP address.

Returns:

  • (String)


75220
75221
75222
75223
75224
75225
# File 'lib/aws-sdk-ec2/types.rb', line 75220

class RestoreAddressToClassicRequest < Struct.new(
  :dry_run,
  :public_ip)
  SENSITIVE = []
  include Aws::Structure
end