Class: Aws::EC2::Types::RestoreAddressToClassicRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


74693
74694
74695
74696
74697
74698
# File 'lib/aws-sdk-ec2/types.rb', line 74693

class RestoreAddressToClassicRequest < Struct.new(
  :dry_run,
  :public_ip)
  SENSITIVE = []
  include Aws::Structure
end

#public_ipString

The Elastic IP address.

Returns:

  • (String)


74693
74694
74695
74696
74697
74698
# File 'lib/aws-sdk-ec2/types.rb', line 74693

class RestoreAddressToClassicRequest < Struct.new(
  :dry_run,
  :public_ip)
  SENSITIVE = []
  include Aws::Structure
end