Class: Aws::EC2::Types::RestoreAddressToClassicRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::RestoreAddressToClassicRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#public_ip ⇒ String
The Elastic IP address.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
73990 73991 73992 73993 73994 73995 |
# File 'lib/aws-sdk-ec2/types.rb', line 73990 class RestoreAddressToClassicRequest < Struct.new( :dry_run, :public_ip) SENSITIVE = [] include Aws::Structure end |
#public_ip ⇒ String
The Elastic IP address.
73990 73991 73992 73993 73994 73995 |
# File 'lib/aws-sdk-ec2/types.rb', line 73990 class RestoreAddressToClassicRequest < Struct.new( :dry_run, :public_ip) SENSITIVE = [] include Aws::Structure end |