Class: Aws::EC2::Types::RestoreImageFromRecycleBinRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::RestoreImageFromRecycleBinRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#image_id ⇒ String
The ID of the AMI to restore.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
76801 76802 76803 76804 76805 76806 |
# File 'lib/aws-sdk-ec2/types.rb', line 76801 class RestoreImageFromRecycleBinRequest < Struct.new( :image_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#image_id ⇒ String
The ID of the AMI to restore.
76801 76802 76803 76804 76805 76806 |
# File 'lib/aws-sdk-ec2/types.rb', line 76801 class RestoreImageFromRecycleBinRequest < Struct.new( :image_id, :dry_run) SENSITIVE = [] include Aws::Structure end |