Class: Aws::EC2::Types::RestoreImageFromRecycleBinRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


74036
74037
74038
74039
74040
74041
# File 'lib/aws-sdk-ec2/types.rb', line 74036

class RestoreImageFromRecycleBinRequest < Struct.new(
  :image_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#image_idString

The ID of the AMI to restore.

Returns:

  • (String)


74036
74037
74038
74039
74040
74041
# File 'lib/aws-sdk-ec2/types.rb', line 74036

class RestoreImageFromRecycleBinRequest < Struct.new(
  :image_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end