Class: Aws::EC2::Types::RestoreSnapshotFromRecycleBinRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::RestoreSnapshotFromRecycleBinRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#snapshot_id ⇒ String
The ID of the snapshot to restore.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
74556 74557 74558 74559 74560 74561 |
# File 'lib/aws-sdk-ec2/types.rb', line 74556 class RestoreSnapshotFromRecycleBinRequest < Struct.new( :snapshot_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#snapshot_id ⇒ String
The ID of the snapshot to restore.
74556 74557 74558 74559 74560 74561 |
# File 'lib/aws-sdk-ec2/types.rb', line 74556 class RestoreSnapshotFromRecycleBinRequest < Struct.new( :snapshot_id, :dry_run) SENSITIVE = [] include Aws::Structure end |