Class: Aws::EC2::Types::RestoreSnapshotFromRecycleBinRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


74124
74125
74126
74127
74128
74129
# File 'lib/aws-sdk-ec2/types.rb', line 74124

class RestoreSnapshotFromRecycleBinRequest < Struct.new(
  :snapshot_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_idString

The ID of the snapshot to restore.

Returns:

  • (String)


74124
74125
74126
74127
74128
74129
# File 'lib/aws-sdk-ec2/types.rb', line 74124

class RestoreSnapshotFromRecycleBinRequest < Struct.new(
  :snapshot_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end