Class: Aws::EC2::Types::RestoreSnapshotFromRecycleBinResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::RestoreSnapshotFromRecycleBinResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description for the snapshot.
-
#encrypted ⇒ Boolean
Indicates whether the snapshot is encrypted.
-
#outpost_arn ⇒ String
The ARN of the Outpost on which the snapshot is stored.
-
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the EBS snapshot.
-
#progress ⇒ String
The progress of the snapshot, as a percentage.
-
#snapshot_id ⇒ String
The ID of the snapshot.
-
#sse_type ⇒ String
Reserved for future use.
-
#start_time ⇒ Time
The time stamp when the snapshot was initiated.
-
#state ⇒ String
The state of the snapshot.
-
#volume_id ⇒ String
The ID of the volume that was used to create the snapshot.
-
#volume_size ⇒ Integer
The size of the volume, in GiB.
Instance Attribute Details
#description ⇒ String
The description for the snapshot.
75241 75242 75243 75244 75245 75246 75247 75248 75249 75250 75251 75252 75253 75254 75255 |
# File 'lib/aws-sdk-ec2/types.rb', line 75241 class RestoreSnapshotFromRecycleBinResult < Struct.new( :snapshot_id, :outpost_arn, :description, :encrypted, :owner_id, :progress, :start_time, :state, :volume_id, :volume_size, :sse_type) SENSITIVE = [] include Aws::Structure end |
#encrypted ⇒ Boolean
Indicates whether the snapshot is encrypted.
75241 75242 75243 75244 75245 75246 75247 75248 75249 75250 75251 75252 75253 75254 75255 |
# File 'lib/aws-sdk-ec2/types.rb', line 75241 class RestoreSnapshotFromRecycleBinResult < Struct.new( :snapshot_id, :outpost_arn, :description, :encrypted, :owner_id, :progress, :start_time, :state, :volume_id, :volume_size, :sse_type) SENSITIVE = [] include Aws::Structure end |
#outpost_arn ⇒ String
The ARN of the Outpost on which the snapshot is stored. For more information, see Amazon EBS local snapshots on Outposts in the Amazon EBS User Guide.
75241 75242 75243 75244 75245 75246 75247 75248 75249 75250 75251 75252 75253 75254 75255 |
# File 'lib/aws-sdk-ec2/types.rb', line 75241 class RestoreSnapshotFromRecycleBinResult < Struct.new( :snapshot_id, :outpost_arn, :description, :encrypted, :owner_id, :progress, :start_time, :state, :volume_id, :volume_size, :sse_type) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the EBS snapshot.
75241 75242 75243 75244 75245 75246 75247 75248 75249 75250 75251 75252 75253 75254 75255 |
# File 'lib/aws-sdk-ec2/types.rb', line 75241 class RestoreSnapshotFromRecycleBinResult < Struct.new( :snapshot_id, :outpost_arn, :description, :encrypted, :owner_id, :progress, :start_time, :state, :volume_id, :volume_size, :sse_type) SENSITIVE = [] include Aws::Structure end |
#progress ⇒ String
The progress of the snapshot, as a percentage.
75241 75242 75243 75244 75245 75246 75247 75248 75249 75250 75251 75252 75253 75254 75255 |
# File 'lib/aws-sdk-ec2/types.rb', line 75241 class RestoreSnapshotFromRecycleBinResult < Struct.new( :snapshot_id, :outpost_arn, :description, :encrypted, :owner_id, :progress, :start_time, :state, :volume_id, :volume_size, :sse_type) SENSITIVE = [] include Aws::Structure end |
#snapshot_id ⇒ String
The ID of the snapshot.
75241 75242 75243 75244 75245 75246 75247 75248 75249 75250 75251 75252 75253 75254 75255 |
# File 'lib/aws-sdk-ec2/types.rb', line 75241 class RestoreSnapshotFromRecycleBinResult < Struct.new( :snapshot_id, :outpost_arn, :description, :encrypted, :owner_id, :progress, :start_time, :state, :volume_id, :volume_size, :sse_type) SENSITIVE = [] include Aws::Structure end |
#sse_type ⇒ String
Reserved for future use.
75241 75242 75243 75244 75245 75246 75247 75248 75249 75250 75251 75252 75253 75254 75255 |
# File 'lib/aws-sdk-ec2/types.rb', line 75241 class RestoreSnapshotFromRecycleBinResult < Struct.new( :snapshot_id, :outpost_arn, :description, :encrypted, :owner_id, :progress, :start_time, :state, :volume_id, :volume_size, :sse_type) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The time stamp when the snapshot was initiated.
75241 75242 75243 75244 75245 75246 75247 75248 75249 75250 75251 75252 75253 75254 75255 |
# File 'lib/aws-sdk-ec2/types.rb', line 75241 class RestoreSnapshotFromRecycleBinResult < Struct.new( :snapshot_id, :outpost_arn, :description, :encrypted, :owner_id, :progress, :start_time, :state, :volume_id, :volume_size, :sse_type) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the snapshot.
75241 75242 75243 75244 75245 75246 75247 75248 75249 75250 75251 75252 75253 75254 75255 |
# File 'lib/aws-sdk-ec2/types.rb', line 75241 class RestoreSnapshotFromRecycleBinResult < Struct.new( :snapshot_id, :outpost_arn, :description, :encrypted, :owner_id, :progress, :start_time, :state, :volume_id, :volume_size, :sse_type) SENSITIVE = [] include Aws::Structure end |
#volume_id ⇒ String
The ID of the volume that was used to create the snapshot.
75241 75242 75243 75244 75245 75246 75247 75248 75249 75250 75251 75252 75253 75254 75255 |
# File 'lib/aws-sdk-ec2/types.rb', line 75241 class RestoreSnapshotFromRecycleBinResult < Struct.new( :snapshot_id, :outpost_arn, :description, :encrypted, :owner_id, :progress, :start_time, :state, :volume_id, :volume_size, :sse_type) SENSITIVE = [] include Aws::Structure end |
#volume_size ⇒ Integer
The size of the volume, in GiB.
75241 75242 75243 75244 75245 75246 75247 75248 75249 75250 75251 75252 75253 75254 75255 |
# File 'lib/aws-sdk-ec2/types.rb', line 75241 class RestoreSnapshotFromRecycleBinResult < Struct.new( :snapshot_id, :outpost_arn, :description, :encrypted, :owner_id, :progress, :start_time, :state, :volume_id, :volume_size, :sse_type) SENSITIVE = [] include Aws::Structure end |