Class: Aws::EC2::Types::RestoreSnapshotTierRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::RestoreSnapshotTierRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#permanent_restore ⇒ Boolean
Indicates whether to permanently restore an archived snapshot.
-
#snapshot_id ⇒ String
The ID of the snapshot to restore.
-
#temporary_restore_days ⇒ Integer
Specifies the number of days for which to temporarily restore an archived snapshot.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
75253 75254 75255 75256 75257 75258 75259 75260 |
# File 'lib/aws-sdk-ec2/types.rb', line 75253 class RestoreSnapshotTierRequest < Struct.new( :snapshot_id, :temporary_restore_days, :permanent_restore, :dry_run) SENSITIVE = [] include Aws::Structure end |
#permanent_restore ⇒ Boolean
Indicates whether to permanently restore an archived snapshot. To
permanently restore an archived snapshot, specify true and omit
the RestoreSnapshotTierRequest$TemporaryRestoreDays parameter.
75253 75254 75255 75256 75257 75258 75259 75260 |
# File 'lib/aws-sdk-ec2/types.rb', line 75253 class RestoreSnapshotTierRequest < Struct.new( :snapshot_id, :temporary_restore_days, :permanent_restore, :dry_run) SENSITIVE = [] include Aws::Structure end |
#snapshot_id ⇒ String
The ID of the snapshot to restore.
75253 75254 75255 75256 75257 75258 75259 75260 |
# File 'lib/aws-sdk-ec2/types.rb', line 75253 class RestoreSnapshotTierRequest < Struct.new( :snapshot_id, :temporary_restore_days, :permanent_restore, :dry_run) SENSITIVE = [] include Aws::Structure end |
#temporary_restore_days ⇒ Integer
Specifies the number of days for which to temporarily restore an archived snapshot. Required for temporary restores only. The snapshot will be automatically re-archived after this period.
To temporarily restore an archived snapshot, specify the number of
days and omit the PermanentRestore parameter or set it to
false.
75253 75254 75255 75256 75257 75258 75259 75260 |
# File 'lib/aws-sdk-ec2/types.rb', line 75253 class RestoreSnapshotTierRequest < Struct.new( :snapshot_id, :temporary_restore_days, :permanent_restore, :dry_run) SENSITIVE = [] include Aws::Structure end |