Class: Aws::EC2::Types::RestoreVolumeFromRecycleBinRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


78491
78492
78493
78494
78495
78496
# File 'lib/aws-sdk-ec2/types.rb', line 78491

class RestoreVolumeFromRecycleBinRequest < Struct.new(
  :volume_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#volume_idString

The ID of the volume to restore.

Returns:

  • (String)


78491
78492
78493
78494
78495
78496
# File 'lib/aws-sdk-ec2/types.rb', line 78491

class RestoreVolumeFromRecycleBinRequest < Struct.new(
  :volume_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end