Class: Aws::EC2::Types::RestoreVolumeFromRecycleBinRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::RestoreVolumeFromRecycleBinRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#volume_id ⇒ String
The ID of the volume to restore.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
74259 74260 74261 74262 74263 74264 |
# File 'lib/aws-sdk-ec2/types.rb', line 74259 class RestoreVolumeFromRecycleBinRequest < Struct.new( :volume_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#volume_id ⇒ String
The ID of the volume to restore.
74259 74260 74261 74262 74263 74264 |
# File 'lib/aws-sdk-ec2/types.rb', line 74259 class RestoreVolumeFromRecycleBinRequest < Struct.new( :volume_id, :dry_run) SENSITIVE = [] include Aws::Structure end |