Class: Aws::EC2::Types::RestoreVolumeFromRecycleBinRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


73710
73711
73712
73713
73714
73715
# File 'lib/aws-sdk-ec2/types.rb', line 73710

class RestoreVolumeFromRecycleBinRequest < Struct.new(
  :volume_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#volume_idString

The ID of the volume to restore.

Returns:

  • (String)


73710
73711
73712
73713
73714
73715
# File 'lib/aws-sdk-ec2/types.rb', line 73710

class RestoreVolumeFromRecycleBinRequest < Struct.new(
  :volume_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end