Class: Aws::EC2::Types::RevokeClientVpnIngressRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::RevokeClientVpnIngressRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_group_id ⇒ String
The ID of the Active Directory group for which to revoke access.
-
#client_vpn_endpoint_id ⇒ String
The ID of the Client VPN endpoint with which the authorization rule is associated.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#revoke_all_groups ⇒ Boolean
Indicates whether access should be revoked for all groups for a single
TargetNetworkCidrthat earlier authorized ingress for all groups usingAuthorizeAllGroups. -
#target_network_cidr ⇒ String
The IPv4 address range, in CIDR notation, of the network for which access is being removed.
Instance Attribute Details
#access_group_id ⇒ String
The ID of the Active Directory group for which to revoke access.
75013 75014 75015 75016 75017 75018 75019 75020 75021 |
# File 'lib/aws-sdk-ec2/types.rb', line 75013 class RevokeClientVpnIngressRequest < Struct.new( :client_vpn_endpoint_id, :target_network_cidr, :access_group_id, :revoke_all_groups, :dry_run) SENSITIVE = [] include Aws::Structure end |
#client_vpn_endpoint_id ⇒ String
The ID of the Client VPN endpoint with which the authorization rule is associated.
75013 75014 75015 75016 75017 75018 75019 75020 75021 |
# File 'lib/aws-sdk-ec2/types.rb', line 75013 class RevokeClientVpnIngressRequest < Struct.new( :client_vpn_endpoint_id, :target_network_cidr, :access_group_id, :revoke_all_groups, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
75013 75014 75015 75016 75017 75018 75019 75020 75021 |
# File 'lib/aws-sdk-ec2/types.rb', line 75013 class RevokeClientVpnIngressRequest < Struct.new( :client_vpn_endpoint_id, :target_network_cidr, :access_group_id, :revoke_all_groups, :dry_run) SENSITIVE = [] include Aws::Structure end |
#revoke_all_groups ⇒ Boolean
Indicates whether access should be revoked for all groups for a
single TargetNetworkCidr that earlier authorized ingress for all
groups using AuthorizeAllGroups. This does not impact other
authorization rules that allowed ingress to the same
TargetNetworkCidr with a specific AccessGroupId.
75013 75014 75015 75016 75017 75018 75019 75020 75021 |
# File 'lib/aws-sdk-ec2/types.rb', line 75013 class RevokeClientVpnIngressRequest < Struct.new( :client_vpn_endpoint_id, :target_network_cidr, :access_group_id, :revoke_all_groups, :dry_run) SENSITIVE = [] include Aws::Structure end |
#target_network_cidr ⇒ String
The IPv4 address range, in CIDR notation, of the network for which access is being removed.
75013 75014 75015 75016 75017 75018 75019 75020 75021 |
# File 'lib/aws-sdk-ec2/types.rb', line 75013 class RevokeClientVpnIngressRequest < Struct.new( :client_vpn_endpoint_id, :target_network_cidr, :access_group_id, :revoke_all_groups, :dry_run) SENSITIVE = [] include Aws::Structure end |