Class: Aws::EC2::Types::RevokeClientVpnIngressRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_group_idString

The ID of the Active Directory group for which to revoke access.

Returns:

  • (String)


74896
74897
74898
74899
74900
74901
74902
74903
74904
# File 'lib/aws-sdk-ec2/types.rb', line 74896

class RevokeClientVpnIngressRequest < Struct.new(
  :client_vpn_endpoint_id,
  :target_network_cidr,
  :access_group_id,
  :revoke_all_groups,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#client_vpn_endpoint_idString

The ID of the Client VPN endpoint with which the authorization rule is associated.

Returns:

  • (String)


74896
74897
74898
74899
74900
74901
74902
74903
74904
# File 'lib/aws-sdk-ec2/types.rb', line 74896

class RevokeClientVpnIngressRequest < Struct.new(
  :client_vpn_endpoint_id,
  :target_network_cidr,
  :access_group_id,
  :revoke_all_groups,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


74896
74897
74898
74899
74900
74901
74902
74903
74904
# File 'lib/aws-sdk-ec2/types.rb', line 74896

class RevokeClientVpnIngressRequest < Struct.new(
  :client_vpn_endpoint_id,
  :target_network_cidr,
  :access_group_id,
  :revoke_all_groups,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#revoke_all_groupsBoolean

Indicates whether access should be revoked for all groups for a single ‘TargetNetworkCidr` that earlier authorized ingress for all groups using `AuthorizeAllGroups`. This does not impact other authorization rules that allowed ingress to the same `TargetNetworkCidr` with a specific `AccessGroupId`.

Returns:

  • (Boolean)


74896
74897
74898
74899
74900
74901
74902
74903
74904
# File 'lib/aws-sdk-ec2/types.rb', line 74896

class RevokeClientVpnIngressRequest < Struct.new(
  :client_vpn_endpoint_id,
  :target_network_cidr,
  :access_group_id,
  :revoke_all_groups,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#target_network_cidrString

The IPv4 address range, in CIDR notation, of the network for which access is being removed.

Returns:

  • (String)


74896
74897
74898
74899
74900
74901
74902
74903
74904
# File 'lib/aws-sdk-ec2/types.rb', line 74896

class RevokeClientVpnIngressRequest < Struct.new(
  :client_vpn_endpoint_id,
  :target_network_cidr,
  :access_group_id,
  :revoke_all_groups,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end