Class: Aws::EC2::Types::RevokeSecurityGroupIngressRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::RevokeSecurityGroupIngressRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cidr_ip ⇒ String
The CIDR IP address range.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#from_port ⇒ Integer
If the protocol is TCP or UDP, this is the start of the port range.
-
#group_id ⇒ String
The ID of the security group.
-
#group_name ⇒ String
[Default VPC] The name of the security group.
-
#ip_permissions ⇒ Array<Types::IpPermission>
The sets of IP permissions.
-
#ip_protocol ⇒ String
The IP protocol name (‘tcp`, `udp`, `icmp`) or number (see [Protocol Numbers]).
-
#security_group_rule_ids ⇒ Array<String>
The IDs of the security group rules.
-
#source_security_group_name ⇒ String
[Default VPC] The name of the source security group.
-
#source_security_group_owner_id ⇒ String
Not supported.
-
#to_port ⇒ Integer
If the protocol is TCP or UDP, this is the end of the port range.
Instance Attribute Details
#cidr_ip ⇒ String
The CIDR IP address range. You can’t specify this parameter when specifying a source security group.
74510 74511 74512 74513 74514 74515 74516 74517 74518 74519 74520 74521 74522 74523 74524 |
# File 'lib/aws-sdk-ec2/types.rb', line 74510 class RevokeSecurityGroupIngressRequest < Struct.new( :cidr_ip, :from_port, :group_id, :group_name, :ip_permissions, :ip_protocol, :source_security_group_name, :source_security_group_owner_id, :to_port, :security_group_rule_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
74510 74511 74512 74513 74514 74515 74516 74517 74518 74519 74520 74521 74522 74523 74524 |
# File 'lib/aws-sdk-ec2/types.rb', line 74510 class RevokeSecurityGroupIngressRequest < Struct.new( :cidr_ip, :from_port, :group_id, :group_name, :ip_permissions, :ip_protocol, :source_security_group_name, :source_security_group_owner_id, :to_port, :security_group_rule_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#from_port ⇒ Integer
If the protocol is TCP or UDP, this is the start of the port range. If the protocol is ICMP, this is the ICMP type or -1 (all ICMP types).
74510 74511 74512 74513 74514 74515 74516 74517 74518 74519 74520 74521 74522 74523 74524 |
# File 'lib/aws-sdk-ec2/types.rb', line 74510 class RevokeSecurityGroupIngressRequest < Struct.new( :cidr_ip, :from_port, :group_id, :group_name, :ip_permissions, :ip_protocol, :source_security_group_name, :source_security_group_owner_id, :to_port, :security_group_rule_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#group_id ⇒ String
The ID of the security group.
74510 74511 74512 74513 74514 74515 74516 74517 74518 74519 74520 74521 74522 74523 74524 |
# File 'lib/aws-sdk-ec2/types.rb', line 74510 class RevokeSecurityGroupIngressRequest < Struct.new( :cidr_ip, :from_port, :group_id, :group_name, :ip_permissions, :ip_protocol, :source_security_group_name, :source_security_group_owner_id, :to_port, :security_group_rule_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#group_name ⇒ String
[Default VPC] The name of the security group. You must specify either the security group ID or the security group name in the request. For security groups in a nondefault VPC, you must specify the security group ID.
74510 74511 74512 74513 74514 74515 74516 74517 74518 74519 74520 74521 74522 74523 74524 |
# File 'lib/aws-sdk-ec2/types.rb', line 74510 class RevokeSecurityGroupIngressRequest < Struct.new( :cidr_ip, :from_port, :group_id, :group_name, :ip_permissions, :ip_protocol, :source_security_group_name, :source_security_group_owner_id, :to_port, :security_group_rule_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#ip_permissions ⇒ Array<Types::IpPermission>
The sets of IP permissions. You can’t specify a source security group and a CIDR IP address range in the same set of permissions.
74510 74511 74512 74513 74514 74515 74516 74517 74518 74519 74520 74521 74522 74523 74524 |
# File 'lib/aws-sdk-ec2/types.rb', line 74510 class RevokeSecurityGroupIngressRequest < Struct.new( :cidr_ip, :from_port, :group_id, :group_name, :ip_permissions, :ip_protocol, :source_security_group_name, :source_security_group_owner_id, :to_port, :security_group_rule_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#ip_protocol ⇒ String
The IP protocol name (‘tcp`, `udp`, `icmp`) or number (see [Protocol Numbers]). Use `-1` to specify all.
[1]: www.iana.org/assignments/protocol-numbers/protocol-numbers.xhtml
74510 74511 74512 74513 74514 74515 74516 74517 74518 74519 74520 74521 74522 74523 74524 |
# File 'lib/aws-sdk-ec2/types.rb', line 74510 class RevokeSecurityGroupIngressRequest < Struct.new( :cidr_ip, :from_port, :group_id, :group_name, :ip_permissions, :ip_protocol, :source_security_group_name, :source_security_group_owner_id, :to_port, :security_group_rule_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#security_group_rule_ids ⇒ Array<String>
The IDs of the security group rules.
74510 74511 74512 74513 74514 74515 74516 74517 74518 74519 74520 74521 74522 74523 74524 |
# File 'lib/aws-sdk-ec2/types.rb', line 74510 class RevokeSecurityGroupIngressRequest < Struct.new( :cidr_ip, :from_port, :group_id, :group_name, :ip_permissions, :ip_protocol, :source_security_group_name, :source_security_group_owner_id, :to_port, :security_group_rule_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#source_security_group_name ⇒ String
[Default VPC] The name of the source security group. You can’t specify this parameter in combination with the following parameters: the CIDR IP address range, the start of the port range, the IP protocol, and the end of the port range. The source security group must be in the same VPC. To revoke a specific rule for an IP protocol and port range, use a set of IP permissions instead.
74510 74511 74512 74513 74514 74515 74516 74517 74518 74519 74520 74521 74522 74523 74524 |
# File 'lib/aws-sdk-ec2/types.rb', line 74510 class RevokeSecurityGroupIngressRequest < Struct.new( :cidr_ip, :from_port, :group_id, :group_name, :ip_permissions, :ip_protocol, :source_security_group_name, :source_security_group_owner_id, :to_port, :security_group_rule_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#source_security_group_owner_id ⇒ String
Not supported.
74510 74511 74512 74513 74514 74515 74516 74517 74518 74519 74520 74521 74522 74523 74524 |
# File 'lib/aws-sdk-ec2/types.rb', line 74510 class RevokeSecurityGroupIngressRequest < Struct.new( :cidr_ip, :from_port, :group_id, :group_name, :ip_permissions, :ip_protocol, :source_security_group_name, :source_security_group_owner_id, :to_port, :security_group_rule_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#to_port ⇒ Integer
If the protocol is TCP or UDP, this is the end of the port range. If the protocol is ICMP, this is the ICMP code or -1 (all ICMP codes).
74510 74511 74512 74513 74514 74515 74516 74517 74518 74519 74520 74521 74522 74523 74524 |
# File 'lib/aws-sdk-ec2/types.rb', line 74510 class RevokeSecurityGroupIngressRequest < Struct.new( :cidr_ip, :from_port, :group_id, :group_name, :ip_permissions, :ip_protocol, :source_security_group_name, :source_security_group_owner_id, :to_port, :security_group_rule_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |