Class: Aws::EC2::Types::Route

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes a route in a route table.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#carrier_gateway_idString

The ID of the carrier gateway.

Returns:

  • (String)


76096
76097
76098
76099
76100
76101
76102
76103
76104
76105
76106
76107
76108
76109
76110
76111
76112
76113
76114
76115
76116
76117
# File 'lib/aws-sdk-ec2/types.rb', line 76096

class Route < Struct.new(
  :destination_cidr_block,
  :destination_ipv_6_cidr_block,
  :destination_prefix_list_id,
  :egress_only_internet_gateway_id,
  :gateway_id,
  :instance_id,
  :instance_owner_id,
  :nat_gateway_id,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :network_interface_id,
  :origin,
  :state,
  :vpc_peering_connection_id,
  :core_network_arn,
  :odb_network_arn,
  :ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#core_network_arnString

The Amazon Resource Name (ARN) of the core network.

Returns:

  • (String)


76096
76097
76098
76099
76100
76101
76102
76103
76104
76105
76106
76107
76108
76109
76110
76111
76112
76113
76114
76115
76116
76117
# File 'lib/aws-sdk-ec2/types.rb', line 76096

class Route < Struct.new(
  :destination_cidr_block,
  :destination_ipv_6_cidr_block,
  :destination_prefix_list_id,
  :egress_only_internet_gateway_id,
  :gateway_id,
  :instance_id,
  :instance_owner_id,
  :nat_gateway_id,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :network_interface_id,
  :origin,
  :state,
  :vpc_peering_connection_id,
  :core_network_arn,
  :odb_network_arn,
  :ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#destination_cidr_blockString

The IPv4 CIDR block used for the destination match.

Returns:

  • (String)


76096
76097
76098
76099
76100
76101
76102
76103
76104
76105
76106
76107
76108
76109
76110
76111
76112
76113
76114
76115
76116
76117
# File 'lib/aws-sdk-ec2/types.rb', line 76096

class Route < Struct.new(
  :destination_cidr_block,
  :destination_ipv_6_cidr_block,
  :destination_prefix_list_id,
  :egress_only_internet_gateway_id,
  :gateway_id,
  :instance_id,
  :instance_owner_id,
  :nat_gateway_id,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :network_interface_id,
  :origin,
  :state,
  :vpc_peering_connection_id,
  :core_network_arn,
  :odb_network_arn,
  :ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#destination_ipv_6_cidr_blockString

The IPv6 CIDR block used for the destination match.

Returns:

  • (String)


76096
76097
76098
76099
76100
76101
76102
76103
76104
76105
76106
76107
76108
76109
76110
76111
76112
76113
76114
76115
76116
76117
# File 'lib/aws-sdk-ec2/types.rb', line 76096

class Route < Struct.new(
  :destination_cidr_block,
  :destination_ipv_6_cidr_block,
  :destination_prefix_list_id,
  :egress_only_internet_gateway_id,
  :gateway_id,
  :instance_id,
  :instance_owner_id,
  :nat_gateway_id,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :network_interface_id,
  :origin,
  :state,
  :vpc_peering_connection_id,
  :core_network_arn,
  :odb_network_arn,
  :ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#destination_prefix_list_idString

The prefix of the Amazon Web Services service.

Returns:

  • (String)


76096
76097
76098
76099
76100
76101
76102
76103
76104
76105
76106
76107
76108
76109
76110
76111
76112
76113
76114
76115
76116
76117
# File 'lib/aws-sdk-ec2/types.rb', line 76096

class Route < Struct.new(
  :destination_cidr_block,
  :destination_ipv_6_cidr_block,
  :destination_prefix_list_id,
  :egress_only_internet_gateway_id,
  :gateway_id,
  :instance_id,
  :instance_owner_id,
  :nat_gateway_id,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :network_interface_id,
  :origin,
  :state,
  :vpc_peering_connection_id,
  :core_network_arn,
  :odb_network_arn,
  :ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#egress_only_internet_gateway_idString

The ID of the egress-only internet gateway.

Returns:

  • (String)


76096
76097
76098
76099
76100
76101
76102
76103
76104
76105
76106
76107
76108
76109
76110
76111
76112
76113
76114
76115
76116
76117
# File 'lib/aws-sdk-ec2/types.rb', line 76096

class Route < Struct.new(
  :destination_cidr_block,
  :destination_ipv_6_cidr_block,
  :destination_prefix_list_id,
  :egress_only_internet_gateway_id,
  :gateway_id,
  :instance_id,
  :instance_owner_id,
  :nat_gateway_id,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :network_interface_id,
  :origin,
  :state,
  :vpc_peering_connection_id,
  :core_network_arn,
  :odb_network_arn,
  :ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#gateway_idString

The ID of a gateway attached to your VPC.

Returns:

  • (String)


76096
76097
76098
76099
76100
76101
76102
76103
76104
76105
76106
76107
76108
76109
76110
76111
76112
76113
76114
76115
76116
76117
# File 'lib/aws-sdk-ec2/types.rb', line 76096

class Route < Struct.new(
  :destination_cidr_block,
  :destination_ipv_6_cidr_block,
  :destination_prefix_list_id,
  :egress_only_internet_gateway_id,
  :gateway_id,
  :instance_id,
  :instance_owner_id,
  :nat_gateway_id,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :network_interface_id,
  :origin,
  :state,
  :vpc_peering_connection_id,
  :core_network_arn,
  :odb_network_arn,
  :ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The ID of a NAT instance in your VPC.

Returns:

  • (String)


76096
76097
76098
76099
76100
76101
76102
76103
76104
76105
76106
76107
76108
76109
76110
76111
76112
76113
76114
76115
76116
76117
# File 'lib/aws-sdk-ec2/types.rb', line 76096

class Route < Struct.new(
  :destination_cidr_block,
  :destination_ipv_6_cidr_block,
  :destination_prefix_list_id,
  :egress_only_internet_gateway_id,
  :gateway_id,
  :instance_id,
  :instance_owner_id,
  :nat_gateway_id,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :network_interface_id,
  :origin,
  :state,
  :vpc_peering_connection_id,
  :core_network_arn,
  :odb_network_arn,
  :ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#instance_owner_idString

The ID of Amazon Web Services account that owns the instance.

Returns:

  • (String)


76096
76097
76098
76099
76100
76101
76102
76103
76104
76105
76106
76107
76108
76109
76110
76111
76112
76113
76114
76115
76116
76117
# File 'lib/aws-sdk-ec2/types.rb', line 76096

class Route < Struct.new(
  :destination_cidr_block,
  :destination_ipv_6_cidr_block,
  :destination_prefix_list_id,
  :egress_only_internet_gateway_id,
  :gateway_id,
  :instance_id,
  :instance_owner_id,
  :nat_gateway_id,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :network_interface_id,
  :origin,
  :state,
  :vpc_peering_connection_id,
  :core_network_arn,
  :odb_network_arn,
  :ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#ip_addressString

The next hop IP address for routes propagated by VPC Route Server into VPC route tables.

Returns:

  • (String)


76096
76097
76098
76099
76100
76101
76102
76103
76104
76105
76106
76107
76108
76109
76110
76111
76112
76113
76114
76115
76116
76117
# File 'lib/aws-sdk-ec2/types.rb', line 76096

class Route < Struct.new(
  :destination_cidr_block,
  :destination_ipv_6_cidr_block,
  :destination_prefix_list_id,
  :egress_only_internet_gateway_id,
  :gateway_id,
  :instance_id,
  :instance_owner_id,
  :nat_gateway_id,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :network_interface_id,
  :origin,
  :state,
  :vpc_peering_connection_id,
  :core_network_arn,
  :odb_network_arn,
  :ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#local_gateway_idString

The ID of the local gateway.

Returns:

  • (String)


76096
76097
76098
76099
76100
76101
76102
76103
76104
76105
76106
76107
76108
76109
76110
76111
76112
76113
76114
76115
76116
76117
# File 'lib/aws-sdk-ec2/types.rb', line 76096

class Route < Struct.new(
  :destination_cidr_block,
  :destination_ipv_6_cidr_block,
  :destination_prefix_list_id,
  :egress_only_internet_gateway_id,
  :gateway_id,
  :instance_id,
  :instance_owner_id,
  :nat_gateway_id,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :network_interface_id,
  :origin,
  :state,
  :vpc_peering_connection_id,
  :core_network_arn,
  :odb_network_arn,
  :ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#nat_gateway_idString

The ID of a NAT gateway.

Returns:

  • (String)


76096
76097
76098
76099
76100
76101
76102
76103
76104
76105
76106
76107
76108
76109
76110
76111
76112
76113
76114
76115
76116
76117
# File 'lib/aws-sdk-ec2/types.rb', line 76096

class Route < Struct.new(
  :destination_cidr_block,
  :destination_ipv_6_cidr_block,
  :destination_prefix_list_id,
  :egress_only_internet_gateway_id,
  :gateway_id,
  :instance_id,
  :instance_owner_id,
  :nat_gateway_id,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :network_interface_id,
  :origin,
  :state,
  :vpc_peering_connection_id,
  :core_network_arn,
  :odb_network_arn,
  :ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#network_interface_idString

The ID of the network interface.

Returns:

  • (String)


76096
76097
76098
76099
76100
76101
76102
76103
76104
76105
76106
76107
76108
76109
76110
76111
76112
76113
76114
76115
76116
76117
# File 'lib/aws-sdk-ec2/types.rb', line 76096

class Route < Struct.new(
  :destination_cidr_block,
  :destination_ipv_6_cidr_block,
  :destination_prefix_list_id,
  :egress_only_internet_gateway_id,
  :gateway_id,
  :instance_id,
  :instance_owner_id,
  :nat_gateway_id,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :network_interface_id,
  :origin,
  :state,
  :vpc_peering_connection_id,
  :core_network_arn,
  :odb_network_arn,
  :ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#odb_network_arnString

The Amazon Resource Name (ARN) of the ODB network.

Returns:

  • (String)


76096
76097
76098
76099
76100
76101
76102
76103
76104
76105
76106
76107
76108
76109
76110
76111
76112
76113
76114
76115
76116
76117
# File 'lib/aws-sdk-ec2/types.rb', line 76096

class Route < Struct.new(
  :destination_cidr_block,
  :destination_ipv_6_cidr_block,
  :destination_prefix_list_id,
  :egress_only_internet_gateway_id,
  :gateway_id,
  :instance_id,
  :instance_owner_id,
  :nat_gateway_id,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :network_interface_id,
  :origin,
  :state,
  :vpc_peering_connection_id,
  :core_network_arn,
  :odb_network_arn,
  :ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#originString

Describes how the route was created.

  • CreateRouteTable - The route was automatically created when the route table was created.

  • CreateRoute - The route was manually added to the route table.

  • EnableVgwRoutePropagation - The route was propagated by route propagation.

  • Advertisement - The route was created dynamically by Amazon VPC Route Server.

Returns:

  • (String)


76096
76097
76098
76099
76100
76101
76102
76103
76104
76105
76106
76107
76108
76109
76110
76111
76112
76113
76114
76115
76116
76117
# File 'lib/aws-sdk-ec2/types.rb', line 76096

class Route < Struct.new(
  :destination_cidr_block,
  :destination_ipv_6_cidr_block,
  :destination_prefix_list_id,
  :egress_only_internet_gateway_id,
  :gateway_id,
  :instance_id,
  :instance_owner_id,
  :nat_gateway_id,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :network_interface_id,
  :origin,
  :state,
  :vpc_peering_connection_id,
  :core_network_arn,
  :odb_network_arn,
  :ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of the route. The blackhole state indicates that the route's target isn't available (for example, the specified gateway isn't attached to the VPC, or the specified NAT instance has been terminated).

Returns:

  • (String)


76096
76097
76098
76099
76100
76101
76102
76103
76104
76105
76106
76107
76108
76109
76110
76111
76112
76113
76114
76115
76116
76117
# File 'lib/aws-sdk-ec2/types.rb', line 76096

class Route < Struct.new(
  :destination_cidr_block,
  :destination_ipv_6_cidr_block,
  :destination_prefix_list_id,
  :egress_only_internet_gateway_id,
  :gateway_id,
  :instance_id,
  :instance_owner_id,
  :nat_gateway_id,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :network_interface_id,
  :origin,
  :state,
  :vpc_peering_connection_id,
  :core_network_arn,
  :odb_network_arn,
  :ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_idString

The ID of a transit gateway.

Returns:

  • (String)


76096
76097
76098
76099
76100
76101
76102
76103
76104
76105
76106
76107
76108
76109
76110
76111
76112
76113
76114
76115
76116
76117
# File 'lib/aws-sdk-ec2/types.rb', line 76096

class Route < Struct.new(
  :destination_cidr_block,
  :destination_ipv_6_cidr_block,
  :destination_prefix_list_id,
  :egress_only_internet_gateway_id,
  :gateway_id,
  :instance_id,
  :instance_owner_id,
  :nat_gateway_id,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :network_interface_id,
  :origin,
  :state,
  :vpc_peering_connection_id,
  :core_network_arn,
  :odb_network_arn,
  :ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_peering_connection_idString

The ID of a VPC peering connection.

Returns:

  • (String)


76096
76097
76098
76099
76100
76101
76102
76103
76104
76105
76106
76107
76108
76109
76110
76111
76112
76113
76114
76115
76116
76117
# File 'lib/aws-sdk-ec2/types.rb', line 76096

class Route < Struct.new(
  :destination_cidr_block,
  :destination_ipv_6_cidr_block,
  :destination_prefix_list_id,
  :egress_only_internet_gateway_id,
  :gateway_id,
  :instance_id,
  :instance_owner_id,
  :nat_gateway_id,
  :transit_gateway_id,
  :local_gateway_id,
  :carrier_gateway_id,
  :network_interface_id,
  :origin,
  :state,
  :vpc_peering_connection_id,
  :core_network_arn,
  :odb_network_arn,
  :ip_address)
  SENSITIVE = []
  include Aws::Structure
end