Class: Aws::EC2::Types::Route
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::Route
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a route in a route table.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#carrier_gateway_id ⇒ String
The ID of the carrier gateway.
-
#core_network_arn ⇒ String
The Amazon Resource Name (ARN) of the core network.
-
#destination_cidr_block ⇒ String
The IPv4 CIDR block used for the destination match.
-
#destination_ipv_6_cidr_block ⇒ String
The IPv6 CIDR block used for the destination match.
-
#destination_prefix_list_id ⇒ String
The prefix of the Amazon Web Services service.
-
#egress_only_internet_gateway_id ⇒ String
The ID of the egress-only internet gateway.
-
#gateway_id ⇒ String
The ID of a gateway attached to your VPC.
-
#instance_id ⇒ String
The ID of a NAT instance in your VPC.
-
#instance_owner_id ⇒ String
The ID of Amazon Web Services account that owns the instance.
-
#ip_address ⇒ String
The next hop IP address for routes propagated by VPC Route Server into VPC route tables.
-
#local_gateway_id ⇒ String
The ID of the local gateway.
-
#nat_gateway_id ⇒ String
The ID of a NAT gateway.
-
#network_interface_id ⇒ String
The ID of the network interface.
-
#odb_network_arn ⇒ String
The Amazon Resource Name (ARN) of the ODB network.
-
#origin ⇒ String
Describes how the route was created.
-
#state ⇒ String
The state of the route.
-
#transit_gateway_id ⇒ String
The ID of a transit gateway.
-
#vpc_peering_connection_id ⇒ String
The ID of a VPC peering connection.
Instance Attribute Details
#carrier_gateway_id ⇒ String
The ID of the carrier gateway.
75131 75132 75133 75134 75135 75136 75137 75138 75139 75140 75141 75142 75143 75144 75145 75146 75147 75148 75149 75150 75151 75152 |
# File 'lib/aws-sdk-ec2/types.rb', line 75131 class Route < Struct.new( :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :nat_gateway_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :network_interface_id, :origin, :state, :vpc_peering_connection_id, :core_network_arn, :odb_network_arn, :ip_address) SENSITIVE = [] include Aws::Structure end |
#core_network_arn ⇒ String
The Amazon Resource Name (ARN) of the core network.
75131 75132 75133 75134 75135 75136 75137 75138 75139 75140 75141 75142 75143 75144 75145 75146 75147 75148 75149 75150 75151 75152 |
# File 'lib/aws-sdk-ec2/types.rb', line 75131 class Route < Struct.new( :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :nat_gateway_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :network_interface_id, :origin, :state, :vpc_peering_connection_id, :core_network_arn, :odb_network_arn, :ip_address) SENSITIVE = [] include Aws::Structure end |
#destination_cidr_block ⇒ String
The IPv4 CIDR block used for the destination match.
75131 75132 75133 75134 75135 75136 75137 75138 75139 75140 75141 75142 75143 75144 75145 75146 75147 75148 75149 75150 75151 75152 |
# File 'lib/aws-sdk-ec2/types.rb', line 75131 class Route < Struct.new( :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :nat_gateway_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :network_interface_id, :origin, :state, :vpc_peering_connection_id, :core_network_arn, :odb_network_arn, :ip_address) SENSITIVE = [] include Aws::Structure end |
#destination_ipv_6_cidr_block ⇒ String
The IPv6 CIDR block used for the destination match.
75131 75132 75133 75134 75135 75136 75137 75138 75139 75140 75141 75142 75143 75144 75145 75146 75147 75148 75149 75150 75151 75152 |
# File 'lib/aws-sdk-ec2/types.rb', line 75131 class Route < Struct.new( :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :nat_gateway_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :network_interface_id, :origin, :state, :vpc_peering_connection_id, :core_network_arn, :odb_network_arn, :ip_address) SENSITIVE = [] include Aws::Structure end |
#destination_prefix_list_id ⇒ String
The prefix of the Amazon Web Services service.
75131 75132 75133 75134 75135 75136 75137 75138 75139 75140 75141 75142 75143 75144 75145 75146 75147 75148 75149 75150 75151 75152 |
# File 'lib/aws-sdk-ec2/types.rb', line 75131 class Route < Struct.new( :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :nat_gateway_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :network_interface_id, :origin, :state, :vpc_peering_connection_id, :core_network_arn, :odb_network_arn, :ip_address) SENSITIVE = [] include Aws::Structure end |
#egress_only_internet_gateway_id ⇒ String
The ID of the egress-only internet gateway.
75131 75132 75133 75134 75135 75136 75137 75138 75139 75140 75141 75142 75143 75144 75145 75146 75147 75148 75149 75150 75151 75152 |
# File 'lib/aws-sdk-ec2/types.rb', line 75131 class Route < Struct.new( :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :nat_gateway_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :network_interface_id, :origin, :state, :vpc_peering_connection_id, :core_network_arn, :odb_network_arn, :ip_address) SENSITIVE = [] include Aws::Structure end |
#gateway_id ⇒ String
The ID of a gateway attached to your VPC.
75131 75132 75133 75134 75135 75136 75137 75138 75139 75140 75141 75142 75143 75144 75145 75146 75147 75148 75149 75150 75151 75152 |
# File 'lib/aws-sdk-ec2/types.rb', line 75131 class Route < Struct.new( :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :nat_gateway_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :network_interface_id, :origin, :state, :vpc_peering_connection_id, :core_network_arn, :odb_network_arn, :ip_address) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of a NAT instance in your VPC.
75131 75132 75133 75134 75135 75136 75137 75138 75139 75140 75141 75142 75143 75144 75145 75146 75147 75148 75149 75150 75151 75152 |
# File 'lib/aws-sdk-ec2/types.rb', line 75131 class Route < Struct.new( :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :nat_gateway_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :network_interface_id, :origin, :state, :vpc_peering_connection_id, :core_network_arn, :odb_network_arn, :ip_address) SENSITIVE = [] include Aws::Structure end |
#instance_owner_id ⇒ String
The ID of Amazon Web Services account that owns the instance.
75131 75132 75133 75134 75135 75136 75137 75138 75139 75140 75141 75142 75143 75144 75145 75146 75147 75148 75149 75150 75151 75152 |
# File 'lib/aws-sdk-ec2/types.rb', line 75131 class Route < Struct.new( :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :nat_gateway_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :network_interface_id, :origin, :state, :vpc_peering_connection_id, :core_network_arn, :odb_network_arn, :ip_address) SENSITIVE = [] include Aws::Structure end |
#ip_address ⇒ String
The next hop IP address for routes propagated by VPC Route Server into VPC route tables.
75131 75132 75133 75134 75135 75136 75137 75138 75139 75140 75141 75142 75143 75144 75145 75146 75147 75148 75149 75150 75151 75152 |
# File 'lib/aws-sdk-ec2/types.rb', line 75131 class Route < Struct.new( :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :nat_gateway_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :network_interface_id, :origin, :state, :vpc_peering_connection_id, :core_network_arn, :odb_network_arn, :ip_address) SENSITIVE = [] include Aws::Structure end |
#local_gateway_id ⇒ String
The ID of the local gateway.
75131 75132 75133 75134 75135 75136 75137 75138 75139 75140 75141 75142 75143 75144 75145 75146 75147 75148 75149 75150 75151 75152 |
# File 'lib/aws-sdk-ec2/types.rb', line 75131 class Route < Struct.new( :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :nat_gateway_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :network_interface_id, :origin, :state, :vpc_peering_connection_id, :core_network_arn, :odb_network_arn, :ip_address) SENSITIVE = [] include Aws::Structure end |
#nat_gateway_id ⇒ String
The ID of a NAT gateway.
75131 75132 75133 75134 75135 75136 75137 75138 75139 75140 75141 75142 75143 75144 75145 75146 75147 75148 75149 75150 75151 75152 |
# File 'lib/aws-sdk-ec2/types.rb', line 75131 class Route < Struct.new( :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :nat_gateway_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :network_interface_id, :origin, :state, :vpc_peering_connection_id, :core_network_arn, :odb_network_arn, :ip_address) SENSITIVE = [] include Aws::Structure end |
#network_interface_id ⇒ String
The ID of the network interface.
75131 75132 75133 75134 75135 75136 75137 75138 75139 75140 75141 75142 75143 75144 75145 75146 75147 75148 75149 75150 75151 75152 |
# File 'lib/aws-sdk-ec2/types.rb', line 75131 class Route < Struct.new( :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :nat_gateway_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :network_interface_id, :origin, :state, :vpc_peering_connection_id, :core_network_arn, :odb_network_arn, :ip_address) SENSITIVE = [] include Aws::Structure end |
#odb_network_arn ⇒ String
The Amazon Resource Name (ARN) of the ODB network.
75131 75132 75133 75134 75135 75136 75137 75138 75139 75140 75141 75142 75143 75144 75145 75146 75147 75148 75149 75150 75151 75152 |
# File 'lib/aws-sdk-ec2/types.rb', line 75131 class Route < Struct.new( :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :nat_gateway_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :network_interface_id, :origin, :state, :vpc_peering_connection_id, :core_network_arn, :odb_network_arn, :ip_address) SENSITIVE = [] include Aws::Structure end |
#origin ⇒ String
Describes how the route was created.
-
‘CreateRouteTable` - The route was automatically created when the route table was created.
-
‘CreateRoute` - The route was manually added to the route table.
-
‘EnableVgwRoutePropagation` - The route was propagated by route propagation.
-
‘Advertisement` - The route was created dynamically by Amazon VPC Route Server.
75131 75132 75133 75134 75135 75136 75137 75138 75139 75140 75141 75142 75143 75144 75145 75146 75147 75148 75149 75150 75151 75152 |
# File 'lib/aws-sdk-ec2/types.rb', line 75131 class Route < Struct.new( :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :nat_gateway_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :network_interface_id, :origin, :state, :vpc_peering_connection_id, :core_network_arn, :odb_network_arn, :ip_address) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the route. The ‘blackhole` state indicates that the route’s target isn’t available (for example, the specified gateway isn’t attached to the VPC, or the specified NAT instance has been terminated).
75131 75132 75133 75134 75135 75136 75137 75138 75139 75140 75141 75142 75143 75144 75145 75146 75147 75148 75149 75150 75151 75152 |
# File 'lib/aws-sdk-ec2/types.rb', line 75131 class Route < Struct.new( :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :nat_gateway_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :network_interface_id, :origin, :state, :vpc_peering_connection_id, :core_network_arn, :odb_network_arn, :ip_address) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_id ⇒ String
The ID of a transit gateway.
75131 75132 75133 75134 75135 75136 75137 75138 75139 75140 75141 75142 75143 75144 75145 75146 75147 75148 75149 75150 75151 75152 |
# File 'lib/aws-sdk-ec2/types.rb', line 75131 class Route < Struct.new( :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :nat_gateway_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :network_interface_id, :origin, :state, :vpc_peering_connection_id, :core_network_arn, :odb_network_arn, :ip_address) SENSITIVE = [] include Aws::Structure end |
#vpc_peering_connection_id ⇒ String
The ID of a VPC peering connection.
75131 75132 75133 75134 75135 75136 75137 75138 75139 75140 75141 75142 75143 75144 75145 75146 75147 75148 75149 75150 75151 75152 |
# File 'lib/aws-sdk-ec2/types.rb', line 75131 class Route < Struct.new( :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :nat_gateway_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :network_interface_id, :origin, :state, :vpc_peering_connection_id, :core_network_arn, :odb_network_arn, :ip_address) SENSITIVE = [] include Aws::Structure end |