Class: Aws::EC2::Types::Route
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::Route
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a route in a route table.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#carrier_gateway_id ⇒ String
The ID of the carrier gateway.
-
#core_network_arn ⇒ String
The Amazon Resource Name (ARN) of the core network.
-
#destination_cidr_block ⇒ String
The IPv4 CIDR block used for the destination match.
-
#destination_ipv_6_cidr_block ⇒ String
The IPv6 CIDR block used for the destination match.
-
#destination_prefix_list_id ⇒ String
The prefix of the Amazon Web Services service.
-
#egress_only_internet_gateway_id ⇒ String
The ID of the egress-only internet gateway.
-
#gateway_id ⇒ String
The ID of a gateway attached to your VPC.
-
#instance_id ⇒ String
The ID of a NAT instance in your VPC.
-
#instance_owner_id ⇒ String
The ID of Amazon Web Services account that owns the instance.
-
#ip_address ⇒ String
The next hop IP address for routes propagated by VPC Route Server into VPC route tables.
-
#local_gateway_id ⇒ String
The ID of the local gateway.
-
#nat_gateway_id ⇒ String
The ID of a NAT gateway.
-
#network_interface_id ⇒ String
The ID of the network interface.
-
#odb_network_arn ⇒ String
The Amazon Resource Name (ARN) of the ODB network.
-
#origin ⇒ String
Describes how the route was created.
-
#state ⇒ String
The state of the route.
-
#transit_gateway_id ⇒ String
The ID of a transit gateway.
-
#vpc_peering_connection_id ⇒ String
The ID of a VPC peering connection.
Instance Attribute Details
#carrier_gateway_id ⇒ String
The ID of the carrier gateway.
73137 73138 73139 73140 73141 73142 73143 73144 73145 73146 73147 73148 73149 73150 73151 73152 73153 73154 73155 73156 73157 73158 |
# File 'lib/aws-sdk-ec2/types.rb', line 73137 class Route < Struct.new( :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :nat_gateway_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :network_interface_id, :origin, :state, :vpc_peering_connection_id, :core_network_arn, :odb_network_arn, :ip_address) SENSITIVE = [] include Aws::Structure end |
#core_network_arn ⇒ String
The Amazon Resource Name (ARN) of the core network.
73137 73138 73139 73140 73141 73142 73143 73144 73145 73146 73147 73148 73149 73150 73151 73152 73153 73154 73155 73156 73157 73158 |
# File 'lib/aws-sdk-ec2/types.rb', line 73137 class Route < Struct.new( :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :nat_gateway_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :network_interface_id, :origin, :state, :vpc_peering_connection_id, :core_network_arn, :odb_network_arn, :ip_address) SENSITIVE = [] include Aws::Structure end |
#destination_cidr_block ⇒ String
The IPv4 CIDR block used for the destination match.
73137 73138 73139 73140 73141 73142 73143 73144 73145 73146 73147 73148 73149 73150 73151 73152 73153 73154 73155 73156 73157 73158 |
# File 'lib/aws-sdk-ec2/types.rb', line 73137 class Route < Struct.new( :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :nat_gateway_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :network_interface_id, :origin, :state, :vpc_peering_connection_id, :core_network_arn, :odb_network_arn, :ip_address) SENSITIVE = [] include Aws::Structure end |
#destination_ipv_6_cidr_block ⇒ String
The IPv6 CIDR block used for the destination match.
73137 73138 73139 73140 73141 73142 73143 73144 73145 73146 73147 73148 73149 73150 73151 73152 73153 73154 73155 73156 73157 73158 |
# File 'lib/aws-sdk-ec2/types.rb', line 73137 class Route < Struct.new( :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :nat_gateway_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :network_interface_id, :origin, :state, :vpc_peering_connection_id, :core_network_arn, :odb_network_arn, :ip_address) SENSITIVE = [] include Aws::Structure end |
#destination_prefix_list_id ⇒ String
The prefix of the Amazon Web Services service.
73137 73138 73139 73140 73141 73142 73143 73144 73145 73146 73147 73148 73149 73150 73151 73152 73153 73154 73155 73156 73157 73158 |
# File 'lib/aws-sdk-ec2/types.rb', line 73137 class Route < Struct.new( :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :nat_gateway_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :network_interface_id, :origin, :state, :vpc_peering_connection_id, :core_network_arn, :odb_network_arn, :ip_address) SENSITIVE = [] include Aws::Structure end |
#egress_only_internet_gateway_id ⇒ String
The ID of the egress-only internet gateway.
73137 73138 73139 73140 73141 73142 73143 73144 73145 73146 73147 73148 73149 73150 73151 73152 73153 73154 73155 73156 73157 73158 |
# File 'lib/aws-sdk-ec2/types.rb', line 73137 class Route < Struct.new( :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :nat_gateway_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :network_interface_id, :origin, :state, :vpc_peering_connection_id, :core_network_arn, :odb_network_arn, :ip_address) SENSITIVE = [] include Aws::Structure end |
#gateway_id ⇒ String
The ID of a gateway attached to your VPC.
73137 73138 73139 73140 73141 73142 73143 73144 73145 73146 73147 73148 73149 73150 73151 73152 73153 73154 73155 73156 73157 73158 |
# File 'lib/aws-sdk-ec2/types.rb', line 73137 class Route < Struct.new( :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :nat_gateway_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :network_interface_id, :origin, :state, :vpc_peering_connection_id, :core_network_arn, :odb_network_arn, :ip_address) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of a NAT instance in your VPC.
73137 73138 73139 73140 73141 73142 73143 73144 73145 73146 73147 73148 73149 73150 73151 73152 73153 73154 73155 73156 73157 73158 |
# File 'lib/aws-sdk-ec2/types.rb', line 73137 class Route < Struct.new( :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :nat_gateway_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :network_interface_id, :origin, :state, :vpc_peering_connection_id, :core_network_arn, :odb_network_arn, :ip_address) SENSITIVE = [] include Aws::Structure end |
#instance_owner_id ⇒ String
The ID of Amazon Web Services account that owns the instance.
73137 73138 73139 73140 73141 73142 73143 73144 73145 73146 73147 73148 73149 73150 73151 73152 73153 73154 73155 73156 73157 73158 |
# File 'lib/aws-sdk-ec2/types.rb', line 73137 class Route < Struct.new( :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :nat_gateway_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :network_interface_id, :origin, :state, :vpc_peering_connection_id, :core_network_arn, :odb_network_arn, :ip_address) SENSITIVE = [] include Aws::Structure end |
#ip_address ⇒ String
The next hop IP address for routes propagated by VPC Route Server into VPC route tables.
73137 73138 73139 73140 73141 73142 73143 73144 73145 73146 73147 73148 73149 73150 73151 73152 73153 73154 73155 73156 73157 73158 |
# File 'lib/aws-sdk-ec2/types.rb', line 73137 class Route < Struct.new( :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :nat_gateway_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :network_interface_id, :origin, :state, :vpc_peering_connection_id, :core_network_arn, :odb_network_arn, :ip_address) SENSITIVE = [] include Aws::Structure end |
#local_gateway_id ⇒ String
The ID of the local gateway.
73137 73138 73139 73140 73141 73142 73143 73144 73145 73146 73147 73148 73149 73150 73151 73152 73153 73154 73155 73156 73157 73158 |
# File 'lib/aws-sdk-ec2/types.rb', line 73137 class Route < Struct.new( :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :nat_gateway_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :network_interface_id, :origin, :state, :vpc_peering_connection_id, :core_network_arn, :odb_network_arn, :ip_address) SENSITIVE = [] include Aws::Structure end |
#nat_gateway_id ⇒ String
The ID of a NAT gateway.
73137 73138 73139 73140 73141 73142 73143 73144 73145 73146 73147 73148 73149 73150 73151 73152 73153 73154 73155 73156 73157 73158 |
# File 'lib/aws-sdk-ec2/types.rb', line 73137 class Route < Struct.new( :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :nat_gateway_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :network_interface_id, :origin, :state, :vpc_peering_connection_id, :core_network_arn, :odb_network_arn, :ip_address) SENSITIVE = [] include Aws::Structure end |
#network_interface_id ⇒ String
The ID of the network interface.
73137 73138 73139 73140 73141 73142 73143 73144 73145 73146 73147 73148 73149 73150 73151 73152 73153 73154 73155 73156 73157 73158 |
# File 'lib/aws-sdk-ec2/types.rb', line 73137 class Route < Struct.new( :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :nat_gateway_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :network_interface_id, :origin, :state, :vpc_peering_connection_id, :core_network_arn, :odb_network_arn, :ip_address) SENSITIVE = [] include Aws::Structure end |
#odb_network_arn ⇒ String
The Amazon Resource Name (ARN) of the ODB network.
73137 73138 73139 73140 73141 73142 73143 73144 73145 73146 73147 73148 73149 73150 73151 73152 73153 73154 73155 73156 73157 73158 |
# File 'lib/aws-sdk-ec2/types.rb', line 73137 class Route < Struct.new( :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :nat_gateway_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :network_interface_id, :origin, :state, :vpc_peering_connection_id, :core_network_arn, :odb_network_arn, :ip_address) SENSITIVE = [] include Aws::Structure end |
#origin ⇒ String
Describes how the route was created.
-
‘CreateRouteTable` - The route was automatically created when the route table was created.
-
‘CreateRoute` - The route was manually added to the route table.
-
‘EnableVgwRoutePropagation` - The route was propagated by route propagation.
-
‘Advertisement` - The route was created dynamically by Amazon VPC Route Server.
73137 73138 73139 73140 73141 73142 73143 73144 73145 73146 73147 73148 73149 73150 73151 73152 73153 73154 73155 73156 73157 73158 |
# File 'lib/aws-sdk-ec2/types.rb', line 73137 class Route < Struct.new( :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :nat_gateway_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :network_interface_id, :origin, :state, :vpc_peering_connection_id, :core_network_arn, :odb_network_arn, :ip_address) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the route. The ‘blackhole` state indicates that the route’s target isn’t available (for example, the specified gateway isn’t attached to the VPC, or the specified NAT instance has been terminated).
73137 73138 73139 73140 73141 73142 73143 73144 73145 73146 73147 73148 73149 73150 73151 73152 73153 73154 73155 73156 73157 73158 |
# File 'lib/aws-sdk-ec2/types.rb', line 73137 class Route < Struct.new( :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :nat_gateway_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :network_interface_id, :origin, :state, :vpc_peering_connection_id, :core_network_arn, :odb_network_arn, :ip_address) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_id ⇒ String
The ID of a transit gateway.
73137 73138 73139 73140 73141 73142 73143 73144 73145 73146 73147 73148 73149 73150 73151 73152 73153 73154 73155 73156 73157 73158 |
# File 'lib/aws-sdk-ec2/types.rb', line 73137 class Route < Struct.new( :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :nat_gateway_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :network_interface_id, :origin, :state, :vpc_peering_connection_id, :core_network_arn, :odb_network_arn, :ip_address) SENSITIVE = [] include Aws::Structure end |
#vpc_peering_connection_id ⇒ String
The ID of a VPC peering connection.
73137 73138 73139 73140 73141 73142 73143 73144 73145 73146 73147 73148 73149 73150 73151 73152 73153 73154 73155 73156 73157 73158 |
# File 'lib/aws-sdk-ec2/types.rb', line 73137 class Route < Struct.new( :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :nat_gateway_id, :transit_gateway_id, :local_gateway_id, :carrier_gateway_id, :network_interface_id, :origin, :state, :vpc_peering_connection_id, :core_network_arn, :odb_network_arn, :ip_address) SENSITIVE = [] include Aws::Structure end |