Class: Aws::EC2::Types::RouteServerPeer

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes a BGP peer configuration for a route server endpoint.

A route server peer is a session between a route server endpoint and the device deployed in Amazon Web Services (such as a firewall appliance or other network security function running on an EC2 instance). The device must meet these requirements:

  • Have an elastic network interface in the VPC

  • Support BGP (Border Gateway Protocol)

  • Can initiate BGP sessions

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bfd_statusTypes::RouteServerBfdStatus

The current status of the BFD session with this peer.



73522
73523
73524
73525
73526
73527
73528
73529
73530
73531
73532
73533
73534
73535
73536
73537
73538
73539
# File 'lib/aws-sdk-ec2/types.rb', line 73522

class RouteServerPeer < Struct.new(
  :route_server_peer_id,
  :route_server_endpoint_id,
  :route_server_id,
  :vpc_id,
  :subnet_id,
  :state,
  :failure_reason,
  :endpoint_eni_id,
  :endpoint_eni_address,
  :peer_address,
  :bgp_options,
  :bgp_status,
  :bfd_status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#bgp_optionsTypes::RouteServerBgpOptions

The BGP configuration options for this peer, including ASN (Autonomous System Number) and BFD (Bidrectional Forwarding Detection) settings.



73522
73523
73524
73525
73526
73527
73528
73529
73530
73531
73532
73533
73534
73535
73536
73537
73538
73539
# File 'lib/aws-sdk-ec2/types.rb', line 73522

class RouteServerPeer < Struct.new(
  :route_server_peer_id,
  :route_server_endpoint_id,
  :route_server_id,
  :vpc_id,
  :subnet_id,
  :state,
  :failure_reason,
  :endpoint_eni_id,
  :endpoint_eni_address,
  :peer_address,
  :bgp_options,
  :bgp_status,
  :bfd_status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#bgp_statusTypes::RouteServerBgpStatus

The current status of the BGP session with this peer.



73522
73523
73524
73525
73526
73527
73528
73529
73530
73531
73532
73533
73534
73535
73536
73537
73538
73539
# File 'lib/aws-sdk-ec2/types.rb', line 73522

class RouteServerPeer < Struct.new(
  :route_server_peer_id,
  :route_server_endpoint_id,
  :route_server_id,
  :vpc_id,
  :subnet_id,
  :state,
  :failure_reason,
  :endpoint_eni_id,
  :endpoint_eni_address,
  :peer_address,
  :bgp_options,
  :bgp_status,
  :bfd_status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_eni_addressString

The IP address of the Elastic network interface for the route server endpoint.

Returns:

  • (String)


73522
73523
73524
73525
73526
73527
73528
73529
73530
73531
73532
73533
73534
73535
73536
73537
73538
73539
# File 'lib/aws-sdk-ec2/types.rb', line 73522

class RouteServerPeer < Struct.new(
  :route_server_peer_id,
  :route_server_endpoint_id,
  :route_server_id,
  :vpc_id,
  :subnet_id,
  :state,
  :failure_reason,
  :endpoint_eni_id,
  :endpoint_eni_address,
  :peer_address,
  :bgp_options,
  :bgp_status,
  :bfd_status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_eni_idString

The ID of the Elastic network interface for the route server endpoint.

Returns:

  • (String)


73522
73523
73524
73525
73526
73527
73528
73529
73530
73531
73532
73533
73534
73535
73536
73537
73538
73539
# File 'lib/aws-sdk-ec2/types.rb', line 73522

class RouteServerPeer < Struct.new(
  :route_server_peer_id,
  :route_server_endpoint_id,
  :route_server_id,
  :vpc_id,
  :subnet_id,
  :state,
  :failure_reason,
  :endpoint_eni_id,
  :endpoint_eni_address,
  :peer_address,
  :bgp_options,
  :bgp_status,
  :bfd_status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

The reason for any failure in peer creation or operation.

Returns:

  • (String)


73522
73523
73524
73525
73526
73527
73528
73529
73530
73531
73532
73533
73534
73535
73536
73537
73538
73539
# File 'lib/aws-sdk-ec2/types.rb', line 73522

class RouteServerPeer < Struct.new(
  :route_server_peer_id,
  :route_server_endpoint_id,
  :route_server_id,
  :vpc_id,
  :subnet_id,
  :state,
  :failure_reason,
  :endpoint_eni_id,
  :endpoint_eni_address,
  :peer_address,
  :bgp_options,
  :bgp_status,
  :bfd_status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#peer_addressString

The IPv4 address of the peer device.

Returns:

  • (String)


73522
73523
73524
73525
73526
73527
73528
73529
73530
73531
73532
73533
73534
73535
73536
73537
73538
73539
# File 'lib/aws-sdk-ec2/types.rb', line 73522

class RouteServerPeer < Struct.new(
  :route_server_peer_id,
  :route_server_endpoint_id,
  :route_server_id,
  :vpc_id,
  :subnet_id,
  :state,
  :failure_reason,
  :endpoint_eni_id,
  :endpoint_eni_address,
  :peer_address,
  :bgp_options,
  :bgp_status,
  :bfd_status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#route_server_endpoint_idString

The ID of the route server endpoint associated with this peer.

Returns:

  • (String)


73522
73523
73524
73525
73526
73527
73528
73529
73530
73531
73532
73533
73534
73535
73536
73537
73538
73539
# File 'lib/aws-sdk-ec2/types.rb', line 73522

class RouteServerPeer < Struct.new(
  :route_server_peer_id,
  :route_server_endpoint_id,
  :route_server_id,
  :vpc_id,
  :subnet_id,
  :state,
  :failure_reason,
  :endpoint_eni_id,
  :endpoint_eni_address,
  :peer_address,
  :bgp_options,
  :bgp_status,
  :bfd_status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#route_server_idString

The ID of the route server associated with this peer.

Returns:

  • (String)


73522
73523
73524
73525
73526
73527
73528
73529
73530
73531
73532
73533
73534
73535
73536
73537
73538
73539
# File 'lib/aws-sdk-ec2/types.rb', line 73522

class RouteServerPeer < Struct.new(
  :route_server_peer_id,
  :route_server_endpoint_id,
  :route_server_id,
  :vpc_id,
  :subnet_id,
  :state,
  :failure_reason,
  :endpoint_eni_id,
  :endpoint_eni_address,
  :peer_address,
  :bgp_options,
  :bgp_status,
  :bfd_status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#route_server_peer_idString

The unique identifier of the route server peer.

Returns:

  • (String)


73522
73523
73524
73525
73526
73527
73528
73529
73530
73531
73532
73533
73534
73535
73536
73537
73538
73539
# File 'lib/aws-sdk-ec2/types.rb', line 73522

class RouteServerPeer < Struct.new(
  :route_server_peer_id,
  :route_server_endpoint_id,
  :route_server_id,
  :vpc_id,
  :subnet_id,
  :state,
  :failure_reason,
  :endpoint_eni_id,
  :endpoint_eni_address,
  :peer_address,
  :bgp_options,
  :bgp_status,
  :bfd_status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The current state of the route server peer.

Returns:

  • (String)


73522
73523
73524
73525
73526
73527
73528
73529
73530
73531
73532
73533
73534
73535
73536
73537
73538
73539
# File 'lib/aws-sdk-ec2/types.rb', line 73522

class RouteServerPeer < Struct.new(
  :route_server_peer_id,
  :route_server_endpoint_id,
  :route_server_id,
  :vpc_id,
  :subnet_id,
  :state,
  :failure_reason,
  :endpoint_eni_id,
  :endpoint_eni_address,
  :peer_address,
  :bgp_options,
  :bgp_status,
  :bfd_status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idString

The ID of the subnet containing the route server peer.

Returns:

  • (String)


73522
73523
73524
73525
73526
73527
73528
73529
73530
73531
73532
73533
73534
73535
73536
73537
73538
73539
# File 'lib/aws-sdk-ec2/types.rb', line 73522

class RouteServerPeer < Struct.new(
  :route_server_peer_id,
  :route_server_endpoint_id,
  :route_server_id,
  :vpc_id,
  :subnet_id,
  :state,
  :failure_reason,
  :endpoint_eni_id,
  :endpoint_eni_address,
  :peer_address,
  :bgp_options,
  :bgp_status,
  :bfd_status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Any tags assigned to the route server peer.

Returns:



73522
73523
73524
73525
73526
73527
73528
73529
73530
73531
73532
73533
73534
73535
73536
73537
73538
73539
# File 'lib/aws-sdk-ec2/types.rb', line 73522

class RouteServerPeer < Struct.new(
  :route_server_peer_id,
  :route_server_endpoint_id,
  :route_server_id,
  :vpc_id,
  :subnet_id,
  :state,
  :failure_reason,
  :endpoint_eni_id,
  :endpoint_eni_address,
  :peer_address,
  :bgp_options,
  :bgp_status,
  :bfd_status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC containing the route server peer.

Returns:

  • (String)


73522
73523
73524
73525
73526
73527
73528
73529
73530
73531
73532
73533
73534
73535
73536
73537
73538
73539
# File 'lib/aws-sdk-ec2/types.rb', line 73522

class RouteServerPeer < Struct.new(
  :route_server_peer_id,
  :route_server_endpoint_id,
  :route_server_id,
  :vpc_id,
  :subnet_id,
  :state,
  :failure_reason,
  :endpoint_eni_id,
  :endpoint_eni_address,
  :peer_address,
  :bgp_options,
  :bgp_status,
  :bfd_status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end