Class: Aws::EC2::Types::ScheduledInstancesBlockDeviceMapping
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ScheduledInstancesBlockDeviceMapping
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a block device mapping for a Scheduled Instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#device_name ⇒ String
The device name (for example, ‘/dev/sdh` or `xvdh`).
-
#ebs ⇒ Types::ScheduledInstancesEbs
Parameters used to set up EBS volumes automatically when the instance is launched.
-
#no_device ⇒ String
To omit the device from the block device mapping, specify an empty string.
-
#virtual_name ⇒ String
The virtual device name (‘ephemeral`N).
Instance Attribute Details
#device_name ⇒ String
The device name (for example, ‘/dev/sdh` or `xvdh`).
76134 76135 76136 76137 76138 76139 76140 76141 |
# File 'lib/aws-sdk-ec2/types.rb', line 76134 class ScheduledInstancesBlockDeviceMapping < Struct.new( :device_name, :ebs, :no_device, :virtual_name) SENSITIVE = [] include Aws::Structure end |
#ebs ⇒ Types::ScheduledInstancesEbs
Parameters used to set up EBS volumes automatically when the instance is launched.
76134 76135 76136 76137 76138 76139 76140 76141 |
# File 'lib/aws-sdk-ec2/types.rb', line 76134 class ScheduledInstancesBlockDeviceMapping < Struct.new( :device_name, :ebs, :no_device, :virtual_name) SENSITIVE = [] include Aws::Structure end |
#no_device ⇒ String
To omit the device from the block device mapping, specify an empty string.
76134 76135 76136 76137 76138 76139 76140 76141 |
# File 'lib/aws-sdk-ec2/types.rb', line 76134 class ScheduledInstancesBlockDeviceMapping < Struct.new( :device_name, :ebs, :no_device, :virtual_name) SENSITIVE = [] include Aws::Structure end |
#virtual_name ⇒ String
The virtual device name (‘ephemeral`N). Instance store volumes are numbered starting from 0. An instance type with two available instance store volumes can specify mappings for `ephemeral0` and `ephemeral1`. The number of available instance store volumes depends on the instance type. After you connect to the instance, you must mount the volume.
Constraints: For M3 instances, you must specify instance store volumes in the block device mapping for the instance. When you launch an M3 instance, we ignore any instance store volumes specified in the block device mapping for the AMI.
76134 76135 76136 76137 76138 76139 76140 76141 |
# File 'lib/aws-sdk-ec2/types.rb', line 76134 class ScheduledInstancesBlockDeviceMapping < Struct.new( :device_name, :ebs, :no_device, :virtual_name) SENSITIVE = [] include Aws::Structure end |