Class: Aws::EC2::Types::ScheduledInstancesNetworkInterface
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ScheduledInstancesNetworkInterface
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a network interface for a Scheduled Instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#associate_public_ip_address ⇒ Boolean
Indicates whether to assign a public IPv4 address to instances launched in a VPC.
-
#delete_on_termination ⇒ Boolean
Indicates whether to delete the interface when the instance is terminated.
-
#description ⇒ String
The description.
-
#device_index ⇒ Integer
The index of the device for the network interface attachment.
-
#groups ⇒ Array<String>
The IDs of the security groups.
-
#ipv_6_address_count ⇒ Integer
The number of IPv6 addresses to assign to the network interface.
-
#ipv_6_addresses ⇒ Array<Types::ScheduledInstancesIpv6Address>
The specific IPv6 addresses from the subnet range.
-
#network_interface_id ⇒ String
The ID of the network interface.
-
#private_ip_address ⇒ String
The IPv4 address of the network interface within the subnet.
-
#private_ip_address_configs ⇒ Array<Types::ScheduledInstancesPrivateIpAddressConfig>
The private IPv4 addresses.
-
#secondary_private_ip_address_count ⇒ Integer
The number of secondary private IPv4 addresses.
-
#subnet_id ⇒ String
The ID of the subnet.
Instance Attribute Details
#associate_public_ip_address ⇒ Boolean
Indicates whether to assign a public IPv4 address to instances launched in a VPC. The public IPv4 address can only be assigned to a network interface for eth0, and can only be assigned to a new network interface, not an existing one. You cannot specify more than one network interface in the request. If launching into a default subnet, the default value is ‘true`.
Amazon Web Services charges for all public IPv4 addresses, including public IPv4 addresses associated with running instances and Elastic IP addresses. For more information, see the *Public IPv4 Address* tab on the [Amazon VPC pricing page].
74987 74988 74989 74990 74991 74992 74993 74994 74995 74996 74997 74998 74999 75000 75001 75002 |
# File 'lib/aws-sdk-ec2/types.rb', line 74987 class ScheduledInstancesNetworkInterface < Struct.new( :associate_public_ip_address, :delete_on_termination, :description, :device_index, :groups, :ipv_6_address_count, :ipv_6_addresses, :network_interface_id, :private_ip_address, :private_ip_address_configs, :secondary_private_ip_address_count, :subnet_id) SENSITIVE = [] include Aws::Structure end |
#delete_on_termination ⇒ Boolean
Indicates whether to delete the interface when the instance is terminated.
74987 74988 74989 74990 74991 74992 74993 74994 74995 74996 74997 74998 74999 75000 75001 75002 |
# File 'lib/aws-sdk-ec2/types.rb', line 74987 class ScheduledInstancesNetworkInterface < Struct.new( :associate_public_ip_address, :delete_on_termination, :description, :device_index, :groups, :ipv_6_address_count, :ipv_6_addresses, :network_interface_id, :private_ip_address, :private_ip_address_configs, :secondary_private_ip_address_count, :subnet_id) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description.
74987 74988 74989 74990 74991 74992 74993 74994 74995 74996 74997 74998 74999 75000 75001 75002 |
# File 'lib/aws-sdk-ec2/types.rb', line 74987 class ScheduledInstancesNetworkInterface < Struct.new( :associate_public_ip_address, :delete_on_termination, :description, :device_index, :groups, :ipv_6_address_count, :ipv_6_addresses, :network_interface_id, :private_ip_address, :private_ip_address_configs, :secondary_private_ip_address_count, :subnet_id) SENSITIVE = [] include Aws::Structure end |
#device_index ⇒ Integer
The index of the device for the network interface attachment.
74987 74988 74989 74990 74991 74992 74993 74994 74995 74996 74997 74998 74999 75000 75001 75002 |
# File 'lib/aws-sdk-ec2/types.rb', line 74987 class ScheduledInstancesNetworkInterface < Struct.new( :associate_public_ip_address, :delete_on_termination, :description, :device_index, :groups, :ipv_6_address_count, :ipv_6_addresses, :network_interface_id, :private_ip_address, :private_ip_address_configs, :secondary_private_ip_address_count, :subnet_id) SENSITIVE = [] include Aws::Structure end |
#groups ⇒ Array<String>
The IDs of the security groups.
74987 74988 74989 74990 74991 74992 74993 74994 74995 74996 74997 74998 74999 75000 75001 75002 |
# File 'lib/aws-sdk-ec2/types.rb', line 74987 class ScheduledInstancesNetworkInterface < Struct.new( :associate_public_ip_address, :delete_on_termination, :description, :device_index, :groups, :ipv_6_address_count, :ipv_6_addresses, :network_interface_id, :private_ip_address, :private_ip_address_configs, :secondary_private_ip_address_count, :subnet_id) SENSITIVE = [] include Aws::Structure end |
#ipv_6_address_count ⇒ Integer
The number of IPv6 addresses to assign to the network interface. The IPv6 addresses are automatically selected from the subnet range.
74987 74988 74989 74990 74991 74992 74993 74994 74995 74996 74997 74998 74999 75000 75001 75002 |
# File 'lib/aws-sdk-ec2/types.rb', line 74987 class ScheduledInstancesNetworkInterface < Struct.new( :associate_public_ip_address, :delete_on_termination, :description, :device_index, :groups, :ipv_6_address_count, :ipv_6_addresses, :network_interface_id, :private_ip_address, :private_ip_address_configs, :secondary_private_ip_address_count, :subnet_id) SENSITIVE = [] include Aws::Structure end |
#ipv_6_addresses ⇒ Array<Types::ScheduledInstancesIpv6Address>
The specific IPv6 addresses from the subnet range.
74987 74988 74989 74990 74991 74992 74993 74994 74995 74996 74997 74998 74999 75000 75001 75002 |
# File 'lib/aws-sdk-ec2/types.rb', line 74987 class ScheduledInstancesNetworkInterface < Struct.new( :associate_public_ip_address, :delete_on_termination, :description, :device_index, :groups, :ipv_6_address_count, :ipv_6_addresses, :network_interface_id, :private_ip_address, :private_ip_address_configs, :secondary_private_ip_address_count, :subnet_id) SENSITIVE = [] include Aws::Structure end |
#network_interface_id ⇒ String
The ID of the network interface.
74987 74988 74989 74990 74991 74992 74993 74994 74995 74996 74997 74998 74999 75000 75001 75002 |
# File 'lib/aws-sdk-ec2/types.rb', line 74987 class ScheduledInstancesNetworkInterface < Struct.new( :associate_public_ip_address, :delete_on_termination, :description, :device_index, :groups, :ipv_6_address_count, :ipv_6_addresses, :network_interface_id, :private_ip_address, :private_ip_address_configs, :secondary_private_ip_address_count, :subnet_id) SENSITIVE = [] include Aws::Structure end |
#private_ip_address ⇒ String
The IPv4 address of the network interface within the subnet.
74987 74988 74989 74990 74991 74992 74993 74994 74995 74996 74997 74998 74999 75000 75001 75002 |
# File 'lib/aws-sdk-ec2/types.rb', line 74987 class ScheduledInstancesNetworkInterface < Struct.new( :associate_public_ip_address, :delete_on_termination, :description, :device_index, :groups, :ipv_6_address_count, :ipv_6_addresses, :network_interface_id, :private_ip_address, :private_ip_address_configs, :secondary_private_ip_address_count, :subnet_id) SENSITIVE = [] include Aws::Structure end |
#private_ip_address_configs ⇒ Array<Types::ScheduledInstancesPrivateIpAddressConfig>
The private IPv4 addresses.
74987 74988 74989 74990 74991 74992 74993 74994 74995 74996 74997 74998 74999 75000 75001 75002 |
# File 'lib/aws-sdk-ec2/types.rb', line 74987 class ScheduledInstancesNetworkInterface < Struct.new( :associate_public_ip_address, :delete_on_termination, :description, :device_index, :groups, :ipv_6_address_count, :ipv_6_addresses, :network_interface_id, :private_ip_address, :private_ip_address_configs, :secondary_private_ip_address_count, :subnet_id) SENSITIVE = [] include Aws::Structure end |
#secondary_private_ip_address_count ⇒ Integer
The number of secondary private IPv4 addresses.
74987 74988 74989 74990 74991 74992 74993 74994 74995 74996 74997 74998 74999 75000 75001 75002 |
# File 'lib/aws-sdk-ec2/types.rb', line 74987 class ScheduledInstancesNetworkInterface < Struct.new( :associate_public_ip_address, :delete_on_termination, :description, :device_index, :groups, :ipv_6_address_count, :ipv_6_addresses, :network_interface_id, :private_ip_address, :private_ip_address_configs, :secondary_private_ip_address_count, :subnet_id) SENSITIVE = [] include Aws::Structure end |
#subnet_id ⇒ String
The ID of the subnet.
74987 74988 74989 74990 74991 74992 74993 74994 74995 74996 74997 74998 74999 75000 75001 75002 |
# File 'lib/aws-sdk-ec2/types.rb', line 74987 class ScheduledInstancesNetworkInterface < Struct.new( :associate_public_ip_address, :delete_on_termination, :description, :device_index, :groups, :ipv_6_address_count, :ipv_6_addresses, :network_interface_id, :private_ip_address, :private_ip_address_configs, :secondary_private_ip_address_count, :subnet_id) SENSITIVE = [] include Aws::Structure end |