Class: Aws::EC2::Types::SearchLocalGatewayRoutesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::SearchLocalGatewayRoutesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters.
-
#local_gateway_route_table_id ⇒ String
The ID of the local gateway route table.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
77234 77235 77236 77237 77238 77239 77240 77241 77242 |
# File 'lib/aws-sdk-ec2/types.rb', line 77234 class SearchLocalGatewayRoutesRequest < Struct.new( :local_gateway_route_table_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters.
-
‘prefix-list-id` - The ID of the prefix list.
-
‘route-search.exact-match` - The exact match of the specified filter.
-
‘route-search.longest-prefix-match` - The longest prefix that matches the route.
-
‘route-search.subnet-of-match` - The routes with a subnet that match the specified CIDR filter.
-
‘route-search.supernet-of-match` - The routes with a CIDR that encompass the CIDR filter. For example, if you have 10.0.1.0/29 and 10.0.1.0/31 routes in your route table and you specify `supernet-of-match` as 10.0.1.0/30, then the result returns 10.0.1.0/29.
-
‘state` - The state of the route.
-
‘type` - The route type.
77234 77235 77236 77237 77238 77239 77240 77241 77242 |
# File 'lib/aws-sdk-ec2/types.rb', line 77234 class SearchLocalGatewayRoutesRequest < Struct.new( :local_gateway_route_table_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#local_gateway_route_table_id ⇒ String
The ID of the local gateway route table.
77234 77235 77236 77237 77238 77239 77240 77241 77242 |
# File 'lib/aws-sdk-ec2/types.rb', line 77234 class SearchLocalGatewayRoutesRequest < Struct.new( :local_gateway_route_table_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.
77234 77235 77236 77237 77238 77239 77240 77241 77242 |
# File 'lib/aws-sdk-ec2/types.rb', line 77234 class SearchLocalGatewayRoutesRequest < Struct.new( :local_gateway_route_table_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
77234 77235 77236 77237 77238 77239 77240 77241 77242 |
# File 'lib/aws-sdk-ec2/types.rb', line 77234 class SearchLocalGatewayRoutesRequest < Struct.new( :local_gateway_route_table_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |