Class: Aws::EC2::Types::SearchTransitGatewayMulticastGroupsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::SearchTransitGatewayMulticastGroupsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filters ⇒ Array<Types::Filter>
One or more filters.
-
#max_results ⇒ Integer
The maximum number of results to return with a single call.
-
#next_token ⇒ String
The token for the next page of results.
-
#transit_gateway_multicast_domain_id ⇒ String
The ID of the transit gateway multicast domain.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
77420 77421 77422 77423 77424 77425 77426 77427 77428 |
# File 'lib/aws-sdk-ec2/types.rb', line 77420 class SearchTransitGatewayMulticastGroupsRequest < Struct.new( :transit_gateway_multicast_domain_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters. The possible values are:
-
‘group-ip-address` - The IP address of the transit gateway multicast group.
-
‘is-group-member` - The resource is a group member. Valid values are `true` | `false`.
-
‘is-group-source` - The resource is a group source. Valid values are `true` | `false`.
-
‘member-type` - The member type. Valid values are `igmp` | `static`.
-
‘resource-id` - The ID of the resource.
-
‘resource-type` - The type of resource. Valid values are `vpc` | `vpn` | `direct-connect-gateway` | `tgw-peering`.
-
‘source-type` - The source type. Valid values are `igmp` | `static`.
-
‘subnet-id` - The ID of the subnet.
-
‘transit-gateway-attachment-id` - The id of the transit gateway attachment.
77420 77421 77422 77423 77424 77425 77426 77427 77428 |
# File 'lib/aws-sdk-ec2/types.rb', line 77420 class SearchTransitGatewayMulticastGroupsRequest < Struct.new( :transit_gateway_multicast_domain_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.
77420 77421 77422 77423 77424 77425 77426 77427 77428 |
# File 'lib/aws-sdk-ec2/types.rb', line 77420 class SearchTransitGatewayMulticastGroupsRequest < Struct.new( :transit_gateway_multicast_domain_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
77420 77421 77422 77423 77424 77425 77426 77427 77428 |
# File 'lib/aws-sdk-ec2/types.rb', line 77420 class SearchTransitGatewayMulticastGroupsRequest < Struct.new( :transit_gateway_multicast_domain_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_multicast_domain_id ⇒ String
The ID of the transit gateway multicast domain.
77420 77421 77422 77423 77424 77425 77426 77427 77428 |
# File 'lib/aws-sdk-ec2/types.rb', line 77420 class SearchTransitGatewayMulticastGroupsRequest < Struct.new( :transit_gateway_multicast_domain_id, :filters, :max_results, :next_token, :dry_run) SENSITIVE = [] include Aws::Structure end |