Class: Aws::EC2::Types::SearchTransitGatewayRoutesResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::SearchTransitGatewayRoutesResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_routes_available ⇒ Boolean
Indicates whether there are additional routes available.
-
#next_token ⇒ String
The token to use to retrieve the next page of results.
-
#routes ⇒ Array<Types::TransitGatewayRoute>
Information about the routes.
Instance Attribute Details
#additional_routes_available ⇒ Boolean
Indicates whether there are additional routes available.
79612 79613 79614 79615 79616 79617 79618 |
# File 'lib/aws-sdk-ec2/types.rb', line 79612 class SearchTransitGatewayRoutesResult < Struct.new( :routes, :additional_routes_available, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to retrieve the next page of results. This value is
null when there are no more results to return.
79612 79613 79614 79615 79616 79617 79618 |
# File 'lib/aws-sdk-ec2/types.rb', line 79612 class SearchTransitGatewayRoutesResult < Struct.new( :routes, :additional_routes_available, :next_token) SENSITIVE = [] include Aws::Structure end |
#routes ⇒ Array<Types::TransitGatewayRoute>
Information about the routes.
79612 79613 79614 79615 79616 79617 79618 |
# File 'lib/aws-sdk-ec2/types.rb', line 79612 class SearchTransitGatewayRoutesResult < Struct.new( :routes, :additional_routes_available, :next_token) SENSITIVE = [] include Aws::Structure end |