Class: Aws::EC2::Types::SearchTransitGatewayRoutesResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::SearchTransitGatewayRoutesResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_routes_available ⇒ Boolean
Indicates whether there are additional routes available.
-
#next_token ⇒ String
The token to use to retrieve the next page of results.
-
#routes ⇒ Array<Types::TransitGatewayRoute>
Information about the routes.
Instance Attribute Details
#additional_routes_available ⇒ Boolean
Indicates whether there are additional routes available.
78068 78069 78070 78071 78072 78073 78074 |
# File 'lib/aws-sdk-ec2/types.rb', line 78068 class SearchTransitGatewayRoutesResult < Struct.new( :routes, :additional_routes_available, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to retrieve the next page of results. This value is
null when there are no more results to return.
78068 78069 78070 78071 78072 78073 78074 |
# File 'lib/aws-sdk-ec2/types.rb', line 78068 class SearchTransitGatewayRoutesResult < Struct.new( :routes, :additional_routes_available, :next_token) SENSITIVE = [] include Aws::Structure end |
#routes ⇒ Array<Types::TransitGatewayRoute>
Information about the routes.
78068 78069 78070 78071 78072 78073 78074 |
# File 'lib/aws-sdk-ec2/types.rb', line 78068 class SearchTransitGatewayRoutesResult < Struct.new( :routes, :additional_routes_available, :next_token) SENSITIVE = [] include Aws::Structure end |