Class: Aws::EC2::Types::SearchTransitGatewayRoutesResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::SearchTransitGatewayRoutesResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_routes_available ⇒ Boolean
Indicates whether there are additional routes available.
-
#next_token ⇒ String
The token to use to retrieve the next page of results.
-
#routes ⇒ Array<Types::TransitGatewayRoute>
Information about the routes.
Instance Attribute Details
#additional_routes_available ⇒ Boolean
Indicates whether there are additional routes available.
77884 77885 77886 77887 77888 77889 77890 |
# File 'lib/aws-sdk-ec2/types.rb', line 77884 class SearchTransitGatewayRoutesResult < Struct.new( :routes, :additional_routes_available, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to retrieve the next page of results. This value is
null when there are no more results to return.
77884 77885 77886 77887 77888 77889 77890 |
# File 'lib/aws-sdk-ec2/types.rb', line 77884 class SearchTransitGatewayRoutesResult < Struct.new( :routes, :additional_routes_available, :next_token) SENSITIVE = [] include Aws::Structure end |
#routes ⇒ Array<Types::TransitGatewayRoute>
Information about the routes.
77884 77885 77886 77887 77888 77889 77890 |
# File 'lib/aws-sdk-ec2/types.rb', line 77884 class SearchTransitGatewayRoutesResult < Struct.new( :routes, :additional_routes_available, :next_token) SENSITIVE = [] include Aws::Structure end |