Class: Aws::EC2::Types::SecondaryInterface
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::SecondaryInterface
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a secondary interface.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attachment ⇒ Types::SecondaryInterfaceAttachment
The attachment information for the secondary interface.
-
#availability_zone ⇒ String
The Availability Zone of the secondary interface.
-
#availability_zone_id ⇒ String
The ID of the Availability Zone of the secondary interface.
-
#mac_address ⇒ String
The MAC address of the secondary interface.
-
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the secondary interface.
-
#private_ipv_4_addresses ⇒ Array<Types::SecondaryInterfaceIpv4Address>
The private IPv4 addresses associated with the secondary interface.
-
#secondary_interface_arn ⇒ String
The Amazon Resource Name (ARN) of the secondary interface.
-
#secondary_interface_id ⇒ String
The ID of the secondary interface.
-
#secondary_interface_type ⇒ String
The type of secondary interface.
-
#secondary_network_id ⇒ String
The ID of the secondary network.
-
#secondary_network_type ⇒ String
The type of the secondary network.
-
#secondary_subnet_id ⇒ String
The ID of the secondary subnet.
-
#source_dest_check ⇒ Boolean
Indicates whether source/destination checking is enabled.
-
#status ⇒ String
The status of the secondary interface.
-
#tags ⇒ Array<Types::Tag>
The tags assigned to the secondary interface.
Instance Attribute Details
#attachment ⇒ Types::SecondaryInterfaceAttachment
The attachment information for the secondary interface.
76920 76921 76922 76923 76924 76925 76926 76927 76928 76929 76930 76931 76932 76933 76934 76935 76936 76937 76938 |
# File 'lib/aws-sdk-ec2/types.rb', line 76920 class SecondaryInterface < Struct.new( :availability_zone, :availability_zone_id, :attachment, :mac_address, :owner_id, :private_ipv_4_addresses, :secondary_interface_id, :secondary_interface_arn, :secondary_interface_type, :secondary_subnet_id, :secondary_network_id, :secondary_network_type, :source_dest_check, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#availability_zone ⇒ String
The Availability Zone of the secondary interface.
76920 76921 76922 76923 76924 76925 76926 76927 76928 76929 76930 76931 76932 76933 76934 76935 76936 76937 76938 |
# File 'lib/aws-sdk-ec2/types.rb', line 76920 class SecondaryInterface < Struct.new( :availability_zone, :availability_zone_id, :attachment, :mac_address, :owner_id, :private_ipv_4_addresses, :secondary_interface_id, :secondary_interface_arn, :secondary_interface_type, :secondary_subnet_id, :secondary_network_id, :secondary_network_type, :source_dest_check, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
The ID of the Availability Zone of the secondary interface.
76920 76921 76922 76923 76924 76925 76926 76927 76928 76929 76930 76931 76932 76933 76934 76935 76936 76937 76938 |
# File 'lib/aws-sdk-ec2/types.rb', line 76920 class SecondaryInterface < Struct.new( :availability_zone, :availability_zone_id, :attachment, :mac_address, :owner_id, :private_ipv_4_addresses, :secondary_interface_id, :secondary_interface_arn, :secondary_interface_type, :secondary_subnet_id, :secondary_network_id, :secondary_network_type, :source_dest_check, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#mac_address ⇒ String
The MAC address of the secondary interface.
76920 76921 76922 76923 76924 76925 76926 76927 76928 76929 76930 76931 76932 76933 76934 76935 76936 76937 76938 |
# File 'lib/aws-sdk-ec2/types.rb', line 76920 class SecondaryInterface < Struct.new( :availability_zone, :availability_zone_id, :attachment, :mac_address, :owner_id, :private_ipv_4_addresses, :secondary_interface_id, :secondary_interface_arn, :secondary_interface_type, :secondary_subnet_id, :secondary_network_id, :secondary_network_type, :source_dest_check, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the secondary interface.
76920 76921 76922 76923 76924 76925 76926 76927 76928 76929 76930 76931 76932 76933 76934 76935 76936 76937 76938 |
# File 'lib/aws-sdk-ec2/types.rb', line 76920 class SecondaryInterface < Struct.new( :availability_zone, :availability_zone_id, :attachment, :mac_address, :owner_id, :private_ipv_4_addresses, :secondary_interface_id, :secondary_interface_arn, :secondary_interface_type, :secondary_subnet_id, :secondary_network_id, :secondary_network_type, :source_dest_check, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#private_ipv_4_addresses ⇒ Array<Types::SecondaryInterfaceIpv4Address>
The private IPv4 addresses associated with the secondary interface.
76920 76921 76922 76923 76924 76925 76926 76927 76928 76929 76930 76931 76932 76933 76934 76935 76936 76937 76938 |
# File 'lib/aws-sdk-ec2/types.rb', line 76920 class SecondaryInterface < Struct.new( :availability_zone, :availability_zone_id, :attachment, :mac_address, :owner_id, :private_ipv_4_addresses, :secondary_interface_id, :secondary_interface_arn, :secondary_interface_type, :secondary_subnet_id, :secondary_network_id, :secondary_network_type, :source_dest_check, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#secondary_interface_arn ⇒ String
The Amazon Resource Name (ARN) of the secondary interface.
76920 76921 76922 76923 76924 76925 76926 76927 76928 76929 76930 76931 76932 76933 76934 76935 76936 76937 76938 |
# File 'lib/aws-sdk-ec2/types.rb', line 76920 class SecondaryInterface < Struct.new( :availability_zone, :availability_zone_id, :attachment, :mac_address, :owner_id, :private_ipv_4_addresses, :secondary_interface_id, :secondary_interface_arn, :secondary_interface_type, :secondary_subnet_id, :secondary_network_id, :secondary_network_type, :source_dest_check, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#secondary_interface_id ⇒ String
The ID of the secondary interface.
76920 76921 76922 76923 76924 76925 76926 76927 76928 76929 76930 76931 76932 76933 76934 76935 76936 76937 76938 |
# File 'lib/aws-sdk-ec2/types.rb', line 76920 class SecondaryInterface < Struct.new( :availability_zone, :availability_zone_id, :attachment, :mac_address, :owner_id, :private_ipv_4_addresses, :secondary_interface_id, :secondary_interface_arn, :secondary_interface_type, :secondary_subnet_id, :secondary_network_id, :secondary_network_type, :source_dest_check, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#secondary_interface_type ⇒ String
The type of secondary interface.
76920 76921 76922 76923 76924 76925 76926 76927 76928 76929 76930 76931 76932 76933 76934 76935 76936 76937 76938 |
# File 'lib/aws-sdk-ec2/types.rb', line 76920 class SecondaryInterface < Struct.new( :availability_zone, :availability_zone_id, :attachment, :mac_address, :owner_id, :private_ipv_4_addresses, :secondary_interface_id, :secondary_interface_arn, :secondary_interface_type, :secondary_subnet_id, :secondary_network_id, :secondary_network_type, :source_dest_check, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#secondary_network_id ⇒ String
The ID of the secondary network.
76920 76921 76922 76923 76924 76925 76926 76927 76928 76929 76930 76931 76932 76933 76934 76935 76936 76937 76938 |
# File 'lib/aws-sdk-ec2/types.rb', line 76920 class SecondaryInterface < Struct.new( :availability_zone, :availability_zone_id, :attachment, :mac_address, :owner_id, :private_ipv_4_addresses, :secondary_interface_id, :secondary_interface_arn, :secondary_interface_type, :secondary_subnet_id, :secondary_network_id, :secondary_network_type, :source_dest_check, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#secondary_network_type ⇒ String
The type of the secondary network.
76920 76921 76922 76923 76924 76925 76926 76927 76928 76929 76930 76931 76932 76933 76934 76935 76936 76937 76938 |
# File 'lib/aws-sdk-ec2/types.rb', line 76920 class SecondaryInterface < Struct.new( :availability_zone, :availability_zone_id, :attachment, :mac_address, :owner_id, :private_ipv_4_addresses, :secondary_interface_id, :secondary_interface_arn, :secondary_interface_type, :secondary_subnet_id, :secondary_network_id, :secondary_network_type, :source_dest_check, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#secondary_subnet_id ⇒ String
The ID of the secondary subnet.
76920 76921 76922 76923 76924 76925 76926 76927 76928 76929 76930 76931 76932 76933 76934 76935 76936 76937 76938 |
# File 'lib/aws-sdk-ec2/types.rb', line 76920 class SecondaryInterface < Struct.new( :availability_zone, :availability_zone_id, :attachment, :mac_address, :owner_id, :private_ipv_4_addresses, :secondary_interface_id, :secondary_interface_arn, :secondary_interface_type, :secondary_subnet_id, :secondary_network_id, :secondary_network_type, :source_dest_check, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#source_dest_check ⇒ Boolean
Indicates whether source/destination checking is enabled.
76920 76921 76922 76923 76924 76925 76926 76927 76928 76929 76930 76931 76932 76933 76934 76935 76936 76937 76938 |
# File 'lib/aws-sdk-ec2/types.rb', line 76920 class SecondaryInterface < Struct.new( :availability_zone, :availability_zone_id, :attachment, :mac_address, :owner_id, :private_ipv_4_addresses, :secondary_interface_id, :secondary_interface_arn, :secondary_interface_type, :secondary_subnet_id, :secondary_network_id, :secondary_network_type, :source_dest_check, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the secondary interface.
76920 76921 76922 76923 76924 76925 76926 76927 76928 76929 76930 76931 76932 76933 76934 76935 76936 76937 76938 |
# File 'lib/aws-sdk-ec2/types.rb', line 76920 class SecondaryInterface < Struct.new( :availability_zone, :availability_zone_id, :attachment, :mac_address, :owner_id, :private_ipv_4_addresses, :secondary_interface_id, :secondary_interface_arn, :secondary_interface_type, :secondary_subnet_id, :secondary_network_id, :secondary_network_type, :source_dest_check, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags assigned to the secondary interface.
76920 76921 76922 76923 76924 76925 76926 76927 76928 76929 76930 76931 76932 76933 76934 76935 76936 76937 76938 |
# File 'lib/aws-sdk-ec2/types.rb', line 76920 class SecondaryInterface < Struct.new( :availability_zone, :availability_zone_id, :attachment, :mac_address, :owner_id, :private_ipv_4_addresses, :secondary_interface_id, :secondary_interface_arn, :secondary_interface_type, :secondary_subnet_id, :secondary_network_id, :secondary_network_type, :source_dest_check, :status, :tags) SENSITIVE = [] include Aws::Structure end |