Class: Aws::EC2::Types::SecondaryInterfaceAttachment

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes the attachment of a secondary interface to an instance.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attach_timeTime

The timestamp when the attachment was created.

Returns:

  • (Time)


77412
77413
77414
77415
77416
77417
77418
77419
77420
77421
77422
77423
# File 'lib/aws-sdk-ec2/types.rb', line 77412

class SecondaryInterfaceAttachment < Struct.new(
  :attachment_id,
  :attach_time,
  :delete_on_termination,
  :device_index,
  :instance_id,
  :instance_owner_id,
  :network_card_index,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#attachment_idString

The ID of the attachment.

Returns:

  • (String)


77412
77413
77414
77415
77416
77417
77418
77419
77420
77421
77422
77423
# File 'lib/aws-sdk-ec2/types.rb', line 77412

class SecondaryInterfaceAttachment < Struct.new(
  :attachment_id,
  :attach_time,
  :delete_on_termination,
  :device_index,
  :instance_id,
  :instance_owner_id,
  :network_card_index,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#delete_on_terminationBoolean

Indicates whether the secondary interface is deleted when the instance is terminated.

The only supported value for this field is ‘true`.

Returns:

  • (Boolean)


77412
77413
77414
77415
77416
77417
77418
77419
77420
77421
77422
77423
# File 'lib/aws-sdk-ec2/types.rb', line 77412

class SecondaryInterfaceAttachment < Struct.new(
  :attachment_id,
  :attach_time,
  :delete_on_termination,
  :device_index,
  :instance_id,
  :instance_owner_id,
  :network_card_index,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#device_indexInteger

The device index of the secondary interface.

Returns:

  • (Integer)


77412
77413
77414
77415
77416
77417
77418
77419
77420
77421
77422
77423
# File 'lib/aws-sdk-ec2/types.rb', line 77412

class SecondaryInterfaceAttachment < Struct.new(
  :attachment_id,
  :attach_time,
  :delete_on_termination,
  :device_index,
  :instance_id,
  :instance_owner_id,
  :network_card_index,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The ID of the instance to which the secondary interface is attached.

Returns:

  • (String)


77412
77413
77414
77415
77416
77417
77418
77419
77420
77421
77422
77423
# File 'lib/aws-sdk-ec2/types.rb', line 77412

class SecondaryInterfaceAttachment < Struct.new(
  :attachment_id,
  :attach_time,
  :delete_on_termination,
  :device_index,
  :instance_id,
  :instance_owner_id,
  :network_card_index,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#instance_owner_idString

The Amazon Web Services account ID of the owner of the instance.

Returns:

  • (String)


77412
77413
77414
77415
77416
77417
77418
77419
77420
77421
77422
77423
# File 'lib/aws-sdk-ec2/types.rb', line 77412

class SecondaryInterfaceAttachment < Struct.new(
  :attachment_id,
  :attach_time,
  :delete_on_termination,
  :device_index,
  :instance_id,
  :instance_owner_id,
  :network_card_index,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#network_card_indexInteger

The index of the network card.

Returns:

  • (Integer)


77412
77413
77414
77415
77416
77417
77418
77419
77420
77421
77422
77423
# File 'lib/aws-sdk-ec2/types.rb', line 77412

class SecondaryInterfaceAttachment < Struct.new(
  :attachment_id,
  :attach_time,
  :delete_on_termination,
  :device_index,
  :instance_id,
  :instance_owner_id,
  :network_card_index,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The attachment state.

Returns:

  • (String)


77412
77413
77414
77415
77416
77417
77418
77419
77420
77421
77422
77423
# File 'lib/aws-sdk-ec2/types.rb', line 77412

class SecondaryInterfaceAttachment < Struct.new(
  :attachment_id,
  :attach_time,
  :delete_on_termination,
  :device_index,
  :instance_id,
  :instance_owner_id,
  :network_card_index,
  :status)
  SENSITIVE = []
  include Aws::Structure
end