Class: Aws::EC2::Types::SecondaryInterfaceAttachment
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::SecondaryInterfaceAttachment
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the attachment of a secondary interface to an instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attach_time ⇒ Time
The timestamp when the attachment was created.
-
#attachment_id ⇒ String
The ID of the attachment.
-
#delete_on_termination ⇒ Boolean
Indicates whether the secondary interface is deleted when the instance is terminated.
-
#device_index ⇒ Integer
The device index of the secondary interface.
-
#instance_id ⇒ String
The ID of the instance to which the secondary interface is attached.
-
#instance_owner_id ⇒ String
The Amazon Web Services account ID of the owner of the instance.
-
#network_card_index ⇒ Integer
The index of the network card.
-
#status ⇒ String
The attachment state.
Instance Attribute Details
#attach_time ⇒ Time
The timestamp when the attachment was created.
76820 76821 76822 76823 76824 76825 76826 76827 76828 76829 76830 76831 |
# File 'lib/aws-sdk-ec2/types.rb', line 76820 class SecondaryInterfaceAttachment < Struct.new( :attachment_id, :attach_time, :delete_on_termination, :device_index, :instance_id, :instance_owner_id, :network_card_index, :status) SENSITIVE = [] include Aws::Structure end |
#attachment_id ⇒ String
The ID of the attachment.
76820 76821 76822 76823 76824 76825 76826 76827 76828 76829 76830 76831 |
# File 'lib/aws-sdk-ec2/types.rb', line 76820 class SecondaryInterfaceAttachment < Struct.new( :attachment_id, :attach_time, :delete_on_termination, :device_index, :instance_id, :instance_owner_id, :network_card_index, :status) SENSITIVE = [] include Aws::Structure end |
#delete_on_termination ⇒ Boolean
Indicates whether the secondary interface is deleted when the instance is terminated.
The only supported value for this field is ‘true`.
76820 76821 76822 76823 76824 76825 76826 76827 76828 76829 76830 76831 |
# File 'lib/aws-sdk-ec2/types.rb', line 76820 class SecondaryInterfaceAttachment < Struct.new( :attachment_id, :attach_time, :delete_on_termination, :device_index, :instance_id, :instance_owner_id, :network_card_index, :status) SENSITIVE = [] include Aws::Structure end |
#device_index ⇒ Integer
The device index of the secondary interface.
76820 76821 76822 76823 76824 76825 76826 76827 76828 76829 76830 76831 |
# File 'lib/aws-sdk-ec2/types.rb', line 76820 class SecondaryInterfaceAttachment < Struct.new( :attachment_id, :attach_time, :delete_on_termination, :device_index, :instance_id, :instance_owner_id, :network_card_index, :status) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the instance to which the secondary interface is attached.
76820 76821 76822 76823 76824 76825 76826 76827 76828 76829 76830 76831 |
# File 'lib/aws-sdk-ec2/types.rb', line 76820 class SecondaryInterfaceAttachment < Struct.new( :attachment_id, :attach_time, :delete_on_termination, :device_index, :instance_id, :instance_owner_id, :network_card_index, :status) SENSITIVE = [] include Aws::Structure end |
#instance_owner_id ⇒ String
The Amazon Web Services account ID of the owner of the instance.
76820 76821 76822 76823 76824 76825 76826 76827 76828 76829 76830 76831 |
# File 'lib/aws-sdk-ec2/types.rb', line 76820 class SecondaryInterfaceAttachment < Struct.new( :attachment_id, :attach_time, :delete_on_termination, :device_index, :instance_id, :instance_owner_id, :network_card_index, :status) SENSITIVE = [] include Aws::Structure end |
#network_card_index ⇒ Integer
The index of the network card.
76820 76821 76822 76823 76824 76825 76826 76827 76828 76829 76830 76831 |
# File 'lib/aws-sdk-ec2/types.rb', line 76820 class SecondaryInterfaceAttachment < Struct.new( :attachment_id, :attach_time, :delete_on_termination, :device_index, :instance_id, :instance_owner_id, :network_card_index, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The attachment state.
76820 76821 76822 76823 76824 76825 76826 76827 76828 76829 76830 76831 |
# File 'lib/aws-sdk-ec2/types.rb', line 76820 class SecondaryInterfaceAttachment < Struct.new( :attachment_id, :attach_time, :delete_on_termination, :device_index, :instance_id, :instance_owner_id, :network_card_index, :status) SENSITIVE = [] include Aws::Structure end |