Class: Aws::EC2::Types::SecondaryNetwork
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::SecondaryNetwork
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a secondary network.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ipv_4_cidr_block_associations ⇒ Array<Types::SecondaryNetworkIpv4CidrBlockAssociation>
Information about the IPv4 CIDR blocks associated with the secondary network.
-
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the secondary network.
-
#secondary_network_arn ⇒ String
The Amazon Resource Name (ARN) of the secondary network.
-
#secondary_network_id ⇒ String
The ID of the secondary network.
-
#state ⇒ String
The state of the secondary network.
-
#state_reason ⇒ String
The reason for the current state of the secondary network.
-
#tags ⇒ Array<Types::Tag>
The tags assigned to the secondary network.
-
#type ⇒ String
The type of the secondary network.
Instance Attribute Details
#ipv_4_cidr_block_associations ⇒ Array<Types::SecondaryNetworkIpv4CidrBlockAssociation>
Information about the IPv4 CIDR blocks associated with the secondary network.
76516 76517 76518 76519 76520 76521 76522 76523 76524 76525 76526 76527 |
# File 'lib/aws-sdk-ec2/types.rb', line 76516 class SecondaryNetwork < Struct.new( :secondary_network_id, :secondary_network_arn, :owner_id, :type, :state, :state_reason, :ipv_4_cidr_block_associations, :tags) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the secondary network.
76516 76517 76518 76519 76520 76521 76522 76523 76524 76525 76526 76527 |
# File 'lib/aws-sdk-ec2/types.rb', line 76516 class SecondaryNetwork < Struct.new( :secondary_network_id, :secondary_network_arn, :owner_id, :type, :state, :state_reason, :ipv_4_cidr_block_associations, :tags) SENSITIVE = [] include Aws::Structure end |
#secondary_network_arn ⇒ String
The Amazon Resource Name (ARN) of the secondary network.
76516 76517 76518 76519 76520 76521 76522 76523 76524 76525 76526 76527 |
# File 'lib/aws-sdk-ec2/types.rb', line 76516 class SecondaryNetwork < Struct.new( :secondary_network_id, :secondary_network_arn, :owner_id, :type, :state, :state_reason, :ipv_4_cidr_block_associations, :tags) SENSITIVE = [] include Aws::Structure end |
#secondary_network_id ⇒ String
The ID of the secondary network.
76516 76517 76518 76519 76520 76521 76522 76523 76524 76525 76526 76527 |
# File 'lib/aws-sdk-ec2/types.rb', line 76516 class SecondaryNetwork < Struct.new( :secondary_network_id, :secondary_network_arn, :owner_id, :type, :state, :state_reason, :ipv_4_cidr_block_associations, :tags) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the secondary network.
76516 76517 76518 76519 76520 76521 76522 76523 76524 76525 76526 76527 |
# File 'lib/aws-sdk-ec2/types.rb', line 76516 class SecondaryNetwork < Struct.new( :secondary_network_id, :secondary_network_arn, :owner_id, :type, :state, :state_reason, :ipv_4_cidr_block_associations, :tags) SENSITIVE = [] include Aws::Structure end |
#state_reason ⇒ String
The reason for the current state of the secondary network.
76516 76517 76518 76519 76520 76521 76522 76523 76524 76525 76526 76527 |
# File 'lib/aws-sdk-ec2/types.rb', line 76516 class SecondaryNetwork < Struct.new( :secondary_network_id, :secondary_network_arn, :owner_id, :type, :state, :state_reason, :ipv_4_cidr_block_associations, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags assigned to the secondary network.
76516 76517 76518 76519 76520 76521 76522 76523 76524 76525 76526 76527 |
# File 'lib/aws-sdk-ec2/types.rb', line 76516 class SecondaryNetwork < Struct.new( :secondary_network_id, :secondary_network_arn, :owner_id, :type, :state, :state_reason, :ipv_4_cidr_block_associations, :tags) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the secondary network.
76516 76517 76518 76519 76520 76521 76522 76523 76524 76525 76526 76527 |
# File 'lib/aws-sdk-ec2/types.rb', line 76516 class SecondaryNetwork < Struct.new( :secondary_network_id, :secondary_network_arn, :owner_id, :type, :state, :state_reason, :ipv_4_cidr_block_associations, :tags) SENSITIVE = [] include Aws::Structure end |