Class: Aws::EC2::Types::SecurityGroupReference
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::SecurityGroupReference
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a VPC with a security group that references your security group.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#group_id ⇒ String
The ID of your security group.
-
#referencing_vpc_id ⇒ String
The ID of the VPC with the referencing security group.
-
#transit_gateway_id ⇒ String
The ID of the transit gateway (if applicable).
-
#vpc_peering_connection_id ⇒ String
The ID of the VPC peering connection (if applicable).
Instance Attribute Details
#group_id ⇒ String
The ID of your security group.
80128 80129 80130 80131 80132 80133 80134 80135 |
# File 'lib/aws-sdk-ec2/types.rb', line 80128 class SecurityGroupReference < Struct.new( :group_id, :referencing_vpc_id, :vpc_peering_connection_id, :transit_gateway_id) SENSITIVE = [] include Aws::Structure end |
#referencing_vpc_id ⇒ String
The ID of the VPC with the referencing security group.
80128 80129 80130 80131 80132 80133 80134 80135 |
# File 'lib/aws-sdk-ec2/types.rb', line 80128 class SecurityGroupReference < Struct.new( :group_id, :referencing_vpc_id, :vpc_peering_connection_id, :transit_gateway_id) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_id ⇒ String
The ID of the transit gateway (if applicable).
80128 80129 80130 80131 80132 80133 80134 80135 |
# File 'lib/aws-sdk-ec2/types.rb', line 80128 class SecurityGroupReference < Struct.new( :group_id, :referencing_vpc_id, :vpc_peering_connection_id, :transit_gateway_id) SENSITIVE = [] include Aws::Structure end |
#vpc_peering_connection_id ⇒ String
The ID of the VPC peering connection (if applicable). For more information about security group referencing for peering connections, see Update your security groups to reference peer security groups in the VPC Peering Guide.
80128 80129 80130 80131 80132 80133 80134 80135 |
# File 'lib/aws-sdk-ec2/types.rb', line 80128 class SecurityGroupReference < Struct.new( :group_id, :referencing_vpc_id, :vpc_peering_connection_id, :transit_gateway_id) SENSITIVE = [] include Aws::Structure end |