Class: Aws::EC2::Types::SecurityGroupRule
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::SecurityGroupRule
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a security group rule.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cidr_ipv_4 ⇒ String
The IPv4 CIDR range.
-
#cidr_ipv_6 ⇒ String
The IPv6 CIDR range.
-
#description ⇒ String
The security group rule description.
-
#from_port ⇒ Integer
If the protocol is TCP or UDP, this is the start of the port range.
-
#group_id ⇒ String
The ID of the security group.
-
#group_owner_id ⇒ String
The ID of the Amazon Web Services account that owns the security group.
-
#ip_protocol ⇒ String
The IP protocol name (
tcp,udp,icmp,icmpv6) or number (see [Protocol Numbers][1]). -
#is_egress ⇒ Boolean
Indicates whether the security group rule is an outbound rule.
-
#prefix_list_id ⇒ String
The ID of the prefix list.
-
#referenced_group_info ⇒ Types::ReferencedSecurityGroup
Describes the security group that is referenced in the rule.
-
#security_group_rule_arn ⇒ String
The ARN of the security group rule.
-
#security_group_rule_id ⇒ String
The ID of the security group rule.
-
#tags ⇒ Array<Types::Tag>
The tags applied to the security group rule.
-
#to_port ⇒ Integer
If the protocol is TCP or UDP, this is the end of the port range.
Instance Attribute Details
#cidr_ipv_4 ⇒ String
The IPv4 CIDR range.
78529 78530 78531 78532 78533 78534 78535 78536 78537 78538 78539 78540 78541 78542 78543 78544 78545 78546 |
# File 'lib/aws-sdk-ec2/types.rb', line 78529 class SecurityGroupRule < Struct.new( :security_group_rule_id, :group_id, :group_owner_id, :is_egress, :ip_protocol, :from_port, :to_port, :cidr_ipv_4, :cidr_ipv_6, :prefix_list_id, :referenced_group_info, :description, :tags, :security_group_rule_arn) SENSITIVE = [] include Aws::Structure end |
#cidr_ipv_6 ⇒ String
The IPv6 CIDR range.
78529 78530 78531 78532 78533 78534 78535 78536 78537 78538 78539 78540 78541 78542 78543 78544 78545 78546 |
# File 'lib/aws-sdk-ec2/types.rb', line 78529 class SecurityGroupRule < Struct.new( :security_group_rule_id, :group_id, :group_owner_id, :is_egress, :ip_protocol, :from_port, :to_port, :cidr_ipv_4, :cidr_ipv_6, :prefix_list_id, :referenced_group_info, :description, :tags, :security_group_rule_arn) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The security group rule description.
78529 78530 78531 78532 78533 78534 78535 78536 78537 78538 78539 78540 78541 78542 78543 78544 78545 78546 |
# File 'lib/aws-sdk-ec2/types.rb', line 78529 class SecurityGroupRule < Struct.new( :security_group_rule_id, :group_id, :group_owner_id, :is_egress, :ip_protocol, :from_port, :to_port, :cidr_ipv_4, :cidr_ipv_6, :prefix_list_id, :referenced_group_info, :description, :tags, :security_group_rule_arn) SENSITIVE = [] include Aws::Structure end |
#from_port ⇒ Integer
If the protocol is TCP or UDP, this is the start of the port range. If the protocol is ICMP or ICMPv6, this is the ICMP type or -1 (all ICMP types).
78529 78530 78531 78532 78533 78534 78535 78536 78537 78538 78539 78540 78541 78542 78543 78544 78545 78546 |
# File 'lib/aws-sdk-ec2/types.rb', line 78529 class SecurityGroupRule < Struct.new( :security_group_rule_id, :group_id, :group_owner_id, :is_egress, :ip_protocol, :from_port, :to_port, :cidr_ipv_4, :cidr_ipv_6, :prefix_list_id, :referenced_group_info, :description, :tags, :security_group_rule_arn) SENSITIVE = [] include Aws::Structure end |
#group_id ⇒ String
The ID of the security group.
78529 78530 78531 78532 78533 78534 78535 78536 78537 78538 78539 78540 78541 78542 78543 78544 78545 78546 |
# File 'lib/aws-sdk-ec2/types.rb', line 78529 class SecurityGroupRule < Struct.new( :security_group_rule_id, :group_id, :group_owner_id, :is_egress, :ip_protocol, :from_port, :to_port, :cidr_ipv_4, :cidr_ipv_6, :prefix_list_id, :referenced_group_info, :description, :tags, :security_group_rule_arn) SENSITIVE = [] include Aws::Structure end |
#group_owner_id ⇒ String
The ID of the Amazon Web Services account that owns the security group.
78529 78530 78531 78532 78533 78534 78535 78536 78537 78538 78539 78540 78541 78542 78543 78544 78545 78546 |
# File 'lib/aws-sdk-ec2/types.rb', line 78529 class SecurityGroupRule < Struct.new( :security_group_rule_id, :group_id, :group_owner_id, :is_egress, :ip_protocol, :from_port, :to_port, :cidr_ipv_4, :cidr_ipv_6, :prefix_list_id, :referenced_group_info, :description, :tags, :security_group_rule_arn) SENSITIVE = [] include Aws::Structure end |
#ip_protocol ⇒ String
The IP protocol name (tcp, udp, icmp, icmpv6) or number (see
Protocol Numbers).
Use -1 to specify all protocols.
78529 78530 78531 78532 78533 78534 78535 78536 78537 78538 78539 78540 78541 78542 78543 78544 78545 78546 |
# File 'lib/aws-sdk-ec2/types.rb', line 78529 class SecurityGroupRule < Struct.new( :security_group_rule_id, :group_id, :group_owner_id, :is_egress, :ip_protocol, :from_port, :to_port, :cidr_ipv_4, :cidr_ipv_6, :prefix_list_id, :referenced_group_info, :description, :tags, :security_group_rule_arn) SENSITIVE = [] include Aws::Structure end |
#is_egress ⇒ Boolean
Indicates whether the security group rule is an outbound rule.
78529 78530 78531 78532 78533 78534 78535 78536 78537 78538 78539 78540 78541 78542 78543 78544 78545 78546 |
# File 'lib/aws-sdk-ec2/types.rb', line 78529 class SecurityGroupRule < Struct.new( :security_group_rule_id, :group_id, :group_owner_id, :is_egress, :ip_protocol, :from_port, :to_port, :cidr_ipv_4, :cidr_ipv_6, :prefix_list_id, :referenced_group_info, :description, :tags, :security_group_rule_arn) SENSITIVE = [] include Aws::Structure end |
#prefix_list_id ⇒ String
The ID of the prefix list.
78529 78530 78531 78532 78533 78534 78535 78536 78537 78538 78539 78540 78541 78542 78543 78544 78545 78546 |
# File 'lib/aws-sdk-ec2/types.rb', line 78529 class SecurityGroupRule < Struct.new( :security_group_rule_id, :group_id, :group_owner_id, :is_egress, :ip_protocol, :from_port, :to_port, :cidr_ipv_4, :cidr_ipv_6, :prefix_list_id, :referenced_group_info, :description, :tags, :security_group_rule_arn) SENSITIVE = [] include Aws::Structure end |
#referenced_group_info ⇒ Types::ReferencedSecurityGroup
Describes the security group that is referenced in the rule.
78529 78530 78531 78532 78533 78534 78535 78536 78537 78538 78539 78540 78541 78542 78543 78544 78545 78546 |
# File 'lib/aws-sdk-ec2/types.rb', line 78529 class SecurityGroupRule < Struct.new( :security_group_rule_id, :group_id, :group_owner_id, :is_egress, :ip_protocol, :from_port, :to_port, :cidr_ipv_4, :cidr_ipv_6, :prefix_list_id, :referenced_group_info, :description, :tags, :security_group_rule_arn) SENSITIVE = [] include Aws::Structure end |
#security_group_rule_arn ⇒ String
The ARN of the security group rule.
78529 78530 78531 78532 78533 78534 78535 78536 78537 78538 78539 78540 78541 78542 78543 78544 78545 78546 |
# File 'lib/aws-sdk-ec2/types.rb', line 78529 class SecurityGroupRule < Struct.new( :security_group_rule_id, :group_id, :group_owner_id, :is_egress, :ip_protocol, :from_port, :to_port, :cidr_ipv_4, :cidr_ipv_6, :prefix_list_id, :referenced_group_info, :description, :tags, :security_group_rule_arn) SENSITIVE = [] include Aws::Structure end |
#security_group_rule_id ⇒ String
The ID of the security group rule.
78529 78530 78531 78532 78533 78534 78535 78536 78537 78538 78539 78540 78541 78542 78543 78544 78545 78546 |
# File 'lib/aws-sdk-ec2/types.rb', line 78529 class SecurityGroupRule < Struct.new( :security_group_rule_id, :group_id, :group_owner_id, :is_egress, :ip_protocol, :from_port, :to_port, :cidr_ipv_4, :cidr_ipv_6, :prefix_list_id, :referenced_group_info, :description, :tags, :security_group_rule_arn) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags applied to the security group rule.
78529 78530 78531 78532 78533 78534 78535 78536 78537 78538 78539 78540 78541 78542 78543 78544 78545 78546 |
# File 'lib/aws-sdk-ec2/types.rb', line 78529 class SecurityGroupRule < Struct.new( :security_group_rule_id, :group_id, :group_owner_id, :is_egress, :ip_protocol, :from_port, :to_port, :cidr_ipv_4, :cidr_ipv_6, :prefix_list_id, :referenced_group_info, :description, :tags, :security_group_rule_arn) SENSITIVE = [] include Aws::Structure end |
#to_port ⇒ Integer
If the protocol is TCP or UDP, this is the end of the port range. If the protocol is ICMP or ICMPv6, this is the ICMP code or -1 (all ICMP codes). If the start port is -1 (all ICMP types), then the end port must be -1 (all ICMP codes).
78529 78530 78531 78532 78533 78534 78535 78536 78537 78538 78539 78540 78541 78542 78543 78544 78545 78546 |
# File 'lib/aws-sdk-ec2/types.rb', line 78529 class SecurityGroupRule < Struct.new( :security_group_rule_id, :group_id, :group_owner_id, :is_egress, :ip_protocol, :from_port, :to_port, :cidr_ipv_4, :cidr_ipv_6, :prefix_list_id, :referenced_group_info, :description, :tags, :security_group_rule_arn) SENSITIVE = [] include Aws::Structure end |