Class: Aws::EC2::Types::SendDiagnosticInterruptRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::SendDiagnosticInterruptRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#instance_id ⇒ String
The ID of the instance.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
77488 77489 77490 77491 77492 77493 |
# File 'lib/aws-sdk-ec2/types.rb', line 77488 class SendDiagnosticInterruptRequest < Struct.new( :instance_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the instance.
77488 77489 77490 77491 77492 77493 |
# File 'lib/aws-sdk-ec2/types.rb', line 77488 class SendDiagnosticInterruptRequest < Struct.new( :instance_id, :dry_run) SENSITIVE = [] include Aws::Structure end |