Class: Aws::EC2::Types::SendDiagnosticInterruptRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


77089
77090
77091
77092
77093
77094
# File 'lib/aws-sdk-ec2/types.rb', line 77089

class SendDiagnosticInterruptRequest < Struct.new(
  :instance_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The ID of the instance.

Returns:

  • (String)


77089
77090
77091
77092
77093
77094
# File 'lib/aws-sdk-ec2/types.rb', line 77089

class SendDiagnosticInterruptRequest < Struct.new(
  :instance_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end