Class: Aws::EC2::Types::ServiceConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes a service configuration for a VPC endpoint service.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#acceptance_requiredBoolean

Indicates whether requests from other Amazon Web Services accounts to create an endpoint to the service must first be accepted.

Returns:

  • (Boolean)


78187
78188
78189
78190
78191
78192
78193
78194
78195
78196
78197
78198
78199
78200
78201
78202
78203
78204
78205
78206
78207
78208
# File 'lib/aws-sdk-ec2/types.rb', line 78187

class ServiceConfiguration < Struct.new(
  :service_type,
  :service_id,
  :service_name,
  :service_state,
  :availability_zone_ids,
  :availability_zones,
  :acceptance_required,
  :manages_vpc_endpoints,
  :network_load_balancer_arns,
  :gateway_load_balancer_arns,
  :supported_ip_address_types,
  :base_endpoint_dns_names,
  :private_dns_name,
  :private_dns_name_configuration,
  :payer_responsibility,
  :tags,
  :supported_regions,
  :remote_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zone_idsArray<String>

The IDs of the Availability Zones in which the service is available.

Either ‘AvailabilityZone` or `AvailabilityZoneId` can be specified, but not both

Returns:

  • (Array<String>)


78187
78188
78189
78190
78191
78192
78193
78194
78195
78196
78197
78198
78199
78200
78201
78202
78203
78204
78205
78206
78207
78208
# File 'lib/aws-sdk-ec2/types.rb', line 78187

class ServiceConfiguration < Struct.new(
  :service_type,
  :service_id,
  :service_name,
  :service_state,
  :availability_zone_ids,
  :availability_zones,
  :acceptance_required,
  :manages_vpc_endpoints,
  :network_load_balancer_arns,
  :gateway_load_balancer_arns,
  :supported_ip_address_types,
  :base_endpoint_dns_names,
  :private_dns_name,
  :private_dns_name_configuration,
  :payer_responsibility,
  :tags,
  :supported_regions,
  :remote_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zonesArray<String>

The Availability Zones in which the service is available.

Either ‘AvailabilityZone` or `AvailabilityZoneId` can be specified, but not both

Returns:

  • (Array<String>)


78187
78188
78189
78190
78191
78192
78193
78194
78195
78196
78197
78198
78199
78200
78201
78202
78203
78204
78205
78206
78207
78208
# File 'lib/aws-sdk-ec2/types.rb', line 78187

class ServiceConfiguration < Struct.new(
  :service_type,
  :service_id,
  :service_name,
  :service_state,
  :availability_zone_ids,
  :availability_zones,
  :acceptance_required,
  :manages_vpc_endpoints,
  :network_load_balancer_arns,
  :gateway_load_balancer_arns,
  :supported_ip_address_types,
  :base_endpoint_dns_names,
  :private_dns_name,
  :private_dns_name_configuration,
  :payer_responsibility,
  :tags,
  :supported_regions,
  :remote_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#base_endpoint_dns_namesArray<String>

The DNS names for the service.

Returns:

  • (Array<String>)


78187
78188
78189
78190
78191
78192
78193
78194
78195
78196
78197
78198
78199
78200
78201
78202
78203
78204
78205
78206
78207
78208
# File 'lib/aws-sdk-ec2/types.rb', line 78187

class ServiceConfiguration < Struct.new(
  :service_type,
  :service_id,
  :service_name,
  :service_state,
  :availability_zone_ids,
  :availability_zones,
  :acceptance_required,
  :manages_vpc_endpoints,
  :network_load_balancer_arns,
  :gateway_load_balancer_arns,
  :supported_ip_address_types,
  :base_endpoint_dns_names,
  :private_dns_name,
  :private_dns_name_configuration,
  :payer_responsibility,
  :tags,
  :supported_regions,
  :remote_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#gateway_load_balancer_arnsArray<String>

The Amazon Resource Names (ARNs) of the Gateway Load Balancers for the service.

Returns:

  • (Array<String>)


78187
78188
78189
78190
78191
78192
78193
78194
78195
78196
78197
78198
78199
78200
78201
78202
78203
78204
78205
78206
78207
78208
# File 'lib/aws-sdk-ec2/types.rb', line 78187

class ServiceConfiguration < Struct.new(
  :service_type,
  :service_id,
  :service_name,
  :service_state,
  :availability_zone_ids,
  :availability_zones,
  :acceptance_required,
  :manages_vpc_endpoints,
  :network_load_balancer_arns,
  :gateway_load_balancer_arns,
  :supported_ip_address_types,
  :base_endpoint_dns_names,
  :private_dns_name,
  :private_dns_name_configuration,
  :payer_responsibility,
  :tags,
  :supported_regions,
  :remote_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#manages_vpc_endpointsBoolean

Indicates whether the service manages its VPC endpoints. Management of the service VPC endpoints using the VPC endpoint API is restricted.

Returns:

  • (Boolean)


78187
78188
78189
78190
78191
78192
78193
78194
78195
78196
78197
78198
78199
78200
78201
78202
78203
78204
78205
78206
78207
78208
# File 'lib/aws-sdk-ec2/types.rb', line 78187

class ServiceConfiguration < Struct.new(
  :service_type,
  :service_id,
  :service_name,
  :service_state,
  :availability_zone_ids,
  :availability_zones,
  :acceptance_required,
  :manages_vpc_endpoints,
  :network_load_balancer_arns,
  :gateway_load_balancer_arns,
  :supported_ip_address_types,
  :base_endpoint_dns_names,
  :private_dns_name,
  :private_dns_name_configuration,
  :payer_responsibility,
  :tags,
  :supported_regions,
  :remote_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#network_load_balancer_arnsArray<String>

The Amazon Resource Names (ARNs) of the Network Load Balancers for the service.

Returns:

  • (Array<String>)


78187
78188
78189
78190
78191
78192
78193
78194
78195
78196
78197
78198
78199
78200
78201
78202
78203
78204
78205
78206
78207
78208
# File 'lib/aws-sdk-ec2/types.rb', line 78187

class ServiceConfiguration < Struct.new(
  :service_type,
  :service_id,
  :service_name,
  :service_state,
  :availability_zone_ids,
  :availability_zones,
  :acceptance_required,
  :manages_vpc_endpoints,
  :network_load_balancer_arns,
  :gateway_load_balancer_arns,
  :supported_ip_address_types,
  :base_endpoint_dns_names,
  :private_dns_name,
  :private_dns_name_configuration,
  :payer_responsibility,
  :tags,
  :supported_regions,
  :remote_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#payer_responsibilityString

The payer responsibility.

Returns:

  • (String)


78187
78188
78189
78190
78191
78192
78193
78194
78195
78196
78197
78198
78199
78200
78201
78202
78203
78204
78205
78206
78207
78208
# File 'lib/aws-sdk-ec2/types.rb', line 78187

class ServiceConfiguration < Struct.new(
  :service_type,
  :service_id,
  :service_name,
  :service_state,
  :availability_zone_ids,
  :availability_zones,
  :acceptance_required,
  :manages_vpc_endpoints,
  :network_load_balancer_arns,
  :gateway_load_balancer_arns,
  :supported_ip_address_types,
  :base_endpoint_dns_names,
  :private_dns_name,
  :private_dns_name_configuration,
  :payer_responsibility,
  :tags,
  :supported_regions,
  :remote_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#private_dns_nameString

The private DNS name for the service.

Returns:

  • (String)


78187
78188
78189
78190
78191
78192
78193
78194
78195
78196
78197
78198
78199
78200
78201
78202
78203
78204
78205
78206
78207
78208
# File 'lib/aws-sdk-ec2/types.rb', line 78187

class ServiceConfiguration < Struct.new(
  :service_type,
  :service_id,
  :service_name,
  :service_state,
  :availability_zone_ids,
  :availability_zones,
  :acceptance_required,
  :manages_vpc_endpoints,
  :network_load_balancer_arns,
  :gateway_load_balancer_arns,
  :supported_ip_address_types,
  :base_endpoint_dns_names,
  :private_dns_name,
  :private_dns_name_configuration,
  :payer_responsibility,
  :tags,
  :supported_regions,
  :remote_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#private_dns_name_configurationTypes::PrivateDnsNameConfiguration

Information about the endpoint service private DNS name configuration.



78187
78188
78189
78190
78191
78192
78193
78194
78195
78196
78197
78198
78199
78200
78201
78202
78203
78204
78205
78206
78207
78208
# File 'lib/aws-sdk-ec2/types.rb', line 78187

class ServiceConfiguration < Struct.new(
  :service_type,
  :service_id,
  :service_name,
  :service_state,
  :availability_zone_ids,
  :availability_zones,
  :acceptance_required,
  :manages_vpc_endpoints,
  :network_load_balancer_arns,
  :gateway_load_balancer_arns,
  :supported_ip_address_types,
  :base_endpoint_dns_names,
  :private_dns_name,
  :private_dns_name_configuration,
  :payer_responsibility,
  :tags,
  :supported_regions,
  :remote_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#remote_access_enabledBoolean

Indicates whether consumers can access the service from a Region other than the Region where the service is hosted.

Returns:

  • (Boolean)


78187
78188
78189
78190
78191
78192
78193
78194
78195
78196
78197
78198
78199
78200
78201
78202
78203
78204
78205
78206
78207
78208
# File 'lib/aws-sdk-ec2/types.rb', line 78187

class ServiceConfiguration < Struct.new(
  :service_type,
  :service_id,
  :service_name,
  :service_state,
  :availability_zone_ids,
  :availability_zones,
  :acceptance_required,
  :manages_vpc_endpoints,
  :network_load_balancer_arns,
  :gateway_load_balancer_arns,
  :supported_ip_address_types,
  :base_endpoint_dns_names,
  :private_dns_name,
  :private_dns_name_configuration,
  :payer_responsibility,
  :tags,
  :supported_regions,
  :remote_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#service_idString

The ID of the service.

Returns:

  • (String)


78187
78188
78189
78190
78191
78192
78193
78194
78195
78196
78197
78198
78199
78200
78201
78202
78203
78204
78205
78206
78207
78208
# File 'lib/aws-sdk-ec2/types.rb', line 78187

class ServiceConfiguration < Struct.new(
  :service_type,
  :service_id,
  :service_name,
  :service_state,
  :availability_zone_ids,
  :availability_zones,
  :acceptance_required,
  :manages_vpc_endpoints,
  :network_load_balancer_arns,
  :gateway_load_balancer_arns,
  :supported_ip_address_types,
  :base_endpoint_dns_names,
  :private_dns_name,
  :private_dns_name_configuration,
  :payer_responsibility,
  :tags,
  :supported_regions,
  :remote_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#service_nameString

The name of the service.

Returns:

  • (String)


78187
78188
78189
78190
78191
78192
78193
78194
78195
78196
78197
78198
78199
78200
78201
78202
78203
78204
78205
78206
78207
78208
# File 'lib/aws-sdk-ec2/types.rb', line 78187

class ServiceConfiguration < Struct.new(
  :service_type,
  :service_id,
  :service_name,
  :service_state,
  :availability_zone_ids,
  :availability_zones,
  :acceptance_required,
  :manages_vpc_endpoints,
  :network_load_balancer_arns,
  :gateway_load_balancer_arns,
  :supported_ip_address_types,
  :base_endpoint_dns_names,
  :private_dns_name,
  :private_dns_name_configuration,
  :payer_responsibility,
  :tags,
  :supported_regions,
  :remote_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#service_stateString

The service state.

Returns:

  • (String)


78187
78188
78189
78190
78191
78192
78193
78194
78195
78196
78197
78198
78199
78200
78201
78202
78203
78204
78205
78206
78207
78208
# File 'lib/aws-sdk-ec2/types.rb', line 78187

class ServiceConfiguration < Struct.new(
  :service_type,
  :service_id,
  :service_name,
  :service_state,
  :availability_zone_ids,
  :availability_zones,
  :acceptance_required,
  :manages_vpc_endpoints,
  :network_load_balancer_arns,
  :gateway_load_balancer_arns,
  :supported_ip_address_types,
  :base_endpoint_dns_names,
  :private_dns_name,
  :private_dns_name_configuration,
  :payer_responsibility,
  :tags,
  :supported_regions,
  :remote_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#service_typeArray<Types::ServiceTypeDetail>

The type of service.

Returns:



78187
78188
78189
78190
78191
78192
78193
78194
78195
78196
78197
78198
78199
78200
78201
78202
78203
78204
78205
78206
78207
78208
# File 'lib/aws-sdk-ec2/types.rb', line 78187

class ServiceConfiguration < Struct.new(
  :service_type,
  :service_id,
  :service_name,
  :service_state,
  :availability_zone_ids,
  :availability_zones,
  :acceptance_required,
  :manages_vpc_endpoints,
  :network_load_balancer_arns,
  :gateway_load_balancer_arns,
  :supported_ip_address_types,
  :base_endpoint_dns_names,
  :private_dns_name,
  :private_dns_name_configuration,
  :payer_responsibility,
  :tags,
  :supported_regions,
  :remote_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#supported_ip_address_typesArray<String>

The supported IP address types.

Returns:

  • (Array<String>)


78187
78188
78189
78190
78191
78192
78193
78194
78195
78196
78197
78198
78199
78200
78201
78202
78203
78204
78205
78206
78207
78208
# File 'lib/aws-sdk-ec2/types.rb', line 78187

class ServiceConfiguration < Struct.new(
  :service_type,
  :service_id,
  :service_name,
  :service_state,
  :availability_zone_ids,
  :availability_zones,
  :acceptance_required,
  :manages_vpc_endpoints,
  :network_load_balancer_arns,
  :gateway_load_balancer_arns,
  :supported_ip_address_types,
  :base_endpoint_dns_names,
  :private_dns_name,
  :private_dns_name_configuration,
  :payer_responsibility,
  :tags,
  :supported_regions,
  :remote_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#supported_regionsArray<Types::SupportedRegionDetail>

The supported Regions.

Returns:



78187
78188
78189
78190
78191
78192
78193
78194
78195
78196
78197
78198
78199
78200
78201
78202
78203
78204
78205
78206
78207
78208
# File 'lib/aws-sdk-ec2/types.rb', line 78187

class ServiceConfiguration < Struct.new(
  :service_type,
  :service_id,
  :service_name,
  :service_state,
  :availability_zone_ids,
  :availability_zones,
  :acceptance_required,
  :manages_vpc_endpoints,
  :network_load_balancer_arns,
  :gateway_load_balancer_arns,
  :supported_ip_address_types,
  :base_endpoint_dns_names,
  :private_dns_name,
  :private_dns_name_configuration,
  :payer_responsibility,
  :tags,
  :supported_regions,
  :remote_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The tags assigned to the service.

Returns:



78187
78188
78189
78190
78191
78192
78193
78194
78195
78196
78197
78198
78199
78200
78201
78202
78203
78204
78205
78206
78207
78208
# File 'lib/aws-sdk-ec2/types.rb', line 78187

class ServiceConfiguration < Struct.new(
  :service_type,
  :service_id,
  :service_name,
  :service_state,
  :availability_zone_ids,
  :availability_zones,
  :acceptance_required,
  :manages_vpc_endpoints,
  :network_load_balancer_arns,
  :gateway_load_balancer_arns,
  :supported_ip_address_types,
  :base_endpoint_dns_names,
  :private_dns_name,
  :private_dns_name_configuration,
  :payer_responsibility,
  :tags,
  :supported_regions,
  :remote_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end