Class: Aws::EC2::Types::ServiceConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ServiceConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a service configuration for a VPC endpoint service.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#acceptance_required ⇒ Boolean
Indicates whether requests from other Amazon Web Services accounts to create an endpoint to the service must first be accepted.
-
#availability_zone_ids ⇒ Array<String>
The IDs of the Availability Zones in which the service is available.
-
#availability_zones ⇒ Array<String>
The Availability Zones in which the service is available.
-
#base_endpoint_dns_names ⇒ Array<String>
The DNS names for the service.
-
#gateway_load_balancer_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the Gateway Load Balancers for the service.
-
#manages_vpc_endpoints ⇒ Boolean
Indicates whether the service manages its VPC endpoints.
-
#network_load_balancer_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the Network Load Balancers for the service.
-
#payer_responsibility ⇒ String
The payer responsibility.
-
#private_dns_name ⇒ String
The private DNS name for the service.
-
#private_dns_name_configuration ⇒ Types::PrivateDnsNameConfiguration
Information about the endpoint service private DNS name configuration.
-
#remote_access_enabled ⇒ Boolean
Indicates whether consumers can access the service from a Region other than the Region where the service is hosted.
-
#service_id ⇒ String
The ID of the service.
-
#service_name ⇒ String
The name of the service.
-
#service_state ⇒ String
The service state.
-
#service_type ⇒ Array<Types::ServiceTypeDetail>
The type of service.
-
#supported_ip_address_types ⇒ Array<String>
The supported IP address types.
-
#supported_regions ⇒ Array<Types::SupportedRegionDetail>
The supported Regions.
-
#tags ⇒ Array<Types::Tag>
The tags assigned to the service.
Instance Attribute Details
#acceptance_required ⇒ Boolean
Indicates whether requests from other Amazon Web Services accounts to create an endpoint to the service must first be accepted.
75694 75695 75696 75697 75698 75699 75700 75701 75702 75703 75704 75705 75706 75707 75708 75709 75710 75711 75712 75713 75714 75715 |
# File 'lib/aws-sdk-ec2/types.rb', line 75694 class ServiceConfiguration < Struct.new( :service_type, :service_id, :service_name, :service_state, :availability_zone_ids, :availability_zones, :acceptance_required, :manages_vpc_endpoints, :network_load_balancer_arns, :gateway_load_balancer_arns, :supported_ip_address_types, :base_endpoint_dns_names, :private_dns_name, :private_dns_name_configuration, :payer_responsibility, :tags, :supported_regions, :remote_access_enabled) SENSITIVE = [] include Aws::Structure end |
#availability_zone_ids ⇒ Array<String>
The IDs of the Availability Zones in which the service is available.
Either ‘AvailabilityZone` or `AvailabilityZoneId` can be specified, but not both
75694 75695 75696 75697 75698 75699 75700 75701 75702 75703 75704 75705 75706 75707 75708 75709 75710 75711 75712 75713 75714 75715 |
# File 'lib/aws-sdk-ec2/types.rb', line 75694 class ServiceConfiguration < Struct.new( :service_type, :service_id, :service_name, :service_state, :availability_zone_ids, :availability_zones, :acceptance_required, :manages_vpc_endpoints, :network_load_balancer_arns, :gateway_load_balancer_arns, :supported_ip_address_types, :base_endpoint_dns_names, :private_dns_name, :private_dns_name_configuration, :payer_responsibility, :tags, :supported_regions, :remote_access_enabled) SENSITIVE = [] include Aws::Structure end |
#availability_zones ⇒ Array<String>
The Availability Zones in which the service is available.
Either ‘AvailabilityZone` or `AvailabilityZoneId` can be specified, but not both
75694 75695 75696 75697 75698 75699 75700 75701 75702 75703 75704 75705 75706 75707 75708 75709 75710 75711 75712 75713 75714 75715 |
# File 'lib/aws-sdk-ec2/types.rb', line 75694 class ServiceConfiguration < Struct.new( :service_type, :service_id, :service_name, :service_state, :availability_zone_ids, :availability_zones, :acceptance_required, :manages_vpc_endpoints, :network_load_balancer_arns, :gateway_load_balancer_arns, :supported_ip_address_types, :base_endpoint_dns_names, :private_dns_name, :private_dns_name_configuration, :payer_responsibility, :tags, :supported_regions, :remote_access_enabled) SENSITIVE = [] include Aws::Structure end |
#base_endpoint_dns_names ⇒ Array<String>
The DNS names for the service.
75694 75695 75696 75697 75698 75699 75700 75701 75702 75703 75704 75705 75706 75707 75708 75709 75710 75711 75712 75713 75714 75715 |
# File 'lib/aws-sdk-ec2/types.rb', line 75694 class ServiceConfiguration < Struct.new( :service_type, :service_id, :service_name, :service_state, :availability_zone_ids, :availability_zones, :acceptance_required, :manages_vpc_endpoints, :network_load_balancer_arns, :gateway_load_balancer_arns, :supported_ip_address_types, :base_endpoint_dns_names, :private_dns_name, :private_dns_name_configuration, :payer_responsibility, :tags, :supported_regions, :remote_access_enabled) SENSITIVE = [] include Aws::Structure end |
#gateway_load_balancer_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the Gateway Load Balancers for the service.
75694 75695 75696 75697 75698 75699 75700 75701 75702 75703 75704 75705 75706 75707 75708 75709 75710 75711 75712 75713 75714 75715 |
# File 'lib/aws-sdk-ec2/types.rb', line 75694 class ServiceConfiguration < Struct.new( :service_type, :service_id, :service_name, :service_state, :availability_zone_ids, :availability_zones, :acceptance_required, :manages_vpc_endpoints, :network_load_balancer_arns, :gateway_load_balancer_arns, :supported_ip_address_types, :base_endpoint_dns_names, :private_dns_name, :private_dns_name_configuration, :payer_responsibility, :tags, :supported_regions, :remote_access_enabled) SENSITIVE = [] include Aws::Structure end |
#manages_vpc_endpoints ⇒ Boolean
Indicates whether the service manages its VPC endpoints. Management of the service VPC endpoints using the VPC endpoint API is restricted.
75694 75695 75696 75697 75698 75699 75700 75701 75702 75703 75704 75705 75706 75707 75708 75709 75710 75711 75712 75713 75714 75715 |
# File 'lib/aws-sdk-ec2/types.rb', line 75694 class ServiceConfiguration < Struct.new( :service_type, :service_id, :service_name, :service_state, :availability_zone_ids, :availability_zones, :acceptance_required, :manages_vpc_endpoints, :network_load_balancer_arns, :gateway_load_balancer_arns, :supported_ip_address_types, :base_endpoint_dns_names, :private_dns_name, :private_dns_name_configuration, :payer_responsibility, :tags, :supported_regions, :remote_access_enabled) SENSITIVE = [] include Aws::Structure end |
#network_load_balancer_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the Network Load Balancers for the service.
75694 75695 75696 75697 75698 75699 75700 75701 75702 75703 75704 75705 75706 75707 75708 75709 75710 75711 75712 75713 75714 75715 |
# File 'lib/aws-sdk-ec2/types.rb', line 75694 class ServiceConfiguration < Struct.new( :service_type, :service_id, :service_name, :service_state, :availability_zone_ids, :availability_zones, :acceptance_required, :manages_vpc_endpoints, :network_load_balancer_arns, :gateway_load_balancer_arns, :supported_ip_address_types, :base_endpoint_dns_names, :private_dns_name, :private_dns_name_configuration, :payer_responsibility, :tags, :supported_regions, :remote_access_enabled) SENSITIVE = [] include Aws::Structure end |
#payer_responsibility ⇒ String
The payer responsibility.
75694 75695 75696 75697 75698 75699 75700 75701 75702 75703 75704 75705 75706 75707 75708 75709 75710 75711 75712 75713 75714 75715 |
# File 'lib/aws-sdk-ec2/types.rb', line 75694 class ServiceConfiguration < Struct.new( :service_type, :service_id, :service_name, :service_state, :availability_zone_ids, :availability_zones, :acceptance_required, :manages_vpc_endpoints, :network_load_balancer_arns, :gateway_load_balancer_arns, :supported_ip_address_types, :base_endpoint_dns_names, :private_dns_name, :private_dns_name_configuration, :payer_responsibility, :tags, :supported_regions, :remote_access_enabled) SENSITIVE = [] include Aws::Structure end |
#private_dns_name ⇒ String
The private DNS name for the service.
75694 75695 75696 75697 75698 75699 75700 75701 75702 75703 75704 75705 75706 75707 75708 75709 75710 75711 75712 75713 75714 75715 |
# File 'lib/aws-sdk-ec2/types.rb', line 75694 class ServiceConfiguration < Struct.new( :service_type, :service_id, :service_name, :service_state, :availability_zone_ids, :availability_zones, :acceptance_required, :manages_vpc_endpoints, :network_load_balancer_arns, :gateway_load_balancer_arns, :supported_ip_address_types, :base_endpoint_dns_names, :private_dns_name, :private_dns_name_configuration, :payer_responsibility, :tags, :supported_regions, :remote_access_enabled) SENSITIVE = [] include Aws::Structure end |
#private_dns_name_configuration ⇒ Types::PrivateDnsNameConfiguration
Information about the endpoint service private DNS name configuration.
75694 75695 75696 75697 75698 75699 75700 75701 75702 75703 75704 75705 75706 75707 75708 75709 75710 75711 75712 75713 75714 75715 |
# File 'lib/aws-sdk-ec2/types.rb', line 75694 class ServiceConfiguration < Struct.new( :service_type, :service_id, :service_name, :service_state, :availability_zone_ids, :availability_zones, :acceptance_required, :manages_vpc_endpoints, :network_load_balancer_arns, :gateway_load_balancer_arns, :supported_ip_address_types, :base_endpoint_dns_names, :private_dns_name, :private_dns_name_configuration, :payer_responsibility, :tags, :supported_regions, :remote_access_enabled) SENSITIVE = [] include Aws::Structure end |
#remote_access_enabled ⇒ Boolean
Indicates whether consumers can access the service from a Region other than the Region where the service is hosted.
75694 75695 75696 75697 75698 75699 75700 75701 75702 75703 75704 75705 75706 75707 75708 75709 75710 75711 75712 75713 75714 75715 |
# File 'lib/aws-sdk-ec2/types.rb', line 75694 class ServiceConfiguration < Struct.new( :service_type, :service_id, :service_name, :service_state, :availability_zone_ids, :availability_zones, :acceptance_required, :manages_vpc_endpoints, :network_load_balancer_arns, :gateway_load_balancer_arns, :supported_ip_address_types, :base_endpoint_dns_names, :private_dns_name, :private_dns_name_configuration, :payer_responsibility, :tags, :supported_regions, :remote_access_enabled) SENSITIVE = [] include Aws::Structure end |
#service_id ⇒ String
The ID of the service.
75694 75695 75696 75697 75698 75699 75700 75701 75702 75703 75704 75705 75706 75707 75708 75709 75710 75711 75712 75713 75714 75715 |
# File 'lib/aws-sdk-ec2/types.rb', line 75694 class ServiceConfiguration < Struct.new( :service_type, :service_id, :service_name, :service_state, :availability_zone_ids, :availability_zones, :acceptance_required, :manages_vpc_endpoints, :network_load_balancer_arns, :gateway_load_balancer_arns, :supported_ip_address_types, :base_endpoint_dns_names, :private_dns_name, :private_dns_name_configuration, :payer_responsibility, :tags, :supported_regions, :remote_access_enabled) SENSITIVE = [] include Aws::Structure end |
#service_name ⇒ String
The name of the service.
75694 75695 75696 75697 75698 75699 75700 75701 75702 75703 75704 75705 75706 75707 75708 75709 75710 75711 75712 75713 75714 75715 |
# File 'lib/aws-sdk-ec2/types.rb', line 75694 class ServiceConfiguration < Struct.new( :service_type, :service_id, :service_name, :service_state, :availability_zone_ids, :availability_zones, :acceptance_required, :manages_vpc_endpoints, :network_load_balancer_arns, :gateway_load_balancer_arns, :supported_ip_address_types, :base_endpoint_dns_names, :private_dns_name, :private_dns_name_configuration, :payer_responsibility, :tags, :supported_regions, :remote_access_enabled) SENSITIVE = [] include Aws::Structure end |
#service_state ⇒ String
The service state.
75694 75695 75696 75697 75698 75699 75700 75701 75702 75703 75704 75705 75706 75707 75708 75709 75710 75711 75712 75713 75714 75715 |
# File 'lib/aws-sdk-ec2/types.rb', line 75694 class ServiceConfiguration < Struct.new( :service_type, :service_id, :service_name, :service_state, :availability_zone_ids, :availability_zones, :acceptance_required, :manages_vpc_endpoints, :network_load_balancer_arns, :gateway_load_balancer_arns, :supported_ip_address_types, :base_endpoint_dns_names, :private_dns_name, :private_dns_name_configuration, :payer_responsibility, :tags, :supported_regions, :remote_access_enabled) SENSITIVE = [] include Aws::Structure end |
#service_type ⇒ Array<Types::ServiceTypeDetail>
The type of service.
75694 75695 75696 75697 75698 75699 75700 75701 75702 75703 75704 75705 75706 75707 75708 75709 75710 75711 75712 75713 75714 75715 |
# File 'lib/aws-sdk-ec2/types.rb', line 75694 class ServiceConfiguration < Struct.new( :service_type, :service_id, :service_name, :service_state, :availability_zone_ids, :availability_zones, :acceptance_required, :manages_vpc_endpoints, :network_load_balancer_arns, :gateway_load_balancer_arns, :supported_ip_address_types, :base_endpoint_dns_names, :private_dns_name, :private_dns_name_configuration, :payer_responsibility, :tags, :supported_regions, :remote_access_enabled) SENSITIVE = [] include Aws::Structure end |
#supported_ip_address_types ⇒ Array<String>
The supported IP address types.
75694 75695 75696 75697 75698 75699 75700 75701 75702 75703 75704 75705 75706 75707 75708 75709 75710 75711 75712 75713 75714 75715 |
# File 'lib/aws-sdk-ec2/types.rb', line 75694 class ServiceConfiguration < Struct.new( :service_type, :service_id, :service_name, :service_state, :availability_zone_ids, :availability_zones, :acceptance_required, :manages_vpc_endpoints, :network_load_balancer_arns, :gateway_load_balancer_arns, :supported_ip_address_types, :base_endpoint_dns_names, :private_dns_name, :private_dns_name_configuration, :payer_responsibility, :tags, :supported_regions, :remote_access_enabled) SENSITIVE = [] include Aws::Structure end |
#supported_regions ⇒ Array<Types::SupportedRegionDetail>
The supported Regions.
75694 75695 75696 75697 75698 75699 75700 75701 75702 75703 75704 75705 75706 75707 75708 75709 75710 75711 75712 75713 75714 75715 |
# File 'lib/aws-sdk-ec2/types.rb', line 75694 class ServiceConfiguration < Struct.new( :service_type, :service_id, :service_name, :service_state, :availability_zone_ids, :availability_zones, :acceptance_required, :manages_vpc_endpoints, :network_load_balancer_arns, :gateway_load_balancer_arns, :supported_ip_address_types, :base_endpoint_dns_names, :private_dns_name, :private_dns_name_configuration, :payer_responsibility, :tags, :supported_regions, :remote_access_enabled) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags assigned to the service.
75694 75695 75696 75697 75698 75699 75700 75701 75702 75703 75704 75705 75706 75707 75708 75709 75710 75711 75712 75713 75714 75715 |
# File 'lib/aws-sdk-ec2/types.rb', line 75694 class ServiceConfiguration < Struct.new( :service_type, :service_id, :service_name, :service_state, :availability_zone_ids, :availability_zones, :acceptance_required, :manages_vpc_endpoints, :network_load_balancer_arns, :gateway_load_balancer_arns, :supported_ip_address_types, :base_endpoint_dns_names, :private_dns_name, :private_dns_name_configuration, :payer_responsibility, :tags, :supported_regions, :remote_access_enabled) SENSITIVE = [] include Aws::Structure end |