Class: Aws::EC2::Types::ServiceDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ServiceDetail
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a VPC endpoint service.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#acceptance_required ⇒ Boolean
Indicates whether VPC endpoint connection requests to the service must be accepted by the service owner.
-
#availability_zone_ids ⇒ Array<String>
The IDs of the Availability Zones in which the service is available.
-
#availability_zones ⇒ Array<String>
The Availability Zones in which the service is available.
-
#base_endpoint_dns_names ⇒ Array<String>
The DNS names for the service.
-
#manages_vpc_endpoints ⇒ Boolean
Indicates whether the service manages its VPC endpoints.
-
#owner ⇒ String
The Amazon Web Services account ID of the service owner.
-
#payer_responsibility ⇒ String
The payer responsibility.
-
#private_dns_name ⇒ String
The private DNS name for the service.
-
#private_dns_name_verification_state ⇒ String
The verification state of the VPC endpoint service.
-
#private_dns_names ⇒ Array<Types::PrivateDnsDetails>
The private DNS names assigned to the VPC endpoint service.
-
#service_id ⇒ String
The ID of the endpoint service.
-
#service_name ⇒ String
The name of the service.
-
#service_region ⇒ String
The Region where the service is hosted.
-
#service_type ⇒ Array<Types::ServiceTypeDetail>
The type of service.
-
#supported_ip_address_types ⇒ Array<String>
The supported IP address types.
-
#tags ⇒ Array<Types::Tag>
The tags assigned to the service.
-
#vpc_endpoint_policy_supported ⇒ Boolean
Indicates whether the service supports endpoint policies.
Instance Attribute Details
#acceptance_required ⇒ Boolean
Indicates whether VPC endpoint connection requests to the service must be accepted by the service owner.
77841 77842 77843 77844 77845 77846 77847 77848 77849 77850 77851 77852 77853 77854 77855 77856 77857 77858 77859 77860 77861 |
# File 'lib/aws-sdk-ec2/types.rb', line 77841 class ServiceDetail < Struct.new( :service_name, :service_id, :service_type, :service_region, :availability_zone_ids, :availability_zones, :owner, :base_endpoint_dns_names, :private_dns_name, :private_dns_names, :vpc_endpoint_policy_supported, :acceptance_required, :manages_vpc_endpoints, :payer_responsibility, :tags, :private_dns_name_verification_state, :supported_ip_address_types) SENSITIVE = [] include Aws::Structure end |
#availability_zone_ids ⇒ Array<String>
The IDs of the Availability Zones in which the service is available.
Either ‘AvailabilityZone` or `AvailabilityZoneId` can be specified, but not both
77841 77842 77843 77844 77845 77846 77847 77848 77849 77850 77851 77852 77853 77854 77855 77856 77857 77858 77859 77860 77861 |
# File 'lib/aws-sdk-ec2/types.rb', line 77841 class ServiceDetail < Struct.new( :service_name, :service_id, :service_type, :service_region, :availability_zone_ids, :availability_zones, :owner, :base_endpoint_dns_names, :private_dns_name, :private_dns_names, :vpc_endpoint_policy_supported, :acceptance_required, :manages_vpc_endpoints, :payer_responsibility, :tags, :private_dns_name_verification_state, :supported_ip_address_types) SENSITIVE = [] include Aws::Structure end |
#availability_zones ⇒ Array<String>
The Availability Zones in which the service is available.
Either ‘AvailabilityZone` or `AvailabilityZoneId` can be specified, but not both
77841 77842 77843 77844 77845 77846 77847 77848 77849 77850 77851 77852 77853 77854 77855 77856 77857 77858 77859 77860 77861 |
# File 'lib/aws-sdk-ec2/types.rb', line 77841 class ServiceDetail < Struct.new( :service_name, :service_id, :service_type, :service_region, :availability_zone_ids, :availability_zones, :owner, :base_endpoint_dns_names, :private_dns_name, :private_dns_names, :vpc_endpoint_policy_supported, :acceptance_required, :manages_vpc_endpoints, :payer_responsibility, :tags, :private_dns_name_verification_state, :supported_ip_address_types) SENSITIVE = [] include Aws::Structure end |
#base_endpoint_dns_names ⇒ Array<String>
The DNS names for the service.
77841 77842 77843 77844 77845 77846 77847 77848 77849 77850 77851 77852 77853 77854 77855 77856 77857 77858 77859 77860 77861 |
# File 'lib/aws-sdk-ec2/types.rb', line 77841 class ServiceDetail < Struct.new( :service_name, :service_id, :service_type, :service_region, :availability_zone_ids, :availability_zones, :owner, :base_endpoint_dns_names, :private_dns_name, :private_dns_names, :vpc_endpoint_policy_supported, :acceptance_required, :manages_vpc_endpoints, :payer_responsibility, :tags, :private_dns_name_verification_state, :supported_ip_address_types) SENSITIVE = [] include Aws::Structure end |
#manages_vpc_endpoints ⇒ Boolean
Indicates whether the service manages its VPC endpoints. Management of the service VPC endpoints using the VPC endpoint API is restricted.
77841 77842 77843 77844 77845 77846 77847 77848 77849 77850 77851 77852 77853 77854 77855 77856 77857 77858 77859 77860 77861 |
# File 'lib/aws-sdk-ec2/types.rb', line 77841 class ServiceDetail < Struct.new( :service_name, :service_id, :service_type, :service_region, :availability_zone_ids, :availability_zones, :owner, :base_endpoint_dns_names, :private_dns_name, :private_dns_names, :vpc_endpoint_policy_supported, :acceptance_required, :manages_vpc_endpoints, :payer_responsibility, :tags, :private_dns_name_verification_state, :supported_ip_address_types) SENSITIVE = [] include Aws::Structure end |
#owner ⇒ String
The Amazon Web Services account ID of the service owner.
77841 77842 77843 77844 77845 77846 77847 77848 77849 77850 77851 77852 77853 77854 77855 77856 77857 77858 77859 77860 77861 |
# File 'lib/aws-sdk-ec2/types.rb', line 77841 class ServiceDetail < Struct.new( :service_name, :service_id, :service_type, :service_region, :availability_zone_ids, :availability_zones, :owner, :base_endpoint_dns_names, :private_dns_name, :private_dns_names, :vpc_endpoint_policy_supported, :acceptance_required, :manages_vpc_endpoints, :payer_responsibility, :tags, :private_dns_name_verification_state, :supported_ip_address_types) SENSITIVE = [] include Aws::Structure end |
#payer_responsibility ⇒ String
The payer responsibility.
77841 77842 77843 77844 77845 77846 77847 77848 77849 77850 77851 77852 77853 77854 77855 77856 77857 77858 77859 77860 77861 |
# File 'lib/aws-sdk-ec2/types.rb', line 77841 class ServiceDetail < Struct.new( :service_name, :service_id, :service_type, :service_region, :availability_zone_ids, :availability_zones, :owner, :base_endpoint_dns_names, :private_dns_name, :private_dns_names, :vpc_endpoint_policy_supported, :acceptance_required, :manages_vpc_endpoints, :payer_responsibility, :tags, :private_dns_name_verification_state, :supported_ip_address_types) SENSITIVE = [] include Aws::Structure end |
#private_dns_name ⇒ String
The private DNS name for the service.
77841 77842 77843 77844 77845 77846 77847 77848 77849 77850 77851 77852 77853 77854 77855 77856 77857 77858 77859 77860 77861 |
# File 'lib/aws-sdk-ec2/types.rb', line 77841 class ServiceDetail < Struct.new( :service_name, :service_id, :service_type, :service_region, :availability_zone_ids, :availability_zones, :owner, :base_endpoint_dns_names, :private_dns_name, :private_dns_names, :vpc_endpoint_policy_supported, :acceptance_required, :manages_vpc_endpoints, :payer_responsibility, :tags, :private_dns_name_verification_state, :supported_ip_address_types) SENSITIVE = [] include Aws::Structure end |
#private_dns_name_verification_state ⇒ String
The verification state of the VPC endpoint service.
Consumers of the endpoint service cannot use the private name when the state is not ‘verified`.
77841 77842 77843 77844 77845 77846 77847 77848 77849 77850 77851 77852 77853 77854 77855 77856 77857 77858 77859 77860 77861 |
# File 'lib/aws-sdk-ec2/types.rb', line 77841 class ServiceDetail < Struct.new( :service_name, :service_id, :service_type, :service_region, :availability_zone_ids, :availability_zones, :owner, :base_endpoint_dns_names, :private_dns_name, :private_dns_names, :vpc_endpoint_policy_supported, :acceptance_required, :manages_vpc_endpoints, :payer_responsibility, :tags, :private_dns_name_verification_state, :supported_ip_address_types) SENSITIVE = [] include Aws::Structure end |
#private_dns_names ⇒ Array<Types::PrivateDnsDetails>
The private DNS names assigned to the VPC endpoint service.
77841 77842 77843 77844 77845 77846 77847 77848 77849 77850 77851 77852 77853 77854 77855 77856 77857 77858 77859 77860 77861 |
# File 'lib/aws-sdk-ec2/types.rb', line 77841 class ServiceDetail < Struct.new( :service_name, :service_id, :service_type, :service_region, :availability_zone_ids, :availability_zones, :owner, :base_endpoint_dns_names, :private_dns_name, :private_dns_names, :vpc_endpoint_policy_supported, :acceptance_required, :manages_vpc_endpoints, :payer_responsibility, :tags, :private_dns_name_verification_state, :supported_ip_address_types) SENSITIVE = [] include Aws::Structure end |
#service_id ⇒ String
The ID of the endpoint service.
77841 77842 77843 77844 77845 77846 77847 77848 77849 77850 77851 77852 77853 77854 77855 77856 77857 77858 77859 77860 77861 |
# File 'lib/aws-sdk-ec2/types.rb', line 77841 class ServiceDetail < Struct.new( :service_name, :service_id, :service_type, :service_region, :availability_zone_ids, :availability_zones, :owner, :base_endpoint_dns_names, :private_dns_name, :private_dns_names, :vpc_endpoint_policy_supported, :acceptance_required, :manages_vpc_endpoints, :payer_responsibility, :tags, :private_dns_name_verification_state, :supported_ip_address_types) SENSITIVE = [] include Aws::Structure end |
#service_name ⇒ String
The name of the service.
77841 77842 77843 77844 77845 77846 77847 77848 77849 77850 77851 77852 77853 77854 77855 77856 77857 77858 77859 77860 77861 |
# File 'lib/aws-sdk-ec2/types.rb', line 77841 class ServiceDetail < Struct.new( :service_name, :service_id, :service_type, :service_region, :availability_zone_ids, :availability_zones, :owner, :base_endpoint_dns_names, :private_dns_name, :private_dns_names, :vpc_endpoint_policy_supported, :acceptance_required, :manages_vpc_endpoints, :payer_responsibility, :tags, :private_dns_name_verification_state, :supported_ip_address_types) SENSITIVE = [] include Aws::Structure end |
#service_region ⇒ String
The Region where the service is hosted.
77841 77842 77843 77844 77845 77846 77847 77848 77849 77850 77851 77852 77853 77854 77855 77856 77857 77858 77859 77860 77861 |
# File 'lib/aws-sdk-ec2/types.rb', line 77841 class ServiceDetail < Struct.new( :service_name, :service_id, :service_type, :service_region, :availability_zone_ids, :availability_zones, :owner, :base_endpoint_dns_names, :private_dns_name, :private_dns_names, :vpc_endpoint_policy_supported, :acceptance_required, :manages_vpc_endpoints, :payer_responsibility, :tags, :private_dns_name_verification_state, :supported_ip_address_types) SENSITIVE = [] include Aws::Structure end |
#service_type ⇒ Array<Types::ServiceTypeDetail>
The type of service.
77841 77842 77843 77844 77845 77846 77847 77848 77849 77850 77851 77852 77853 77854 77855 77856 77857 77858 77859 77860 77861 |
# File 'lib/aws-sdk-ec2/types.rb', line 77841 class ServiceDetail < Struct.new( :service_name, :service_id, :service_type, :service_region, :availability_zone_ids, :availability_zones, :owner, :base_endpoint_dns_names, :private_dns_name, :private_dns_names, :vpc_endpoint_policy_supported, :acceptance_required, :manages_vpc_endpoints, :payer_responsibility, :tags, :private_dns_name_verification_state, :supported_ip_address_types) SENSITIVE = [] include Aws::Structure end |
#supported_ip_address_types ⇒ Array<String>
The supported IP address types.
77841 77842 77843 77844 77845 77846 77847 77848 77849 77850 77851 77852 77853 77854 77855 77856 77857 77858 77859 77860 77861 |
# File 'lib/aws-sdk-ec2/types.rb', line 77841 class ServiceDetail < Struct.new( :service_name, :service_id, :service_type, :service_region, :availability_zone_ids, :availability_zones, :owner, :base_endpoint_dns_names, :private_dns_name, :private_dns_names, :vpc_endpoint_policy_supported, :acceptance_required, :manages_vpc_endpoints, :payer_responsibility, :tags, :private_dns_name_verification_state, :supported_ip_address_types) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags assigned to the service.
77841 77842 77843 77844 77845 77846 77847 77848 77849 77850 77851 77852 77853 77854 77855 77856 77857 77858 77859 77860 77861 |
# File 'lib/aws-sdk-ec2/types.rb', line 77841 class ServiceDetail < Struct.new( :service_name, :service_id, :service_type, :service_region, :availability_zone_ids, :availability_zones, :owner, :base_endpoint_dns_names, :private_dns_name, :private_dns_names, :vpc_endpoint_policy_supported, :acceptance_required, :manages_vpc_endpoints, :payer_responsibility, :tags, :private_dns_name_verification_state, :supported_ip_address_types) SENSITIVE = [] include Aws::Structure end |
#vpc_endpoint_policy_supported ⇒ Boolean
Indicates whether the service supports endpoint policies.
77841 77842 77843 77844 77845 77846 77847 77848 77849 77850 77851 77852 77853 77854 77855 77856 77857 77858 77859 77860 77861 |
# File 'lib/aws-sdk-ec2/types.rb', line 77841 class ServiceDetail < Struct.new( :service_name, :service_id, :service_type, :service_region, :availability_zone_ids, :availability_zones, :owner, :base_endpoint_dns_names, :private_dns_name, :private_dns_names, :vpc_endpoint_policy_supported, :acceptance_required, :manages_vpc_endpoints, :payer_responsibility, :tags, :private_dns_name_verification_state, :supported_ip_address_types) SENSITIVE = [] include Aws::Structure end |