Class: Aws::EC2::Types::ServiceLinkVirtualInterface
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::ServiceLinkVirtualInterface
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the service link virtual interfaces that establish connectivity between Amazon Web Services Outpost and on-premises networks.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration_state ⇒ String
The current state of the service link virtual interface.
-
#local_address ⇒ String
The IPv4 address assigned to the local gateway virtual interface on the Outpost side.
-
#outpost_arn ⇒ String
The Outpost Amazon Resource Number (ARN) for the service link virtual interface.
-
#outpost_id ⇒ String
The Outpost ID for the service link virtual interface.
-
#outpost_lag_id ⇒ String
The link aggregation group (LAG) ID for the service link virtual interface.
-
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the service link virtual interface..
-
#peer_address ⇒ String
The IPv4 peer address for the service link virtual interface.
-
#peer_bgp_asn ⇒ Integer
The ASN for the Border Gateway Protocol (BGP) associated with the service link virtual interface.
-
#service_link_virtual_interface_arn ⇒ String
The Amazon Resource Number (ARN) for the service link virtual interface.
-
#service_link_virtual_interface_id ⇒ String
The ID of the service link virtual interface.
-
#tags ⇒ Array<Types::Tag>
The tags associated with the service link virtual interface.
-
#vlan ⇒ Integer
The virtual local area network for the service link virtual interface.
Instance Attribute Details
#configuration_state ⇒ String
The current state of the service link virtual interface.
79342 79343 79344 79345 79346 79347 79348 79349 79350 79351 79352 79353 79354 79355 79356 79357 |
# File 'lib/aws-sdk-ec2/types.rb', line 79342 class ServiceLinkVirtualInterface < Struct.new( :service_link_virtual_interface_id, :service_link_virtual_interface_arn, :outpost_id, :outpost_arn, :owner_id, :local_address, :peer_address, :peer_bgp_asn, :vlan, :outpost_lag_id, :tags, :configuration_state) SENSITIVE = [] include Aws::Structure end |
#local_address ⇒ String
The IPv4 address assigned to the local gateway virtual interface on the Outpost side.
79342 79343 79344 79345 79346 79347 79348 79349 79350 79351 79352 79353 79354 79355 79356 79357 |
# File 'lib/aws-sdk-ec2/types.rb', line 79342 class ServiceLinkVirtualInterface < Struct.new( :service_link_virtual_interface_id, :service_link_virtual_interface_arn, :outpost_id, :outpost_arn, :owner_id, :local_address, :peer_address, :peer_bgp_asn, :vlan, :outpost_lag_id, :tags, :configuration_state) SENSITIVE = [] include Aws::Structure end |
#outpost_arn ⇒ String
The Outpost Amazon Resource Number (ARN) for the service link virtual interface.
79342 79343 79344 79345 79346 79347 79348 79349 79350 79351 79352 79353 79354 79355 79356 79357 |
# File 'lib/aws-sdk-ec2/types.rb', line 79342 class ServiceLinkVirtualInterface < Struct.new( :service_link_virtual_interface_id, :service_link_virtual_interface_arn, :outpost_id, :outpost_arn, :owner_id, :local_address, :peer_address, :peer_bgp_asn, :vlan, :outpost_lag_id, :tags, :configuration_state) SENSITIVE = [] include Aws::Structure end |
#outpost_id ⇒ String
The Outpost ID for the service link virtual interface.
79342 79343 79344 79345 79346 79347 79348 79349 79350 79351 79352 79353 79354 79355 79356 79357 |
# File 'lib/aws-sdk-ec2/types.rb', line 79342 class ServiceLinkVirtualInterface < Struct.new( :service_link_virtual_interface_id, :service_link_virtual_interface_arn, :outpost_id, :outpost_arn, :owner_id, :local_address, :peer_address, :peer_bgp_asn, :vlan, :outpost_lag_id, :tags, :configuration_state) SENSITIVE = [] include Aws::Structure end |
#outpost_lag_id ⇒ String
The link aggregation group (LAG) ID for the service link virtual interface.
79342 79343 79344 79345 79346 79347 79348 79349 79350 79351 79352 79353 79354 79355 79356 79357 |
# File 'lib/aws-sdk-ec2/types.rb', line 79342 class ServiceLinkVirtualInterface < Struct.new( :service_link_virtual_interface_id, :service_link_virtual_interface_arn, :outpost_id, :outpost_arn, :owner_id, :local_address, :peer_address, :peer_bgp_asn, :vlan, :outpost_lag_id, :tags, :configuration_state) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the service link virtual interface..
79342 79343 79344 79345 79346 79347 79348 79349 79350 79351 79352 79353 79354 79355 79356 79357 |
# File 'lib/aws-sdk-ec2/types.rb', line 79342 class ServiceLinkVirtualInterface < Struct.new( :service_link_virtual_interface_id, :service_link_virtual_interface_arn, :outpost_id, :outpost_arn, :owner_id, :local_address, :peer_address, :peer_bgp_asn, :vlan, :outpost_lag_id, :tags, :configuration_state) SENSITIVE = [] include Aws::Structure end |
#peer_address ⇒ String
The IPv4 peer address for the service link virtual interface.
79342 79343 79344 79345 79346 79347 79348 79349 79350 79351 79352 79353 79354 79355 79356 79357 |
# File 'lib/aws-sdk-ec2/types.rb', line 79342 class ServiceLinkVirtualInterface < Struct.new( :service_link_virtual_interface_id, :service_link_virtual_interface_arn, :outpost_id, :outpost_arn, :owner_id, :local_address, :peer_address, :peer_bgp_asn, :vlan, :outpost_lag_id, :tags, :configuration_state) SENSITIVE = [] include Aws::Structure end |
#peer_bgp_asn ⇒ Integer
The ASN for the Border Gateway Protocol (BGP) associated with the service link virtual interface.
79342 79343 79344 79345 79346 79347 79348 79349 79350 79351 79352 79353 79354 79355 79356 79357 |
# File 'lib/aws-sdk-ec2/types.rb', line 79342 class ServiceLinkVirtualInterface < Struct.new( :service_link_virtual_interface_id, :service_link_virtual_interface_arn, :outpost_id, :outpost_arn, :owner_id, :local_address, :peer_address, :peer_bgp_asn, :vlan, :outpost_lag_id, :tags, :configuration_state) SENSITIVE = [] include Aws::Structure end |
#service_link_virtual_interface_arn ⇒ String
The Amazon Resource Number (ARN) for the service link virtual interface.
79342 79343 79344 79345 79346 79347 79348 79349 79350 79351 79352 79353 79354 79355 79356 79357 |
# File 'lib/aws-sdk-ec2/types.rb', line 79342 class ServiceLinkVirtualInterface < Struct.new( :service_link_virtual_interface_id, :service_link_virtual_interface_arn, :outpost_id, :outpost_arn, :owner_id, :local_address, :peer_address, :peer_bgp_asn, :vlan, :outpost_lag_id, :tags, :configuration_state) SENSITIVE = [] include Aws::Structure end |
#service_link_virtual_interface_id ⇒ String
The ID of the service link virtual interface.
79342 79343 79344 79345 79346 79347 79348 79349 79350 79351 79352 79353 79354 79355 79356 79357 |
# File 'lib/aws-sdk-ec2/types.rb', line 79342 class ServiceLinkVirtualInterface < Struct.new( :service_link_virtual_interface_id, :service_link_virtual_interface_arn, :outpost_id, :outpost_arn, :owner_id, :local_address, :peer_address, :peer_bgp_asn, :vlan, :outpost_lag_id, :tags, :configuration_state) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags associated with the service link virtual interface.
79342 79343 79344 79345 79346 79347 79348 79349 79350 79351 79352 79353 79354 79355 79356 79357 |
# File 'lib/aws-sdk-ec2/types.rb', line 79342 class ServiceLinkVirtualInterface < Struct.new( :service_link_virtual_interface_id, :service_link_virtual_interface_arn, :outpost_id, :outpost_arn, :owner_id, :local_address, :peer_address, :peer_bgp_asn, :vlan, :outpost_lag_id, :tags, :configuration_state) SENSITIVE = [] include Aws::Structure end |
#vlan ⇒ Integer
The virtual local area network for the service link virtual interface.
79342 79343 79344 79345 79346 79347 79348 79349 79350 79351 79352 79353 79354 79355 79356 79357 |
# File 'lib/aws-sdk-ec2/types.rb', line 79342 class ServiceLinkVirtualInterface < Struct.new( :service_link_virtual_interface_id, :service_link_virtual_interface_arn, :outpost_id, :outpost_arn, :owner_id, :local_address, :peer_address, :peer_bgp_asn, :vlan, :outpost_lag_id, :tags, :configuration_state) SENSITIVE = [] include Aws::Structure end |