Class: Aws::EC2::Types::SlotDateTimeRangeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::SlotDateTimeRangeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the time period for a Scheduled Instance to start its first schedule. The time period must span less than one day.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#earliest_time ⇒ Time
The earliest date and time, in UTC, for the Scheduled Instance to start.
-
#latest_time ⇒ Time
The latest date and time, in UTC, for the Scheduled Instance to start.
Instance Attribute Details
#earliest_time ⇒ Time
The earliest date and time, in UTC, for the Scheduled Instance to start.
78685 78686 78687 78688 78689 78690 |
# File 'lib/aws-sdk-ec2/types.rb', line 78685 class SlotDateTimeRangeRequest < Struct.new( :earliest_time, :latest_time) SENSITIVE = [] include Aws::Structure end |
#latest_time ⇒ Time
The latest date and time, in UTC, for the Scheduled Instance to start. This value must be later than or equal to the earliest date and at most three months in the future.
78685 78686 78687 78688 78689 78690 |
# File 'lib/aws-sdk-ec2/types.rb', line 78685 class SlotDateTimeRangeRequest < Struct.new( :earliest_time, :latest_time) SENSITIVE = [] include Aws::Structure end |