Class: Aws::EC2::Types::SlotDateTimeRangeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes the time period for a Scheduled Instance to start its first schedule. The time period must span less than one day.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#earliest_timeTime

The earliest date and time, in UTC, for the Scheduled Instance to start.

Returns:

  • (Time)


78436
78437
78438
78439
78440
78441
# File 'lib/aws-sdk-ec2/types.rb', line 78436

class SlotDateTimeRangeRequest < Struct.new(
  :earliest_time,
  :latest_time)
  SENSITIVE = []
  include Aws::Structure
end

#latest_timeTime

The latest date and time, in UTC, for the Scheduled Instance to start. This value must be later than or equal to the earliest date and at most three months in the future.

Returns:

  • (Time)


78436
78437
78438
78439
78440
78441
# File 'lib/aws-sdk-ec2/types.rb', line 78436

class SlotDateTimeRangeRequest < Struct.new(
  :earliest_time,
  :latest_time)
  SENSITIVE = []
  include Aws::Structure
end