Class: Aws::EC2::Types::SnapshotInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::SnapshotInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Information about a snapshot.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone ⇒ String
The Availability Zone or Local Zone of the snapshots.
-
#description ⇒ String
Description specified by the CreateSnapshotRequest that has been applied to all snapshots.
-
#encrypted ⇒ Boolean
Indicates whether the snapshot is encrypted.
-
#outpost_arn ⇒ String
The ARN of the Outpost on which the snapshot is stored.
-
#owner_id ⇒ String
Account id used when creating this snapshot.
-
#progress ⇒ String
Progress this snapshot has made towards completing.
-
#snapshot_id ⇒ String
Snapshot id that can be used to describe this snapshot.
-
#sse_type ⇒ String
Reserved for future use.
-
#start_time ⇒ Time
Time this snapshot was started.
-
#state ⇒ String
Current state of the snapshot.
-
#tags ⇒ Array<Types::Tag>
Tags associated with this snapshot.
-
#volume_id ⇒ String
Source volume from which this snapshot was created.
-
#volume_size ⇒ Integer
Size of the volume from which this snapshot was created.
Instance Attribute Details
#availability_zone ⇒ String
The Availability Zone or Local Zone of the snapshots. For example,
us-west-1a (Availability Zone) or us-west-2-lax-1a (Local Zone).
79050 79051 79052 79053 79054 79055 79056 79057 79058 79059 79060 79061 79062 79063 79064 79065 79066 |
# File 'lib/aws-sdk-ec2/types.rb', line 79050 class SnapshotInfo < Struct.new( :description, :tags, :encrypted, :volume_id, :state, :volume_size, :start_time, :progress, :owner_id, :snapshot_id, :outpost_arn, :sse_type, :availability_zone) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Description specified by the CreateSnapshotRequest that has been applied to all snapshots.
79050 79051 79052 79053 79054 79055 79056 79057 79058 79059 79060 79061 79062 79063 79064 79065 79066 |
# File 'lib/aws-sdk-ec2/types.rb', line 79050 class SnapshotInfo < Struct.new( :description, :tags, :encrypted, :volume_id, :state, :volume_size, :start_time, :progress, :owner_id, :snapshot_id, :outpost_arn, :sse_type, :availability_zone) SENSITIVE = [] include Aws::Structure end |
#encrypted ⇒ Boolean
Indicates whether the snapshot is encrypted.
79050 79051 79052 79053 79054 79055 79056 79057 79058 79059 79060 79061 79062 79063 79064 79065 79066 |
# File 'lib/aws-sdk-ec2/types.rb', line 79050 class SnapshotInfo < Struct.new( :description, :tags, :encrypted, :volume_id, :state, :volume_size, :start_time, :progress, :owner_id, :snapshot_id, :outpost_arn, :sse_type, :availability_zone) SENSITIVE = [] include Aws::Structure end |
#outpost_arn ⇒ String
The ARN of the Outpost on which the snapshot is stored. For more information, see Amazon EBS local snapshots on Outposts in the Amazon EBS User Guide.
79050 79051 79052 79053 79054 79055 79056 79057 79058 79059 79060 79061 79062 79063 79064 79065 79066 |
# File 'lib/aws-sdk-ec2/types.rb', line 79050 class SnapshotInfo < Struct.new( :description, :tags, :encrypted, :volume_id, :state, :volume_size, :start_time, :progress, :owner_id, :snapshot_id, :outpost_arn, :sse_type, :availability_zone) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
Account id used when creating this snapshot.
79050 79051 79052 79053 79054 79055 79056 79057 79058 79059 79060 79061 79062 79063 79064 79065 79066 |
# File 'lib/aws-sdk-ec2/types.rb', line 79050 class SnapshotInfo < Struct.new( :description, :tags, :encrypted, :volume_id, :state, :volume_size, :start_time, :progress, :owner_id, :snapshot_id, :outpost_arn, :sse_type, :availability_zone) SENSITIVE = [] include Aws::Structure end |
#progress ⇒ String
Progress this snapshot has made towards completing.
79050 79051 79052 79053 79054 79055 79056 79057 79058 79059 79060 79061 79062 79063 79064 79065 79066 |
# File 'lib/aws-sdk-ec2/types.rb', line 79050 class SnapshotInfo < Struct.new( :description, :tags, :encrypted, :volume_id, :state, :volume_size, :start_time, :progress, :owner_id, :snapshot_id, :outpost_arn, :sse_type, :availability_zone) SENSITIVE = [] include Aws::Structure end |
#snapshot_id ⇒ String
Snapshot id that can be used to describe this snapshot.
79050 79051 79052 79053 79054 79055 79056 79057 79058 79059 79060 79061 79062 79063 79064 79065 79066 |
# File 'lib/aws-sdk-ec2/types.rb', line 79050 class SnapshotInfo < Struct.new( :description, :tags, :encrypted, :volume_id, :state, :volume_size, :start_time, :progress, :owner_id, :snapshot_id, :outpost_arn, :sse_type, :availability_zone) SENSITIVE = [] include Aws::Structure end |
#sse_type ⇒ String
Reserved for future use.
79050 79051 79052 79053 79054 79055 79056 79057 79058 79059 79060 79061 79062 79063 79064 79065 79066 |
# File 'lib/aws-sdk-ec2/types.rb', line 79050 class SnapshotInfo < Struct.new( :description, :tags, :encrypted, :volume_id, :state, :volume_size, :start_time, :progress, :owner_id, :snapshot_id, :outpost_arn, :sse_type, :availability_zone) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
Time this snapshot was started. This is the same for all snapshots initiated by the same request.
79050 79051 79052 79053 79054 79055 79056 79057 79058 79059 79060 79061 79062 79063 79064 79065 79066 |
# File 'lib/aws-sdk-ec2/types.rb', line 79050 class SnapshotInfo < Struct.new( :description, :tags, :encrypted, :volume_id, :state, :volume_size, :start_time, :progress, :owner_id, :snapshot_id, :outpost_arn, :sse_type, :availability_zone) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
Current state of the snapshot.
79050 79051 79052 79053 79054 79055 79056 79057 79058 79059 79060 79061 79062 79063 79064 79065 79066 |
# File 'lib/aws-sdk-ec2/types.rb', line 79050 class SnapshotInfo < Struct.new( :description, :tags, :encrypted, :volume_id, :state, :volume_size, :start_time, :progress, :owner_id, :snapshot_id, :outpost_arn, :sse_type, :availability_zone) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Tags associated with this snapshot.
79050 79051 79052 79053 79054 79055 79056 79057 79058 79059 79060 79061 79062 79063 79064 79065 79066 |
# File 'lib/aws-sdk-ec2/types.rb', line 79050 class SnapshotInfo < Struct.new( :description, :tags, :encrypted, :volume_id, :state, :volume_size, :start_time, :progress, :owner_id, :snapshot_id, :outpost_arn, :sse_type, :availability_zone) SENSITIVE = [] include Aws::Structure end |
#volume_id ⇒ String
Source volume from which this snapshot was created.
79050 79051 79052 79053 79054 79055 79056 79057 79058 79059 79060 79061 79062 79063 79064 79065 79066 |
# File 'lib/aws-sdk-ec2/types.rb', line 79050 class SnapshotInfo < Struct.new( :description, :tags, :encrypted, :volume_id, :state, :volume_size, :start_time, :progress, :owner_id, :snapshot_id, :outpost_arn, :sse_type, :availability_zone) SENSITIVE = [] include Aws::Structure end |
#volume_size ⇒ Integer
Size of the volume from which this snapshot was created.
79050 79051 79052 79053 79054 79055 79056 79057 79058 79059 79060 79061 79062 79063 79064 79065 79066 |
# File 'lib/aws-sdk-ec2/types.rb', line 79050 class SnapshotInfo < Struct.new( :description, :tags, :encrypted, :volume_id, :state, :volume_size, :start_time, :progress, :owner_id, :snapshot_id, :outpost_arn, :sse_type, :availability_zone) SENSITIVE = [] include Aws::Structure end |