Class: Aws::EC2::Types::SnapshotTierStatus
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::SnapshotTierStatus
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Provides information about a snapshot’s storage tier.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#archival_complete_time ⇒ Time
The date and time when the last archive process was completed.
-
#last_tiering_operation_status ⇒ String
The status of the last archive or restore process.
-
#last_tiering_operation_status_detail ⇒ String
A message describing the status of the last archive or restore process.
-
#last_tiering_progress ⇒ Integer
The progress of the last archive or restore process, as a percentage.
-
#last_tiering_start_time ⇒ Time
The date and time when the last archive or restore process was started.
-
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the snapshot.
-
#restore_expiry_time ⇒ Time
Only for archived snapshots that are temporarily restored.
-
#snapshot_id ⇒ String
The ID of the snapshot.
-
#status ⇒ String
The state of the snapshot.
-
#storage_tier ⇒ String
The storage tier in which the snapshot is stored.
-
#tags ⇒ Array<Types::Tag>
The tags that are assigned to the snapshot.
-
#volume_id ⇒ String
The ID of the volume from which the snapshot was created.
Instance Attribute Details
#archival_complete_time ⇒ Time
The date and time when the last archive process was completed.
78365 78366 78367 78368 78369 78370 78371 78372 78373 78374 78375 78376 78377 78378 78379 78380 |
# File 'lib/aws-sdk-ec2/types.rb', line 78365 class SnapshotTierStatus < Struct.new( :snapshot_id, :volume_id, :status, :owner_id, :tags, :storage_tier, :last_tiering_start_time, :last_tiering_progress, :last_tiering_operation_status, :last_tiering_operation_status_detail, :archival_complete_time, :restore_expiry_time) SENSITIVE = [] include Aws::Structure end |
#last_tiering_operation_status ⇒ String
The status of the last archive or restore process.
78365 78366 78367 78368 78369 78370 78371 78372 78373 78374 78375 78376 78377 78378 78379 78380 |
# File 'lib/aws-sdk-ec2/types.rb', line 78365 class SnapshotTierStatus < Struct.new( :snapshot_id, :volume_id, :status, :owner_id, :tags, :storage_tier, :last_tiering_start_time, :last_tiering_progress, :last_tiering_operation_status, :last_tiering_operation_status_detail, :archival_complete_time, :restore_expiry_time) SENSITIVE = [] include Aws::Structure end |
#last_tiering_operation_status_detail ⇒ String
A message describing the status of the last archive or restore process.
78365 78366 78367 78368 78369 78370 78371 78372 78373 78374 78375 78376 78377 78378 78379 78380 |
# File 'lib/aws-sdk-ec2/types.rb', line 78365 class SnapshotTierStatus < Struct.new( :snapshot_id, :volume_id, :status, :owner_id, :tags, :storage_tier, :last_tiering_start_time, :last_tiering_progress, :last_tiering_operation_status, :last_tiering_operation_status_detail, :archival_complete_time, :restore_expiry_time) SENSITIVE = [] include Aws::Structure end |
#last_tiering_progress ⇒ Integer
The progress of the last archive or restore process, as a percentage.
78365 78366 78367 78368 78369 78370 78371 78372 78373 78374 78375 78376 78377 78378 78379 78380 |
# File 'lib/aws-sdk-ec2/types.rb', line 78365 class SnapshotTierStatus < Struct.new( :snapshot_id, :volume_id, :status, :owner_id, :tags, :storage_tier, :last_tiering_start_time, :last_tiering_progress, :last_tiering_operation_status, :last_tiering_operation_status_detail, :archival_complete_time, :restore_expiry_time) SENSITIVE = [] include Aws::Structure end |
#last_tiering_start_time ⇒ Time
The date and time when the last archive or restore process was started.
78365 78366 78367 78368 78369 78370 78371 78372 78373 78374 78375 78376 78377 78378 78379 78380 |
# File 'lib/aws-sdk-ec2/types.rb', line 78365 class SnapshotTierStatus < Struct.new( :snapshot_id, :volume_id, :status, :owner_id, :tags, :storage_tier, :last_tiering_start_time, :last_tiering_progress, :last_tiering_operation_status, :last_tiering_operation_status_detail, :archival_complete_time, :restore_expiry_time) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the snapshot.
78365 78366 78367 78368 78369 78370 78371 78372 78373 78374 78375 78376 78377 78378 78379 78380 |
# File 'lib/aws-sdk-ec2/types.rb', line 78365 class SnapshotTierStatus < Struct.new( :snapshot_id, :volume_id, :status, :owner_id, :tags, :storage_tier, :last_tiering_start_time, :last_tiering_progress, :last_tiering_operation_status, :last_tiering_operation_status_detail, :archival_complete_time, :restore_expiry_time) SENSITIVE = [] include Aws::Structure end |
#restore_expiry_time ⇒ Time
Only for archived snapshots that are temporarily restored. Indicates the date and time when a temporarily restored snapshot will be automatically re-archived.
78365 78366 78367 78368 78369 78370 78371 78372 78373 78374 78375 78376 78377 78378 78379 78380 |
# File 'lib/aws-sdk-ec2/types.rb', line 78365 class SnapshotTierStatus < Struct.new( :snapshot_id, :volume_id, :status, :owner_id, :tags, :storage_tier, :last_tiering_start_time, :last_tiering_progress, :last_tiering_operation_status, :last_tiering_operation_status_detail, :archival_complete_time, :restore_expiry_time) SENSITIVE = [] include Aws::Structure end |
#snapshot_id ⇒ String
The ID of the snapshot.
78365 78366 78367 78368 78369 78370 78371 78372 78373 78374 78375 78376 78377 78378 78379 78380 |
# File 'lib/aws-sdk-ec2/types.rb', line 78365 class SnapshotTierStatus < Struct.new( :snapshot_id, :volume_id, :status, :owner_id, :tags, :storage_tier, :last_tiering_start_time, :last_tiering_progress, :last_tiering_operation_status, :last_tiering_operation_status_detail, :archival_complete_time, :restore_expiry_time) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The state of the snapshot.
78365 78366 78367 78368 78369 78370 78371 78372 78373 78374 78375 78376 78377 78378 78379 78380 |
# File 'lib/aws-sdk-ec2/types.rb', line 78365 class SnapshotTierStatus < Struct.new( :snapshot_id, :volume_id, :status, :owner_id, :tags, :storage_tier, :last_tiering_start_time, :last_tiering_progress, :last_tiering_operation_status, :last_tiering_operation_status_detail, :archival_complete_time, :restore_expiry_time) SENSITIVE = [] include Aws::Structure end |
#storage_tier ⇒ String
The storage tier in which the snapshot is stored. ‘standard` indicates that the snapshot is stored in the standard snapshot storage tier and that it is ready for use. `archive` indicates that the snapshot is currently archived and that it must be restored before it can be used.
78365 78366 78367 78368 78369 78370 78371 78372 78373 78374 78375 78376 78377 78378 78379 78380 |
# File 'lib/aws-sdk-ec2/types.rb', line 78365 class SnapshotTierStatus < Struct.new( :snapshot_id, :volume_id, :status, :owner_id, :tags, :storage_tier, :last_tiering_start_time, :last_tiering_progress, :last_tiering_operation_status, :last_tiering_operation_status_detail, :archival_complete_time, :restore_expiry_time) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags that are assigned to the snapshot.
78365 78366 78367 78368 78369 78370 78371 78372 78373 78374 78375 78376 78377 78378 78379 78380 |
# File 'lib/aws-sdk-ec2/types.rb', line 78365 class SnapshotTierStatus < Struct.new( :snapshot_id, :volume_id, :status, :owner_id, :tags, :storage_tier, :last_tiering_start_time, :last_tiering_progress, :last_tiering_operation_status, :last_tiering_operation_status_detail, :archival_complete_time, :restore_expiry_time) SENSITIVE = [] include Aws::Structure end |
#volume_id ⇒ String
The ID of the volume from which the snapshot was created.
78365 78366 78367 78368 78369 78370 78371 78372 78373 78374 78375 78376 78377 78378 78379 78380 |
# File 'lib/aws-sdk-ec2/types.rb', line 78365 class SnapshotTierStatus < Struct.new( :snapshot_id, :volume_id, :status, :owner_id, :tags, :storage_tier, :last_tiering_start_time, :last_tiering_progress, :last_tiering_operation_status, :last_tiering_operation_status_detail, :archival_complete_time, :restore_expiry_time) SENSITIVE = [] include Aws::Structure end |