Class: Aws::EC2::Types::SpotPrice
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::SpotPrice
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
The maximum price per unit hour that you are willing to pay for a Spot Instance. We do not recommend using this parameter because it can lead to increased interruptions. If you do not specify this parameter, you will pay the current Spot price.
If you specify a maximum price, your instances will be interrupted more frequently than if you do not specify this parameter.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone ⇒ String
The Availability Zone.
-
#availability_zone_id ⇒ String
The ID of the Availability Zone.
-
#instance_type ⇒ String
The instance type.
-
#product_description ⇒ String
A general description of the AMI.
-
#spot_price ⇒ String
The maximum price per unit hour that you are willing to pay for a Spot Instance.
-
#timestamp ⇒ Time
The date and time the request was created, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ).
Instance Attribute Details
#availability_zone ⇒ String
The Availability Zone.
81054 81055 81056 81057 81058 81059 81060 81061 81062 81063 |
# File 'lib/aws-sdk-ec2/types.rb', line 81054 class SpotPrice < Struct.new( :availability_zone, :availability_zone_id, :instance_type, :product_description, :spot_price, :timestamp) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
The ID of the Availability Zone.
81054 81055 81056 81057 81058 81059 81060 81061 81062 81063 |
# File 'lib/aws-sdk-ec2/types.rb', line 81054 class SpotPrice < Struct.new( :availability_zone, :availability_zone_id, :instance_type, :product_description, :spot_price, :timestamp) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The instance type.
81054 81055 81056 81057 81058 81059 81060 81061 81062 81063 |
# File 'lib/aws-sdk-ec2/types.rb', line 81054 class SpotPrice < Struct.new( :availability_zone, :availability_zone_id, :instance_type, :product_description, :spot_price, :timestamp) SENSITIVE = [] include Aws::Structure end |
#product_description ⇒ String
A general description of the AMI.
81054 81055 81056 81057 81058 81059 81060 81061 81062 81063 |
# File 'lib/aws-sdk-ec2/types.rb', line 81054 class SpotPrice < Struct.new( :availability_zone, :availability_zone_id, :instance_type, :product_description, :spot_price, :timestamp) SENSITIVE = [] include Aws::Structure end |
#spot_price ⇒ String
The maximum price per unit hour that you are willing to pay for a Spot Instance. We do not recommend using this parameter because it can lead to increased interruptions. If you do not specify this parameter, you will pay the current Spot price.
If you specify a maximum price, your instances will be interrupted more frequently than if you do not specify this parameter.
81054 81055 81056 81057 81058 81059 81060 81061 81062 81063 |
# File 'lib/aws-sdk-ec2/types.rb', line 81054 class SpotPrice < Struct.new( :availability_zone, :availability_zone_id, :instance_type, :product_description, :spot_price, :timestamp) SENSITIVE = [] include Aws::Structure end |
#timestamp ⇒ Time
The date and time the request was created, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ).
81054 81055 81056 81057 81058 81059 81060 81061 81062 81063 |
# File 'lib/aws-sdk-ec2/types.rb', line 81054 class SpotPrice < Struct.new( :availability_zone, :availability_zone_id, :instance_type, :product_description, :spot_price, :timestamp) SENSITIVE = [] include Aws::Structure end |