Class: Aws::EC2::Types::SpotPrice

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

The maximum price per unit hour that you are willing to pay for a Spot Instance. We do not recommend using this parameter because it can lead to increased interruptions. If you do not specify this parameter, you will pay the current Spot price.

If you specify a maximum price, your instances will be interrupted more frequently than if you do not specify this parameter.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_zoneString

The Availability Zone.

Returns:

  • (String)


81007
81008
81009
81010
81011
81012
81013
81014
81015
81016
# File 'lib/aws-sdk-ec2/types.rb', line 81007

class SpotPrice < Struct.new(
  :availability_zone,
  :availability_zone_id,
  :instance_type,
  :product_description,
  :spot_price,
  :timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zone_idString

The ID of the Availability Zone.

Returns:

  • (String)


81007
81008
81009
81010
81011
81012
81013
81014
81015
81016
# File 'lib/aws-sdk-ec2/types.rb', line 81007

class SpotPrice < Struct.new(
  :availability_zone,
  :availability_zone_id,
  :instance_type,
  :product_description,
  :spot_price,
  :timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

The instance type.

Returns:

  • (String)


81007
81008
81009
81010
81011
81012
81013
81014
81015
81016
# File 'lib/aws-sdk-ec2/types.rb', line 81007

class SpotPrice < Struct.new(
  :availability_zone,
  :availability_zone_id,
  :instance_type,
  :product_description,
  :spot_price,
  :timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#product_descriptionString

A general description of the AMI.

Returns:

  • (String)


81007
81008
81009
81010
81011
81012
81013
81014
81015
81016
# File 'lib/aws-sdk-ec2/types.rb', line 81007

class SpotPrice < Struct.new(
  :availability_zone,
  :availability_zone_id,
  :instance_type,
  :product_description,
  :spot_price,
  :timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#spot_priceString

The maximum price per unit hour that you are willing to pay for a Spot Instance. We do not recommend using this parameter because it can lead to increased interruptions. If you do not specify this parameter, you will pay the current Spot price.

If you specify a maximum price, your instances will be interrupted more frequently than if you do not specify this parameter.

Returns:

  • (String)


81007
81008
81009
81010
81011
81012
81013
81014
81015
81016
# File 'lib/aws-sdk-ec2/types.rb', line 81007

class SpotPrice < Struct.new(
  :availability_zone,
  :availability_zone_id,
  :instance_type,
  :product_description,
  :spot_price,
  :timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#timestampTime

The date and time the request was created, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ).

Returns:

  • (Time)


81007
81008
81009
81010
81011
81012
81013
81014
81015
81016
# File 'lib/aws-sdk-ec2/types.rb', line 81007

class SpotPrice < Struct.new(
  :availability_zone,
  :availability_zone_id,
  :instance_type,
  :product_description,
  :spot_price,
  :timestamp)
  SENSITIVE = []
  include Aws::Structure
end