Class: Aws::EC2::Types::SpotPrice

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

The maximum price per unit hour that you are willing to pay for a Spot Instance. We do not recommend using this parameter because it can lead to increased interruptions. If you do not specify this parameter, you will pay the current Spot price.

If you specify a maximum price, your instances will be interrupted more frequently than if you do not specify this parameter.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_zoneString

The Availability Zone.

Returns:

  • (String)


79972
79973
79974
79975
79976
79977
79978
79979
79980
79981
# File 'lib/aws-sdk-ec2/types.rb', line 79972

class SpotPrice < Struct.new(
  :availability_zone,
  :availability_zone_id,
  :instance_type,
  :product_description,
  :spot_price,
  :timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zone_idString

The ID of the Availability Zone.

Returns:

  • (String)


79972
79973
79974
79975
79976
79977
79978
79979
79980
79981
# File 'lib/aws-sdk-ec2/types.rb', line 79972

class SpotPrice < Struct.new(
  :availability_zone,
  :availability_zone_id,
  :instance_type,
  :product_description,
  :spot_price,
  :timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

The instance type.

Returns:

  • (String)


79972
79973
79974
79975
79976
79977
79978
79979
79980
79981
# File 'lib/aws-sdk-ec2/types.rb', line 79972

class SpotPrice < Struct.new(
  :availability_zone,
  :availability_zone_id,
  :instance_type,
  :product_description,
  :spot_price,
  :timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#product_descriptionString

A general description of the AMI.

Returns:

  • (String)


79972
79973
79974
79975
79976
79977
79978
79979
79980
79981
# File 'lib/aws-sdk-ec2/types.rb', line 79972

class SpotPrice < Struct.new(
  :availability_zone,
  :availability_zone_id,
  :instance_type,
  :product_description,
  :spot_price,
  :timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#spot_priceString

The maximum price per unit hour that you are willing to pay for a Spot Instance. We do not recommend using this parameter because it can lead to increased interruptions. If you do not specify this parameter, you will pay the current Spot price.

If you specify a maximum price, your instances will be interrupted more frequently than if you do not specify this parameter.

Returns:

  • (String)


79972
79973
79974
79975
79976
79977
79978
79979
79980
79981
# File 'lib/aws-sdk-ec2/types.rb', line 79972

class SpotPrice < Struct.new(
  :availability_zone,
  :availability_zone_id,
  :instance_type,
  :product_description,
  :spot_price,
  :timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#timestampTime

The date and time the request was created, in UTC format (for example, YYYY-MM-*DD*T*HH*:MM:*SS*Z).

Returns:

  • (Time)


79972
79973
79974
79975
79976
79977
79978
79979
79980
79981
# File 'lib/aws-sdk-ec2/types.rb', line 79972

class SpotPrice < Struct.new(
  :availability_zone,
  :availability_zone_id,
  :instance_type,
  :product_description,
  :spot_price,
  :timestamp)
  SENSITIVE = []
  include Aws::Structure
end