Class: Aws::EC2::Types::StaleIpPermission
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::StaleIpPermission
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a stale rule in a security group.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#from_port ⇒ Integer
If the protocol is TCP or UDP, this is the start of the port range.
-
#ip_protocol ⇒ String
The IP protocol name (‘tcp`, `udp`, `icmp`, `icmpv6`) or number (see [Protocol Numbers)].
-
#ip_ranges ⇒ Array<String>
The IP ranges.
-
#prefix_list_ids ⇒ Array<String>
The prefix list IDs.
-
#to_port ⇒ Integer
If the protocol is TCP or UDP, this is the end of the port range.
-
#user_id_group_pairs ⇒ Array<Types::UserIdGroupPair>
The security group pairs.
Instance Attribute Details
#from_port ⇒ Integer
If the protocol is TCP or UDP, this is the start of the port range. If the protocol is ICMP or ICMPv6, this is the ICMP type or -1 (all ICMP types).
80170 80171 80172 80173 80174 80175 80176 80177 80178 80179 |
# File 'lib/aws-sdk-ec2/types.rb', line 80170 class StaleIpPermission < Struct.new( :from_port, :ip_protocol, :ip_ranges, :prefix_list_ids, :to_port, :user_id_group_pairs) SENSITIVE = [] include Aws::Structure end |
#ip_protocol ⇒ String
The IP protocol name (‘tcp`, `udp`, `icmp`, `icmpv6`) or number (see [Protocol Numbers)].
[1]: www.iana.org/assignments/protocol-numbers/protocol-numbers.xhtml
80170 80171 80172 80173 80174 80175 80176 80177 80178 80179 |
# File 'lib/aws-sdk-ec2/types.rb', line 80170 class StaleIpPermission < Struct.new( :from_port, :ip_protocol, :ip_ranges, :prefix_list_ids, :to_port, :user_id_group_pairs) SENSITIVE = [] include Aws::Structure end |
#ip_ranges ⇒ Array<String>
The IP ranges. Not applicable for stale security group rules.
80170 80171 80172 80173 80174 80175 80176 80177 80178 80179 |
# File 'lib/aws-sdk-ec2/types.rb', line 80170 class StaleIpPermission < Struct.new( :from_port, :ip_protocol, :ip_ranges, :prefix_list_ids, :to_port, :user_id_group_pairs) SENSITIVE = [] include Aws::Structure end |
#prefix_list_ids ⇒ Array<String>
The prefix list IDs. Not applicable for stale security group rules.
80170 80171 80172 80173 80174 80175 80176 80177 80178 80179 |
# File 'lib/aws-sdk-ec2/types.rb', line 80170 class StaleIpPermission < Struct.new( :from_port, :ip_protocol, :ip_ranges, :prefix_list_ids, :to_port, :user_id_group_pairs) SENSITIVE = [] include Aws::Structure end |
#to_port ⇒ Integer
If the protocol is TCP or UDP, this is the end of the port range. If the protocol is ICMP or ICMPv6, this is the ICMP code or -1 (all ICMP codes).
80170 80171 80172 80173 80174 80175 80176 80177 80178 80179 |
# File 'lib/aws-sdk-ec2/types.rb', line 80170 class StaleIpPermission < Struct.new( :from_port, :ip_protocol, :ip_ranges, :prefix_list_ids, :to_port, :user_id_group_pairs) SENSITIVE = [] include Aws::Structure end |
#user_id_group_pairs ⇒ Array<Types::UserIdGroupPair>
The security group pairs. Returns the ID of the referenced security group and VPC, and the ID and status of the VPC peering connection.
80170 80171 80172 80173 80174 80175 80176 80177 80178 80179 |
# File 'lib/aws-sdk-ec2/types.rb', line 80170 class StaleIpPermission < Struct.new( :from_port, :ip_protocol, :ip_ranges, :prefix_list_ids, :to_port, :user_id_group_pairs) SENSITIVE = [] include Aws::Structure end |