Class: Aws::EC2::Types::StartDeclarativePoliciesReportRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::StartDeclarativePoliciesReportRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#s3_bucket ⇒ String
The name of the S3 bucket where the report will be saved.
-
#s3_prefix ⇒ String
The prefix for your S3 object.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply.
-
#target_id ⇒ String
The root ID, organizational unit ID, or account ID.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
81326 81327 81328 81329 81330 81331 81332 81333 81334 |
# File 'lib/aws-sdk-ec2/types.rb', line 81326 class StartDeclarativePoliciesReportRequest < Struct.new( :dry_run, :s3_bucket, :s3_prefix, :target_id, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#s3_bucket ⇒ String
The name of the S3 bucket where the report will be saved. The bucket must be in the same Region where the report generation request is made.
81326 81327 81328 81329 81330 81331 81332 81333 81334 |
# File 'lib/aws-sdk-ec2/types.rb', line 81326 class StartDeclarativePoliciesReportRequest < Struct.new( :dry_run, :s3_bucket, :s3_prefix, :target_id, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#s3_prefix ⇒ String
The prefix for your S3 object.
81326 81327 81328 81329 81330 81331 81332 81333 81334 |
# File 'lib/aws-sdk-ec2/types.rb', line 81326 class StartDeclarativePoliciesReportRequest < Struct.new( :dry_run, :s3_bucket, :s3_prefix, :target_id, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply.
81326 81327 81328 81329 81330 81331 81332 81333 81334 |
# File 'lib/aws-sdk-ec2/types.rb', line 81326 class StartDeclarativePoliciesReportRequest < Struct.new( :dry_run, :s3_bucket, :s3_prefix, :target_id, :tag_specifications) SENSITIVE = [] include Aws::Structure end |
#target_id ⇒ String
The root ID, organizational unit ID, or account ID.
Format:
-
For root:
r-ab12 -
For OU:
ou-ab12-cdef1234 -
For account:
123456789012
81326 81327 81328 81329 81330 81331 81332 81333 81334 |
# File 'lib/aws-sdk-ec2/types.rb', line 81326 class StartDeclarativePoliciesReportRequest < Struct.new( :dry_run, :s3_bucket, :s3_prefix, :target_id, :tag_specifications) SENSITIVE = [] include Aws::Structure end |