Class: Aws::EC2::Types::StartDeclarativePoliciesReportRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


80107
80108
80109
80110
80111
80112
80113
80114
80115
# File 'lib/aws-sdk-ec2/types.rb', line 80107

class StartDeclarativePoliciesReportRequest < Struct.new(
  :dry_run,
  :s3_bucket,
  :s3_prefix,
  :target_id,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#s3_bucketString

The name of the S3 bucket where the report will be saved. The bucket must be in the same Region where the report generation request is made.

Returns:

  • (String)


80107
80108
80109
80110
80111
80112
80113
80114
80115
# File 'lib/aws-sdk-ec2/types.rb', line 80107

class StartDeclarativePoliciesReportRequest < Struct.new(
  :dry_run,
  :s3_bucket,
  :s3_prefix,
  :target_id,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#s3_prefixString

The prefix for your S3 object.

Returns:

  • (String)


80107
80108
80109
80110
80111
80112
80113
80114
80115
# File 'lib/aws-sdk-ec2/types.rb', line 80107

class StartDeclarativePoliciesReportRequest < Struct.new(
  :dry_run,
  :s3_bucket,
  :s3_prefix,
  :target_id,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply.

Returns:



80107
80108
80109
80110
80111
80112
80113
80114
80115
# File 'lib/aws-sdk-ec2/types.rb', line 80107

class StartDeclarativePoliciesReportRequest < Struct.new(
  :dry_run,
  :s3_bucket,
  :s3_prefix,
  :target_id,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end

#target_idString

The root ID, organizational unit ID, or account ID.

Format:

  • For root: ‘r-ab12`

  • For OU: ‘ou-ab12-cdef1234`

  • For account: ‘123456789012`

Returns:

  • (String)


80107
80108
80109
80110
80111
80112
80113
80114
80115
# File 'lib/aws-sdk-ec2/types.rb', line 80107

class StartDeclarativePoliciesReportRequest < Struct.new(
  :dry_run,
  :s3_bucket,
  :s3_prefix,
  :target_id,
  :tag_specifications)
  SENSITIVE = []
  include Aws::Structure
end