Class: Aws::EC2::Types::StartInstancesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_infoString

Reserved.

Returns:

  • (String)


84353
84354
84355
84356
84357
84358
84359
# File 'lib/aws-sdk-ec2/types.rb', line 84353

class StartInstancesRequest < Struct.new(
  :instance_ids,
  :additional_info,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


84353
84354
84355
84356
84357
84358
84359
# File 'lib/aws-sdk-ec2/types.rb', line 84353

class StartInstancesRequest < Struct.new(
  :instance_ids,
  :additional_info,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idsArray<String>

The IDs of the instances.

Returns:

  • (Array<String>)


84353
84354
84355
84356
84357
84358
84359
# File 'lib/aws-sdk-ec2/types.rb', line 84353

class StartInstancesRequest < Struct.new(
  :instance_ids,
  :additional_info,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end