Class: Aws::EC2::Types::StartInstancesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_infoString

Reserved.

Returns:

  • (String)


80721
80722
80723
80724
80725
80726
80727
# File 'lib/aws-sdk-ec2/types.rb', line 80721

class StartInstancesRequest < Struct.new(
  :instance_ids,
  :additional_info,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


80721
80722
80723
80724
80725
80726
80727
# File 'lib/aws-sdk-ec2/types.rb', line 80721

class StartInstancesRequest < Struct.new(
  :instance_ids,
  :additional_info,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idsArray<String>

The IDs of the instances.

Returns:

  • (Array<String>)


80721
80722
80723
80724
80725
80726
80727
# File 'lib/aws-sdk-ec2/types.rb', line 80721

class StartInstancesRequest < Struct.new(
  :instance_ids,
  :additional_info,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end