Class: Aws::EC2::Types::StartInstancesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::StartInstancesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_info ⇒ String
Reserved.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#instance_ids ⇒ Array<String>
The IDs of the instances.
Instance Attribute Details
#additional_info ⇒ String
Reserved.
79974 79975 79976 79977 79978 79979 79980 |
# File 'lib/aws-sdk-ec2/types.rb', line 79974 class StartInstancesRequest < Struct.new( :instance_ids, :additional_info, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
79974 79975 79976 79977 79978 79979 79980 |
# File 'lib/aws-sdk-ec2/types.rb', line 79974 class StartInstancesRequest < Struct.new( :instance_ids, :additional_info, :dry_run) SENSITIVE = [] include Aws::Structure end |
#instance_ids ⇒ Array<String>
The IDs of the instances.
79974 79975 79976 79977 79978 79979 79980 |
# File 'lib/aws-sdk-ec2/types.rb', line 79974 class StartInstancesRequest < Struct.new( :instance_ids, :additional_info, :dry_run) SENSITIVE = [] include Aws::Structure end |