Class: Aws::EC2::Types::StartNetworkInsightsAccessScopeAnalysisRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::StartNetworkInsightsAccessScopeAnalysisRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#network_insights_access_scope_id ⇒ String
The ID of the Network Access Scope.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [How to ensure idempotency].
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html
80174 80175 80176 80177 80178 80179 80180 80181 |
# File 'lib/aws-sdk-ec2/types.rb', line 80174 class StartNetworkInsightsAccessScopeAnalysisRequest < Struct.new( :network_insights_access_scope_id, :dry_run, :tag_specifications, :client_token) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
80174 80175 80176 80177 80178 80179 80180 80181 |
# File 'lib/aws-sdk-ec2/types.rb', line 80174 class StartNetworkInsightsAccessScopeAnalysisRequest < Struct.new( :network_insights_access_scope_id, :dry_run, :tag_specifications, :client_token) SENSITIVE = [] include Aws::Structure end |
#network_insights_access_scope_id ⇒ String
The ID of the Network Access Scope.
80174 80175 80176 80177 80178 80179 80180 80181 |
# File 'lib/aws-sdk-ec2/types.rb', line 80174 class StartNetworkInsightsAccessScopeAnalysisRequest < Struct.new( :network_insights_access_scope_id, :dry_run, :tag_specifications, :client_token) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply.
80174 80175 80176 80177 80178 80179 80180 80181 |
# File 'lib/aws-sdk-ec2/types.rb', line 80174 class StartNetworkInsightsAccessScopeAnalysisRequest < Struct.new( :network_insights_access_scope_id, :dry_run, :tag_specifications, :client_token) SENSITIVE = [] include Aws::Structure end |