Class: Aws::EC2::Types::StartNetworkInsightsAccessScopeAnalysisRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [How to ensure idempotency].

**A suitable default value is auto-generated.** You should normally not need to pass this option.

[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html

Returns:

  • (String)


78134
78135
78136
78137
78138
78139
78140
78141
# File 'lib/aws-sdk-ec2/types.rb', line 78134

class StartNetworkInsightsAccessScopeAnalysisRequest < Struct.new(
  :network_insights_access_scope_id,
  :dry_run,
  :tag_specifications,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


78134
78135
78136
78137
78138
78139
78140
78141
# File 'lib/aws-sdk-ec2/types.rb', line 78134

class StartNetworkInsightsAccessScopeAnalysisRequest < Struct.new(
  :network_insights_access_scope_id,
  :dry_run,
  :tag_specifications,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#network_insights_access_scope_idString

The ID of the Network Access Scope.

Returns:

  • (String)


78134
78135
78136
78137
78138
78139
78140
78141
# File 'lib/aws-sdk-ec2/types.rb', line 78134

class StartNetworkInsightsAccessScopeAnalysisRequest < Struct.new(
  :network_insights_access_scope_id,
  :dry_run,
  :tag_specifications,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply.

Returns:



78134
78135
78136
78137
78138
78139
78140
78141
# File 'lib/aws-sdk-ec2/types.rb', line 78134

class StartNetworkInsightsAccessScopeAnalysisRequest < Struct.new(
  :network_insights_access_scope_id,
  :dry_run,
  :tag_specifications,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end