Class: Aws::EC2::Types::StartNetworkInsightsAnalysisRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::StartNetworkInsightsAnalysisRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_accounts ⇒ Array<String>
The member accounts that contain resources that the path can traverse.
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#filter_in_arns ⇒ Array<String>
The Amazon Resource Names (ARN) of the resources that the path must traverse.
-
#filter_out_arns ⇒ Array<String>
The Amazon Resource Names (ARN) of the resources that the path will ignore.
-
#network_insights_path_id ⇒ String
The ID of the path.
-
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply.
Instance Attribute Details
#additional_accounts ⇒ Array<String>
The member accounts that contain resources that the path can traverse.
81330 81331 81332 81333 81334 81335 81336 81337 81338 81339 81340 |
# File 'lib/aws-sdk-ec2/types.rb', line 81330 class StartNetworkInsightsAnalysisRequest < Struct.new( :network_insights_path_id, :additional_accounts, :filter_in_arns, :filter_out_arns, :dry_run, :tag_specifications, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency.
A suitable default value is auto-generated. You should normally not need to pass this option.
81330 81331 81332 81333 81334 81335 81336 81337 81338 81339 81340 |
# File 'lib/aws-sdk-ec2/types.rb', line 81330 class StartNetworkInsightsAnalysisRequest < Struct.new( :network_insights_path_id, :additional_accounts, :filter_in_arns, :filter_out_arns, :dry_run, :tag_specifications, :client_token) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
81330 81331 81332 81333 81334 81335 81336 81337 81338 81339 81340 |
# File 'lib/aws-sdk-ec2/types.rb', line 81330 class StartNetworkInsightsAnalysisRequest < Struct.new( :network_insights_path_id, :additional_accounts, :filter_in_arns, :filter_out_arns, :dry_run, :tag_specifications, :client_token) SENSITIVE = [] include Aws::Structure end |
#filter_in_arns ⇒ Array<String>
The Amazon Resource Names (ARN) of the resources that the path must traverse.
81330 81331 81332 81333 81334 81335 81336 81337 81338 81339 81340 |
# File 'lib/aws-sdk-ec2/types.rb', line 81330 class StartNetworkInsightsAnalysisRequest < Struct.new( :network_insights_path_id, :additional_accounts, :filter_in_arns, :filter_out_arns, :dry_run, :tag_specifications, :client_token) SENSITIVE = [] include Aws::Structure end |
#filter_out_arns ⇒ Array<String>
The Amazon Resource Names (ARN) of the resources that the path will ignore.
81330 81331 81332 81333 81334 81335 81336 81337 81338 81339 81340 |
# File 'lib/aws-sdk-ec2/types.rb', line 81330 class StartNetworkInsightsAnalysisRequest < Struct.new( :network_insights_path_id, :additional_accounts, :filter_in_arns, :filter_out_arns, :dry_run, :tag_specifications, :client_token) SENSITIVE = [] include Aws::Structure end |
#network_insights_path_id ⇒ String
The ID of the path.
81330 81331 81332 81333 81334 81335 81336 81337 81338 81339 81340 |
# File 'lib/aws-sdk-ec2/types.rb', line 81330 class StartNetworkInsightsAnalysisRequest < Struct.new( :network_insights_path_id, :additional_accounts, :filter_in_arns, :filter_out_arns, :dry_run, :tag_specifications, :client_token) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Array<Types::TagSpecification>
The tags to apply.
81330 81331 81332 81333 81334 81335 81336 81337 81338 81339 81340 |
# File 'lib/aws-sdk-ec2/types.rb', line 81330 class StartNetworkInsightsAnalysisRequest < Struct.new( :network_insights_path_id, :additional_accounts, :filter_in_arns, :filter_out_arns, :dry_run, :tag_specifications, :client_token) SENSITIVE = [] include Aws::Structure end |