Class: Aws::EC2::Types::StartNetworkInsightsAnalysisRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_accountsArray<String>

The member accounts that contain resources that the path can traverse.

Returns:

  • (Array<String>)


78327
78328
78329
78330
78331
78332
78333
78334
78335
78336
78337
# File 'lib/aws-sdk-ec2/types.rb', line 78327

class StartNetworkInsightsAnalysisRequest < Struct.new(
  :network_insights_path_id,
  :additional_accounts,
  :filter_in_arns,
  :filter_out_arns,
  :dry_run,
  :tag_specifications,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see [How to ensure idempotency].

**A suitable default value is auto-generated.** You should normally not need to pass this option.

[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html

Returns:

  • (String)


78327
78328
78329
78330
78331
78332
78333
78334
78335
78336
78337
# File 'lib/aws-sdk-ec2/types.rb', line 78327

class StartNetworkInsightsAnalysisRequest < Struct.new(
  :network_insights_path_id,
  :additional_accounts,
  :filter_in_arns,
  :filter_out_arns,
  :dry_run,
  :tag_specifications,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


78327
78328
78329
78330
78331
78332
78333
78334
78335
78336
78337
# File 'lib/aws-sdk-ec2/types.rb', line 78327

class StartNetworkInsightsAnalysisRequest < Struct.new(
  :network_insights_path_id,
  :additional_accounts,
  :filter_in_arns,
  :filter_out_arns,
  :dry_run,
  :tag_specifications,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#filter_in_arnsArray<String>

The Amazon Resource Names (ARN) of the resources that the path must traverse.

Returns:

  • (Array<String>)


78327
78328
78329
78330
78331
78332
78333
78334
78335
78336
78337
# File 'lib/aws-sdk-ec2/types.rb', line 78327

class StartNetworkInsightsAnalysisRequest < Struct.new(
  :network_insights_path_id,
  :additional_accounts,
  :filter_in_arns,
  :filter_out_arns,
  :dry_run,
  :tag_specifications,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#filter_out_arnsArray<String>

The Amazon Resource Names (ARN) of the resources that the path will ignore.

Returns:

  • (Array<String>)


78327
78328
78329
78330
78331
78332
78333
78334
78335
78336
78337
# File 'lib/aws-sdk-ec2/types.rb', line 78327

class StartNetworkInsightsAnalysisRequest < Struct.new(
  :network_insights_path_id,
  :additional_accounts,
  :filter_in_arns,
  :filter_out_arns,
  :dry_run,
  :tag_specifications,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#network_insights_path_idString

The ID of the path.

Returns:

  • (String)


78327
78328
78329
78330
78331
78332
78333
78334
78335
78336
78337
# File 'lib/aws-sdk-ec2/types.rb', line 78327

class StartNetworkInsightsAnalysisRequest < Struct.new(
  :network_insights_path_id,
  :additional_accounts,
  :filter_in_arns,
  :filter_out_arns,
  :dry_run,
  :tag_specifications,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#tag_specificationsArray<Types::TagSpecification>

The tags to apply.

Returns:



78327
78328
78329
78330
78331
78332
78333
78334
78335
78336
78337
# File 'lib/aws-sdk-ec2/types.rb', line 78327

class StartNetworkInsightsAnalysisRequest < Struct.new(
  :network_insights_path_id,
  :additional_accounts,
  :filter_in_arns,
  :filter_out_arns,
  :dry_run,
  :tag_specifications,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end