Class: Aws::EC2::Types::StartVpcEndpointServicePrivateDnsVerificationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


83062
83063
83064
83065
83066
83067
# File 'lib/aws-sdk-ec2/types.rb', line 83062

class StartVpcEndpointServicePrivateDnsVerificationRequest < Struct.new(
  :dry_run,
  :service_id)
  SENSITIVE = []
  include Aws::Structure
end

#service_idString

The ID of the endpoint service.

Returns:

  • (String)


83062
83063
83064
83065
83066
83067
# File 'lib/aws-sdk-ec2/types.rb', line 83062

class StartVpcEndpointServicePrivateDnsVerificationRequest < Struct.new(
  :dry_run,
  :service_id)
  SENSITIVE = []
  include Aws::Structure
end