Class: Aws::EC2::Types::StartVpcEndpointServicePrivateDnsVerificationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::StartVpcEndpointServicePrivateDnsVerificationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#service_id ⇒ String
The ID of the endpoint service.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
83062 83063 83064 83065 83066 83067 |
# File 'lib/aws-sdk-ec2/types.rb', line 83062 class StartVpcEndpointServicePrivateDnsVerificationRequest < Struct.new( :dry_run, :service_id) SENSITIVE = [] include Aws::Structure end |
#service_id ⇒ String
The ID of the endpoint service.
83062 83063 83064 83065 83066 83067 |
# File 'lib/aws-sdk-ec2/types.rb', line 83062 class StartVpcEndpointServicePrivateDnsVerificationRequest < Struct.new( :dry_run, :service_id) SENSITIVE = [] include Aws::Structure end |