Class: Aws::EC2::Types::StartVpcEndpointServicePrivateDnsVerificationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::StartVpcEndpointServicePrivateDnsVerificationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#service_id ⇒ String
The ID of the endpoint service.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
80991 80992 80993 80994 80995 80996 |
# File 'lib/aws-sdk-ec2/types.rb', line 80991 class StartVpcEndpointServicePrivateDnsVerificationRequest < Struct.new( :dry_run, :service_id) SENSITIVE = [] include Aws::Structure end |
#service_id ⇒ String
The ID of the endpoint service.
80991 80992 80993 80994 80995 80996 |
# File 'lib/aws-sdk-ec2/types.rb', line 80991 class StartVpcEndpointServicePrivateDnsVerificationRequest < Struct.new( :dry_run, :service_id) SENSITIVE = [] include Aws::Structure end |