Class: Aws::EC2::Types::StoreImageTaskResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::StoreImageTaskResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
The information about the AMI store task, including the progress of the task.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ami_id ⇒ String
The ID of the AMI that is being stored.
-
#bucket ⇒ String
The name of the Amazon S3 bucket that contains the stored AMI object.
-
#progress_percentage ⇒ Integer
The progress of the task as a percentage.
-
#s3object_key ⇒ String
The name of the stored AMI object in the bucket.
-
#store_task_failure_reason ⇒ String
If the tasks fails, the reason for the failure is returned.
-
#store_task_state ⇒ String
The state of the store task (
InProgress,Completed, orFailed). -
#task_start_time ⇒ Time
The time the task started.
Instance Attribute Details
#ami_id ⇒ String
The ID of the AMI that is being stored.
81218 81219 81220 81221 81222 81223 81224 81225 81226 81227 81228 |
# File 'lib/aws-sdk-ec2/types.rb', line 81218 class StoreImageTaskResult < Struct.new( :ami_id, :task_start_time, :bucket, :s3object_key, :progress_percentage, :store_task_state, :store_task_failure_reason) SENSITIVE = [] include Aws::Structure end |
#bucket ⇒ String
The name of the Amazon S3 bucket that contains the stored AMI object.
81218 81219 81220 81221 81222 81223 81224 81225 81226 81227 81228 |
# File 'lib/aws-sdk-ec2/types.rb', line 81218 class StoreImageTaskResult < Struct.new( :ami_id, :task_start_time, :bucket, :s3object_key, :progress_percentage, :store_task_state, :store_task_failure_reason) SENSITIVE = [] include Aws::Structure end |
#progress_percentage ⇒ Integer
The progress of the task as a percentage.
81218 81219 81220 81221 81222 81223 81224 81225 81226 81227 81228 |
# File 'lib/aws-sdk-ec2/types.rb', line 81218 class StoreImageTaskResult < Struct.new( :ami_id, :task_start_time, :bucket, :s3object_key, :progress_percentage, :store_task_state, :store_task_failure_reason) SENSITIVE = [] include Aws::Structure end |
#s3object_key ⇒ String
The name of the stored AMI object in the bucket.
81218 81219 81220 81221 81222 81223 81224 81225 81226 81227 81228 |
# File 'lib/aws-sdk-ec2/types.rb', line 81218 class StoreImageTaskResult < Struct.new( :ami_id, :task_start_time, :bucket, :s3object_key, :progress_percentage, :store_task_state, :store_task_failure_reason) SENSITIVE = [] include Aws::Structure end |
#store_task_failure_reason ⇒ String
If the tasks fails, the reason for the failure is returned. If the
task succeeds, null is returned.
81218 81219 81220 81221 81222 81223 81224 81225 81226 81227 81228 |
# File 'lib/aws-sdk-ec2/types.rb', line 81218 class StoreImageTaskResult < Struct.new( :ami_id, :task_start_time, :bucket, :s3object_key, :progress_percentage, :store_task_state, :store_task_failure_reason) SENSITIVE = [] include Aws::Structure end |
#store_task_state ⇒ String
The state of the store task (InProgress, Completed, or
Failed).
81218 81219 81220 81221 81222 81223 81224 81225 81226 81227 81228 |
# File 'lib/aws-sdk-ec2/types.rb', line 81218 class StoreImageTaskResult < Struct.new( :ami_id, :task_start_time, :bucket, :s3object_key, :progress_percentage, :store_task_state, :store_task_failure_reason) SENSITIVE = [] include Aws::Structure end |
#task_start_time ⇒ Time
The time the task started.
81218 81219 81220 81221 81222 81223 81224 81225 81226 81227 81228 |
# File 'lib/aws-sdk-ec2/types.rb', line 81218 class StoreImageTaskResult < Struct.new( :ami_id, :task_start_time, :bucket, :s3object_key, :progress_percentage, :store_task_state, :store_task_failure_reason) SENSITIVE = [] include Aws::Structure end |