Class: Aws::EC2::Types::Subnet
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::Subnet
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a subnet.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#assign_ipv_6_address_on_creation ⇒ Boolean
Indicates whether a network interface created in this subnet (including a network interface created by RunInstances) receives an IPv6 address.
-
#availability_zone ⇒ String
The Availability Zone of the subnet.
-
#availability_zone_id ⇒ String
The AZ ID of the subnet.
-
#available_ip_address_count ⇒ Integer
The number of unused private IPv4 addresses in the subnet.
-
#block_public_access_states ⇒ Types::BlockPublicAccessStates
The state of VPC Block Public Access (BPA).
-
#cidr_block ⇒ String
The IPv4 CIDR block assigned to the subnet.
-
#customer_owned_ipv_4_pool ⇒ String
The customer-owned IPv4 address pool associated with the subnet.
-
#default_for_az ⇒ Boolean
Indicates whether this is the default subnet for the Availability Zone.
-
#enable_dns_64 ⇒ Boolean
Indicates whether DNS queries made to the Amazon-provided DNS Resolver in this subnet should return synthetic IPv6 addresses for IPv4-only destinations.
-
#enable_lni_at_device_index ⇒ Integer
Indicates the device position for local network interfaces in this subnet.
-
#ipv_6_cidr_block_association_set ⇒ Array<Types::SubnetIpv6CidrBlockAssociation>
Information about the IPv6 CIDR blocks associated with the subnet.
-
#ipv_6_native ⇒ Boolean
Indicates whether this is an IPv6 only subnet.
-
#map_customer_owned_ip_on_launch ⇒ Boolean
Indicates whether a network interface created in this subnet (including a network interface created by RunInstances) receives a customer-owned IPv4 address.
-
#map_public_ip_on_launch ⇒ Boolean
Indicates whether instances launched in this subnet receive a public IPv4 address.
-
#outpost_arn ⇒ String
The Amazon Resource Name (ARN) of the Outpost.
-
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the subnet.
-
#private_dns_name_options_on_launch ⇒ Types::PrivateDnsNameOptionsOnLaunch
The type of hostnames to assign to instances in the subnet at launch.
-
#state ⇒ String
The current state of the subnet.
-
#subnet_arn ⇒ String
The Amazon Resource Name (ARN) of the subnet.
-
#subnet_id ⇒ String
The ID of the subnet.
-
#tags ⇒ Array<Types::Tag>
Any tags assigned to the subnet.
-
#type ⇒ String
Indicates if this is a subnet used with Amazon Elastic VMware Service (EVS).
-
#vpc_id ⇒ String
The ID of the VPC the subnet is in.
Instance Attribute Details
#assign_ipv_6_address_on_creation ⇒ Boolean
Indicates whether a network interface created in this subnet (including a network interface created by RunInstances) receives an IPv6 address.
78735 78736 78737 78738 78739 78740 78741 78742 78743 78744 78745 78746 78747 78748 78749 78750 78751 78752 78753 78754 78755 78756 78757 78758 78759 78760 78761 |
# File 'lib/aws-sdk-ec2/types.rb', line 78735 class Subnet < Struct.new( :availability_zone_id, :enable_lni_at_device_index, :map_customer_owned_ip_on_launch, :customer_owned_ipv_4_pool, :owner_id, :assign_ipv_6_address_on_creation, :ipv_6_cidr_block_association_set, :tags, :subnet_arn, :outpost_arn, :enable_dns_64, :ipv_6_native, :private_dns_name_options_on_launch, :block_public_access_states, :type, :subnet_id, :state, :vpc_id, :cidr_block, :available_ip_address_count, :availability_zone, :default_for_az, :map_public_ip_on_launch) SENSITIVE = [] include Aws::Structure end |
#availability_zone ⇒ String
The Availability Zone of the subnet.
78735 78736 78737 78738 78739 78740 78741 78742 78743 78744 78745 78746 78747 78748 78749 78750 78751 78752 78753 78754 78755 78756 78757 78758 78759 78760 78761 |
# File 'lib/aws-sdk-ec2/types.rb', line 78735 class Subnet < Struct.new( :availability_zone_id, :enable_lni_at_device_index, :map_customer_owned_ip_on_launch, :customer_owned_ipv_4_pool, :owner_id, :assign_ipv_6_address_on_creation, :ipv_6_cidr_block_association_set, :tags, :subnet_arn, :outpost_arn, :enable_dns_64, :ipv_6_native, :private_dns_name_options_on_launch, :block_public_access_states, :type, :subnet_id, :state, :vpc_id, :cidr_block, :available_ip_address_count, :availability_zone, :default_for_az, :map_public_ip_on_launch) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
The AZ ID of the subnet.
78735 78736 78737 78738 78739 78740 78741 78742 78743 78744 78745 78746 78747 78748 78749 78750 78751 78752 78753 78754 78755 78756 78757 78758 78759 78760 78761 |
# File 'lib/aws-sdk-ec2/types.rb', line 78735 class Subnet < Struct.new( :availability_zone_id, :enable_lni_at_device_index, :map_customer_owned_ip_on_launch, :customer_owned_ipv_4_pool, :owner_id, :assign_ipv_6_address_on_creation, :ipv_6_cidr_block_association_set, :tags, :subnet_arn, :outpost_arn, :enable_dns_64, :ipv_6_native, :private_dns_name_options_on_launch, :block_public_access_states, :type, :subnet_id, :state, :vpc_id, :cidr_block, :available_ip_address_count, :availability_zone, :default_for_az, :map_public_ip_on_launch) SENSITIVE = [] include Aws::Structure end |
#available_ip_address_count ⇒ Integer
The number of unused private IPv4 addresses in the subnet. The IPv4 addresses for any stopped instances are considered unavailable.
78735 78736 78737 78738 78739 78740 78741 78742 78743 78744 78745 78746 78747 78748 78749 78750 78751 78752 78753 78754 78755 78756 78757 78758 78759 78760 78761 |
# File 'lib/aws-sdk-ec2/types.rb', line 78735 class Subnet < Struct.new( :availability_zone_id, :enable_lni_at_device_index, :map_customer_owned_ip_on_launch, :customer_owned_ipv_4_pool, :owner_id, :assign_ipv_6_address_on_creation, :ipv_6_cidr_block_association_set, :tags, :subnet_arn, :outpost_arn, :enable_dns_64, :ipv_6_native, :private_dns_name_options_on_launch, :block_public_access_states, :type, :subnet_id, :state, :vpc_id, :cidr_block, :available_ip_address_count, :availability_zone, :default_for_az, :map_public_ip_on_launch) SENSITIVE = [] include Aws::Structure end |
#block_public_access_states ⇒ Types::BlockPublicAccessStates
The state of VPC Block Public Access (BPA).
78735 78736 78737 78738 78739 78740 78741 78742 78743 78744 78745 78746 78747 78748 78749 78750 78751 78752 78753 78754 78755 78756 78757 78758 78759 78760 78761 |
# File 'lib/aws-sdk-ec2/types.rb', line 78735 class Subnet < Struct.new( :availability_zone_id, :enable_lni_at_device_index, :map_customer_owned_ip_on_launch, :customer_owned_ipv_4_pool, :owner_id, :assign_ipv_6_address_on_creation, :ipv_6_cidr_block_association_set, :tags, :subnet_arn, :outpost_arn, :enable_dns_64, :ipv_6_native, :private_dns_name_options_on_launch, :block_public_access_states, :type, :subnet_id, :state, :vpc_id, :cidr_block, :available_ip_address_count, :availability_zone, :default_for_az, :map_public_ip_on_launch) SENSITIVE = [] include Aws::Structure end |
#cidr_block ⇒ String
The IPv4 CIDR block assigned to the subnet.
78735 78736 78737 78738 78739 78740 78741 78742 78743 78744 78745 78746 78747 78748 78749 78750 78751 78752 78753 78754 78755 78756 78757 78758 78759 78760 78761 |
# File 'lib/aws-sdk-ec2/types.rb', line 78735 class Subnet < Struct.new( :availability_zone_id, :enable_lni_at_device_index, :map_customer_owned_ip_on_launch, :customer_owned_ipv_4_pool, :owner_id, :assign_ipv_6_address_on_creation, :ipv_6_cidr_block_association_set, :tags, :subnet_arn, :outpost_arn, :enable_dns_64, :ipv_6_native, :private_dns_name_options_on_launch, :block_public_access_states, :type, :subnet_id, :state, :vpc_id, :cidr_block, :available_ip_address_count, :availability_zone, :default_for_az, :map_public_ip_on_launch) SENSITIVE = [] include Aws::Structure end |
#customer_owned_ipv_4_pool ⇒ String
The customer-owned IPv4 address pool associated with the subnet.
78735 78736 78737 78738 78739 78740 78741 78742 78743 78744 78745 78746 78747 78748 78749 78750 78751 78752 78753 78754 78755 78756 78757 78758 78759 78760 78761 |
# File 'lib/aws-sdk-ec2/types.rb', line 78735 class Subnet < Struct.new( :availability_zone_id, :enable_lni_at_device_index, :map_customer_owned_ip_on_launch, :customer_owned_ipv_4_pool, :owner_id, :assign_ipv_6_address_on_creation, :ipv_6_cidr_block_association_set, :tags, :subnet_arn, :outpost_arn, :enable_dns_64, :ipv_6_native, :private_dns_name_options_on_launch, :block_public_access_states, :type, :subnet_id, :state, :vpc_id, :cidr_block, :available_ip_address_count, :availability_zone, :default_for_az, :map_public_ip_on_launch) SENSITIVE = [] include Aws::Structure end |
#default_for_az ⇒ Boolean
Indicates whether this is the default subnet for the Availability Zone.
78735 78736 78737 78738 78739 78740 78741 78742 78743 78744 78745 78746 78747 78748 78749 78750 78751 78752 78753 78754 78755 78756 78757 78758 78759 78760 78761 |
# File 'lib/aws-sdk-ec2/types.rb', line 78735 class Subnet < Struct.new( :availability_zone_id, :enable_lni_at_device_index, :map_customer_owned_ip_on_launch, :customer_owned_ipv_4_pool, :owner_id, :assign_ipv_6_address_on_creation, :ipv_6_cidr_block_association_set, :tags, :subnet_arn, :outpost_arn, :enable_dns_64, :ipv_6_native, :private_dns_name_options_on_launch, :block_public_access_states, :type, :subnet_id, :state, :vpc_id, :cidr_block, :available_ip_address_count, :availability_zone, :default_for_az, :map_public_ip_on_launch) SENSITIVE = [] include Aws::Structure end |
#enable_dns_64 ⇒ Boolean
Indicates whether DNS queries made to the Amazon-provided DNS Resolver in this subnet should return synthetic IPv6 addresses for IPv4-only destinations.
78735 78736 78737 78738 78739 78740 78741 78742 78743 78744 78745 78746 78747 78748 78749 78750 78751 78752 78753 78754 78755 78756 78757 78758 78759 78760 78761 |
# File 'lib/aws-sdk-ec2/types.rb', line 78735 class Subnet < Struct.new( :availability_zone_id, :enable_lni_at_device_index, :map_customer_owned_ip_on_launch, :customer_owned_ipv_4_pool, :owner_id, :assign_ipv_6_address_on_creation, :ipv_6_cidr_block_association_set, :tags, :subnet_arn, :outpost_arn, :enable_dns_64, :ipv_6_native, :private_dns_name_options_on_launch, :block_public_access_states, :type, :subnet_id, :state, :vpc_id, :cidr_block, :available_ip_address_count, :availability_zone, :default_for_az, :map_public_ip_on_launch) SENSITIVE = [] include Aws::Structure end |
#enable_lni_at_device_index ⇒ Integer
Indicates the device position for local network interfaces in this subnet. For example, ‘1` indicates local network interfaces in this subnet are the secondary network interface (eth1).
78735 78736 78737 78738 78739 78740 78741 78742 78743 78744 78745 78746 78747 78748 78749 78750 78751 78752 78753 78754 78755 78756 78757 78758 78759 78760 78761 |
# File 'lib/aws-sdk-ec2/types.rb', line 78735 class Subnet < Struct.new( :availability_zone_id, :enable_lni_at_device_index, :map_customer_owned_ip_on_launch, :customer_owned_ipv_4_pool, :owner_id, :assign_ipv_6_address_on_creation, :ipv_6_cidr_block_association_set, :tags, :subnet_arn, :outpost_arn, :enable_dns_64, :ipv_6_native, :private_dns_name_options_on_launch, :block_public_access_states, :type, :subnet_id, :state, :vpc_id, :cidr_block, :available_ip_address_count, :availability_zone, :default_for_az, :map_public_ip_on_launch) SENSITIVE = [] include Aws::Structure end |
#ipv_6_cidr_block_association_set ⇒ Array<Types::SubnetIpv6CidrBlockAssociation>
Information about the IPv6 CIDR blocks associated with the subnet.
78735 78736 78737 78738 78739 78740 78741 78742 78743 78744 78745 78746 78747 78748 78749 78750 78751 78752 78753 78754 78755 78756 78757 78758 78759 78760 78761 |
# File 'lib/aws-sdk-ec2/types.rb', line 78735 class Subnet < Struct.new( :availability_zone_id, :enable_lni_at_device_index, :map_customer_owned_ip_on_launch, :customer_owned_ipv_4_pool, :owner_id, :assign_ipv_6_address_on_creation, :ipv_6_cidr_block_association_set, :tags, :subnet_arn, :outpost_arn, :enable_dns_64, :ipv_6_native, :private_dns_name_options_on_launch, :block_public_access_states, :type, :subnet_id, :state, :vpc_id, :cidr_block, :available_ip_address_count, :availability_zone, :default_for_az, :map_public_ip_on_launch) SENSITIVE = [] include Aws::Structure end |
#ipv_6_native ⇒ Boolean
Indicates whether this is an IPv6 only subnet.
78735 78736 78737 78738 78739 78740 78741 78742 78743 78744 78745 78746 78747 78748 78749 78750 78751 78752 78753 78754 78755 78756 78757 78758 78759 78760 78761 |
# File 'lib/aws-sdk-ec2/types.rb', line 78735 class Subnet < Struct.new( :availability_zone_id, :enable_lni_at_device_index, :map_customer_owned_ip_on_launch, :customer_owned_ipv_4_pool, :owner_id, :assign_ipv_6_address_on_creation, :ipv_6_cidr_block_association_set, :tags, :subnet_arn, :outpost_arn, :enable_dns_64, :ipv_6_native, :private_dns_name_options_on_launch, :block_public_access_states, :type, :subnet_id, :state, :vpc_id, :cidr_block, :available_ip_address_count, :availability_zone, :default_for_az, :map_public_ip_on_launch) SENSITIVE = [] include Aws::Structure end |
#map_customer_owned_ip_on_launch ⇒ Boolean
Indicates whether a network interface created in this subnet (including a network interface created by RunInstances) receives a customer-owned IPv4 address.
78735 78736 78737 78738 78739 78740 78741 78742 78743 78744 78745 78746 78747 78748 78749 78750 78751 78752 78753 78754 78755 78756 78757 78758 78759 78760 78761 |
# File 'lib/aws-sdk-ec2/types.rb', line 78735 class Subnet < Struct.new( :availability_zone_id, :enable_lni_at_device_index, :map_customer_owned_ip_on_launch, :customer_owned_ipv_4_pool, :owner_id, :assign_ipv_6_address_on_creation, :ipv_6_cidr_block_association_set, :tags, :subnet_arn, :outpost_arn, :enable_dns_64, :ipv_6_native, :private_dns_name_options_on_launch, :block_public_access_states, :type, :subnet_id, :state, :vpc_id, :cidr_block, :available_ip_address_count, :availability_zone, :default_for_az, :map_public_ip_on_launch) SENSITIVE = [] include Aws::Structure end |
#map_public_ip_on_launch ⇒ Boolean
Indicates whether instances launched in this subnet receive a public IPv4 address.
Amazon Web Services charges for all public IPv4 addresses, including public IPv4 addresses associated with running instances and Elastic IP addresses. For more information, see the *Public IPv4 Address* tab on the [Amazon VPC pricing page].
78735 78736 78737 78738 78739 78740 78741 78742 78743 78744 78745 78746 78747 78748 78749 78750 78751 78752 78753 78754 78755 78756 78757 78758 78759 78760 78761 |
# File 'lib/aws-sdk-ec2/types.rb', line 78735 class Subnet < Struct.new( :availability_zone_id, :enable_lni_at_device_index, :map_customer_owned_ip_on_launch, :customer_owned_ipv_4_pool, :owner_id, :assign_ipv_6_address_on_creation, :ipv_6_cidr_block_association_set, :tags, :subnet_arn, :outpost_arn, :enable_dns_64, :ipv_6_native, :private_dns_name_options_on_launch, :block_public_access_states, :type, :subnet_id, :state, :vpc_id, :cidr_block, :available_ip_address_count, :availability_zone, :default_for_az, :map_public_ip_on_launch) SENSITIVE = [] include Aws::Structure end |
#outpost_arn ⇒ String
The Amazon Resource Name (ARN) of the Outpost.
78735 78736 78737 78738 78739 78740 78741 78742 78743 78744 78745 78746 78747 78748 78749 78750 78751 78752 78753 78754 78755 78756 78757 78758 78759 78760 78761 |
# File 'lib/aws-sdk-ec2/types.rb', line 78735 class Subnet < Struct.new( :availability_zone_id, :enable_lni_at_device_index, :map_customer_owned_ip_on_launch, :customer_owned_ipv_4_pool, :owner_id, :assign_ipv_6_address_on_creation, :ipv_6_cidr_block_association_set, :tags, :subnet_arn, :outpost_arn, :enable_dns_64, :ipv_6_native, :private_dns_name_options_on_launch, :block_public_access_states, :type, :subnet_id, :state, :vpc_id, :cidr_block, :available_ip_address_count, :availability_zone, :default_for_az, :map_public_ip_on_launch) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the subnet.
78735 78736 78737 78738 78739 78740 78741 78742 78743 78744 78745 78746 78747 78748 78749 78750 78751 78752 78753 78754 78755 78756 78757 78758 78759 78760 78761 |
# File 'lib/aws-sdk-ec2/types.rb', line 78735 class Subnet < Struct.new( :availability_zone_id, :enable_lni_at_device_index, :map_customer_owned_ip_on_launch, :customer_owned_ipv_4_pool, :owner_id, :assign_ipv_6_address_on_creation, :ipv_6_cidr_block_association_set, :tags, :subnet_arn, :outpost_arn, :enable_dns_64, :ipv_6_native, :private_dns_name_options_on_launch, :block_public_access_states, :type, :subnet_id, :state, :vpc_id, :cidr_block, :available_ip_address_count, :availability_zone, :default_for_az, :map_public_ip_on_launch) SENSITIVE = [] include Aws::Structure end |
#private_dns_name_options_on_launch ⇒ Types::PrivateDnsNameOptionsOnLaunch
The type of hostnames to assign to instances in the subnet at launch. An instance hostname is based on the IPv4 address or ID of the instance.
78735 78736 78737 78738 78739 78740 78741 78742 78743 78744 78745 78746 78747 78748 78749 78750 78751 78752 78753 78754 78755 78756 78757 78758 78759 78760 78761 |
# File 'lib/aws-sdk-ec2/types.rb', line 78735 class Subnet < Struct.new( :availability_zone_id, :enable_lni_at_device_index, :map_customer_owned_ip_on_launch, :customer_owned_ipv_4_pool, :owner_id, :assign_ipv_6_address_on_creation, :ipv_6_cidr_block_association_set, :tags, :subnet_arn, :outpost_arn, :enable_dns_64, :ipv_6_native, :private_dns_name_options_on_launch, :block_public_access_states, :type, :subnet_id, :state, :vpc_id, :cidr_block, :available_ip_address_count, :availability_zone, :default_for_az, :map_public_ip_on_launch) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the subnet.
-
‘failed`: The underlying infrastructure to support the subnet failed to provision as expected.
-
‘failed-insufficient-capacity`: The underlying infrastructure to support the subnet failed to provision due to a shortage of EC2 instance capacity.
78735 78736 78737 78738 78739 78740 78741 78742 78743 78744 78745 78746 78747 78748 78749 78750 78751 78752 78753 78754 78755 78756 78757 78758 78759 78760 78761 |
# File 'lib/aws-sdk-ec2/types.rb', line 78735 class Subnet < Struct.new( :availability_zone_id, :enable_lni_at_device_index, :map_customer_owned_ip_on_launch, :customer_owned_ipv_4_pool, :owner_id, :assign_ipv_6_address_on_creation, :ipv_6_cidr_block_association_set, :tags, :subnet_arn, :outpost_arn, :enable_dns_64, :ipv_6_native, :private_dns_name_options_on_launch, :block_public_access_states, :type, :subnet_id, :state, :vpc_id, :cidr_block, :available_ip_address_count, :availability_zone, :default_for_az, :map_public_ip_on_launch) SENSITIVE = [] include Aws::Structure end |
#subnet_arn ⇒ String
The Amazon Resource Name (ARN) of the subnet.
78735 78736 78737 78738 78739 78740 78741 78742 78743 78744 78745 78746 78747 78748 78749 78750 78751 78752 78753 78754 78755 78756 78757 78758 78759 78760 78761 |
# File 'lib/aws-sdk-ec2/types.rb', line 78735 class Subnet < Struct.new( :availability_zone_id, :enable_lni_at_device_index, :map_customer_owned_ip_on_launch, :customer_owned_ipv_4_pool, :owner_id, :assign_ipv_6_address_on_creation, :ipv_6_cidr_block_association_set, :tags, :subnet_arn, :outpost_arn, :enable_dns_64, :ipv_6_native, :private_dns_name_options_on_launch, :block_public_access_states, :type, :subnet_id, :state, :vpc_id, :cidr_block, :available_ip_address_count, :availability_zone, :default_for_az, :map_public_ip_on_launch) SENSITIVE = [] include Aws::Structure end |
#subnet_id ⇒ String
The ID of the subnet.
78735 78736 78737 78738 78739 78740 78741 78742 78743 78744 78745 78746 78747 78748 78749 78750 78751 78752 78753 78754 78755 78756 78757 78758 78759 78760 78761 |
# File 'lib/aws-sdk-ec2/types.rb', line 78735 class Subnet < Struct.new( :availability_zone_id, :enable_lni_at_device_index, :map_customer_owned_ip_on_launch, :customer_owned_ipv_4_pool, :owner_id, :assign_ipv_6_address_on_creation, :ipv_6_cidr_block_association_set, :tags, :subnet_arn, :outpost_arn, :enable_dns_64, :ipv_6_native, :private_dns_name_options_on_launch, :block_public_access_states, :type, :subnet_id, :state, :vpc_id, :cidr_block, :available_ip_address_count, :availability_zone, :default_for_az, :map_public_ip_on_launch) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Any tags assigned to the subnet.
78735 78736 78737 78738 78739 78740 78741 78742 78743 78744 78745 78746 78747 78748 78749 78750 78751 78752 78753 78754 78755 78756 78757 78758 78759 78760 78761 |
# File 'lib/aws-sdk-ec2/types.rb', line 78735 class Subnet < Struct.new( :availability_zone_id, :enable_lni_at_device_index, :map_customer_owned_ip_on_launch, :customer_owned_ipv_4_pool, :owner_id, :assign_ipv_6_address_on_creation, :ipv_6_cidr_block_association_set, :tags, :subnet_arn, :outpost_arn, :enable_dns_64, :ipv_6_native, :private_dns_name_options_on_launch, :block_public_access_states, :type, :subnet_id, :state, :vpc_id, :cidr_block, :available_ip_address_count, :availability_zone, :default_for_az, :map_public_ip_on_launch) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
Indicates if this is a subnet used with Amazon Elastic VMware Service (EVS). Possible values are ‘Elastic VMware Service` or no value. For more information about Amazon EVS, see [ *Amazon Elastic VMware Service API Reference* ][1].
[1]: docs.aws.amazon.com/evs/latest/APIReference/Welcome.html
78735 78736 78737 78738 78739 78740 78741 78742 78743 78744 78745 78746 78747 78748 78749 78750 78751 78752 78753 78754 78755 78756 78757 78758 78759 78760 78761 |
# File 'lib/aws-sdk-ec2/types.rb', line 78735 class Subnet < Struct.new( :availability_zone_id, :enable_lni_at_device_index, :map_customer_owned_ip_on_launch, :customer_owned_ipv_4_pool, :owner_id, :assign_ipv_6_address_on_creation, :ipv_6_cidr_block_association_set, :tags, :subnet_arn, :outpost_arn, :enable_dns_64, :ipv_6_native, :private_dns_name_options_on_launch, :block_public_access_states, :type, :subnet_id, :state, :vpc_id, :cidr_block, :available_ip_address_count, :availability_zone, :default_for_az, :map_public_ip_on_launch) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC the subnet is in.
78735 78736 78737 78738 78739 78740 78741 78742 78743 78744 78745 78746 78747 78748 78749 78750 78751 78752 78753 78754 78755 78756 78757 78758 78759 78760 78761 |
# File 'lib/aws-sdk-ec2/types.rb', line 78735 class Subnet < Struct.new( :availability_zone_id, :enable_lni_at_device_index, :map_customer_owned_ip_on_launch, :customer_owned_ipv_4_pool, :owner_id, :assign_ipv_6_address_on_creation, :ipv_6_cidr_block_association_set, :tags, :subnet_arn, :outpost_arn, :enable_dns_64, :ipv_6_native, :private_dns_name_options_on_launch, :block_public_access_states, :type, :subnet_id, :state, :vpc_id, :cidr_block, :available_ip_address_count, :availability_zone, :default_for_az, :map_public_ip_on_launch) SENSITIVE = [] include Aws::Structure end |