Class: Aws::EC2::Types::TargetNetwork
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::TargetNetwork
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a target network associated with a Client VPN endpoint.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#association_id ⇒ String
The ID of the association.
-
#availability_zone_ids ⇒ Array<String>
The Availability Zone IDs for the target network association, if the Client VPN endpoint uses a Transit Gateway.
-
#availability_zones ⇒ Array<String>
The Availability Zone names for the target network association, if the Client VPN endpoint uses a Transit Gateway.
-
#client_vpn_endpoint_id ⇒ String
The ID of the Client VPN endpoint with which the target network is associated.
-
#security_groups ⇒ Array<String>
The IDs of the security groups applied to the target network association.
-
#status ⇒ Types::AssociationStatus
The current state of the target network association.
-
#target_network_id ⇒ String
The ID of the subnet specified as the target network.
-
#vpc_id ⇒ String
The ID of the VPC in which the target network (subnet) is located.
Instance Attribute Details
#association_id ⇒ String
The ID of the association.
81100 81101 81102 81103 81104 81105 81106 81107 81108 81109 81110 81111 |
# File 'lib/aws-sdk-ec2/types.rb', line 81100 class TargetNetwork < Struct.new( :association_id, :vpc_id, :target_network_id, :client_vpn_endpoint_id, :status, :security_groups, :availability_zones, :availability_zone_ids) SENSITIVE = [] include Aws::Structure end |
#availability_zone_ids ⇒ Array<String>
The Availability Zone IDs for the target network association, if the Client VPN endpoint uses a Transit Gateway.
81100 81101 81102 81103 81104 81105 81106 81107 81108 81109 81110 81111 |
# File 'lib/aws-sdk-ec2/types.rb', line 81100 class TargetNetwork < Struct.new( :association_id, :vpc_id, :target_network_id, :client_vpn_endpoint_id, :status, :security_groups, :availability_zones, :availability_zone_ids) SENSITIVE = [] include Aws::Structure end |
#availability_zones ⇒ Array<String>
The Availability Zone names for the target network association, if the Client VPN endpoint uses a Transit Gateway.
81100 81101 81102 81103 81104 81105 81106 81107 81108 81109 81110 81111 |
# File 'lib/aws-sdk-ec2/types.rb', line 81100 class TargetNetwork < Struct.new( :association_id, :vpc_id, :target_network_id, :client_vpn_endpoint_id, :status, :security_groups, :availability_zones, :availability_zone_ids) SENSITIVE = [] include Aws::Structure end |
#client_vpn_endpoint_id ⇒ String
The ID of the Client VPN endpoint with which the target network is associated.
81100 81101 81102 81103 81104 81105 81106 81107 81108 81109 81110 81111 |
# File 'lib/aws-sdk-ec2/types.rb', line 81100 class TargetNetwork < Struct.new( :association_id, :vpc_id, :target_network_id, :client_vpn_endpoint_id, :status, :security_groups, :availability_zones, :availability_zone_ids) SENSITIVE = [] include Aws::Structure end |
#security_groups ⇒ Array<String>
The IDs of the security groups applied to the target network association.
81100 81101 81102 81103 81104 81105 81106 81107 81108 81109 81110 81111 |
# File 'lib/aws-sdk-ec2/types.rb', line 81100 class TargetNetwork < Struct.new( :association_id, :vpc_id, :target_network_id, :client_vpn_endpoint_id, :status, :security_groups, :availability_zones, :availability_zone_ids) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::AssociationStatus
The current state of the target network association.
81100 81101 81102 81103 81104 81105 81106 81107 81108 81109 81110 81111 |
# File 'lib/aws-sdk-ec2/types.rb', line 81100 class TargetNetwork < Struct.new( :association_id, :vpc_id, :target_network_id, :client_vpn_endpoint_id, :status, :security_groups, :availability_zones, :availability_zone_ids) SENSITIVE = [] include Aws::Structure end |
#target_network_id ⇒ String
The ID of the subnet specified as the target network.
81100 81101 81102 81103 81104 81105 81106 81107 81108 81109 81110 81111 |
# File 'lib/aws-sdk-ec2/types.rb', line 81100 class TargetNetwork < Struct.new( :association_id, :vpc_id, :target_network_id, :client_vpn_endpoint_id, :status, :security_groups, :availability_zones, :availability_zone_ids) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC in which the target network (subnet) is located.
81100 81101 81102 81103 81104 81105 81106 81107 81108 81109 81110 81111 |
# File 'lib/aws-sdk-ec2/types.rb', line 81100 class TargetNetwork < Struct.new( :association_id, :vpc_id, :target_network_id, :client_vpn_endpoint_id, :status, :security_groups, :availability_zones, :availability_zone_ids) SENSITIVE = [] include Aws::Structure end |