Class: Aws::EC2::Types::TargetReservationValue

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

The total value of the new Convertible Reserved Instances.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#reservation_valueTypes::ReservationValue

The total value of the Convertible Reserved Instances that make up the exchange. This is the sum of the list value, remaining upfront price, and additional upfront cost of the exchange.



82025
82026
82027
82028
82029
82030
# File 'lib/aws-sdk-ec2/types.rb', line 82025

class TargetReservationValue < Struct.new(
  :reservation_value,
  :target_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#target_configurationTypes::TargetConfiguration

The configuration of the Convertible Reserved Instances that make up the exchange.



82025
82026
82027
82028
82029
82030
# File 'lib/aws-sdk-ec2/types.rb', line 82025

class TargetReservationValue < Struct.new(
  :reservation_value,
  :target_configuration)
  SENSITIVE = []
  include Aws::Structure
end