Class: Aws::EC2::Types::TargetReservationValue
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::TargetReservationValue
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
The total value of the new Convertible Reserved Instances.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#reservation_value ⇒ Types::ReservationValue
The total value of the Convertible Reserved Instances that make up the exchange.
-
#target_configuration ⇒ Types::TargetConfiguration
The configuration of the Convertible Reserved Instances that make up the exchange.
Instance Attribute Details
#reservation_value ⇒ Types::ReservationValue
The total value of the Convertible Reserved Instances that make up the exchange. This is the sum of the list value, remaining upfront price, and additional upfront cost of the exchange.
80717 80718 80719 80720 80721 80722 |
# File 'lib/aws-sdk-ec2/types.rb', line 80717 class TargetReservationValue < Struct.new( :reservation_value, :target_configuration) SENSITIVE = [] include Aws::Structure end |
#target_configuration ⇒ Types::TargetConfiguration
The configuration of the Convertible Reserved Instances that make up the exchange.
80717 80718 80719 80720 80721 80722 |
# File 'lib/aws-sdk-ec2/types.rb', line 80717 class TargetReservationValue < Struct.new( :reservation_value, :target_configuration) SENSITIVE = [] include Aws::Structure end |