Class: Aws::EC2::Types::TerminateClientVpnConnectionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_vpn_endpoint_idString

The ID of the Client VPN endpoint to which the client is connected.

Returns:

  • (String)


85645
85646
85647
85648
85649
85650
85651
85652
# File 'lib/aws-sdk-ec2/types.rb', line 85645

class TerminateClientVpnConnectionsRequest < Struct.new(
  :client_vpn_endpoint_id,
  :connection_id,
  :username,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#connection_idString

The ID of the client connection to be terminated.

Returns:

  • (String)


85645
85646
85647
85648
85649
85650
85651
85652
# File 'lib/aws-sdk-ec2/types.rb', line 85645

class TerminateClientVpnConnectionsRequest < Struct.new(
  :client_vpn_endpoint_id,
  :connection_id,
  :username,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


85645
85646
85647
85648
85649
85650
85651
85652
# File 'lib/aws-sdk-ec2/types.rb', line 85645

class TerminateClientVpnConnectionsRequest < Struct.new(
  :client_vpn_endpoint_id,
  :connection_id,
  :username,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#usernameString

The name of the user who initiated the connection. Use this option to terminate all active connections for the specified user. This option can only be used if the user has established up to five connections.

Returns:

  • (String)


85645
85646
85647
85648
85649
85650
85651
85652
# File 'lib/aws-sdk-ec2/types.rb', line 85645

class TerminateClientVpnConnectionsRequest < Struct.new(
  :client_vpn_endpoint_id,
  :connection_id,
  :username,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end