Class: Aws::EC2::Types::TerminateInstancesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::TerminateInstancesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#force ⇒ Boolean
Forces the instances to terminate.
-
#instance_ids ⇒ Array<String>
The IDs of the instances.
-
#skip_os_shutdown ⇒ Boolean
Specifies whether to bypass the graceful OS shutdown process when the instance is terminated.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
82543 82544 82545 82546 82547 82548 82549 82550 |
# File 'lib/aws-sdk-ec2/types.rb', line 82543 class TerminateInstancesRequest < Struct.new( :instance_ids, :force, :skip_os_shutdown, :dry_run) SENSITIVE = [] include Aws::Structure end |
#force ⇒ Boolean
Forces the instances to terminate. The instance will first attempt a graceful shutdown, which includes flushing file system caches and metadata. If the graceful shutdown fails to complete within the timeout period, the instance shuts down forcibly without flushing the file system caches and metadata.
82543 82544 82545 82546 82547 82548 82549 82550 |
# File 'lib/aws-sdk-ec2/types.rb', line 82543 class TerminateInstancesRequest < Struct.new( :instance_ids, :force, :skip_os_shutdown, :dry_run) SENSITIVE = [] include Aws::Structure end |
#instance_ids ⇒ Array<String>
The IDs of the instances.
Constraints: Up to 1000 instance IDs. We recommend breaking up this request into smaller batches.
82543 82544 82545 82546 82547 82548 82549 82550 |
# File 'lib/aws-sdk-ec2/types.rb', line 82543 class TerminateInstancesRequest < Struct.new( :instance_ids, :force, :skip_os_shutdown, :dry_run) SENSITIVE = [] include Aws::Structure end |
#skip_os_shutdown ⇒ Boolean
Specifies whether to bypass the graceful OS shutdown process when the instance is terminated.
Default: false
82543 82544 82545 82546 82547 82548 82549 82550 |
# File 'lib/aws-sdk-ec2/types.rb', line 82543 class TerminateInstancesRequest < Struct.new( :instance_ids, :force, :skip_os_shutdown, :dry_run) SENSITIVE = [] include Aws::Structure end |