Class: Aws::EC2::Types::TerminateInstancesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


81566
81567
81568
81569
81570
81571
81572
81573
# File 'lib/aws-sdk-ec2/types.rb', line 81566

class TerminateInstancesRequest < Struct.new(
  :instance_ids,
  :force,
  :skip_os_shutdown,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#forceBoolean

Forces the instances to terminate. The instance will first attempt a graceful shutdown, which includes flushing file system caches and metadata. If the graceful shutdown fails to complete within the timeout period, the instance shuts down forcibly without flushing the file system caches and metadata.

Returns:

  • (Boolean)


81566
81567
81568
81569
81570
81571
81572
81573
# File 'lib/aws-sdk-ec2/types.rb', line 81566

class TerminateInstancesRequest < Struct.new(
  :instance_ids,
  :force,
  :skip_os_shutdown,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idsArray<String>

The IDs of the instances.

Constraints: Up to 1000 instance IDs. We recommend breaking up this request into smaller batches.

Returns:

  • (Array<String>)


81566
81567
81568
81569
81570
81571
81572
81573
# File 'lib/aws-sdk-ec2/types.rb', line 81566

class TerminateInstancesRequest < Struct.new(
  :instance_ids,
  :force,
  :skip_os_shutdown,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#skip_os_shutdownBoolean

Specifies whether to bypass the graceful OS shutdown process when the instance is terminated.

Default: ‘false`

Returns:

  • (Boolean)


81566
81567
81568
81569
81570
81571
81572
81573
# File 'lib/aws-sdk-ec2/types.rb', line 81566

class TerminateInstancesRequest < Struct.new(
  :instance_ids,
  :force,
  :skip_os_shutdown,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end