Class: Aws::EC2::Types::TrafficMirrorSession
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::TrafficMirrorSession
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a Traffic Mirror session.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the Traffic Mirror session.
-
#network_interface_id ⇒ String
The ID of the Traffic Mirror session’s network interface.
-
#owner_id ⇒ String
The ID of the account that owns the Traffic Mirror session.
-
#packet_length ⇒ Integer
The number of bytes in each packet to mirror.
-
#session_number ⇒ Integer
The session number determines the order in which sessions are evaluated when an interface is used by multiple sessions.
-
#tags ⇒ Array<Types::Tag>
The tags assigned to the Traffic Mirror session.
-
#traffic_mirror_filter_id ⇒ String
The ID of the Traffic Mirror filter.
-
#traffic_mirror_session_id ⇒ String
The ID for the Traffic Mirror session.
-
#traffic_mirror_target_id ⇒ String
The ID of the Traffic Mirror target.
-
#virtual_network_id ⇒ Integer
The virtual network ID associated with the Traffic Mirror session.
Instance Attribute Details
#description ⇒ String
The description of the Traffic Mirror session.
82440 82441 82442 82443 82444 82445 82446 82447 82448 82449 82450 82451 82452 82453 |
# File 'lib/aws-sdk-ec2/types.rb', line 82440 class TrafficMirrorSession < Struct.new( :traffic_mirror_session_id, :traffic_mirror_target_id, :traffic_mirror_filter_id, :network_interface_id, :owner_id, :packet_length, :session_number, :virtual_network_id, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#network_interface_id ⇒ String
The ID of the Traffic Mirror session’s network interface.
82440 82441 82442 82443 82444 82445 82446 82447 82448 82449 82450 82451 82452 82453 |
# File 'lib/aws-sdk-ec2/types.rb', line 82440 class TrafficMirrorSession < Struct.new( :traffic_mirror_session_id, :traffic_mirror_target_id, :traffic_mirror_filter_id, :network_interface_id, :owner_id, :packet_length, :session_number, :virtual_network_id, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
The ID of the account that owns the Traffic Mirror session.
82440 82441 82442 82443 82444 82445 82446 82447 82448 82449 82450 82451 82452 82453 |
# File 'lib/aws-sdk-ec2/types.rb', line 82440 class TrafficMirrorSession < Struct.new( :traffic_mirror_session_id, :traffic_mirror_target_id, :traffic_mirror_filter_id, :network_interface_id, :owner_id, :packet_length, :session_number, :virtual_network_id, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#packet_length ⇒ Integer
The number of bytes in each packet to mirror. These are the bytes after the VXLAN header. To mirror a subset, set this to the length (in bytes) to mirror. For example, if you set this value to 100, then the first 100 bytes that meet the filter criteria are copied to the target. Do not specify this parameter when you want to mirror the entire packet
82440 82441 82442 82443 82444 82445 82446 82447 82448 82449 82450 82451 82452 82453 |
# File 'lib/aws-sdk-ec2/types.rb', line 82440 class TrafficMirrorSession < Struct.new( :traffic_mirror_session_id, :traffic_mirror_target_id, :traffic_mirror_filter_id, :network_interface_id, :owner_id, :packet_length, :session_number, :virtual_network_id, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#session_number ⇒ Integer
The session number determines the order in which sessions are evaluated when an interface is used by multiple sessions. The first session with a matching filter is the one that mirrors the packets.
Valid values are 1-32766.
82440 82441 82442 82443 82444 82445 82446 82447 82448 82449 82450 82451 82452 82453 |
# File 'lib/aws-sdk-ec2/types.rb', line 82440 class TrafficMirrorSession < Struct.new( :traffic_mirror_session_id, :traffic_mirror_target_id, :traffic_mirror_filter_id, :network_interface_id, :owner_id, :packet_length, :session_number, :virtual_network_id, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags assigned to the Traffic Mirror session.
82440 82441 82442 82443 82444 82445 82446 82447 82448 82449 82450 82451 82452 82453 |
# File 'lib/aws-sdk-ec2/types.rb', line 82440 class TrafficMirrorSession < Struct.new( :traffic_mirror_session_id, :traffic_mirror_target_id, :traffic_mirror_filter_id, :network_interface_id, :owner_id, :packet_length, :session_number, :virtual_network_id, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#traffic_mirror_filter_id ⇒ String
The ID of the Traffic Mirror filter.
82440 82441 82442 82443 82444 82445 82446 82447 82448 82449 82450 82451 82452 82453 |
# File 'lib/aws-sdk-ec2/types.rb', line 82440 class TrafficMirrorSession < Struct.new( :traffic_mirror_session_id, :traffic_mirror_target_id, :traffic_mirror_filter_id, :network_interface_id, :owner_id, :packet_length, :session_number, :virtual_network_id, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#traffic_mirror_session_id ⇒ String
The ID for the Traffic Mirror session.
82440 82441 82442 82443 82444 82445 82446 82447 82448 82449 82450 82451 82452 82453 |
# File 'lib/aws-sdk-ec2/types.rb', line 82440 class TrafficMirrorSession < Struct.new( :traffic_mirror_session_id, :traffic_mirror_target_id, :traffic_mirror_filter_id, :network_interface_id, :owner_id, :packet_length, :session_number, :virtual_network_id, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#traffic_mirror_target_id ⇒ String
The ID of the Traffic Mirror target.
82440 82441 82442 82443 82444 82445 82446 82447 82448 82449 82450 82451 82452 82453 |
# File 'lib/aws-sdk-ec2/types.rb', line 82440 class TrafficMirrorSession < Struct.new( :traffic_mirror_session_id, :traffic_mirror_target_id, :traffic_mirror_filter_id, :network_interface_id, :owner_id, :packet_length, :session_number, :virtual_network_id, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#virtual_network_id ⇒ Integer
The virtual network ID associated with the Traffic Mirror session.
82440 82441 82442 82443 82444 82445 82446 82447 82448 82449 82450 82451 82452 82453 |
# File 'lib/aws-sdk-ec2/types.rb', line 82440 class TrafficMirrorSession < Struct.new( :traffic_mirror_session_id, :traffic_mirror_target_id, :traffic_mirror_filter_id, :network_interface_id, :owner_id, :packet_length, :session_number, :virtual_network_id, :description, :tags) SENSITIVE = [] include Aws::Structure end |