Class: Aws::EC2::Types::TransitGatewayClientVpnAttachment

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes a Transit Gateway attachment for a Client VPN endpoint.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_vpn_endpoint_idString

The ID of the Client VPN endpoint.

Returns:

  • (String)


81856
81857
81858
81859
81860
81861
81862
81863
81864
81865
# File 'lib/aws-sdk-ec2/types.rb', line 81856

class TransitGatewayClientVpnAttachment < Struct.new(
  :transit_gateway_attachment_id,
  :transit_gateway_id,
  :client_vpn_endpoint_id,
  :client_vpn_owner_id,
  :state,
  :creation_time)
  SENSITIVE = []
  include Aws::Structure
end

#client_vpn_owner_idString

The ID of the Amazon Web Services account that owns the Client VPN endpoint.

Returns:

  • (String)


81856
81857
81858
81859
81860
81861
81862
81863
81864
81865
# File 'lib/aws-sdk-ec2/types.rb', line 81856

class TransitGatewayClientVpnAttachment < Struct.new(
  :transit_gateway_attachment_id,
  :transit_gateway_id,
  :client_vpn_endpoint_id,
  :client_vpn_owner_id,
  :state,
  :creation_time)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeString

The date and time the Transit Gateway attachment was created.

Returns:

  • (String)


81856
81857
81858
81859
81860
81861
81862
81863
81864
81865
# File 'lib/aws-sdk-ec2/types.rb', line 81856

class TransitGatewayClientVpnAttachment < Struct.new(
  :transit_gateway_attachment_id,
  :transit_gateway_id,
  :client_vpn_endpoint_id,
  :client_vpn_owner_id,
  :state,
  :creation_time)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of the Transit Gateway attachment.

Returns:

  • (String)


81856
81857
81858
81859
81860
81861
81862
81863
81864
81865
# File 'lib/aws-sdk-ec2/types.rb', line 81856

class TransitGatewayClientVpnAttachment < Struct.new(
  :transit_gateway_attachment_id,
  :transit_gateway_id,
  :client_vpn_endpoint_id,
  :client_vpn_owner_id,
  :state,
  :creation_time)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_attachment_idString

The ID of the Transit Gateway attachment.

Returns:

  • (String)


81856
81857
81858
81859
81860
81861
81862
81863
81864
81865
# File 'lib/aws-sdk-ec2/types.rb', line 81856

class TransitGatewayClientVpnAttachment < Struct.new(
  :transit_gateway_attachment_id,
  :transit_gateway_id,
  :client_vpn_endpoint_id,
  :client_vpn_owner_id,
  :state,
  :creation_time)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_idString

The ID of the Transit Gateway.

Returns:

  • (String)


81856
81857
81858
81859
81860
81861
81862
81863
81864
81865
# File 'lib/aws-sdk-ec2/types.rb', line 81856

class TransitGatewayClientVpnAttachment < Struct.new(
  :transit_gateway_attachment_id,
  :transit_gateway_id,
  :client_vpn_endpoint_id,
  :client_vpn_owner_id,
  :state,
  :creation_time)
  SENSITIVE = []
  include Aws::Structure
end