Class: Aws::EC2::Types::TransitGatewayMulticastGroup
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::TransitGatewayMulticastGroup
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the transit gateway multicast group resources.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#group_ip_address ⇒ String
The IP address assigned to the transit gateway multicast group.
-
#group_member ⇒ Boolean
Indicates that the resource is a transit gateway multicast group member.
-
#group_source ⇒ Boolean
Indicates that the resource is a transit gateway multicast group member.
-
#member_type ⇒ String
The member type (for example,
static). -
#network_interface_id ⇒ String
The ID of the transit gateway attachment.
-
#resource_id ⇒ String
The ID of the resource.
-
#resource_owner_id ⇒ String
The ID of the Amazon Web Services account that owns the transit gateway multicast domain group resource.
-
#resource_type ⇒ String
The type of resource, for example a VPC attachment.
-
#source_type ⇒ String
The source type.
-
#subnet_id ⇒ String
The ID of the subnet.
-
#transit_gateway_attachment_id ⇒ String
The ID of the transit gateway attachment.
Instance Attribute Details
#group_ip_address ⇒ String
The IP address assigned to the transit gateway multicast group.
86935 86936 86937 86938 86939 86940 86941 86942 86943 86944 86945 86946 86947 86948 86949 |
# File 'lib/aws-sdk-ec2/types.rb', line 86935 class TransitGatewayMulticastGroup < Struct.new( :group_ip_address, :transit_gateway_attachment_id, :subnet_id, :resource_id, :resource_type, :resource_owner_id, :network_interface_id, :group_member, :group_source, :member_type, :source_type) SENSITIVE = [] include Aws::Structure end |
#group_member ⇒ Boolean
Indicates that the resource is a transit gateway multicast group member.
86935 86936 86937 86938 86939 86940 86941 86942 86943 86944 86945 86946 86947 86948 86949 |
# File 'lib/aws-sdk-ec2/types.rb', line 86935 class TransitGatewayMulticastGroup < Struct.new( :group_ip_address, :transit_gateway_attachment_id, :subnet_id, :resource_id, :resource_type, :resource_owner_id, :network_interface_id, :group_member, :group_source, :member_type, :source_type) SENSITIVE = [] include Aws::Structure end |
#group_source ⇒ Boolean
Indicates that the resource is a transit gateway multicast group member.
86935 86936 86937 86938 86939 86940 86941 86942 86943 86944 86945 86946 86947 86948 86949 |
# File 'lib/aws-sdk-ec2/types.rb', line 86935 class TransitGatewayMulticastGroup < Struct.new( :group_ip_address, :transit_gateway_attachment_id, :subnet_id, :resource_id, :resource_type, :resource_owner_id, :network_interface_id, :group_member, :group_source, :member_type, :source_type) SENSITIVE = [] include Aws::Structure end |
#member_type ⇒ String
The member type (for example, static).
86935 86936 86937 86938 86939 86940 86941 86942 86943 86944 86945 86946 86947 86948 86949 |
# File 'lib/aws-sdk-ec2/types.rb', line 86935 class TransitGatewayMulticastGroup < Struct.new( :group_ip_address, :transit_gateway_attachment_id, :subnet_id, :resource_id, :resource_type, :resource_owner_id, :network_interface_id, :group_member, :group_source, :member_type, :source_type) SENSITIVE = [] include Aws::Structure end |
#network_interface_id ⇒ String
The ID of the transit gateway attachment.
86935 86936 86937 86938 86939 86940 86941 86942 86943 86944 86945 86946 86947 86948 86949 |
# File 'lib/aws-sdk-ec2/types.rb', line 86935 class TransitGatewayMulticastGroup < Struct.new( :group_ip_address, :transit_gateway_attachment_id, :subnet_id, :resource_id, :resource_type, :resource_owner_id, :network_interface_id, :group_member, :group_source, :member_type, :source_type) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
The ID of the resource.
86935 86936 86937 86938 86939 86940 86941 86942 86943 86944 86945 86946 86947 86948 86949 |
# File 'lib/aws-sdk-ec2/types.rb', line 86935 class TransitGatewayMulticastGroup < Struct.new( :group_ip_address, :transit_gateway_attachment_id, :subnet_id, :resource_id, :resource_type, :resource_owner_id, :network_interface_id, :group_member, :group_source, :member_type, :source_type) SENSITIVE = [] include Aws::Structure end |
#resource_owner_id ⇒ String
The ID of the Amazon Web Services account that owns the transit gateway multicast domain group resource.
86935 86936 86937 86938 86939 86940 86941 86942 86943 86944 86945 86946 86947 86948 86949 |
# File 'lib/aws-sdk-ec2/types.rb', line 86935 class TransitGatewayMulticastGroup < Struct.new( :group_ip_address, :transit_gateway_attachment_id, :subnet_id, :resource_id, :resource_type, :resource_owner_id, :network_interface_id, :group_member, :group_source, :member_type, :source_type) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of resource, for example a VPC attachment.
86935 86936 86937 86938 86939 86940 86941 86942 86943 86944 86945 86946 86947 86948 86949 |
# File 'lib/aws-sdk-ec2/types.rb', line 86935 class TransitGatewayMulticastGroup < Struct.new( :group_ip_address, :transit_gateway_attachment_id, :subnet_id, :resource_id, :resource_type, :resource_owner_id, :network_interface_id, :group_member, :group_source, :member_type, :source_type) SENSITIVE = [] include Aws::Structure end |
#source_type ⇒ String
The source type.
86935 86936 86937 86938 86939 86940 86941 86942 86943 86944 86945 86946 86947 86948 86949 |
# File 'lib/aws-sdk-ec2/types.rb', line 86935 class TransitGatewayMulticastGroup < Struct.new( :group_ip_address, :transit_gateway_attachment_id, :subnet_id, :resource_id, :resource_type, :resource_owner_id, :network_interface_id, :group_member, :group_source, :member_type, :source_type) SENSITIVE = [] include Aws::Structure end |
#subnet_id ⇒ String
The ID of the subnet.
86935 86936 86937 86938 86939 86940 86941 86942 86943 86944 86945 86946 86947 86948 86949 |
# File 'lib/aws-sdk-ec2/types.rb', line 86935 class TransitGatewayMulticastGroup < Struct.new( :group_ip_address, :transit_gateway_attachment_id, :subnet_id, :resource_id, :resource_type, :resource_owner_id, :network_interface_id, :group_member, :group_source, :member_type, :source_type) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_attachment_id ⇒ String
The ID of the transit gateway attachment.
86935 86936 86937 86938 86939 86940 86941 86942 86943 86944 86945 86946 86947 86948 86949 |
# File 'lib/aws-sdk-ec2/types.rb', line 86935 class TransitGatewayMulticastGroup < Struct.new( :group_ip_address, :transit_gateway_attachment_id, :subnet_id, :resource_id, :resource_type, :resource_owner_id, :network_interface_id, :group_member, :group_source, :member_type, :source_type) SENSITIVE = [] include Aws::Structure end |