Class: Aws::EC2::Types::TransitGatewayMulticastGroup
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::TransitGatewayMulticastGroup
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the transit gateway multicast group resources.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#group_ip_address ⇒ String
The IP address assigned to the transit gateway multicast group.
-
#group_member ⇒ Boolean
Indicates that the resource is a transit gateway multicast group member.
-
#group_source ⇒ Boolean
Indicates that the resource is a transit gateway multicast group member.
-
#member_type ⇒ String
The member type (for example, ‘static`).
-
#network_interface_id ⇒ String
The ID of the transit gateway attachment.
-
#resource_id ⇒ String
The ID of the resource.
-
#resource_owner_id ⇒ String
The ID of the Amazon Web Services account that owns the transit gateway multicast domain group resource.
-
#resource_type ⇒ String
The type of resource, for example a VPC attachment.
-
#source_type ⇒ String
The source type.
-
#subnet_id ⇒ String
The ID of the subnet.
-
#transit_gateway_attachment_id ⇒ String
The ID of the transit gateway attachment.
Instance Attribute Details
#group_ip_address ⇒ String
The IP address assigned to the transit gateway multicast group.
82638 82639 82640 82641 82642 82643 82644 82645 82646 82647 82648 82649 82650 82651 82652 |
# File 'lib/aws-sdk-ec2/types.rb', line 82638 class TransitGatewayMulticastGroup < Struct.new( :group_ip_address, :transit_gateway_attachment_id, :subnet_id, :resource_id, :resource_type, :resource_owner_id, :network_interface_id, :group_member, :group_source, :member_type, :source_type) SENSITIVE = [] include Aws::Structure end |
#group_member ⇒ Boolean
Indicates that the resource is a transit gateway multicast group member.
82638 82639 82640 82641 82642 82643 82644 82645 82646 82647 82648 82649 82650 82651 82652 |
# File 'lib/aws-sdk-ec2/types.rb', line 82638 class TransitGatewayMulticastGroup < Struct.new( :group_ip_address, :transit_gateway_attachment_id, :subnet_id, :resource_id, :resource_type, :resource_owner_id, :network_interface_id, :group_member, :group_source, :member_type, :source_type) SENSITIVE = [] include Aws::Structure end |
#group_source ⇒ Boolean
Indicates that the resource is a transit gateway multicast group member.
82638 82639 82640 82641 82642 82643 82644 82645 82646 82647 82648 82649 82650 82651 82652 |
# File 'lib/aws-sdk-ec2/types.rb', line 82638 class TransitGatewayMulticastGroup < Struct.new( :group_ip_address, :transit_gateway_attachment_id, :subnet_id, :resource_id, :resource_type, :resource_owner_id, :network_interface_id, :group_member, :group_source, :member_type, :source_type) SENSITIVE = [] include Aws::Structure end |
#member_type ⇒ String
The member type (for example, ‘static`).
82638 82639 82640 82641 82642 82643 82644 82645 82646 82647 82648 82649 82650 82651 82652 |
# File 'lib/aws-sdk-ec2/types.rb', line 82638 class TransitGatewayMulticastGroup < Struct.new( :group_ip_address, :transit_gateway_attachment_id, :subnet_id, :resource_id, :resource_type, :resource_owner_id, :network_interface_id, :group_member, :group_source, :member_type, :source_type) SENSITIVE = [] include Aws::Structure end |
#network_interface_id ⇒ String
The ID of the transit gateway attachment.
82638 82639 82640 82641 82642 82643 82644 82645 82646 82647 82648 82649 82650 82651 82652 |
# File 'lib/aws-sdk-ec2/types.rb', line 82638 class TransitGatewayMulticastGroup < Struct.new( :group_ip_address, :transit_gateway_attachment_id, :subnet_id, :resource_id, :resource_type, :resource_owner_id, :network_interface_id, :group_member, :group_source, :member_type, :source_type) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
The ID of the resource.
82638 82639 82640 82641 82642 82643 82644 82645 82646 82647 82648 82649 82650 82651 82652 |
# File 'lib/aws-sdk-ec2/types.rb', line 82638 class TransitGatewayMulticastGroup < Struct.new( :group_ip_address, :transit_gateway_attachment_id, :subnet_id, :resource_id, :resource_type, :resource_owner_id, :network_interface_id, :group_member, :group_source, :member_type, :source_type) SENSITIVE = [] include Aws::Structure end |
#resource_owner_id ⇒ String
The ID of the Amazon Web Services account that owns the transit gateway multicast domain group resource.
82638 82639 82640 82641 82642 82643 82644 82645 82646 82647 82648 82649 82650 82651 82652 |
# File 'lib/aws-sdk-ec2/types.rb', line 82638 class TransitGatewayMulticastGroup < Struct.new( :group_ip_address, :transit_gateway_attachment_id, :subnet_id, :resource_id, :resource_type, :resource_owner_id, :network_interface_id, :group_member, :group_source, :member_type, :source_type) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of resource, for example a VPC attachment.
82638 82639 82640 82641 82642 82643 82644 82645 82646 82647 82648 82649 82650 82651 82652 |
# File 'lib/aws-sdk-ec2/types.rb', line 82638 class TransitGatewayMulticastGroup < Struct.new( :group_ip_address, :transit_gateway_attachment_id, :subnet_id, :resource_id, :resource_type, :resource_owner_id, :network_interface_id, :group_member, :group_source, :member_type, :source_type) SENSITIVE = [] include Aws::Structure end |
#source_type ⇒ String
The source type.
82638 82639 82640 82641 82642 82643 82644 82645 82646 82647 82648 82649 82650 82651 82652 |
# File 'lib/aws-sdk-ec2/types.rb', line 82638 class TransitGatewayMulticastGroup < Struct.new( :group_ip_address, :transit_gateway_attachment_id, :subnet_id, :resource_id, :resource_type, :resource_owner_id, :network_interface_id, :group_member, :group_source, :member_type, :source_type) SENSITIVE = [] include Aws::Structure end |
#subnet_id ⇒ String
The ID of the subnet.
82638 82639 82640 82641 82642 82643 82644 82645 82646 82647 82648 82649 82650 82651 82652 |
# File 'lib/aws-sdk-ec2/types.rb', line 82638 class TransitGatewayMulticastGroup < Struct.new( :group_ip_address, :transit_gateway_attachment_id, :subnet_id, :resource_id, :resource_type, :resource_owner_id, :network_interface_id, :group_member, :group_source, :member_type, :source_type) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_attachment_id ⇒ String
The ID of the transit gateway attachment.
82638 82639 82640 82641 82642 82643 82644 82645 82646 82647 82648 82649 82650 82651 82652 |
# File 'lib/aws-sdk-ec2/types.rb', line 82638 class TransitGatewayMulticastGroup < Struct.new( :group_ip_address, :transit_gateway_attachment_id, :subnet_id, :resource_id, :resource_type, :resource_owner_id, :network_interface_id, :group_member, :group_source, :member_type, :source_type) SENSITIVE = [] include Aws::Structure end |