Class: Aws::EC2::Types::TransitGatewayOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::TransitGatewayOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the options for a transit gateway.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#amazon_side_asn ⇒ Integer
A private Autonomous System Number (ASN) for the Amazon side of a BGP session.
-
#association_default_route_table_id ⇒ String
The ID of the default association route table.
-
#auto_accept_shared_attachments ⇒ String
Indicates whether attachment requests are automatically accepted.
-
#default_route_table_association ⇒ String
Indicates whether resource attachments are automatically associated with the default association route table.
-
#default_route_table_propagation ⇒ String
Indicates whether resource attachments automatically propagate routes to the default propagation route table.
-
#dns_support ⇒ String
Indicates whether DNS support is enabled.
-
#encryption_support ⇒ Types::EncryptionSupport
Defines if the Transit Gateway supports VPC Encryption Control.
-
#multicast_support ⇒ String
Indicates whether multicast is enabled on the transit gateway.
-
#propagation_default_route_table_id ⇒ String
The ID of the default propagation route table.
-
#security_group_referencing_support ⇒ String
Enables you to reference a security group across VPCs attached to a transit gateway to simplify security group management.
-
#transit_gateway_cidr_blocks ⇒ Array<String>
The transit gateway CIDR blocks.
-
#vpn_ecmp_support ⇒ String
Indicates whether Equal Cost Multipath Protocol support is enabled.
Instance Attribute Details
#amazon_side_asn ⇒ Integer
A private Autonomous System Number (ASN) for the Amazon side of a BGP session. The range is 64512 to 65534 for 16-bit ASNs and 4200000000 to 4294967294 for 32-bit ASNs.
83848 83849 83850 83851 83852 83853 83854 83855 83856 83857 83858 83859 83860 83861 83862 83863 |
# File 'lib/aws-sdk-ec2/types.rb', line 83848 class TransitGatewayOptions < Struct.new( :amazon_side_asn, :transit_gateway_cidr_blocks, :auto_accept_shared_attachments, :default_route_table_association, :association_default_route_table_id, :default_route_table_propagation, :propagation_default_route_table_id, :vpn_ecmp_support, :dns_support, :security_group_referencing_support, :multicast_support, :encryption_support) SENSITIVE = [] include Aws::Structure end |
#association_default_route_table_id ⇒ String
The ID of the default association route table.
83848 83849 83850 83851 83852 83853 83854 83855 83856 83857 83858 83859 83860 83861 83862 83863 |
# File 'lib/aws-sdk-ec2/types.rb', line 83848 class TransitGatewayOptions < Struct.new( :amazon_side_asn, :transit_gateway_cidr_blocks, :auto_accept_shared_attachments, :default_route_table_association, :association_default_route_table_id, :default_route_table_propagation, :propagation_default_route_table_id, :vpn_ecmp_support, :dns_support, :security_group_referencing_support, :multicast_support, :encryption_support) SENSITIVE = [] include Aws::Structure end |
#auto_accept_shared_attachments ⇒ String
Indicates whether attachment requests are automatically accepted.
83848 83849 83850 83851 83852 83853 83854 83855 83856 83857 83858 83859 83860 83861 83862 83863 |
# File 'lib/aws-sdk-ec2/types.rb', line 83848 class TransitGatewayOptions < Struct.new( :amazon_side_asn, :transit_gateway_cidr_blocks, :auto_accept_shared_attachments, :default_route_table_association, :association_default_route_table_id, :default_route_table_propagation, :propagation_default_route_table_id, :vpn_ecmp_support, :dns_support, :security_group_referencing_support, :multicast_support, :encryption_support) SENSITIVE = [] include Aws::Structure end |
#default_route_table_association ⇒ String
Indicates whether resource attachments are automatically associated
with the default association route table. Enabled by default. Either
defaultRouteTableAssociation or defaultRouteTablePropagation
must be set to enable for Amazon Web Services Transit Gateway to
create the default transit gateway route table.
83848 83849 83850 83851 83852 83853 83854 83855 83856 83857 83858 83859 83860 83861 83862 83863 |
# File 'lib/aws-sdk-ec2/types.rb', line 83848 class TransitGatewayOptions < Struct.new( :amazon_side_asn, :transit_gateway_cidr_blocks, :auto_accept_shared_attachments, :default_route_table_association, :association_default_route_table_id, :default_route_table_propagation, :propagation_default_route_table_id, :vpn_ecmp_support, :dns_support, :security_group_referencing_support, :multicast_support, :encryption_support) SENSITIVE = [] include Aws::Structure end |
#default_route_table_propagation ⇒ String
Indicates whether resource attachments automatically propagate
routes to the default propagation route table. Enabled by default.
If defaultRouteTablePropagation is set to enable, Amazon Web
Services Transit Gateway creates the default transit gateway route
table.
83848 83849 83850 83851 83852 83853 83854 83855 83856 83857 83858 83859 83860 83861 83862 83863 |
# File 'lib/aws-sdk-ec2/types.rb', line 83848 class TransitGatewayOptions < Struct.new( :amazon_side_asn, :transit_gateway_cidr_blocks, :auto_accept_shared_attachments, :default_route_table_association, :association_default_route_table_id, :default_route_table_propagation, :propagation_default_route_table_id, :vpn_ecmp_support, :dns_support, :security_group_referencing_support, :multicast_support, :encryption_support) SENSITIVE = [] include Aws::Structure end |
#dns_support ⇒ String
Indicates whether DNS support is enabled.
83848 83849 83850 83851 83852 83853 83854 83855 83856 83857 83858 83859 83860 83861 83862 83863 |
# File 'lib/aws-sdk-ec2/types.rb', line 83848 class TransitGatewayOptions < Struct.new( :amazon_side_asn, :transit_gateway_cidr_blocks, :auto_accept_shared_attachments, :default_route_table_association, :association_default_route_table_id, :default_route_table_propagation, :propagation_default_route_table_id, :vpn_ecmp_support, :dns_support, :security_group_referencing_support, :multicast_support, :encryption_support) SENSITIVE = [] include Aws::Structure end |
#encryption_support ⇒ Types::EncryptionSupport
Defines if the Transit Gateway supports VPC Encryption Control.
83848 83849 83850 83851 83852 83853 83854 83855 83856 83857 83858 83859 83860 83861 83862 83863 |
# File 'lib/aws-sdk-ec2/types.rb', line 83848 class TransitGatewayOptions < Struct.new( :amazon_side_asn, :transit_gateway_cidr_blocks, :auto_accept_shared_attachments, :default_route_table_association, :association_default_route_table_id, :default_route_table_propagation, :propagation_default_route_table_id, :vpn_ecmp_support, :dns_support, :security_group_referencing_support, :multicast_support, :encryption_support) SENSITIVE = [] include Aws::Structure end |
#multicast_support ⇒ String
Indicates whether multicast is enabled on the transit gateway
83848 83849 83850 83851 83852 83853 83854 83855 83856 83857 83858 83859 83860 83861 83862 83863 |
# File 'lib/aws-sdk-ec2/types.rb', line 83848 class TransitGatewayOptions < Struct.new( :amazon_side_asn, :transit_gateway_cidr_blocks, :auto_accept_shared_attachments, :default_route_table_association, :association_default_route_table_id, :default_route_table_propagation, :propagation_default_route_table_id, :vpn_ecmp_support, :dns_support, :security_group_referencing_support, :multicast_support, :encryption_support) SENSITIVE = [] include Aws::Structure end |
#propagation_default_route_table_id ⇒ String
The ID of the default propagation route table.
83848 83849 83850 83851 83852 83853 83854 83855 83856 83857 83858 83859 83860 83861 83862 83863 |
# File 'lib/aws-sdk-ec2/types.rb', line 83848 class TransitGatewayOptions < Struct.new( :amazon_side_asn, :transit_gateway_cidr_blocks, :auto_accept_shared_attachments, :default_route_table_association, :association_default_route_table_id, :default_route_table_propagation, :propagation_default_route_table_id, :vpn_ecmp_support, :dns_support, :security_group_referencing_support, :multicast_support, :encryption_support) SENSITIVE = [] include Aws::Structure end |
#security_group_referencing_support ⇒ String
Enables you to reference a security group across VPCs attached to a transit gateway to simplify security group management.
This option is disabled by default.
83848 83849 83850 83851 83852 83853 83854 83855 83856 83857 83858 83859 83860 83861 83862 83863 |
# File 'lib/aws-sdk-ec2/types.rb', line 83848 class TransitGatewayOptions < Struct.new( :amazon_side_asn, :transit_gateway_cidr_blocks, :auto_accept_shared_attachments, :default_route_table_association, :association_default_route_table_id, :default_route_table_propagation, :propagation_default_route_table_id, :vpn_ecmp_support, :dns_support, :security_group_referencing_support, :multicast_support, :encryption_support) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_cidr_blocks ⇒ Array<String>
The transit gateway CIDR blocks.
83848 83849 83850 83851 83852 83853 83854 83855 83856 83857 83858 83859 83860 83861 83862 83863 |
# File 'lib/aws-sdk-ec2/types.rb', line 83848 class TransitGatewayOptions < Struct.new( :amazon_side_asn, :transit_gateway_cidr_blocks, :auto_accept_shared_attachments, :default_route_table_association, :association_default_route_table_id, :default_route_table_propagation, :propagation_default_route_table_id, :vpn_ecmp_support, :dns_support, :security_group_referencing_support, :multicast_support, :encryption_support) SENSITIVE = [] include Aws::Structure end |
#vpn_ecmp_support ⇒ String
Indicates whether Equal Cost Multipath Protocol support is enabled.
83848 83849 83850 83851 83852 83853 83854 83855 83856 83857 83858 83859 83860 83861 83862 83863 |
# File 'lib/aws-sdk-ec2/types.rb', line 83848 class TransitGatewayOptions < Struct.new( :amazon_side_asn, :transit_gateway_cidr_blocks, :auto_accept_shared_attachments, :default_route_table_association, :association_default_route_table_id, :default_route_table_propagation, :propagation_default_route_table_id, :vpn_ecmp_support, :dns_support, :security_group_referencing_support, :multicast_support, :encryption_support) SENSITIVE = [] include Aws::Structure end |