Class: Aws::EC2::Types::TransitGatewayRouteTable

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes a transit gateway route table.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timeTime

The creation time.

Returns:

  • (Time)


83113
83114
83115
83116
83117
83118
83119
83120
83121
83122
83123
# File 'lib/aws-sdk-ec2/types.rb', line 83113

class TransitGatewayRouteTable < Struct.new(
  :transit_gateway_route_table_id,
  :transit_gateway_id,
  :state,
  :default_association_route_table,
  :default_propagation_route_table,
  :creation_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#default_association_route_tableBoolean

Indicates whether this is the default association route table for the transit gateway.

Returns:

  • (Boolean)


83113
83114
83115
83116
83117
83118
83119
83120
83121
83122
83123
# File 'lib/aws-sdk-ec2/types.rb', line 83113

class TransitGatewayRouteTable < Struct.new(
  :transit_gateway_route_table_id,
  :transit_gateway_id,
  :state,
  :default_association_route_table,
  :default_propagation_route_table,
  :creation_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#default_propagation_route_tableBoolean

Indicates whether this is the default propagation route table for the transit gateway.

Returns:

  • (Boolean)


83113
83114
83115
83116
83117
83118
83119
83120
83121
83122
83123
# File 'lib/aws-sdk-ec2/types.rb', line 83113

class TransitGatewayRouteTable < Struct.new(
  :transit_gateway_route_table_id,
  :transit_gateway_id,
  :state,
  :default_association_route_table,
  :default_propagation_route_table,
  :creation_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of the transit gateway route table.

Returns:

  • (String)


83113
83114
83115
83116
83117
83118
83119
83120
83121
83122
83123
# File 'lib/aws-sdk-ec2/types.rb', line 83113

class TransitGatewayRouteTable < Struct.new(
  :transit_gateway_route_table_id,
  :transit_gateway_id,
  :state,
  :default_association_route_table,
  :default_propagation_route_table,
  :creation_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Any tags assigned to the route table.

Returns:



83113
83114
83115
83116
83117
83118
83119
83120
83121
83122
83123
# File 'lib/aws-sdk-ec2/types.rb', line 83113

class TransitGatewayRouteTable < Struct.new(
  :transit_gateway_route_table_id,
  :transit_gateway_id,
  :state,
  :default_association_route_table,
  :default_propagation_route_table,
  :creation_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_idString

The ID of the transit gateway.

Returns:

  • (String)


83113
83114
83115
83116
83117
83118
83119
83120
83121
83122
83123
# File 'lib/aws-sdk-ec2/types.rb', line 83113

class TransitGatewayRouteTable < Struct.new(
  :transit_gateway_route_table_id,
  :transit_gateway_id,
  :state,
  :default_association_route_table,
  :default_propagation_route_table,
  :creation_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_route_table_idString

The ID of the transit gateway route table.

Returns:

  • (String)


83113
83114
83115
83116
83117
83118
83119
83120
83121
83122
83123
# File 'lib/aws-sdk-ec2/types.rb', line 83113

class TransitGatewayRouteTable < Struct.new(
  :transit_gateway_route_table_id,
  :transit_gateway_id,
  :state,
  :default_association_route_table,
  :default_propagation_route_table,
  :creation_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end