Class: Aws::EC2::Types::TunnelOption

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

The VPN tunnel options.

Constant Summary collapse

SENSITIVE =
[:pre_shared_key]

Instance Attribute Summary collapse

Instance Attribute Details

#dpd_timeout_actionString

The action to take after a DPD timeout occurs.

Returns:

  • (String)


84453
84454
84455
84456
84457
84458
84459
84460
84461
84462
84463
84464
84465
84466
84467
84468
84469
84470
84471
84472
84473
84474
84475
84476
84477
# File 'lib/aws-sdk-ec2/types.rb', line 84453

class TunnelOption < Struct.new(
  :outside_ip_address,
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#dpd_timeout_secondsInteger

The number of seconds after which a DPD timeout occurs.

Returns:

  • (Integer)


84453
84454
84455
84456
84457
84458
84459
84460
84461
84462
84463
84464
84465
84466
84467
84468
84469
84470
84471
84472
84473
84474
84475
84476
84477
# File 'lib/aws-sdk-ec2/types.rb', line 84453

class TunnelOption < Struct.new(
  :outside_ip_address,
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#enable_tunnel_lifecycle_controlBoolean

Status of tunnel endpoint lifecycle control feature.

Returns:

  • (Boolean)


84453
84454
84455
84456
84457
84458
84459
84460
84461
84462
84463
84464
84465
84466
84467
84468
84469
84470
84471
84472
84473
84474
84475
84476
84477
# File 'lib/aws-sdk-ec2/types.rb', line 84453

class TunnelOption < Struct.new(
  :outside_ip_address,
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#ike_versionsArray<Types::IKEVersionsListValue>

The IKE versions that are permitted for the VPN tunnel.

Returns:



84453
84454
84455
84456
84457
84458
84459
84460
84461
84462
84463
84464
84465
84466
84467
84468
84469
84470
84471
84472
84473
84474
84475
84476
84477
# File 'lib/aws-sdk-ec2/types.rb', line 84453

class TunnelOption < Struct.new(
  :outside_ip_address,
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#log_optionsTypes::VpnTunnelLogOptions

Options for logging VPN tunnel activity.



84453
84454
84455
84456
84457
84458
84459
84460
84461
84462
84463
84464
84465
84466
84467
84468
84469
84470
84471
84472
84473
84474
84475
84476
84477
# File 'lib/aws-sdk-ec2/types.rb', line 84453

class TunnelOption < Struct.new(
  :outside_ip_address,
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#outside_ip_addressString

The external IP address of the VPN tunnel.

Returns:

  • (String)


84453
84454
84455
84456
84457
84458
84459
84460
84461
84462
84463
84464
84465
84466
84467
84468
84469
84470
84471
84472
84473
84474
84475
84476
84477
# File 'lib/aws-sdk-ec2/types.rb', line 84453

class TunnelOption < Struct.new(
  :outside_ip_address,
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#phase_1_dh_group_numbersArray<Types::Phase1DHGroupNumbersListValue>

The permitted Diffie-Hellman group numbers for the VPN tunnel for phase 1 IKE negotiations.



84453
84454
84455
84456
84457
84458
84459
84460
84461
84462
84463
84464
84465
84466
84467
84468
84469
84470
84471
84472
84473
84474
84475
84476
84477
# File 'lib/aws-sdk-ec2/types.rb', line 84453

class TunnelOption < Struct.new(
  :outside_ip_address,
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#phase_1_encryption_algorithmsArray<Types::Phase1EncryptionAlgorithmsListValue>

The permitted encryption algorithms for the VPN tunnel for phase 1 IKE negotiations.



84453
84454
84455
84456
84457
84458
84459
84460
84461
84462
84463
84464
84465
84466
84467
84468
84469
84470
84471
84472
84473
84474
84475
84476
84477
# File 'lib/aws-sdk-ec2/types.rb', line 84453

class TunnelOption < Struct.new(
  :outside_ip_address,
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#phase_1_integrity_algorithmsArray<Types::Phase1IntegrityAlgorithmsListValue>

The permitted integrity algorithms for the VPN tunnel for phase 1 IKE negotiations.



84453
84454
84455
84456
84457
84458
84459
84460
84461
84462
84463
84464
84465
84466
84467
84468
84469
84470
84471
84472
84473
84474
84475
84476
84477
# File 'lib/aws-sdk-ec2/types.rb', line 84453

class TunnelOption < Struct.new(
  :outside_ip_address,
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#phase_1_lifetime_secondsInteger

The lifetime for phase 1 of the IKE negotiation, in seconds.

Returns:

  • (Integer)


84453
84454
84455
84456
84457
84458
84459
84460
84461
84462
84463
84464
84465
84466
84467
84468
84469
84470
84471
84472
84473
84474
84475
84476
84477
# File 'lib/aws-sdk-ec2/types.rb', line 84453

class TunnelOption < Struct.new(
  :outside_ip_address,
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#phase_2_dh_group_numbersArray<Types::Phase2DHGroupNumbersListValue>

The permitted Diffie-Hellman group numbers for the VPN tunnel for phase 2 IKE negotiations.



84453
84454
84455
84456
84457
84458
84459
84460
84461
84462
84463
84464
84465
84466
84467
84468
84469
84470
84471
84472
84473
84474
84475
84476
84477
# File 'lib/aws-sdk-ec2/types.rb', line 84453

class TunnelOption < Struct.new(
  :outside_ip_address,
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#phase_2_encryption_algorithmsArray<Types::Phase2EncryptionAlgorithmsListValue>

The permitted encryption algorithms for the VPN tunnel for phase 2 IKE negotiations.



84453
84454
84455
84456
84457
84458
84459
84460
84461
84462
84463
84464
84465
84466
84467
84468
84469
84470
84471
84472
84473
84474
84475
84476
84477
# File 'lib/aws-sdk-ec2/types.rb', line 84453

class TunnelOption < Struct.new(
  :outside_ip_address,
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#phase_2_integrity_algorithmsArray<Types::Phase2IntegrityAlgorithmsListValue>

The permitted integrity algorithms for the VPN tunnel for phase 2 IKE negotiations.



84453
84454
84455
84456
84457
84458
84459
84460
84461
84462
84463
84464
84465
84466
84467
84468
84469
84470
84471
84472
84473
84474
84475
84476
84477
# File 'lib/aws-sdk-ec2/types.rb', line 84453

class TunnelOption < Struct.new(
  :outside_ip_address,
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#phase_2_lifetime_secondsInteger

The lifetime for phase 2 of the IKE negotiation, in seconds.

Returns:

  • (Integer)


84453
84454
84455
84456
84457
84458
84459
84460
84461
84462
84463
84464
84465
84466
84467
84468
84469
84470
84471
84472
84473
84474
84475
84476
84477
# File 'lib/aws-sdk-ec2/types.rb', line 84453

class TunnelOption < Struct.new(
  :outside_ip_address,
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#pre_shared_keyString

The pre-shared key (PSK) to establish initial authentication between the virtual private gateway and the customer gateway.

Returns:

  • (String)


84453
84454
84455
84456
84457
84458
84459
84460
84461
84462
84463
84464
84465
84466
84467
84468
84469
84470
84471
84472
84473
84474
84475
84476
84477
# File 'lib/aws-sdk-ec2/types.rb', line 84453

class TunnelOption < Struct.new(
  :outside_ip_address,
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#rekey_fuzz_percentageInteger

The percentage of the rekey window determined by RekeyMarginTimeSeconds during which the rekey time is randomly selected.

Returns:

  • (Integer)


84453
84454
84455
84456
84457
84458
84459
84460
84461
84462
84463
84464
84465
84466
84467
84468
84469
84470
84471
84472
84473
84474
84475
84476
84477
# File 'lib/aws-sdk-ec2/types.rb', line 84453

class TunnelOption < Struct.new(
  :outside_ip_address,
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#rekey_margin_time_secondsInteger

The margin time, in seconds, before the phase 2 lifetime expires, during which the Amazon Web Services side of the VPN connection performs an IKE rekey.

Returns:

  • (Integer)


84453
84454
84455
84456
84457
84458
84459
84460
84461
84462
84463
84464
84465
84466
84467
84468
84469
84470
84471
84472
84473
84474
84475
84476
84477
# File 'lib/aws-sdk-ec2/types.rb', line 84453

class TunnelOption < Struct.new(
  :outside_ip_address,
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#replay_window_sizeInteger

The number of packets in an IKE replay window.

Returns:

  • (Integer)


84453
84454
84455
84456
84457
84458
84459
84460
84461
84462
84463
84464
84465
84466
84467
84468
84469
84470
84471
84472
84473
84474
84475
84476
84477
# File 'lib/aws-sdk-ec2/types.rb', line 84453

class TunnelOption < Struct.new(
  :outside_ip_address,
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#startup_actionString

The action to take when the establishing the VPN tunnels for a VPN connection.

Returns:

  • (String)


84453
84454
84455
84456
84457
84458
84459
84460
84461
84462
84463
84464
84465
84466
84467
84468
84469
84470
84471
84472
84473
84474
84475
84476
84477
# File 'lib/aws-sdk-ec2/types.rb', line 84453

class TunnelOption < Struct.new(
  :outside_ip_address,
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#tunnel_inside_cidrString

The range of inside IPv4 addresses for the tunnel.

Returns:

  • (String)


84453
84454
84455
84456
84457
84458
84459
84460
84461
84462
84463
84464
84465
84466
84467
84468
84469
84470
84471
84472
84473
84474
84475
84476
84477
# File 'lib/aws-sdk-ec2/types.rb', line 84453

class TunnelOption < Struct.new(
  :outside_ip_address,
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#tunnel_inside_ipv_6_cidrString

The range of inside IPv6 addresses for the tunnel.

Returns:

  • (String)


84453
84454
84455
84456
84457
84458
84459
84460
84461
84462
84463
84464
84465
84466
84467
84468
84469
84470
84471
84472
84473
84474
84475
84476
84477
# File 'lib/aws-sdk-ec2/types.rb', line 84453

class TunnelOption < Struct.new(
  :outside_ip_address,
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end