Class: Aws::EC2::Types::TunnelOption
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::TunnelOption
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
The VPN tunnel options.
Constant Summary collapse
- SENSITIVE =
[:pre_shared_key]
Instance Attribute Summary collapse
-
#dpd_timeout_action ⇒ String
The action to take after a DPD timeout occurs.
-
#dpd_timeout_seconds ⇒ Integer
The number of seconds after which a DPD timeout occurs.
-
#enable_tunnel_lifecycle_control ⇒ Boolean
Status of tunnel endpoint lifecycle control feature.
-
#ike_versions ⇒ Array<Types::IKEVersionsListValue>
The IKE versions that are permitted for the VPN tunnel.
-
#log_options ⇒ Types::VpnTunnelLogOptions
Options for logging VPN tunnel activity.
-
#outside_ip_address ⇒ String
The external IP address of the VPN tunnel.
-
#phase_1_dh_group_numbers ⇒ Array<Types::Phase1DHGroupNumbersListValue>
The permitted Diffie-Hellman group numbers for the VPN tunnel for phase 1 IKE negotiations.
-
#phase_1_encryption_algorithms ⇒ Array<Types::Phase1EncryptionAlgorithmsListValue>
The permitted encryption algorithms for the VPN tunnel for phase 1 IKE negotiations.
-
#phase_1_integrity_algorithms ⇒ Array<Types::Phase1IntegrityAlgorithmsListValue>
The permitted integrity algorithms for the VPN tunnel for phase 1 IKE negotiations.
-
#phase_1_lifetime_seconds ⇒ Integer
The lifetime for phase 1 of the IKE negotiation, in seconds.
-
#phase_2_dh_group_numbers ⇒ Array<Types::Phase2DHGroupNumbersListValue>
The permitted Diffie-Hellman group numbers for the VPN tunnel for phase 2 IKE negotiations.
-
#phase_2_encryption_algorithms ⇒ Array<Types::Phase2EncryptionAlgorithmsListValue>
The permitted encryption algorithms for the VPN tunnel for phase 2 IKE negotiations.
-
#phase_2_integrity_algorithms ⇒ Array<Types::Phase2IntegrityAlgorithmsListValue>
The permitted integrity algorithms for the VPN tunnel for phase 2 IKE negotiations.
-
#phase_2_lifetime_seconds ⇒ Integer
The lifetime for phase 2 of the IKE negotiation, in seconds.
-
#pre_shared_key ⇒ String
The pre-shared key (PSK) to establish initial authentication between the virtual private gateway and the customer gateway.
-
#rekey_fuzz_percentage ⇒ Integer
The percentage of the rekey window determined by ‘RekeyMarginTimeSeconds` during which the rekey time is randomly selected.
-
#rekey_margin_time_seconds ⇒ Integer
The margin time, in seconds, before the phase 2 lifetime expires, during which the Amazon Web Services side of the VPN connection performs an IKE rekey.
-
#replay_window_size ⇒ Integer
The number of packets in an IKE replay window.
-
#startup_action ⇒ String
The action to take when the establishing the VPN tunnels for a VPN connection.
-
#tunnel_inside_cidr ⇒ String
The range of inside IPv4 addresses for the tunnel.
-
#tunnel_inside_ipv_6_cidr ⇒ String
The range of inside IPv6 addresses for the tunnel.
Instance Attribute Details
#dpd_timeout_action ⇒ String
The action to take after a DPD timeout occurs.
84442 84443 84444 84445 84446 84447 84448 84449 84450 84451 84452 84453 84454 84455 84456 84457 84458 84459 84460 84461 84462 84463 84464 84465 84466 |
# File 'lib/aws-sdk-ec2/types.rb', line 84442 class TunnelOption < Struct.new( :outside_ip_address, :tunnel_inside_cidr, :tunnel_inside_ipv_6_cidr, :pre_shared_key, :phase_1_lifetime_seconds, :phase_2_lifetime_seconds, :rekey_margin_time_seconds, :rekey_fuzz_percentage, :replay_window_size, :dpd_timeout_seconds, :dpd_timeout_action, :phase_1_encryption_algorithms, :phase_2_encryption_algorithms, :phase_1_integrity_algorithms, :phase_2_integrity_algorithms, :phase_1_dh_group_numbers, :phase_2_dh_group_numbers, :ike_versions, :startup_action, :log_options, :enable_tunnel_lifecycle_control) SENSITIVE = [:pre_shared_key] include Aws::Structure end |
#dpd_timeout_seconds ⇒ Integer
The number of seconds after which a DPD timeout occurs.
84442 84443 84444 84445 84446 84447 84448 84449 84450 84451 84452 84453 84454 84455 84456 84457 84458 84459 84460 84461 84462 84463 84464 84465 84466 |
# File 'lib/aws-sdk-ec2/types.rb', line 84442 class TunnelOption < Struct.new( :outside_ip_address, :tunnel_inside_cidr, :tunnel_inside_ipv_6_cidr, :pre_shared_key, :phase_1_lifetime_seconds, :phase_2_lifetime_seconds, :rekey_margin_time_seconds, :rekey_fuzz_percentage, :replay_window_size, :dpd_timeout_seconds, :dpd_timeout_action, :phase_1_encryption_algorithms, :phase_2_encryption_algorithms, :phase_1_integrity_algorithms, :phase_2_integrity_algorithms, :phase_1_dh_group_numbers, :phase_2_dh_group_numbers, :ike_versions, :startup_action, :log_options, :enable_tunnel_lifecycle_control) SENSITIVE = [:pre_shared_key] include Aws::Structure end |
#enable_tunnel_lifecycle_control ⇒ Boolean
Status of tunnel endpoint lifecycle control feature.
84442 84443 84444 84445 84446 84447 84448 84449 84450 84451 84452 84453 84454 84455 84456 84457 84458 84459 84460 84461 84462 84463 84464 84465 84466 |
# File 'lib/aws-sdk-ec2/types.rb', line 84442 class TunnelOption < Struct.new( :outside_ip_address, :tunnel_inside_cidr, :tunnel_inside_ipv_6_cidr, :pre_shared_key, :phase_1_lifetime_seconds, :phase_2_lifetime_seconds, :rekey_margin_time_seconds, :rekey_fuzz_percentage, :replay_window_size, :dpd_timeout_seconds, :dpd_timeout_action, :phase_1_encryption_algorithms, :phase_2_encryption_algorithms, :phase_1_integrity_algorithms, :phase_2_integrity_algorithms, :phase_1_dh_group_numbers, :phase_2_dh_group_numbers, :ike_versions, :startup_action, :log_options, :enable_tunnel_lifecycle_control) SENSITIVE = [:pre_shared_key] include Aws::Structure end |
#ike_versions ⇒ Array<Types::IKEVersionsListValue>
The IKE versions that are permitted for the VPN tunnel.
84442 84443 84444 84445 84446 84447 84448 84449 84450 84451 84452 84453 84454 84455 84456 84457 84458 84459 84460 84461 84462 84463 84464 84465 84466 |
# File 'lib/aws-sdk-ec2/types.rb', line 84442 class TunnelOption < Struct.new( :outside_ip_address, :tunnel_inside_cidr, :tunnel_inside_ipv_6_cidr, :pre_shared_key, :phase_1_lifetime_seconds, :phase_2_lifetime_seconds, :rekey_margin_time_seconds, :rekey_fuzz_percentage, :replay_window_size, :dpd_timeout_seconds, :dpd_timeout_action, :phase_1_encryption_algorithms, :phase_2_encryption_algorithms, :phase_1_integrity_algorithms, :phase_2_integrity_algorithms, :phase_1_dh_group_numbers, :phase_2_dh_group_numbers, :ike_versions, :startup_action, :log_options, :enable_tunnel_lifecycle_control) SENSITIVE = [:pre_shared_key] include Aws::Structure end |
#log_options ⇒ Types::VpnTunnelLogOptions
Options for logging VPN tunnel activity.
84442 84443 84444 84445 84446 84447 84448 84449 84450 84451 84452 84453 84454 84455 84456 84457 84458 84459 84460 84461 84462 84463 84464 84465 84466 |
# File 'lib/aws-sdk-ec2/types.rb', line 84442 class TunnelOption < Struct.new( :outside_ip_address, :tunnel_inside_cidr, :tunnel_inside_ipv_6_cidr, :pre_shared_key, :phase_1_lifetime_seconds, :phase_2_lifetime_seconds, :rekey_margin_time_seconds, :rekey_fuzz_percentage, :replay_window_size, :dpd_timeout_seconds, :dpd_timeout_action, :phase_1_encryption_algorithms, :phase_2_encryption_algorithms, :phase_1_integrity_algorithms, :phase_2_integrity_algorithms, :phase_1_dh_group_numbers, :phase_2_dh_group_numbers, :ike_versions, :startup_action, :log_options, :enable_tunnel_lifecycle_control) SENSITIVE = [:pre_shared_key] include Aws::Structure end |
#outside_ip_address ⇒ String
The external IP address of the VPN tunnel.
84442 84443 84444 84445 84446 84447 84448 84449 84450 84451 84452 84453 84454 84455 84456 84457 84458 84459 84460 84461 84462 84463 84464 84465 84466 |
# File 'lib/aws-sdk-ec2/types.rb', line 84442 class TunnelOption < Struct.new( :outside_ip_address, :tunnel_inside_cidr, :tunnel_inside_ipv_6_cidr, :pre_shared_key, :phase_1_lifetime_seconds, :phase_2_lifetime_seconds, :rekey_margin_time_seconds, :rekey_fuzz_percentage, :replay_window_size, :dpd_timeout_seconds, :dpd_timeout_action, :phase_1_encryption_algorithms, :phase_2_encryption_algorithms, :phase_1_integrity_algorithms, :phase_2_integrity_algorithms, :phase_1_dh_group_numbers, :phase_2_dh_group_numbers, :ike_versions, :startup_action, :log_options, :enable_tunnel_lifecycle_control) SENSITIVE = [:pre_shared_key] include Aws::Structure end |
#phase_1_dh_group_numbers ⇒ Array<Types::Phase1DHGroupNumbersListValue>
The permitted Diffie-Hellman group numbers for the VPN tunnel for phase 1 IKE negotiations.
84442 84443 84444 84445 84446 84447 84448 84449 84450 84451 84452 84453 84454 84455 84456 84457 84458 84459 84460 84461 84462 84463 84464 84465 84466 |
# File 'lib/aws-sdk-ec2/types.rb', line 84442 class TunnelOption < Struct.new( :outside_ip_address, :tunnel_inside_cidr, :tunnel_inside_ipv_6_cidr, :pre_shared_key, :phase_1_lifetime_seconds, :phase_2_lifetime_seconds, :rekey_margin_time_seconds, :rekey_fuzz_percentage, :replay_window_size, :dpd_timeout_seconds, :dpd_timeout_action, :phase_1_encryption_algorithms, :phase_2_encryption_algorithms, :phase_1_integrity_algorithms, :phase_2_integrity_algorithms, :phase_1_dh_group_numbers, :phase_2_dh_group_numbers, :ike_versions, :startup_action, :log_options, :enable_tunnel_lifecycle_control) SENSITIVE = [:pre_shared_key] include Aws::Structure end |
#phase_1_encryption_algorithms ⇒ Array<Types::Phase1EncryptionAlgorithmsListValue>
The permitted encryption algorithms for the VPN tunnel for phase 1 IKE negotiations.
84442 84443 84444 84445 84446 84447 84448 84449 84450 84451 84452 84453 84454 84455 84456 84457 84458 84459 84460 84461 84462 84463 84464 84465 84466 |
# File 'lib/aws-sdk-ec2/types.rb', line 84442 class TunnelOption < Struct.new( :outside_ip_address, :tunnel_inside_cidr, :tunnel_inside_ipv_6_cidr, :pre_shared_key, :phase_1_lifetime_seconds, :phase_2_lifetime_seconds, :rekey_margin_time_seconds, :rekey_fuzz_percentage, :replay_window_size, :dpd_timeout_seconds, :dpd_timeout_action, :phase_1_encryption_algorithms, :phase_2_encryption_algorithms, :phase_1_integrity_algorithms, :phase_2_integrity_algorithms, :phase_1_dh_group_numbers, :phase_2_dh_group_numbers, :ike_versions, :startup_action, :log_options, :enable_tunnel_lifecycle_control) SENSITIVE = [:pre_shared_key] include Aws::Structure end |
#phase_1_integrity_algorithms ⇒ Array<Types::Phase1IntegrityAlgorithmsListValue>
The permitted integrity algorithms for the VPN tunnel for phase 1 IKE negotiations.
84442 84443 84444 84445 84446 84447 84448 84449 84450 84451 84452 84453 84454 84455 84456 84457 84458 84459 84460 84461 84462 84463 84464 84465 84466 |
# File 'lib/aws-sdk-ec2/types.rb', line 84442 class TunnelOption < Struct.new( :outside_ip_address, :tunnel_inside_cidr, :tunnel_inside_ipv_6_cidr, :pre_shared_key, :phase_1_lifetime_seconds, :phase_2_lifetime_seconds, :rekey_margin_time_seconds, :rekey_fuzz_percentage, :replay_window_size, :dpd_timeout_seconds, :dpd_timeout_action, :phase_1_encryption_algorithms, :phase_2_encryption_algorithms, :phase_1_integrity_algorithms, :phase_2_integrity_algorithms, :phase_1_dh_group_numbers, :phase_2_dh_group_numbers, :ike_versions, :startup_action, :log_options, :enable_tunnel_lifecycle_control) SENSITIVE = [:pre_shared_key] include Aws::Structure end |
#phase_1_lifetime_seconds ⇒ Integer
The lifetime for phase 1 of the IKE negotiation, in seconds.
84442 84443 84444 84445 84446 84447 84448 84449 84450 84451 84452 84453 84454 84455 84456 84457 84458 84459 84460 84461 84462 84463 84464 84465 84466 |
# File 'lib/aws-sdk-ec2/types.rb', line 84442 class TunnelOption < Struct.new( :outside_ip_address, :tunnel_inside_cidr, :tunnel_inside_ipv_6_cidr, :pre_shared_key, :phase_1_lifetime_seconds, :phase_2_lifetime_seconds, :rekey_margin_time_seconds, :rekey_fuzz_percentage, :replay_window_size, :dpd_timeout_seconds, :dpd_timeout_action, :phase_1_encryption_algorithms, :phase_2_encryption_algorithms, :phase_1_integrity_algorithms, :phase_2_integrity_algorithms, :phase_1_dh_group_numbers, :phase_2_dh_group_numbers, :ike_versions, :startup_action, :log_options, :enable_tunnel_lifecycle_control) SENSITIVE = [:pre_shared_key] include Aws::Structure end |
#phase_2_dh_group_numbers ⇒ Array<Types::Phase2DHGroupNumbersListValue>
The permitted Diffie-Hellman group numbers for the VPN tunnel for phase 2 IKE negotiations.
84442 84443 84444 84445 84446 84447 84448 84449 84450 84451 84452 84453 84454 84455 84456 84457 84458 84459 84460 84461 84462 84463 84464 84465 84466 |
# File 'lib/aws-sdk-ec2/types.rb', line 84442 class TunnelOption < Struct.new( :outside_ip_address, :tunnel_inside_cidr, :tunnel_inside_ipv_6_cidr, :pre_shared_key, :phase_1_lifetime_seconds, :phase_2_lifetime_seconds, :rekey_margin_time_seconds, :rekey_fuzz_percentage, :replay_window_size, :dpd_timeout_seconds, :dpd_timeout_action, :phase_1_encryption_algorithms, :phase_2_encryption_algorithms, :phase_1_integrity_algorithms, :phase_2_integrity_algorithms, :phase_1_dh_group_numbers, :phase_2_dh_group_numbers, :ike_versions, :startup_action, :log_options, :enable_tunnel_lifecycle_control) SENSITIVE = [:pre_shared_key] include Aws::Structure end |
#phase_2_encryption_algorithms ⇒ Array<Types::Phase2EncryptionAlgorithmsListValue>
The permitted encryption algorithms for the VPN tunnel for phase 2 IKE negotiations.
84442 84443 84444 84445 84446 84447 84448 84449 84450 84451 84452 84453 84454 84455 84456 84457 84458 84459 84460 84461 84462 84463 84464 84465 84466 |
# File 'lib/aws-sdk-ec2/types.rb', line 84442 class TunnelOption < Struct.new( :outside_ip_address, :tunnel_inside_cidr, :tunnel_inside_ipv_6_cidr, :pre_shared_key, :phase_1_lifetime_seconds, :phase_2_lifetime_seconds, :rekey_margin_time_seconds, :rekey_fuzz_percentage, :replay_window_size, :dpd_timeout_seconds, :dpd_timeout_action, :phase_1_encryption_algorithms, :phase_2_encryption_algorithms, :phase_1_integrity_algorithms, :phase_2_integrity_algorithms, :phase_1_dh_group_numbers, :phase_2_dh_group_numbers, :ike_versions, :startup_action, :log_options, :enable_tunnel_lifecycle_control) SENSITIVE = [:pre_shared_key] include Aws::Structure end |
#phase_2_integrity_algorithms ⇒ Array<Types::Phase2IntegrityAlgorithmsListValue>
The permitted integrity algorithms for the VPN tunnel for phase 2 IKE negotiations.
84442 84443 84444 84445 84446 84447 84448 84449 84450 84451 84452 84453 84454 84455 84456 84457 84458 84459 84460 84461 84462 84463 84464 84465 84466 |
# File 'lib/aws-sdk-ec2/types.rb', line 84442 class TunnelOption < Struct.new( :outside_ip_address, :tunnel_inside_cidr, :tunnel_inside_ipv_6_cidr, :pre_shared_key, :phase_1_lifetime_seconds, :phase_2_lifetime_seconds, :rekey_margin_time_seconds, :rekey_fuzz_percentage, :replay_window_size, :dpd_timeout_seconds, :dpd_timeout_action, :phase_1_encryption_algorithms, :phase_2_encryption_algorithms, :phase_1_integrity_algorithms, :phase_2_integrity_algorithms, :phase_1_dh_group_numbers, :phase_2_dh_group_numbers, :ike_versions, :startup_action, :log_options, :enable_tunnel_lifecycle_control) SENSITIVE = [:pre_shared_key] include Aws::Structure end |
#phase_2_lifetime_seconds ⇒ Integer
The lifetime for phase 2 of the IKE negotiation, in seconds.
84442 84443 84444 84445 84446 84447 84448 84449 84450 84451 84452 84453 84454 84455 84456 84457 84458 84459 84460 84461 84462 84463 84464 84465 84466 |
# File 'lib/aws-sdk-ec2/types.rb', line 84442 class TunnelOption < Struct.new( :outside_ip_address, :tunnel_inside_cidr, :tunnel_inside_ipv_6_cidr, :pre_shared_key, :phase_1_lifetime_seconds, :phase_2_lifetime_seconds, :rekey_margin_time_seconds, :rekey_fuzz_percentage, :replay_window_size, :dpd_timeout_seconds, :dpd_timeout_action, :phase_1_encryption_algorithms, :phase_2_encryption_algorithms, :phase_1_integrity_algorithms, :phase_2_integrity_algorithms, :phase_1_dh_group_numbers, :phase_2_dh_group_numbers, :ike_versions, :startup_action, :log_options, :enable_tunnel_lifecycle_control) SENSITIVE = [:pre_shared_key] include Aws::Structure end |
#pre_shared_key ⇒ String
The pre-shared key (PSK) to establish initial authentication between the virtual private gateway and the customer gateway.
84442 84443 84444 84445 84446 84447 84448 84449 84450 84451 84452 84453 84454 84455 84456 84457 84458 84459 84460 84461 84462 84463 84464 84465 84466 |
# File 'lib/aws-sdk-ec2/types.rb', line 84442 class TunnelOption < Struct.new( :outside_ip_address, :tunnel_inside_cidr, :tunnel_inside_ipv_6_cidr, :pre_shared_key, :phase_1_lifetime_seconds, :phase_2_lifetime_seconds, :rekey_margin_time_seconds, :rekey_fuzz_percentage, :replay_window_size, :dpd_timeout_seconds, :dpd_timeout_action, :phase_1_encryption_algorithms, :phase_2_encryption_algorithms, :phase_1_integrity_algorithms, :phase_2_integrity_algorithms, :phase_1_dh_group_numbers, :phase_2_dh_group_numbers, :ike_versions, :startup_action, :log_options, :enable_tunnel_lifecycle_control) SENSITIVE = [:pre_shared_key] include Aws::Structure end |
#rekey_fuzz_percentage ⇒ Integer
The percentage of the rekey window determined by ‘RekeyMarginTimeSeconds` during which the rekey time is randomly selected.
84442 84443 84444 84445 84446 84447 84448 84449 84450 84451 84452 84453 84454 84455 84456 84457 84458 84459 84460 84461 84462 84463 84464 84465 84466 |
# File 'lib/aws-sdk-ec2/types.rb', line 84442 class TunnelOption < Struct.new( :outside_ip_address, :tunnel_inside_cidr, :tunnel_inside_ipv_6_cidr, :pre_shared_key, :phase_1_lifetime_seconds, :phase_2_lifetime_seconds, :rekey_margin_time_seconds, :rekey_fuzz_percentage, :replay_window_size, :dpd_timeout_seconds, :dpd_timeout_action, :phase_1_encryption_algorithms, :phase_2_encryption_algorithms, :phase_1_integrity_algorithms, :phase_2_integrity_algorithms, :phase_1_dh_group_numbers, :phase_2_dh_group_numbers, :ike_versions, :startup_action, :log_options, :enable_tunnel_lifecycle_control) SENSITIVE = [:pre_shared_key] include Aws::Structure end |
#rekey_margin_time_seconds ⇒ Integer
The margin time, in seconds, before the phase 2 lifetime expires, during which the Amazon Web Services side of the VPN connection performs an IKE rekey.
84442 84443 84444 84445 84446 84447 84448 84449 84450 84451 84452 84453 84454 84455 84456 84457 84458 84459 84460 84461 84462 84463 84464 84465 84466 |
# File 'lib/aws-sdk-ec2/types.rb', line 84442 class TunnelOption < Struct.new( :outside_ip_address, :tunnel_inside_cidr, :tunnel_inside_ipv_6_cidr, :pre_shared_key, :phase_1_lifetime_seconds, :phase_2_lifetime_seconds, :rekey_margin_time_seconds, :rekey_fuzz_percentage, :replay_window_size, :dpd_timeout_seconds, :dpd_timeout_action, :phase_1_encryption_algorithms, :phase_2_encryption_algorithms, :phase_1_integrity_algorithms, :phase_2_integrity_algorithms, :phase_1_dh_group_numbers, :phase_2_dh_group_numbers, :ike_versions, :startup_action, :log_options, :enable_tunnel_lifecycle_control) SENSITIVE = [:pre_shared_key] include Aws::Structure end |
#replay_window_size ⇒ Integer
The number of packets in an IKE replay window.
84442 84443 84444 84445 84446 84447 84448 84449 84450 84451 84452 84453 84454 84455 84456 84457 84458 84459 84460 84461 84462 84463 84464 84465 84466 |
# File 'lib/aws-sdk-ec2/types.rb', line 84442 class TunnelOption < Struct.new( :outside_ip_address, :tunnel_inside_cidr, :tunnel_inside_ipv_6_cidr, :pre_shared_key, :phase_1_lifetime_seconds, :phase_2_lifetime_seconds, :rekey_margin_time_seconds, :rekey_fuzz_percentage, :replay_window_size, :dpd_timeout_seconds, :dpd_timeout_action, :phase_1_encryption_algorithms, :phase_2_encryption_algorithms, :phase_1_integrity_algorithms, :phase_2_integrity_algorithms, :phase_1_dh_group_numbers, :phase_2_dh_group_numbers, :ike_versions, :startup_action, :log_options, :enable_tunnel_lifecycle_control) SENSITIVE = [:pre_shared_key] include Aws::Structure end |
#startup_action ⇒ String
The action to take when the establishing the VPN tunnels for a VPN connection.
84442 84443 84444 84445 84446 84447 84448 84449 84450 84451 84452 84453 84454 84455 84456 84457 84458 84459 84460 84461 84462 84463 84464 84465 84466 |
# File 'lib/aws-sdk-ec2/types.rb', line 84442 class TunnelOption < Struct.new( :outside_ip_address, :tunnel_inside_cidr, :tunnel_inside_ipv_6_cidr, :pre_shared_key, :phase_1_lifetime_seconds, :phase_2_lifetime_seconds, :rekey_margin_time_seconds, :rekey_fuzz_percentage, :replay_window_size, :dpd_timeout_seconds, :dpd_timeout_action, :phase_1_encryption_algorithms, :phase_2_encryption_algorithms, :phase_1_integrity_algorithms, :phase_2_integrity_algorithms, :phase_1_dh_group_numbers, :phase_2_dh_group_numbers, :ike_versions, :startup_action, :log_options, :enable_tunnel_lifecycle_control) SENSITIVE = [:pre_shared_key] include Aws::Structure end |
#tunnel_inside_cidr ⇒ String
The range of inside IPv4 addresses for the tunnel.
84442 84443 84444 84445 84446 84447 84448 84449 84450 84451 84452 84453 84454 84455 84456 84457 84458 84459 84460 84461 84462 84463 84464 84465 84466 |
# File 'lib/aws-sdk-ec2/types.rb', line 84442 class TunnelOption < Struct.new( :outside_ip_address, :tunnel_inside_cidr, :tunnel_inside_ipv_6_cidr, :pre_shared_key, :phase_1_lifetime_seconds, :phase_2_lifetime_seconds, :rekey_margin_time_seconds, :rekey_fuzz_percentage, :replay_window_size, :dpd_timeout_seconds, :dpd_timeout_action, :phase_1_encryption_algorithms, :phase_2_encryption_algorithms, :phase_1_integrity_algorithms, :phase_2_integrity_algorithms, :phase_1_dh_group_numbers, :phase_2_dh_group_numbers, :ike_versions, :startup_action, :log_options, :enable_tunnel_lifecycle_control) SENSITIVE = [:pre_shared_key] include Aws::Structure end |
#tunnel_inside_ipv_6_cidr ⇒ String
The range of inside IPv6 addresses for the tunnel.
84442 84443 84444 84445 84446 84447 84448 84449 84450 84451 84452 84453 84454 84455 84456 84457 84458 84459 84460 84461 84462 84463 84464 84465 84466 |
# File 'lib/aws-sdk-ec2/types.rb', line 84442 class TunnelOption < Struct.new( :outside_ip_address, :tunnel_inside_cidr, :tunnel_inside_ipv_6_cidr, :pre_shared_key, :phase_1_lifetime_seconds, :phase_2_lifetime_seconds, :rekey_margin_time_seconds, :rekey_fuzz_percentage, :replay_window_size, :dpd_timeout_seconds, :dpd_timeout_action, :phase_1_encryption_algorithms, :phase_2_encryption_algorithms, :phase_1_integrity_algorithms, :phase_2_integrity_algorithms, :phase_1_dh_group_numbers, :phase_2_dh_group_numbers, :ike_versions, :startup_action, :log_options, :enable_tunnel_lifecycle_control) SENSITIVE = [:pre_shared_key] include Aws::Structure end |