Class: Aws::EC2::Types::UnassignPrivateNatGatewayAddressRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::UnassignPrivateNatGatewayAddressRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#max_drain_duration_seconds ⇒ Integer
The maximum amount of time to wait (in seconds) before forcibly releasing the IP addresses if connections are still in progress.
-
#nat_gateway_id ⇒ String
The ID of the NAT gateway.
-
#private_ip_addresses ⇒ Array<String>
The private IPv4 addresses you want to unassign.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
83666 83667 83668 83669 83670 83671 83672 83673 |
# File 'lib/aws-sdk-ec2/types.rb', line 83666 class UnassignPrivateNatGatewayAddressRequest < Struct.new( :nat_gateway_id, :private_ip_addresses, :max_drain_duration_seconds, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_drain_duration_seconds ⇒ Integer
The maximum amount of time to wait (in seconds) before forcibly releasing the IP addresses if connections are still in progress. Default value is 350 seconds.
83666 83667 83668 83669 83670 83671 83672 83673 |
# File 'lib/aws-sdk-ec2/types.rb', line 83666 class UnassignPrivateNatGatewayAddressRequest < Struct.new( :nat_gateway_id, :private_ip_addresses, :max_drain_duration_seconds, :dry_run) SENSITIVE = [] include Aws::Structure end |
#nat_gateway_id ⇒ String
The ID of the NAT gateway.
83666 83667 83668 83669 83670 83671 83672 83673 |
# File 'lib/aws-sdk-ec2/types.rb', line 83666 class UnassignPrivateNatGatewayAddressRequest < Struct.new( :nat_gateway_id, :private_ip_addresses, :max_drain_duration_seconds, :dry_run) SENSITIVE = [] include Aws::Structure end |
#private_ip_addresses ⇒ Array<String>
The private IPv4 addresses you want to unassign.
83666 83667 83668 83669 83670 83671 83672 83673 |
# File 'lib/aws-sdk-ec2/types.rb', line 83666 class UnassignPrivateNatGatewayAddressRequest < Struct.new( :nat_gateway_id, :private_ip_addresses, :max_drain_duration_seconds, :dry_run) SENSITIVE = [] include Aws::Structure end |