Class: Aws::EC2::Types::UnassignPrivateNatGatewayAddressRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


81791
81792
81793
81794
81795
81796
81797
81798
# File 'lib/aws-sdk-ec2/types.rb', line 81791

class UnassignPrivateNatGatewayAddressRequest < Struct.new(
  :nat_gateway_id,
  :private_ip_addresses,
  :max_drain_duration_seconds,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_drain_duration_secondsInteger

The maximum amount of time to wait (in seconds) before forcibly releasing the IP addresses if connections are still in progress. Default value is 350 seconds.

Returns:

  • (Integer)


81791
81792
81793
81794
81795
81796
81797
81798
# File 'lib/aws-sdk-ec2/types.rb', line 81791

class UnassignPrivateNatGatewayAddressRequest < Struct.new(
  :nat_gateway_id,
  :private_ip_addresses,
  :max_drain_duration_seconds,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#nat_gateway_idString

The ID of the NAT gateway.

Returns:

  • (String)


81791
81792
81793
81794
81795
81796
81797
81798
# File 'lib/aws-sdk-ec2/types.rb', line 81791

class UnassignPrivateNatGatewayAddressRequest < Struct.new(
  :nat_gateway_id,
  :private_ip_addresses,
  :max_drain_duration_seconds,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#private_ip_addressesArray<String>

The private IPv4 addresses you want to unassign.

Returns:

  • (Array<String>)


81791
81792
81793
81794
81795
81796
81797
81798
# File 'lib/aws-sdk-ec2/types.rb', line 81791

class UnassignPrivateNatGatewayAddressRequest < Struct.new(
  :nat_gateway_id,
  :private_ip_addresses,
  :max_drain_duration_seconds,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end