Class: Aws::EC2::Types::UnlockSnapshotRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::UnlockSnapshotRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#snapshot_id ⇒ String
The ID of the snapshot to unlock.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
84602 84603 84604 84605 84606 84607 |
# File 'lib/aws-sdk-ec2/types.rb', line 84602 class UnlockSnapshotRequest < Struct.new( :snapshot_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#snapshot_id ⇒ String
The ID of the snapshot to unlock.
84602 84603 84604 84605 84606 84607 |
# File 'lib/aws-sdk-ec2/types.rb', line 84602 class UnlockSnapshotRequest < Struct.new( :snapshot_id, :dry_run) SENSITIVE = [] include Aws::Structure end |