Class: Aws::EC2::Types::UnlockSnapshotRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


84496
84497
84498
84499
84500
84501
# File 'lib/aws-sdk-ec2/types.rb', line 84496

class UnlockSnapshotRequest < Struct.new(
  :snapshot_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_idString

The ID of the snapshot to unlock.

Returns:

  • (String)


84496
84497
84498
84499
84500
84501
# File 'lib/aws-sdk-ec2/types.rb', line 84496

class UnlockSnapshotRequest < Struct.new(
  :snapshot_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end