Class: Aws::EC2::Types::UnmonitorInstancesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::UnmonitorInstancesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response.
-
#instance_ids ⇒ Array<String>
The IDs of the instances.
Instance Attribute Details
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the operation,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
85422 85423 85424 85425 85426 85427 |
# File 'lib/aws-sdk-ec2/types.rb', line 85422 class UnmonitorInstancesRequest < Struct.new( :instance_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#instance_ids ⇒ Array<String>
The IDs of the instances.
85422 85423 85424 85425 85426 85427 |
# File 'lib/aws-sdk-ec2/types.rb', line 85422 class UnmonitorInstancesRequest < Struct.new( :instance_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |