Class: Aws::EC2::Types::UnmonitorInstancesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the operation, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:

  • (Boolean)


83896
83897
83898
83899
83900
83901
# File 'lib/aws-sdk-ec2/types.rb', line 83896

class UnmonitorInstancesRequest < Struct.new(
  :instance_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idsArray<String>

The IDs of the instances.

Returns:

  • (Array<String>)


83896
83897
83898
83899
83900
83901
# File 'lib/aws-sdk-ec2/types.rb', line 83896

class UnmonitorInstancesRequest < Struct.new(
  :instance_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end