Class: Aws::EC2::Types::UnsuccessfulSuppressionResponseObject
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::UnsuccessfulSuppressionResponseObject
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes an unsuccessful application status check suppression.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The ID of the instance.
-
#reason ⇒ String
The reason the suppression failed.
-
#resume_at ⇒ Time
The date and time when health checks would have resumed.
-
#suppress_at ⇒ Time
The date and time when suppression was attempted.
Instance Attribute Details
#instance_id ⇒ String
The ID of the instance.
86992 86993 86994 86995 86996 86997 86998 86999 |
# File 'lib/aws-sdk-ec2/types.rb', line 86992 class UnsuccessfulSuppressionResponseObject < Struct.new( :instance_id, :suppress_at, :resume_at, :reason) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ String
The reason the suppression failed.
86992 86993 86994 86995 86996 86997 86998 86999 |
# File 'lib/aws-sdk-ec2/types.rb', line 86992 class UnsuccessfulSuppressionResponseObject < Struct.new( :instance_id, :suppress_at, :resume_at, :reason) SENSITIVE = [] include Aws::Structure end |
#resume_at ⇒ Time
The date and time when health checks would have resumed.
86992 86993 86994 86995 86996 86997 86998 86999 |
# File 'lib/aws-sdk-ec2/types.rb', line 86992 class UnsuccessfulSuppressionResponseObject < Struct.new( :instance_id, :suppress_at, :resume_at, :reason) SENSITIVE = [] include Aws::Structure end |
#suppress_at ⇒ Time
The date and time when suppression was attempted.
86992 86993 86994 86995 86996 86997 86998 86999 |
# File 'lib/aws-sdk-ec2/types.rb', line 86992 class UnsuccessfulSuppressionResponseObject < Struct.new( :instance_id, :suppress_at, :resume_at, :reason) SENSITIVE = [] include Aws::Structure end |