Class: Aws::EC2::Types::UpdateCapacityManagerOrganizationsAccessRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::UpdateCapacityManagerOrganizationsAccessRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#organizations_access ⇒ Boolean
Specifies whether to enable or disable cross-account access for Amazon Web Services Organizations.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
81862 81863 81864 81865 81866 81867 81868 |
# File 'lib/aws-sdk-ec2/types.rb', line 81862 class UpdateCapacityManagerOrganizationsAccessRequest < Struct.new( :organizations_access, :dry_run, :client_token) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
81862 81863 81864 81865 81866 81867 81868 |
# File 'lib/aws-sdk-ec2/types.rb', line 81862 class UpdateCapacityManagerOrganizationsAccessRequest < Struct.new( :organizations_access, :dry_run, :client_token) SENSITIVE = [] include Aws::Structure end |
#organizations_access ⇒ Boolean
Specifies whether to enable or disable cross-account access for Amazon Web Services Organizations. When enabled, Capacity Manager aggregates data from all accounts in your organization.
81862 81863 81864 81865 81866 81867 81868 |
# File 'lib/aws-sdk-ec2/types.rb', line 81862 class UpdateCapacityManagerOrganizationsAccessRequest < Struct.new( :organizations_access, :dry_run, :client_token) SENSITIVE = [] include Aws::Structure end |