Class: Aws::EC2::Types::UpdateSecurityGroupRuleDescriptionsEgressRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


85721
85722
85723
85724
85725
85726
85727
85728
85729
# File 'lib/aws-sdk-ec2/types.rb', line 85721

class UpdateSecurityGroupRuleDescriptionsEgressRequest < Struct.new(
  :dry_run,
  :group_id,
  :group_name,
  :ip_permissions,
  :security_group_rule_descriptions)
  SENSITIVE = []
  include Aws::Structure
end

#group_idString

The ID of the security group. You must specify either the security group ID or the security group name in the request. For security groups in a nondefault VPC, you must specify the security group ID.

Returns:

  • (String)


85721
85722
85723
85724
85725
85726
85727
85728
85729
# File 'lib/aws-sdk-ec2/types.rb', line 85721

class UpdateSecurityGroupRuleDescriptionsEgressRequest < Struct.new(
  :dry_run,
  :group_id,
  :group_name,
  :ip_permissions,
  :security_group_rule_descriptions)
  SENSITIVE = []
  include Aws::Structure
end

#group_nameString

[Default VPC] The name of the security group. You must specify either the security group ID or the security group name.

Returns:

  • (String)


85721
85722
85723
85724
85725
85726
85727
85728
85729
# File 'lib/aws-sdk-ec2/types.rb', line 85721

class UpdateSecurityGroupRuleDescriptionsEgressRequest < Struct.new(
  :dry_run,
  :group_id,
  :group_name,
  :ip_permissions,
  :security_group_rule_descriptions)
  SENSITIVE = []
  include Aws::Structure
end

#ip_permissionsArray<Types::IpPermission>

The IP permissions for the security group rule. You must specify either the IP permissions or the description.

Returns:



85721
85722
85723
85724
85725
85726
85727
85728
85729
# File 'lib/aws-sdk-ec2/types.rb', line 85721

class UpdateSecurityGroupRuleDescriptionsEgressRequest < Struct.new(
  :dry_run,
  :group_id,
  :group_name,
  :ip_permissions,
  :security_group_rule_descriptions)
  SENSITIVE = []
  include Aws::Structure
end

#security_group_rule_descriptionsArray<Types::SecurityGroupRuleDescription>

The description for the egress security group rules. You must specify either the description or the IP permissions.



85721
85722
85723
85724
85725
85726
85727
85728
85729
# File 'lib/aws-sdk-ec2/types.rb', line 85721

class UpdateSecurityGroupRuleDescriptionsEgressRequest < Struct.new(
  :dry_run,
  :group_id,
  :group_name,
  :ip_permissions,
  :security_group_rule_descriptions)
  SENSITIVE = []
  include Aws::Structure
end