Class: Aws::EC2::Types::UserIdGroupPair
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::UserIdGroupPair
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a security group and Amazon Web Services account ID pair.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description for the security group rule that references this user ID group pair.
-
#group_id ⇒ String
The ID of the security group.
-
#group_name ⇒ String
[Default VPC] The name of the security group.
-
#peering_status ⇒ String
The status of a VPC peering connection, if applicable.
-
#user_id ⇒ String
The ID of an Amazon Web Services account.
-
#vpc_id ⇒ String
The ID of the VPC for the referenced security group, if applicable.
-
#vpc_peering_connection_id ⇒ String
The ID of the VPC peering connection, if applicable.
Instance Attribute Details
#description ⇒ String
A description for the security group rule that references this user ID group pair.
Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@+=;{}!$*
84383 84384 84385 84386 84387 84388 84389 84390 84391 84392 84393 |
# File 'lib/aws-sdk-ec2/types.rb', line 84383 class UserIdGroupPair < Struct.new( :description, :user_id, :group_name, :group_id, :vpc_id, :vpc_peering_connection_id, :peering_status) SENSITIVE = [] include Aws::Structure end |
#group_id ⇒ String
The ID of the security group.
84383 84384 84385 84386 84387 84388 84389 84390 84391 84392 84393 |
# File 'lib/aws-sdk-ec2/types.rb', line 84383 class UserIdGroupPair < Struct.new( :description, :user_id, :group_name, :group_id, :vpc_id, :vpc_peering_connection_id, :peering_status) SENSITIVE = [] include Aws::Structure end |
#group_name ⇒ String
[Default VPC] The name of the security group. For a security group in a nondefault VPC, use the security group ID.
For a referenced security group in another VPC, this value is not returned if the referenced security group is deleted.
84383 84384 84385 84386 84387 84388 84389 84390 84391 84392 84393 |
# File 'lib/aws-sdk-ec2/types.rb', line 84383 class UserIdGroupPair < Struct.new( :description, :user_id, :group_name, :group_id, :vpc_id, :vpc_peering_connection_id, :peering_status) SENSITIVE = [] include Aws::Structure end |
#peering_status ⇒ String
The status of a VPC peering connection, if applicable.
84383 84384 84385 84386 84387 84388 84389 84390 84391 84392 84393 |
# File 'lib/aws-sdk-ec2/types.rb', line 84383 class UserIdGroupPair < Struct.new( :description, :user_id, :group_name, :group_id, :vpc_id, :vpc_peering_connection_id, :peering_status) SENSITIVE = [] include Aws::Structure end |
#user_id ⇒ String
The ID of an Amazon Web Services account.
For a referenced security group in another VPC, the account ID of the referenced security group is returned in the response. If the referenced security group is deleted, this value is not returned.
84383 84384 84385 84386 84387 84388 84389 84390 84391 84392 84393 |
# File 'lib/aws-sdk-ec2/types.rb', line 84383 class UserIdGroupPair < Struct.new( :description, :user_id, :group_name, :group_id, :vpc_id, :vpc_peering_connection_id, :peering_status) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC for the referenced security group, if applicable.
84383 84384 84385 84386 84387 84388 84389 84390 84391 84392 84393 |
# File 'lib/aws-sdk-ec2/types.rb', line 84383 class UserIdGroupPair < Struct.new( :description, :user_id, :group_name, :group_id, :vpc_id, :vpc_peering_connection_id, :peering_status) SENSITIVE = [] include Aws::Structure end |
#vpc_peering_connection_id ⇒ String
The ID of the VPC peering connection, if applicable.
84383 84384 84385 84386 84387 84388 84389 84390 84391 84392 84393 |
# File 'lib/aws-sdk-ec2/types.rb', line 84383 class UserIdGroupPair < Struct.new( :description, :user_id, :group_name, :group_id, :vpc_id, :vpc_peering_connection_id, :peering_status) SENSITIVE = [] include Aws::Structure end |