Class: Aws::EC2::Types::VerifiedAccessEndpoint

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

An Amazon Web Services Verified Access endpoint specifies the application that Amazon Web Services Verified Access provides access to. It must be attached to an Amazon Web Services Verified Access group. An Amazon Web Services Verified Access endpoint must also have an attached access policy before you attached it to a group.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_domainString

The DNS name for users to reach your application.

Returns:

  • (String)


87607
87608
87609
87610
87611
87612
87613
87614
87615
87616
87617
87618
87619
87620
87621
87622
87623
87624
87625
87626
87627
87628
87629
87630
87631
# File 'lib/aws-sdk-ec2/types.rb', line 87607

class VerifiedAccessEndpoint < Struct.new(
  :verified_access_instance_id,
  :verified_access_group_id,
  :verified_access_endpoint_id,
  :application_domain,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :endpoint_domain,
  :device_validation_domain,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :status,
  :description,
  :creation_time,
  :last_updated_time,
  :deletion_time,
  :tags,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#attachment_typeString

The type of attachment used to provide connectivity between the Amazon Web Services Verified Access endpoint and the application.

Returns:

  • (String)


87607
87608
87609
87610
87611
87612
87613
87614
87615
87616
87617
87618
87619
87620
87621
87622
87623
87624
87625
87626
87627
87628
87629
87630
87631
# File 'lib/aws-sdk-ec2/types.rb', line 87607

class VerifiedAccessEndpoint < Struct.new(
  :verified_access_instance_id,
  :verified_access_group_id,
  :verified_access_endpoint_id,
  :application_domain,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :endpoint_domain,
  :device_validation_domain,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :status,
  :description,
  :creation_time,
  :last_updated_time,
  :deletion_time,
  :tags,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#cidr_optionsTypes::VerifiedAccessEndpointCidrOptions

The options for a CIDR endpoint.



87607
87608
87609
87610
87611
87612
87613
87614
87615
87616
87617
87618
87619
87620
87621
87622
87623
87624
87625
87626
87627
87628
87629
87630
87631
# File 'lib/aws-sdk-ec2/types.rb', line 87607

class VerifiedAccessEndpoint < Struct.new(
  :verified_access_instance_id,
  :verified_access_group_id,
  :verified_access_endpoint_id,
  :application_domain,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :endpoint_domain,
  :device_validation_domain,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :status,
  :description,
  :creation_time,
  :last_updated_time,
  :deletion_time,
  :tags,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeString

The creation time.

Returns:

  • (String)


87607
87608
87609
87610
87611
87612
87613
87614
87615
87616
87617
87618
87619
87620
87621
87622
87623
87624
87625
87626
87627
87628
87629
87630
87631
# File 'lib/aws-sdk-ec2/types.rb', line 87607

class VerifiedAccessEndpoint < Struct.new(
  :verified_access_instance_id,
  :verified_access_group_id,
  :verified_access_endpoint_id,
  :application_domain,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :endpoint_domain,
  :device_validation_domain,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :status,
  :description,
  :creation_time,
  :last_updated_time,
  :deletion_time,
  :tags,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#deletion_timeString

The deletion time.

Returns:

  • (String)


87607
87608
87609
87610
87611
87612
87613
87614
87615
87616
87617
87618
87619
87620
87621
87622
87623
87624
87625
87626
87627
87628
87629
87630
87631
# File 'lib/aws-sdk-ec2/types.rb', line 87607

class VerifiedAccessEndpoint < Struct.new(
  :verified_access_instance_id,
  :verified_access_group_id,
  :verified_access_endpoint_id,
  :application_domain,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :endpoint_domain,
  :device_validation_domain,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :status,
  :description,
  :creation_time,
  :last_updated_time,
  :deletion_time,
  :tags,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description for the Amazon Web Services Verified Access endpoint.

Returns:

  • (String)


87607
87608
87609
87610
87611
87612
87613
87614
87615
87616
87617
87618
87619
87620
87621
87622
87623
87624
87625
87626
87627
87628
87629
87630
87631
# File 'lib/aws-sdk-ec2/types.rb', line 87607

class VerifiedAccessEndpoint < Struct.new(
  :verified_access_instance_id,
  :verified_access_group_id,
  :verified_access_endpoint_id,
  :application_domain,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :endpoint_domain,
  :device_validation_domain,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :status,
  :description,
  :creation_time,
  :last_updated_time,
  :deletion_time,
  :tags,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#device_validation_domainString

Returned if endpoint has a device trust provider attached.

Returns:

  • (String)


87607
87608
87609
87610
87611
87612
87613
87614
87615
87616
87617
87618
87619
87620
87621
87622
87623
87624
87625
87626
87627
87628
87629
87630
87631
# File 'lib/aws-sdk-ec2/types.rb', line 87607

class VerifiedAccessEndpoint < Struct.new(
  :verified_access_instance_id,
  :verified_access_group_id,
  :verified_access_endpoint_id,
  :application_domain,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :endpoint_domain,
  :device_validation_domain,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :status,
  :description,
  :creation_time,
  :last_updated_time,
  :deletion_time,
  :tags,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#domain_certificate_arnString

The ARN of a public TLS/SSL certificate imported into or created with ACM.

Returns:

  • (String)


87607
87608
87609
87610
87611
87612
87613
87614
87615
87616
87617
87618
87619
87620
87621
87622
87623
87624
87625
87626
87627
87628
87629
87630
87631
# File 'lib/aws-sdk-ec2/types.rb', line 87607

class VerifiedAccessEndpoint < Struct.new(
  :verified_access_instance_id,
  :verified_access_group_id,
  :verified_access_endpoint_id,
  :application_domain,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :endpoint_domain,
  :device_validation_domain,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :status,
  :description,
  :creation_time,
  :last_updated_time,
  :deletion_time,
  :tags,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_domainString

A DNS name that is generated for the endpoint.

Returns:

  • (String)


87607
87608
87609
87610
87611
87612
87613
87614
87615
87616
87617
87618
87619
87620
87621
87622
87623
87624
87625
87626
87627
87628
87629
87630
87631
# File 'lib/aws-sdk-ec2/types.rb', line 87607

class VerifiedAccessEndpoint < Struct.new(
  :verified_access_instance_id,
  :verified_access_group_id,
  :verified_access_endpoint_id,
  :application_domain,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :endpoint_domain,
  :device_validation_domain,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :status,
  :description,
  :creation_time,
  :last_updated_time,
  :deletion_time,
  :tags,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_typeString

The type of Amazon Web Services Verified Access endpoint. Incoming application requests will be sent to an IP address, load balancer or a network interface depending on the endpoint type specified.

Returns:

  • (String)


87607
87608
87609
87610
87611
87612
87613
87614
87615
87616
87617
87618
87619
87620
87621
87622
87623
87624
87625
87626
87627
87628
87629
87630
87631
# File 'lib/aws-sdk-ec2/types.rb', line 87607

class VerifiedAccessEndpoint < Struct.new(
  :verified_access_instance_id,
  :verified_access_group_id,
  :verified_access_endpoint_id,
  :application_domain,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :endpoint_domain,
  :device_validation_domain,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :status,
  :description,
  :creation_time,
  :last_updated_time,
  :deletion_time,
  :tags,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_timeString

The last updated time.

Returns:

  • (String)


87607
87608
87609
87610
87611
87612
87613
87614
87615
87616
87617
87618
87619
87620
87621
87622
87623
87624
87625
87626
87627
87628
87629
87630
87631
# File 'lib/aws-sdk-ec2/types.rb', line 87607

class VerifiedAccessEndpoint < Struct.new(
  :verified_access_instance_id,
  :verified_access_group_id,
  :verified_access_endpoint_id,
  :application_domain,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :endpoint_domain,
  :device_validation_domain,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :status,
  :description,
  :creation_time,
  :last_updated_time,
  :deletion_time,
  :tags,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#load_balancer_optionsTypes::VerifiedAccessEndpointLoadBalancerOptions

The load balancer details if creating the Amazon Web Services Verified Access endpoint as load-balancertype.



87607
87608
87609
87610
87611
87612
87613
87614
87615
87616
87617
87618
87619
87620
87621
87622
87623
87624
87625
87626
87627
87628
87629
87630
87631
# File 'lib/aws-sdk-ec2/types.rb', line 87607

class VerifiedAccessEndpoint < Struct.new(
  :verified_access_instance_id,
  :verified_access_group_id,
  :verified_access_endpoint_id,
  :application_domain,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :endpoint_domain,
  :device_validation_domain,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :status,
  :description,
  :creation_time,
  :last_updated_time,
  :deletion_time,
  :tags,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#network_interface_optionsTypes::VerifiedAccessEndpointEniOptions

The options for network-interface type endpoint.



87607
87608
87609
87610
87611
87612
87613
87614
87615
87616
87617
87618
87619
87620
87621
87622
87623
87624
87625
87626
87627
87628
87629
87630
87631
# File 'lib/aws-sdk-ec2/types.rb', line 87607

class VerifiedAccessEndpoint < Struct.new(
  :verified_access_instance_id,
  :verified_access_group_id,
  :verified_access_endpoint_id,
  :application_domain,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :endpoint_domain,
  :device_validation_domain,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :status,
  :description,
  :creation_time,
  :last_updated_time,
  :deletion_time,
  :tags,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#rds_optionsTypes::VerifiedAccessEndpointRdsOptions

The options for an RDS endpoint.



87607
87608
87609
87610
87611
87612
87613
87614
87615
87616
87617
87618
87619
87620
87621
87622
87623
87624
87625
87626
87627
87628
87629
87630
87631
# File 'lib/aws-sdk-ec2/types.rb', line 87607

class VerifiedAccessEndpoint < Struct.new(
  :verified_access_instance_id,
  :verified_access_group_id,
  :verified_access_endpoint_id,
  :application_domain,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :endpoint_domain,
  :device_validation_domain,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :status,
  :description,
  :creation_time,
  :last_updated_time,
  :deletion_time,
  :tags,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#security_group_idsArray<String>

The IDs of the security groups for the endpoint.

Returns:

  • (Array<String>)


87607
87608
87609
87610
87611
87612
87613
87614
87615
87616
87617
87618
87619
87620
87621
87622
87623
87624
87625
87626
87627
87628
87629
87630
87631
# File 'lib/aws-sdk-ec2/types.rb', line 87607

class VerifiedAccessEndpoint < Struct.new(
  :verified_access_instance_id,
  :verified_access_group_id,
  :verified_access_endpoint_id,
  :application_domain,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :endpoint_domain,
  :device_validation_domain,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :status,
  :description,
  :creation_time,
  :last_updated_time,
  :deletion_time,
  :tags,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#sse_specificationTypes::VerifiedAccessSseSpecificationResponse

The options in use for server side encryption.



87607
87608
87609
87610
87611
87612
87613
87614
87615
87616
87617
87618
87619
87620
87621
87622
87623
87624
87625
87626
87627
87628
87629
87630
87631
# File 'lib/aws-sdk-ec2/types.rb', line 87607

class VerifiedAccessEndpoint < Struct.new(
  :verified_access_instance_id,
  :verified_access_group_id,
  :verified_access_endpoint_id,
  :application_domain,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :endpoint_domain,
  :device_validation_domain,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :status,
  :description,
  :creation_time,
  :last_updated_time,
  :deletion_time,
  :tags,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#statusTypes::VerifiedAccessEndpointStatus

The endpoint status.



87607
87608
87609
87610
87611
87612
87613
87614
87615
87616
87617
87618
87619
87620
87621
87622
87623
87624
87625
87626
87627
87628
87629
87630
87631
# File 'lib/aws-sdk-ec2/types.rb', line 87607

class VerifiedAccessEndpoint < Struct.new(
  :verified_access_instance_id,
  :verified_access_group_id,
  :verified_access_endpoint_id,
  :application_domain,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :endpoint_domain,
  :device_validation_domain,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :status,
  :description,
  :creation_time,
  :last_updated_time,
  :deletion_time,
  :tags,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The tags.

Returns:



87607
87608
87609
87610
87611
87612
87613
87614
87615
87616
87617
87618
87619
87620
87621
87622
87623
87624
87625
87626
87627
87628
87629
87630
87631
# File 'lib/aws-sdk-ec2/types.rb', line 87607

class VerifiedAccessEndpoint < Struct.new(
  :verified_access_instance_id,
  :verified_access_group_id,
  :verified_access_endpoint_id,
  :application_domain,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :endpoint_domain,
  :device_validation_domain,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :status,
  :description,
  :creation_time,
  :last_updated_time,
  :deletion_time,
  :tags,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#verified_access_endpoint_idString

The ID of the Amazon Web Services Verified Access endpoint.

Returns:

  • (String)


87607
87608
87609
87610
87611
87612
87613
87614
87615
87616
87617
87618
87619
87620
87621
87622
87623
87624
87625
87626
87627
87628
87629
87630
87631
# File 'lib/aws-sdk-ec2/types.rb', line 87607

class VerifiedAccessEndpoint < Struct.new(
  :verified_access_instance_id,
  :verified_access_group_id,
  :verified_access_endpoint_id,
  :application_domain,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :endpoint_domain,
  :device_validation_domain,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :status,
  :description,
  :creation_time,
  :last_updated_time,
  :deletion_time,
  :tags,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#verified_access_group_idString

The ID of the Amazon Web Services Verified Access group.

Returns:

  • (String)


87607
87608
87609
87610
87611
87612
87613
87614
87615
87616
87617
87618
87619
87620
87621
87622
87623
87624
87625
87626
87627
87628
87629
87630
87631
# File 'lib/aws-sdk-ec2/types.rb', line 87607

class VerifiedAccessEndpoint < Struct.new(
  :verified_access_instance_id,
  :verified_access_group_id,
  :verified_access_endpoint_id,
  :application_domain,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :endpoint_domain,
  :device_validation_domain,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :status,
  :description,
  :creation_time,
  :last_updated_time,
  :deletion_time,
  :tags,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end

#verified_access_instance_idString

The ID of the Amazon Web Services Verified Access instance.

Returns:

  • (String)


87607
87608
87609
87610
87611
87612
87613
87614
87615
87616
87617
87618
87619
87620
87621
87622
87623
87624
87625
87626
87627
87628
87629
87630
87631
# File 'lib/aws-sdk-ec2/types.rb', line 87607

class VerifiedAccessEndpoint < Struct.new(
  :verified_access_instance_id,
  :verified_access_group_id,
  :verified_access_endpoint_id,
  :application_domain,
  :endpoint_type,
  :attachment_type,
  :domain_certificate_arn,
  :endpoint_domain,
  :device_validation_domain,
  :security_group_ids,
  :load_balancer_options,
  :network_interface_options,
  :status,
  :description,
  :creation_time,
  :last_updated_time,
  :deletion_time,
  :tags,
  :sse_specification,
  :rds_options,
  :cidr_options)
  SENSITIVE = []
  include Aws::Structure
end