Class: Aws::EC2::Types::VerifiedAccessEndpoint
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::VerifiedAccessEndpoint
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
An Amazon Web Services Verified Access endpoint specifies the application that Amazon Web Services Verified Access provides access to. It must be attached to an Amazon Web Services Verified Access group. An Amazon Web Services Verified Access endpoint must also have an attached access policy before you attached it to a group.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_domain ⇒ String
The DNS name for users to reach your application.
-
#attachment_type ⇒ String
The type of attachment used to provide connectivity between the Amazon Web Services Verified Access endpoint and the application.
-
#cidr_options ⇒ Types::VerifiedAccessEndpointCidrOptions
The options for a CIDR endpoint.
-
#creation_time ⇒ String
The creation time.
-
#deletion_time ⇒ String
The deletion time.
-
#description ⇒ String
A description for the Amazon Web Services Verified Access endpoint.
-
#device_validation_domain ⇒ String
Returned if endpoint has a device trust provider attached.
-
#domain_certificate_arn ⇒ String
The ARN of a public TLS/SSL certificate imported into or created with ACM.
-
#endpoint_domain ⇒ String
A DNS name that is generated for the endpoint.
-
#endpoint_type ⇒ String
The type of Amazon Web Services Verified Access endpoint.
-
#last_updated_time ⇒ String
The last updated time.
-
#load_balancer_options ⇒ Types::VerifiedAccessEndpointLoadBalancerOptions
The load balancer details if creating the Amazon Web Services Verified Access endpoint as
load-balancertype. -
#network_interface_options ⇒ Types::VerifiedAccessEndpointEniOptions
The options for network-interface type endpoint.
-
#rds_options ⇒ Types::VerifiedAccessEndpointRdsOptions
The options for an RDS endpoint.
-
#security_group_ids ⇒ Array<String>
The IDs of the security groups for the endpoint.
-
#sse_specification ⇒ Types::VerifiedAccessSseSpecificationResponse
The options in use for server side encryption.
-
#status ⇒ Types::VerifiedAccessEndpointStatus
The endpoint status.
-
#tags ⇒ Array<Types::Tag>
The tags.
-
#verified_access_endpoint_id ⇒ String
The ID of the Amazon Web Services Verified Access endpoint.
-
#verified_access_group_id ⇒ String
The ID of the Amazon Web Services Verified Access group.
-
#verified_access_instance_id ⇒ String
The ID of the Amazon Web Services Verified Access instance.
Instance Attribute Details
#application_domain ⇒ String
The DNS name for users to reach your application.
85698 85699 85700 85701 85702 85703 85704 85705 85706 85707 85708 85709 85710 85711 85712 85713 85714 85715 85716 85717 85718 85719 85720 85721 85722 |
# File 'lib/aws-sdk-ec2/types.rb', line 85698 class VerifiedAccessEndpoint < Struct.new( :verified_access_instance_id, :verified_access_group_id, :verified_access_endpoint_id, :application_domain, :endpoint_type, :attachment_type, :domain_certificate_arn, :endpoint_domain, :device_validation_domain, :security_group_ids, :load_balancer_options, :network_interface_options, :status, :description, :creation_time, :last_updated_time, :deletion_time, :tags, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#attachment_type ⇒ String
The type of attachment used to provide connectivity between the Amazon Web Services Verified Access endpoint and the application.
85698 85699 85700 85701 85702 85703 85704 85705 85706 85707 85708 85709 85710 85711 85712 85713 85714 85715 85716 85717 85718 85719 85720 85721 85722 |
# File 'lib/aws-sdk-ec2/types.rb', line 85698 class VerifiedAccessEndpoint < Struct.new( :verified_access_instance_id, :verified_access_group_id, :verified_access_endpoint_id, :application_domain, :endpoint_type, :attachment_type, :domain_certificate_arn, :endpoint_domain, :device_validation_domain, :security_group_ids, :load_balancer_options, :network_interface_options, :status, :description, :creation_time, :last_updated_time, :deletion_time, :tags, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#cidr_options ⇒ Types::VerifiedAccessEndpointCidrOptions
The options for a CIDR endpoint.
85698 85699 85700 85701 85702 85703 85704 85705 85706 85707 85708 85709 85710 85711 85712 85713 85714 85715 85716 85717 85718 85719 85720 85721 85722 |
# File 'lib/aws-sdk-ec2/types.rb', line 85698 class VerifiedAccessEndpoint < Struct.new( :verified_access_instance_id, :verified_access_group_id, :verified_access_endpoint_id, :application_domain, :endpoint_type, :attachment_type, :domain_certificate_arn, :endpoint_domain, :device_validation_domain, :security_group_ids, :load_balancer_options, :network_interface_options, :status, :description, :creation_time, :last_updated_time, :deletion_time, :tags, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ String
The creation time.
85698 85699 85700 85701 85702 85703 85704 85705 85706 85707 85708 85709 85710 85711 85712 85713 85714 85715 85716 85717 85718 85719 85720 85721 85722 |
# File 'lib/aws-sdk-ec2/types.rb', line 85698 class VerifiedAccessEndpoint < Struct.new( :verified_access_instance_id, :verified_access_group_id, :verified_access_endpoint_id, :application_domain, :endpoint_type, :attachment_type, :domain_certificate_arn, :endpoint_domain, :device_validation_domain, :security_group_ids, :load_balancer_options, :network_interface_options, :status, :description, :creation_time, :last_updated_time, :deletion_time, :tags, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#deletion_time ⇒ String
The deletion time.
85698 85699 85700 85701 85702 85703 85704 85705 85706 85707 85708 85709 85710 85711 85712 85713 85714 85715 85716 85717 85718 85719 85720 85721 85722 |
# File 'lib/aws-sdk-ec2/types.rb', line 85698 class VerifiedAccessEndpoint < Struct.new( :verified_access_instance_id, :verified_access_group_id, :verified_access_endpoint_id, :application_domain, :endpoint_type, :attachment_type, :domain_certificate_arn, :endpoint_domain, :device_validation_domain, :security_group_ids, :load_balancer_options, :network_interface_options, :status, :description, :creation_time, :last_updated_time, :deletion_time, :tags, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description for the Amazon Web Services Verified Access endpoint.
85698 85699 85700 85701 85702 85703 85704 85705 85706 85707 85708 85709 85710 85711 85712 85713 85714 85715 85716 85717 85718 85719 85720 85721 85722 |
# File 'lib/aws-sdk-ec2/types.rb', line 85698 class VerifiedAccessEndpoint < Struct.new( :verified_access_instance_id, :verified_access_group_id, :verified_access_endpoint_id, :application_domain, :endpoint_type, :attachment_type, :domain_certificate_arn, :endpoint_domain, :device_validation_domain, :security_group_ids, :load_balancer_options, :network_interface_options, :status, :description, :creation_time, :last_updated_time, :deletion_time, :tags, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#device_validation_domain ⇒ String
Returned if endpoint has a device trust provider attached.
85698 85699 85700 85701 85702 85703 85704 85705 85706 85707 85708 85709 85710 85711 85712 85713 85714 85715 85716 85717 85718 85719 85720 85721 85722 |
# File 'lib/aws-sdk-ec2/types.rb', line 85698 class VerifiedAccessEndpoint < Struct.new( :verified_access_instance_id, :verified_access_group_id, :verified_access_endpoint_id, :application_domain, :endpoint_type, :attachment_type, :domain_certificate_arn, :endpoint_domain, :device_validation_domain, :security_group_ids, :load_balancer_options, :network_interface_options, :status, :description, :creation_time, :last_updated_time, :deletion_time, :tags, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#domain_certificate_arn ⇒ String
The ARN of a public TLS/SSL certificate imported into or created with ACM.
85698 85699 85700 85701 85702 85703 85704 85705 85706 85707 85708 85709 85710 85711 85712 85713 85714 85715 85716 85717 85718 85719 85720 85721 85722 |
# File 'lib/aws-sdk-ec2/types.rb', line 85698 class VerifiedAccessEndpoint < Struct.new( :verified_access_instance_id, :verified_access_group_id, :verified_access_endpoint_id, :application_domain, :endpoint_type, :attachment_type, :domain_certificate_arn, :endpoint_domain, :device_validation_domain, :security_group_ids, :load_balancer_options, :network_interface_options, :status, :description, :creation_time, :last_updated_time, :deletion_time, :tags, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#endpoint_domain ⇒ String
A DNS name that is generated for the endpoint.
85698 85699 85700 85701 85702 85703 85704 85705 85706 85707 85708 85709 85710 85711 85712 85713 85714 85715 85716 85717 85718 85719 85720 85721 85722 |
# File 'lib/aws-sdk-ec2/types.rb', line 85698 class VerifiedAccessEndpoint < Struct.new( :verified_access_instance_id, :verified_access_group_id, :verified_access_endpoint_id, :application_domain, :endpoint_type, :attachment_type, :domain_certificate_arn, :endpoint_domain, :device_validation_domain, :security_group_ids, :load_balancer_options, :network_interface_options, :status, :description, :creation_time, :last_updated_time, :deletion_time, :tags, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#endpoint_type ⇒ String
The type of Amazon Web Services Verified Access endpoint. Incoming application requests will be sent to an IP address, load balancer or a network interface depending on the endpoint type specified.
85698 85699 85700 85701 85702 85703 85704 85705 85706 85707 85708 85709 85710 85711 85712 85713 85714 85715 85716 85717 85718 85719 85720 85721 85722 |
# File 'lib/aws-sdk-ec2/types.rb', line 85698 class VerifiedAccessEndpoint < Struct.new( :verified_access_instance_id, :verified_access_group_id, :verified_access_endpoint_id, :application_domain, :endpoint_type, :attachment_type, :domain_certificate_arn, :endpoint_domain, :device_validation_domain, :security_group_ids, :load_balancer_options, :network_interface_options, :status, :description, :creation_time, :last_updated_time, :deletion_time, :tags, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#last_updated_time ⇒ String
The last updated time.
85698 85699 85700 85701 85702 85703 85704 85705 85706 85707 85708 85709 85710 85711 85712 85713 85714 85715 85716 85717 85718 85719 85720 85721 85722 |
# File 'lib/aws-sdk-ec2/types.rb', line 85698 class VerifiedAccessEndpoint < Struct.new( :verified_access_instance_id, :verified_access_group_id, :verified_access_endpoint_id, :application_domain, :endpoint_type, :attachment_type, :domain_certificate_arn, :endpoint_domain, :device_validation_domain, :security_group_ids, :load_balancer_options, :network_interface_options, :status, :description, :creation_time, :last_updated_time, :deletion_time, :tags, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#load_balancer_options ⇒ Types::VerifiedAccessEndpointLoadBalancerOptions
The load balancer details if creating the Amazon Web Services
Verified Access endpoint as load-balancertype.
85698 85699 85700 85701 85702 85703 85704 85705 85706 85707 85708 85709 85710 85711 85712 85713 85714 85715 85716 85717 85718 85719 85720 85721 85722 |
# File 'lib/aws-sdk-ec2/types.rb', line 85698 class VerifiedAccessEndpoint < Struct.new( :verified_access_instance_id, :verified_access_group_id, :verified_access_endpoint_id, :application_domain, :endpoint_type, :attachment_type, :domain_certificate_arn, :endpoint_domain, :device_validation_domain, :security_group_ids, :load_balancer_options, :network_interface_options, :status, :description, :creation_time, :last_updated_time, :deletion_time, :tags, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#network_interface_options ⇒ Types::VerifiedAccessEndpointEniOptions
The options for network-interface type endpoint.
85698 85699 85700 85701 85702 85703 85704 85705 85706 85707 85708 85709 85710 85711 85712 85713 85714 85715 85716 85717 85718 85719 85720 85721 85722 |
# File 'lib/aws-sdk-ec2/types.rb', line 85698 class VerifiedAccessEndpoint < Struct.new( :verified_access_instance_id, :verified_access_group_id, :verified_access_endpoint_id, :application_domain, :endpoint_type, :attachment_type, :domain_certificate_arn, :endpoint_domain, :device_validation_domain, :security_group_ids, :load_balancer_options, :network_interface_options, :status, :description, :creation_time, :last_updated_time, :deletion_time, :tags, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#rds_options ⇒ Types::VerifiedAccessEndpointRdsOptions
The options for an RDS endpoint.
85698 85699 85700 85701 85702 85703 85704 85705 85706 85707 85708 85709 85710 85711 85712 85713 85714 85715 85716 85717 85718 85719 85720 85721 85722 |
# File 'lib/aws-sdk-ec2/types.rb', line 85698 class VerifiedAccessEndpoint < Struct.new( :verified_access_instance_id, :verified_access_group_id, :verified_access_endpoint_id, :application_domain, :endpoint_type, :attachment_type, :domain_certificate_arn, :endpoint_domain, :device_validation_domain, :security_group_ids, :load_balancer_options, :network_interface_options, :status, :description, :creation_time, :last_updated_time, :deletion_time, :tags, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
The IDs of the security groups for the endpoint.
85698 85699 85700 85701 85702 85703 85704 85705 85706 85707 85708 85709 85710 85711 85712 85713 85714 85715 85716 85717 85718 85719 85720 85721 85722 |
# File 'lib/aws-sdk-ec2/types.rb', line 85698 class VerifiedAccessEndpoint < Struct.new( :verified_access_instance_id, :verified_access_group_id, :verified_access_endpoint_id, :application_domain, :endpoint_type, :attachment_type, :domain_certificate_arn, :endpoint_domain, :device_validation_domain, :security_group_ids, :load_balancer_options, :network_interface_options, :status, :description, :creation_time, :last_updated_time, :deletion_time, :tags, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#sse_specification ⇒ Types::VerifiedAccessSseSpecificationResponse
The options in use for server side encryption.
85698 85699 85700 85701 85702 85703 85704 85705 85706 85707 85708 85709 85710 85711 85712 85713 85714 85715 85716 85717 85718 85719 85720 85721 85722 |
# File 'lib/aws-sdk-ec2/types.rb', line 85698 class VerifiedAccessEndpoint < Struct.new( :verified_access_instance_id, :verified_access_group_id, :verified_access_endpoint_id, :application_domain, :endpoint_type, :attachment_type, :domain_certificate_arn, :endpoint_domain, :device_validation_domain, :security_group_ids, :load_balancer_options, :network_interface_options, :status, :description, :creation_time, :last_updated_time, :deletion_time, :tags, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::VerifiedAccessEndpointStatus
The endpoint status.
85698 85699 85700 85701 85702 85703 85704 85705 85706 85707 85708 85709 85710 85711 85712 85713 85714 85715 85716 85717 85718 85719 85720 85721 85722 |
# File 'lib/aws-sdk-ec2/types.rb', line 85698 class VerifiedAccessEndpoint < Struct.new( :verified_access_instance_id, :verified_access_group_id, :verified_access_endpoint_id, :application_domain, :endpoint_type, :attachment_type, :domain_certificate_arn, :endpoint_domain, :device_validation_domain, :security_group_ids, :load_balancer_options, :network_interface_options, :status, :description, :creation_time, :last_updated_time, :deletion_time, :tags, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags.
85698 85699 85700 85701 85702 85703 85704 85705 85706 85707 85708 85709 85710 85711 85712 85713 85714 85715 85716 85717 85718 85719 85720 85721 85722 |
# File 'lib/aws-sdk-ec2/types.rb', line 85698 class VerifiedAccessEndpoint < Struct.new( :verified_access_instance_id, :verified_access_group_id, :verified_access_endpoint_id, :application_domain, :endpoint_type, :attachment_type, :domain_certificate_arn, :endpoint_domain, :device_validation_domain, :security_group_ids, :load_balancer_options, :network_interface_options, :status, :description, :creation_time, :last_updated_time, :deletion_time, :tags, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#verified_access_endpoint_id ⇒ String
The ID of the Amazon Web Services Verified Access endpoint.
85698 85699 85700 85701 85702 85703 85704 85705 85706 85707 85708 85709 85710 85711 85712 85713 85714 85715 85716 85717 85718 85719 85720 85721 85722 |
# File 'lib/aws-sdk-ec2/types.rb', line 85698 class VerifiedAccessEndpoint < Struct.new( :verified_access_instance_id, :verified_access_group_id, :verified_access_endpoint_id, :application_domain, :endpoint_type, :attachment_type, :domain_certificate_arn, :endpoint_domain, :device_validation_domain, :security_group_ids, :load_balancer_options, :network_interface_options, :status, :description, :creation_time, :last_updated_time, :deletion_time, :tags, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#verified_access_group_id ⇒ String
The ID of the Amazon Web Services Verified Access group.
85698 85699 85700 85701 85702 85703 85704 85705 85706 85707 85708 85709 85710 85711 85712 85713 85714 85715 85716 85717 85718 85719 85720 85721 85722 |
# File 'lib/aws-sdk-ec2/types.rb', line 85698 class VerifiedAccessEndpoint < Struct.new( :verified_access_instance_id, :verified_access_group_id, :verified_access_endpoint_id, :application_domain, :endpoint_type, :attachment_type, :domain_certificate_arn, :endpoint_domain, :device_validation_domain, :security_group_ids, :load_balancer_options, :network_interface_options, :status, :description, :creation_time, :last_updated_time, :deletion_time, :tags, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |
#verified_access_instance_id ⇒ String
The ID of the Amazon Web Services Verified Access instance.
85698 85699 85700 85701 85702 85703 85704 85705 85706 85707 85708 85709 85710 85711 85712 85713 85714 85715 85716 85717 85718 85719 85720 85721 85722 |
# File 'lib/aws-sdk-ec2/types.rb', line 85698 class VerifiedAccessEndpoint < Struct.new( :verified_access_instance_id, :verified_access_group_id, :verified_access_endpoint_id, :application_domain, :endpoint_type, :attachment_type, :domain_certificate_arn, :endpoint_domain, :device_validation_domain, :security_group_ids, :load_balancer_options, :network_interface_options, :status, :description, :creation_time, :last_updated_time, :deletion_time, :tags, :sse_specification, :rds_options, :cidr_options) SENSITIVE = [] include Aws::Structure end |