Class: Aws::EC2::Types::VgwTelemetry
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::VgwTelemetry
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes telemetry for a VPN tunnel.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#accepted_route_count ⇒ Integer
The number of accepted routes.
-
#certificate_arn ⇒ String
The Amazon Resource Name (ARN) of the VPN tunnel endpoint certificate.
-
#last_status_change ⇒ Time
The date and time of the last change in status.
-
#outside_ip_address ⇒ String
The Internet-routable IP address of the virtual private gateway's outside interface.
-
#status ⇒ String
The status of the VPN tunnel.
-
#status_message ⇒ String
If an error occurs, a description of the error.
Instance Attribute Details
#accepted_route_count ⇒ Integer
The number of accepted routes.
89937 89938 89939 89940 89941 89942 89943 89944 89945 89946 |
# File 'lib/aws-sdk-ec2/types.rb', line 89937 class VgwTelemetry < Struct.new( :accepted_route_count, :last_status_change, :outside_ip_address, :status, :status_message, :certificate_arn) SENSITIVE = [] include Aws::Structure end |
#certificate_arn ⇒ String
The Amazon Resource Name (ARN) of the VPN tunnel endpoint certificate.
89937 89938 89939 89940 89941 89942 89943 89944 89945 89946 |
# File 'lib/aws-sdk-ec2/types.rb', line 89937 class VgwTelemetry < Struct.new( :accepted_route_count, :last_status_change, :outside_ip_address, :status, :status_message, :certificate_arn) SENSITIVE = [] include Aws::Structure end |
#last_status_change ⇒ Time
The date and time of the last change in status. This field is updated when changes in IKE (Phase 1), IPSec (Phase 2), or BGP status are detected.
89937 89938 89939 89940 89941 89942 89943 89944 89945 89946 |
# File 'lib/aws-sdk-ec2/types.rb', line 89937 class VgwTelemetry < Struct.new( :accepted_route_count, :last_status_change, :outside_ip_address, :status, :status_message, :certificate_arn) SENSITIVE = [] include Aws::Structure end |
#outside_ip_address ⇒ String
The Internet-routable IP address of the virtual private gateway's outside interface.
89937 89938 89939 89940 89941 89942 89943 89944 89945 89946 |
# File 'lib/aws-sdk-ec2/types.rb', line 89937 class VgwTelemetry < Struct.new( :accepted_route_count, :last_status_change, :outside_ip_address, :status, :status_message, :certificate_arn) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the VPN tunnel.
89937 89938 89939 89940 89941 89942 89943 89944 89945 89946 |
# File 'lib/aws-sdk-ec2/types.rb', line 89937 class VgwTelemetry < Struct.new( :accepted_route_count, :last_status_change, :outside_ip_address, :status, :status_message, :certificate_arn) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
If an error occurs, a description of the error.
89937 89938 89939 89940 89941 89942 89943 89944 89945 89946 |
# File 'lib/aws-sdk-ec2/types.rb', line 89937 class VgwTelemetry < Struct.new( :accepted_route_count, :last_status_change, :outside_ip_address, :status, :status_message, :certificate_arn) SENSITIVE = [] include Aws::Structure end |