Class: Aws::EC2::Types::Volume

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes a volume.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attachmentsArray<Types::VolumeAttachment>

This parameter is not returned by CreateVolume.

Information about the volume attachments.

Returns:



90067
90068
90069
90070
90071
90072
90073
90074
90075
90076
90077
90078
90079
90080
90081
90082
90083
90084
90085
90086
90087
90088
90089
90090
90091
# File 'lib/aws-sdk-ec2/types.rb', line 90067

class Volume < Struct.new(
  :availability_zone_id,
  :outpost_arn,
  :source_volume_id,
  :iops,
  :tags,
  :volume_type,
  :fast_restored,
  :multi_attach_enabled,
  :throughput,
  :sse_type,
  :operator,
  :volume_initialization_rate,
  :volume_id,
  :size,
  :snapshot_id,
  :availability_zone,
  :state,
  :create_time,
  :attachments,
  :encrypted,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zoneString

The Availability Zone for the volume.

Returns:

  • (String)


90067
90068
90069
90070
90071
90072
90073
90074
90075
90076
90077
90078
90079
90080
90081
90082
90083
90084
90085
90086
90087
90088
90089
90090
90091
# File 'lib/aws-sdk-ec2/types.rb', line 90067

class Volume < Struct.new(
  :availability_zone_id,
  :outpost_arn,
  :source_volume_id,
  :iops,
  :tags,
  :volume_type,
  :fast_restored,
  :multi_attach_enabled,
  :throughput,
  :sse_type,
  :operator,
  :volume_initialization_rate,
  :volume_id,
  :size,
  :snapshot_id,
  :availability_zone,
  :state,
  :create_time,
  :attachments,
  :encrypted,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zone_idString

The ID of the Availability Zone for the volume.

Returns:

  • (String)


90067
90068
90069
90070
90071
90072
90073
90074
90075
90076
90077
90078
90079
90080
90081
90082
90083
90084
90085
90086
90087
90088
90089
90090
90091
# File 'lib/aws-sdk-ec2/types.rb', line 90067

class Volume < Struct.new(
  :availability_zone_id,
  :outpost_arn,
  :source_volume_id,
  :iops,
  :tags,
  :volume_type,
  :fast_restored,
  :multi_attach_enabled,
  :throughput,
  :sse_type,
  :operator,
  :volume_initialization_rate,
  :volume_id,
  :size,
  :snapshot_id,
  :availability_zone,
  :state,
  :create_time,
  :attachments,
  :encrypted,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#create_timeTime

The time stamp when volume creation was initiated.

Returns:

  • (Time)


90067
90068
90069
90070
90071
90072
90073
90074
90075
90076
90077
90078
90079
90080
90081
90082
90083
90084
90085
90086
90087
90088
90089
90090
90091
# File 'lib/aws-sdk-ec2/types.rb', line 90067

class Volume < Struct.new(
  :availability_zone_id,
  :outpost_arn,
  :source_volume_id,
  :iops,
  :tags,
  :volume_type,
  :fast_restored,
  :multi_attach_enabled,
  :throughput,
  :sse_type,
  :operator,
  :volume_initialization_rate,
  :volume_id,
  :size,
  :snapshot_id,
  :availability_zone,
  :state,
  :create_time,
  :attachments,
  :encrypted,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#encryptedBoolean

Indicates whether the volume is encrypted.

Returns:

  • (Boolean)


90067
90068
90069
90070
90071
90072
90073
90074
90075
90076
90077
90078
90079
90080
90081
90082
90083
90084
90085
90086
90087
90088
90089
90090
90091
# File 'lib/aws-sdk-ec2/types.rb', line 90067

class Volume < Struct.new(
  :availability_zone_id,
  :outpost_arn,
  :source_volume_id,
  :iops,
  :tags,
  :volume_type,
  :fast_restored,
  :multi_attach_enabled,
  :throughput,
  :sse_type,
  :operator,
  :volume_initialization_rate,
  :volume_id,
  :size,
  :snapshot_id,
  :availability_zone,
  :state,
  :create_time,
  :attachments,
  :encrypted,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#fast_restoredBoolean

This parameter is not returned by CreateVolume.

Indicates whether the volume was created using fast snapshot restore.

Returns:

  • (Boolean)


90067
90068
90069
90070
90071
90072
90073
90074
90075
90076
90077
90078
90079
90080
90081
90082
90083
90084
90085
90086
90087
90088
90089
90090
90091
# File 'lib/aws-sdk-ec2/types.rb', line 90067

class Volume < Struct.new(
  :availability_zone_id,
  :outpost_arn,
  :source_volume_id,
  :iops,
  :tags,
  :volume_type,
  :fast_restored,
  :multi_attach_enabled,
  :throughput,
  :sse_type,
  :operator,
  :volume_initialization_rate,
  :volume_id,
  :size,
  :snapshot_id,
  :availability_zone,
  :state,
  :create_time,
  :attachments,
  :encrypted,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#iopsInteger

The number of I/O operations per second (IOPS). For gp3, io1, and io2 volumes, this represents the number of IOPS that are provisioned for the volume. For gp2 volumes, this represents the baseline performance of the volume and the rate at which the volume accumulates I/O credits for bursting.

Returns:

  • (Integer)


90067
90068
90069
90070
90071
90072
90073
90074
90075
90076
90077
90078
90079
90080
90081
90082
90083
90084
90085
90086
90087
90088
90089
90090
90091
# File 'lib/aws-sdk-ec2/types.rb', line 90067

class Volume < Struct.new(
  :availability_zone_id,
  :outpost_arn,
  :source_volume_id,
  :iops,
  :tags,
  :volume_type,
  :fast_restored,
  :multi_attach_enabled,
  :throughput,
  :sse_type,
  :operator,
  :volume_initialization_rate,
  :volume_id,
  :size,
  :snapshot_id,
  :availability_zone,
  :state,
  :create_time,
  :attachments,
  :encrypted,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

The Amazon Resource Name (ARN) of the KMS key that was used to protect the volume encryption key for the volume.

Returns:

  • (String)


90067
90068
90069
90070
90071
90072
90073
90074
90075
90076
90077
90078
90079
90080
90081
90082
90083
90084
90085
90086
90087
90088
90089
90090
90091
# File 'lib/aws-sdk-ec2/types.rb', line 90067

class Volume < Struct.new(
  :availability_zone_id,
  :outpost_arn,
  :source_volume_id,
  :iops,
  :tags,
  :volume_type,
  :fast_restored,
  :multi_attach_enabled,
  :throughput,
  :sse_type,
  :operator,
  :volume_initialization_rate,
  :volume_id,
  :size,
  :snapshot_id,
  :availability_zone,
  :state,
  :create_time,
  :attachments,
  :encrypted,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#multi_attach_enabledBoolean

Indicates whether Amazon EBS Multi-Attach is enabled.

Returns:

  • (Boolean)


90067
90068
90069
90070
90071
90072
90073
90074
90075
90076
90077
90078
90079
90080
90081
90082
90083
90084
90085
90086
90087
90088
90089
90090
90091
# File 'lib/aws-sdk-ec2/types.rb', line 90067

class Volume < Struct.new(
  :availability_zone_id,
  :outpost_arn,
  :source_volume_id,
  :iops,
  :tags,
  :volume_type,
  :fast_restored,
  :multi_attach_enabled,
  :throughput,
  :sse_type,
  :operator,
  :volume_initialization_rate,
  :volume_id,
  :size,
  :snapshot_id,
  :availability_zone,
  :state,
  :create_time,
  :attachments,
  :encrypted,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#operatorTypes::OperatorResponse

The service provider that manages the volume.



90067
90068
90069
90070
90071
90072
90073
90074
90075
90076
90077
90078
90079
90080
90081
90082
90083
90084
90085
90086
90087
90088
90089
90090
90091
# File 'lib/aws-sdk-ec2/types.rb', line 90067

class Volume < Struct.new(
  :availability_zone_id,
  :outpost_arn,
  :source_volume_id,
  :iops,
  :tags,
  :volume_type,
  :fast_restored,
  :multi_attach_enabled,
  :throughput,
  :sse_type,
  :operator,
  :volume_initialization_rate,
  :volume_id,
  :size,
  :snapshot_id,
  :availability_zone,
  :state,
  :create_time,
  :attachments,
  :encrypted,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#outpost_arnString

The Amazon Resource Name (ARN) of the Outpost.

Returns:

  • (String)


90067
90068
90069
90070
90071
90072
90073
90074
90075
90076
90077
90078
90079
90080
90081
90082
90083
90084
90085
90086
90087
90088
90089
90090
90091
# File 'lib/aws-sdk-ec2/types.rb', line 90067

class Volume < Struct.new(
  :availability_zone_id,
  :outpost_arn,
  :source_volume_id,
  :iops,
  :tags,
  :volume_type,
  :fast_restored,
  :multi_attach_enabled,
  :throughput,
  :sse_type,
  :operator,
  :volume_initialization_rate,
  :volume_id,
  :size,
  :snapshot_id,
  :availability_zone,
  :state,
  :create_time,
  :attachments,
  :encrypted,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#sizeInteger

The size of the volume, in GiBs.

Returns:

  • (Integer)


90067
90068
90069
90070
90071
90072
90073
90074
90075
90076
90077
90078
90079
90080
90081
90082
90083
90084
90085
90086
90087
90088
90089
90090
90091
# File 'lib/aws-sdk-ec2/types.rb', line 90067

class Volume < Struct.new(
  :availability_zone_id,
  :outpost_arn,
  :source_volume_id,
  :iops,
  :tags,
  :volume_type,
  :fast_restored,
  :multi_attach_enabled,
  :throughput,
  :sse_type,
  :operator,
  :volume_initialization_rate,
  :volume_id,
  :size,
  :snapshot_id,
  :availability_zone,
  :state,
  :create_time,
  :attachments,
  :encrypted,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_idString

The snapshot from which the volume was created, if applicable.

Returns:

  • (String)


90067
90068
90069
90070
90071
90072
90073
90074
90075
90076
90077
90078
90079
90080
90081
90082
90083
90084
90085
90086
90087
90088
90089
90090
90091
# File 'lib/aws-sdk-ec2/types.rb', line 90067

class Volume < Struct.new(
  :availability_zone_id,
  :outpost_arn,
  :source_volume_id,
  :iops,
  :tags,
  :volume_type,
  :fast_restored,
  :multi_attach_enabled,
  :throughput,
  :sse_type,
  :operator,
  :volume_initialization_rate,
  :volume_id,
  :size,
  :snapshot_id,
  :availability_zone,
  :state,
  :create_time,
  :attachments,
  :encrypted,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#source_volume_idString

The ID of the source volume from which the volume copy was created. Only for volume copies.

Returns:

  • (String)


90067
90068
90069
90070
90071
90072
90073
90074
90075
90076
90077
90078
90079
90080
90081
90082
90083
90084
90085
90086
90087
90088
90089
90090
90091
# File 'lib/aws-sdk-ec2/types.rb', line 90067

class Volume < Struct.new(
  :availability_zone_id,
  :outpost_arn,
  :source_volume_id,
  :iops,
  :tags,
  :volume_type,
  :fast_restored,
  :multi_attach_enabled,
  :throughput,
  :sse_type,
  :operator,
  :volume_initialization_rate,
  :volume_id,
  :size,
  :snapshot_id,
  :availability_zone,
  :state,
  :create_time,
  :attachments,
  :encrypted,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#sse_typeString

This parameter is not returned by CreateVolume.

Reserved for future use.

Returns:

  • (String)


90067
90068
90069
90070
90071
90072
90073
90074
90075
90076
90077
90078
90079
90080
90081
90082
90083
90084
90085
90086
90087
90088
90089
90090
90091
# File 'lib/aws-sdk-ec2/types.rb', line 90067

class Volume < Struct.new(
  :availability_zone_id,
  :outpost_arn,
  :source_volume_id,
  :iops,
  :tags,
  :volume_type,
  :fast_restored,
  :multi_attach_enabled,
  :throughput,
  :sse_type,
  :operator,
  :volume_initialization_rate,
  :volume_id,
  :size,
  :snapshot_id,
  :availability_zone,
  :state,
  :create_time,
  :attachments,
  :encrypted,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The volume state.

Returns:

  • (String)


90067
90068
90069
90070
90071
90072
90073
90074
90075
90076
90077
90078
90079
90080
90081
90082
90083
90084
90085
90086
90087
90088
90089
90090
90091
# File 'lib/aws-sdk-ec2/types.rb', line 90067

class Volume < Struct.new(
  :availability_zone_id,
  :outpost_arn,
  :source_volume_id,
  :iops,
  :tags,
  :volume_type,
  :fast_restored,
  :multi_attach_enabled,
  :throughput,
  :sse_type,
  :operator,
  :volume_initialization_rate,
  :volume_id,
  :size,
  :snapshot_id,
  :availability_zone,
  :state,
  :create_time,
  :attachments,
  :encrypted,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Any tags assigned to the volume.

Returns:



90067
90068
90069
90070
90071
90072
90073
90074
90075
90076
90077
90078
90079
90080
90081
90082
90083
90084
90085
90086
90087
90088
90089
90090
90091
# File 'lib/aws-sdk-ec2/types.rb', line 90067

class Volume < Struct.new(
  :availability_zone_id,
  :outpost_arn,
  :source_volume_id,
  :iops,
  :tags,
  :volume_type,
  :fast_restored,
  :multi_attach_enabled,
  :throughput,
  :sse_type,
  :operator,
  :volume_initialization_rate,
  :volume_id,
  :size,
  :snapshot_id,
  :availability_zone,
  :state,
  :create_time,
  :attachments,
  :encrypted,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#throughputInteger

The throughput that the volume supports, in MiB/s.

Returns:

  • (Integer)


90067
90068
90069
90070
90071
90072
90073
90074
90075
90076
90077
90078
90079
90080
90081
90082
90083
90084
90085
90086
90087
90088
90089
90090
90091
# File 'lib/aws-sdk-ec2/types.rb', line 90067

class Volume < Struct.new(
  :availability_zone_id,
  :outpost_arn,
  :source_volume_id,
  :iops,
  :tags,
  :volume_type,
  :fast_restored,
  :multi_attach_enabled,
  :throughput,
  :sse_type,
  :operator,
  :volume_initialization_rate,
  :volume_id,
  :size,
  :snapshot_id,
  :availability_zone,
  :state,
  :create_time,
  :attachments,
  :encrypted,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#volume_idString

The ID of the volume.

Returns:

  • (String)


90067
90068
90069
90070
90071
90072
90073
90074
90075
90076
90077
90078
90079
90080
90081
90082
90083
90084
90085
90086
90087
90088
90089
90090
90091
# File 'lib/aws-sdk-ec2/types.rb', line 90067

class Volume < Struct.new(
  :availability_zone_id,
  :outpost_arn,
  :source_volume_id,
  :iops,
  :tags,
  :volume_type,
  :fast_restored,
  :multi_attach_enabled,
  :throughput,
  :sse_type,
  :operator,
  :volume_initialization_rate,
  :volume_id,
  :size,
  :snapshot_id,
  :availability_zone,
  :state,
  :create_time,
  :attachments,
  :encrypted,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#volume_initialization_rateInteger

The Amazon EBS Provisioned Rate for Volume Initialization (volume initialization rate) specified for the volume during creation, in MiB/s. If no volume initialization rate was specified, the value is null.

Returns:

  • (Integer)


90067
90068
90069
90070
90071
90072
90073
90074
90075
90076
90077
90078
90079
90080
90081
90082
90083
90084
90085
90086
90087
90088
90089
90090
90091
# File 'lib/aws-sdk-ec2/types.rb', line 90067

class Volume < Struct.new(
  :availability_zone_id,
  :outpost_arn,
  :source_volume_id,
  :iops,
  :tags,
  :volume_type,
  :fast_restored,
  :multi_attach_enabled,
  :throughput,
  :sse_type,
  :operator,
  :volume_initialization_rate,
  :volume_id,
  :size,
  :snapshot_id,
  :availability_zone,
  :state,
  :create_time,
  :attachments,
  :encrypted,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#volume_typeString

The volume type.

Returns:

  • (String)


90067
90068
90069
90070
90071
90072
90073
90074
90075
90076
90077
90078
90079
90080
90081
90082
90083
90084
90085
90086
90087
90088
90089
90090
90091
# File 'lib/aws-sdk-ec2/types.rb', line 90067

class Volume < Struct.new(
  :availability_zone_id,
  :outpost_arn,
  :source_volume_id,
  :iops,
  :tags,
  :volume_type,
  :fast_restored,
  :multi_attach_enabled,
  :throughput,
  :sse_type,
  :operator,
  :volume_initialization_rate,
  :volume_id,
  :size,
  :snapshot_id,
  :availability_zone,
  :state,
  :create_time,
  :attachments,
  :encrypted,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end