Class: Aws::EC2::Types::Volume
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::Volume
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a volume.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attachments ⇒ Array<Types::VolumeAttachment>
<note markdown=“1”> This parameter is not returned by CreateVolume.
-
#availability_zone ⇒ String
The Availability Zone for the volume.
-
#availability_zone_id ⇒ String
The ID of the Availability Zone for the volume.
-
#create_time ⇒ Time
The time stamp when volume creation was initiated.
-
#encrypted ⇒ Boolean
Indicates whether the volume is encrypted.
-
#fast_restored ⇒ Boolean
<note markdown=“1”> This parameter is not returned by CreateVolume.
-
#iops ⇒ Integer
The number of I/O operations per second (IOPS).
-
#kms_key_id ⇒ String
The Amazon Resource Name (ARN) of the KMS key that was used to protect the volume encryption key for the volume.
-
#multi_attach_enabled ⇒ Boolean
Indicates whether Amazon EBS Multi-Attach is enabled.
-
#operator ⇒ Types::OperatorResponse
The service provider that manages the volume.
-
#outpost_arn ⇒ String
The Amazon Resource Name (ARN) of the Outpost.
-
#size ⇒ Integer
The size of the volume, in GiBs.
-
#snapshot_id ⇒ String
The snapshot from which the volume was created, if applicable.
-
#source_volume_id ⇒ String
The ID of the source volume from which the volume copy was created.
-
#sse_type ⇒ String
<note markdown=“1”> This parameter is not returned by CreateVolume.
-
#state ⇒ String
The volume state.
-
#tags ⇒ Array<Types::Tag>
Any tags assigned to the volume.
-
#throughput ⇒ Integer
The throughput that the volume supports, in MiB/s.
-
#volume_id ⇒ String
The ID of the volume.
-
#volume_initialization_rate ⇒ Integer
The Amazon EBS Provisioned Rate for Volume Initialization (volume initialization rate) specified for the volume during creation, in MiB/s.
-
#volume_type ⇒ String
The volume type.
Instance Attribute Details
#attachments ⇒ Array<Types::VolumeAttachment>
<note markdown=“1”> This parameter is not returned by CreateVolume.
</note>
Information about the volume attachments.
85613 85614 85615 85616 85617 85618 85619 85620 85621 85622 85623 85624 85625 85626 85627 85628 85629 85630 85631 85632 85633 85634 85635 85636 85637 |
# File 'lib/aws-sdk-ec2/types.rb', line 85613 class Volume < Struct.new( :availability_zone_id, :outpost_arn, :source_volume_id, :iops, :tags, :volume_type, :fast_restored, :multi_attach_enabled, :throughput, :sse_type, :operator, :volume_initialization_rate, :volume_id, :size, :snapshot_id, :availability_zone, :state, :create_time, :attachments, :encrypted, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#availability_zone ⇒ String
The Availability Zone for the volume.
85613 85614 85615 85616 85617 85618 85619 85620 85621 85622 85623 85624 85625 85626 85627 85628 85629 85630 85631 85632 85633 85634 85635 85636 85637 |
# File 'lib/aws-sdk-ec2/types.rb', line 85613 class Volume < Struct.new( :availability_zone_id, :outpost_arn, :source_volume_id, :iops, :tags, :volume_type, :fast_restored, :multi_attach_enabled, :throughput, :sse_type, :operator, :volume_initialization_rate, :volume_id, :size, :snapshot_id, :availability_zone, :state, :create_time, :attachments, :encrypted, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
The ID of the Availability Zone for the volume.
85613 85614 85615 85616 85617 85618 85619 85620 85621 85622 85623 85624 85625 85626 85627 85628 85629 85630 85631 85632 85633 85634 85635 85636 85637 |
# File 'lib/aws-sdk-ec2/types.rb', line 85613 class Volume < Struct.new( :availability_zone_id, :outpost_arn, :source_volume_id, :iops, :tags, :volume_type, :fast_restored, :multi_attach_enabled, :throughput, :sse_type, :operator, :volume_initialization_rate, :volume_id, :size, :snapshot_id, :availability_zone, :state, :create_time, :attachments, :encrypted, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time stamp when volume creation was initiated.
85613 85614 85615 85616 85617 85618 85619 85620 85621 85622 85623 85624 85625 85626 85627 85628 85629 85630 85631 85632 85633 85634 85635 85636 85637 |
# File 'lib/aws-sdk-ec2/types.rb', line 85613 class Volume < Struct.new( :availability_zone_id, :outpost_arn, :source_volume_id, :iops, :tags, :volume_type, :fast_restored, :multi_attach_enabled, :throughput, :sse_type, :operator, :volume_initialization_rate, :volume_id, :size, :snapshot_id, :availability_zone, :state, :create_time, :attachments, :encrypted, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#encrypted ⇒ Boolean
Indicates whether the volume is encrypted.
85613 85614 85615 85616 85617 85618 85619 85620 85621 85622 85623 85624 85625 85626 85627 85628 85629 85630 85631 85632 85633 85634 85635 85636 85637 |
# File 'lib/aws-sdk-ec2/types.rb', line 85613 class Volume < Struct.new( :availability_zone_id, :outpost_arn, :source_volume_id, :iops, :tags, :volume_type, :fast_restored, :multi_attach_enabled, :throughput, :sse_type, :operator, :volume_initialization_rate, :volume_id, :size, :snapshot_id, :availability_zone, :state, :create_time, :attachments, :encrypted, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#fast_restored ⇒ Boolean
<note markdown=“1”> This parameter is not returned by CreateVolume.
</note>
Indicates whether the volume was created using fast snapshot restore.
85613 85614 85615 85616 85617 85618 85619 85620 85621 85622 85623 85624 85625 85626 85627 85628 85629 85630 85631 85632 85633 85634 85635 85636 85637 |
# File 'lib/aws-sdk-ec2/types.rb', line 85613 class Volume < Struct.new( :availability_zone_id, :outpost_arn, :source_volume_id, :iops, :tags, :volume_type, :fast_restored, :multi_attach_enabled, :throughput, :sse_type, :operator, :volume_initialization_rate, :volume_id, :size, :snapshot_id, :availability_zone, :state, :create_time, :attachments, :encrypted, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#iops ⇒ Integer
The number of I/O operations per second (IOPS). For ‘gp3`, `io1`, and `io2` volumes, this represents the number of IOPS that are provisioned for the volume. For `gp2` volumes, this represents the baseline performance of the volume and the rate at which the volume accumulates I/O credits for bursting.
85613 85614 85615 85616 85617 85618 85619 85620 85621 85622 85623 85624 85625 85626 85627 85628 85629 85630 85631 85632 85633 85634 85635 85636 85637 |
# File 'lib/aws-sdk-ec2/types.rb', line 85613 class Volume < Struct.new( :availability_zone_id, :outpost_arn, :source_volume_id, :iops, :tags, :volume_type, :fast_restored, :multi_attach_enabled, :throughput, :sse_type, :operator, :volume_initialization_rate, :volume_id, :size, :snapshot_id, :availability_zone, :state, :create_time, :attachments, :encrypted, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The Amazon Resource Name (ARN) of the KMS key that was used to protect the volume encryption key for the volume.
85613 85614 85615 85616 85617 85618 85619 85620 85621 85622 85623 85624 85625 85626 85627 85628 85629 85630 85631 85632 85633 85634 85635 85636 85637 |
# File 'lib/aws-sdk-ec2/types.rb', line 85613 class Volume < Struct.new( :availability_zone_id, :outpost_arn, :source_volume_id, :iops, :tags, :volume_type, :fast_restored, :multi_attach_enabled, :throughput, :sse_type, :operator, :volume_initialization_rate, :volume_id, :size, :snapshot_id, :availability_zone, :state, :create_time, :attachments, :encrypted, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#multi_attach_enabled ⇒ Boolean
Indicates whether Amazon EBS Multi-Attach is enabled.
85613 85614 85615 85616 85617 85618 85619 85620 85621 85622 85623 85624 85625 85626 85627 85628 85629 85630 85631 85632 85633 85634 85635 85636 85637 |
# File 'lib/aws-sdk-ec2/types.rb', line 85613 class Volume < Struct.new( :availability_zone_id, :outpost_arn, :source_volume_id, :iops, :tags, :volume_type, :fast_restored, :multi_attach_enabled, :throughput, :sse_type, :operator, :volume_initialization_rate, :volume_id, :size, :snapshot_id, :availability_zone, :state, :create_time, :attachments, :encrypted, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#operator ⇒ Types::OperatorResponse
The service provider that manages the volume.
85613 85614 85615 85616 85617 85618 85619 85620 85621 85622 85623 85624 85625 85626 85627 85628 85629 85630 85631 85632 85633 85634 85635 85636 85637 |
# File 'lib/aws-sdk-ec2/types.rb', line 85613 class Volume < Struct.new( :availability_zone_id, :outpost_arn, :source_volume_id, :iops, :tags, :volume_type, :fast_restored, :multi_attach_enabled, :throughput, :sse_type, :operator, :volume_initialization_rate, :volume_id, :size, :snapshot_id, :availability_zone, :state, :create_time, :attachments, :encrypted, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#outpost_arn ⇒ String
The Amazon Resource Name (ARN) of the Outpost.
85613 85614 85615 85616 85617 85618 85619 85620 85621 85622 85623 85624 85625 85626 85627 85628 85629 85630 85631 85632 85633 85634 85635 85636 85637 |
# File 'lib/aws-sdk-ec2/types.rb', line 85613 class Volume < Struct.new( :availability_zone_id, :outpost_arn, :source_volume_id, :iops, :tags, :volume_type, :fast_restored, :multi_attach_enabled, :throughput, :sse_type, :operator, :volume_initialization_rate, :volume_id, :size, :snapshot_id, :availability_zone, :state, :create_time, :attachments, :encrypted, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#size ⇒ Integer
The size of the volume, in GiBs.
85613 85614 85615 85616 85617 85618 85619 85620 85621 85622 85623 85624 85625 85626 85627 85628 85629 85630 85631 85632 85633 85634 85635 85636 85637 |
# File 'lib/aws-sdk-ec2/types.rb', line 85613 class Volume < Struct.new( :availability_zone_id, :outpost_arn, :source_volume_id, :iops, :tags, :volume_type, :fast_restored, :multi_attach_enabled, :throughput, :sse_type, :operator, :volume_initialization_rate, :volume_id, :size, :snapshot_id, :availability_zone, :state, :create_time, :attachments, :encrypted, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#snapshot_id ⇒ String
The snapshot from which the volume was created, if applicable.
85613 85614 85615 85616 85617 85618 85619 85620 85621 85622 85623 85624 85625 85626 85627 85628 85629 85630 85631 85632 85633 85634 85635 85636 85637 |
# File 'lib/aws-sdk-ec2/types.rb', line 85613 class Volume < Struct.new( :availability_zone_id, :outpost_arn, :source_volume_id, :iops, :tags, :volume_type, :fast_restored, :multi_attach_enabled, :throughput, :sse_type, :operator, :volume_initialization_rate, :volume_id, :size, :snapshot_id, :availability_zone, :state, :create_time, :attachments, :encrypted, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#source_volume_id ⇒ String
The ID of the source volume from which the volume copy was created. Only for volume copies.
85613 85614 85615 85616 85617 85618 85619 85620 85621 85622 85623 85624 85625 85626 85627 85628 85629 85630 85631 85632 85633 85634 85635 85636 85637 |
# File 'lib/aws-sdk-ec2/types.rb', line 85613 class Volume < Struct.new( :availability_zone_id, :outpost_arn, :source_volume_id, :iops, :tags, :volume_type, :fast_restored, :multi_attach_enabled, :throughput, :sse_type, :operator, :volume_initialization_rate, :volume_id, :size, :snapshot_id, :availability_zone, :state, :create_time, :attachments, :encrypted, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#sse_type ⇒ String
<note markdown=“1”> This parameter is not returned by CreateVolume.
</note>
Reserved for future use.
85613 85614 85615 85616 85617 85618 85619 85620 85621 85622 85623 85624 85625 85626 85627 85628 85629 85630 85631 85632 85633 85634 85635 85636 85637 |
# File 'lib/aws-sdk-ec2/types.rb', line 85613 class Volume < Struct.new( :availability_zone_id, :outpost_arn, :source_volume_id, :iops, :tags, :volume_type, :fast_restored, :multi_attach_enabled, :throughput, :sse_type, :operator, :volume_initialization_rate, :volume_id, :size, :snapshot_id, :availability_zone, :state, :create_time, :attachments, :encrypted, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The volume state.
85613 85614 85615 85616 85617 85618 85619 85620 85621 85622 85623 85624 85625 85626 85627 85628 85629 85630 85631 85632 85633 85634 85635 85636 85637 |
# File 'lib/aws-sdk-ec2/types.rb', line 85613 class Volume < Struct.new( :availability_zone_id, :outpost_arn, :source_volume_id, :iops, :tags, :volume_type, :fast_restored, :multi_attach_enabled, :throughput, :sse_type, :operator, :volume_initialization_rate, :volume_id, :size, :snapshot_id, :availability_zone, :state, :create_time, :attachments, :encrypted, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Any tags assigned to the volume.
85613 85614 85615 85616 85617 85618 85619 85620 85621 85622 85623 85624 85625 85626 85627 85628 85629 85630 85631 85632 85633 85634 85635 85636 85637 |
# File 'lib/aws-sdk-ec2/types.rb', line 85613 class Volume < Struct.new( :availability_zone_id, :outpost_arn, :source_volume_id, :iops, :tags, :volume_type, :fast_restored, :multi_attach_enabled, :throughput, :sse_type, :operator, :volume_initialization_rate, :volume_id, :size, :snapshot_id, :availability_zone, :state, :create_time, :attachments, :encrypted, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#throughput ⇒ Integer
The throughput that the volume supports, in MiB/s.
85613 85614 85615 85616 85617 85618 85619 85620 85621 85622 85623 85624 85625 85626 85627 85628 85629 85630 85631 85632 85633 85634 85635 85636 85637 |
# File 'lib/aws-sdk-ec2/types.rb', line 85613 class Volume < Struct.new( :availability_zone_id, :outpost_arn, :source_volume_id, :iops, :tags, :volume_type, :fast_restored, :multi_attach_enabled, :throughput, :sse_type, :operator, :volume_initialization_rate, :volume_id, :size, :snapshot_id, :availability_zone, :state, :create_time, :attachments, :encrypted, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#volume_id ⇒ String
The ID of the volume.
85613 85614 85615 85616 85617 85618 85619 85620 85621 85622 85623 85624 85625 85626 85627 85628 85629 85630 85631 85632 85633 85634 85635 85636 85637 |
# File 'lib/aws-sdk-ec2/types.rb', line 85613 class Volume < Struct.new( :availability_zone_id, :outpost_arn, :source_volume_id, :iops, :tags, :volume_type, :fast_restored, :multi_attach_enabled, :throughput, :sse_type, :operator, :volume_initialization_rate, :volume_id, :size, :snapshot_id, :availability_zone, :state, :create_time, :attachments, :encrypted, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#volume_initialization_rate ⇒ Integer
The Amazon EBS Provisioned Rate for Volume Initialization (volume initialization rate) specified for the volume during creation, in MiB/s. If no volume initialization rate was specified, the value is ‘null`.
85613 85614 85615 85616 85617 85618 85619 85620 85621 85622 85623 85624 85625 85626 85627 85628 85629 85630 85631 85632 85633 85634 85635 85636 85637 |
# File 'lib/aws-sdk-ec2/types.rb', line 85613 class Volume < Struct.new( :availability_zone_id, :outpost_arn, :source_volume_id, :iops, :tags, :volume_type, :fast_restored, :multi_attach_enabled, :throughput, :sse_type, :operator, :volume_initialization_rate, :volume_id, :size, :snapshot_id, :availability_zone, :state, :create_time, :attachments, :encrypted, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#volume_type ⇒ String
The volume type.
85613 85614 85615 85616 85617 85618 85619 85620 85621 85622 85623 85624 85625 85626 85627 85628 85629 85630 85631 85632 85633 85634 85635 85636 85637 |
# File 'lib/aws-sdk-ec2/types.rb', line 85613 class Volume < Struct.new( :availability_zone_id, :outpost_arn, :source_volume_id, :iops, :tags, :volume_type, :fast_restored, :multi_attach_enabled, :throughput, :sse_type, :operator, :volume_initialization_rate, :volume_id, :size, :snapshot_id, :availability_zone, :state, :create_time, :attachments, :encrypted, :kms_key_id) SENSITIVE = [] include Aws::Structure end |