Class: Aws::EC2::Types::VolumeAttachment
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::VolumeAttachment
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes volume attachment details.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#associated_resource ⇒ String
The ARN of the Amazon Web Services-managed resource to which the volume is attached.
-
#attach_time ⇒ Time
The time stamp when the attachment initiated.
-
#delete_on_termination ⇒ Boolean
Indicates whether the EBS volume is deleted on instance termination.
-
#device ⇒ String
The device name.
-
#ebs_card_index ⇒ Integer
The index of the EBS card.
-
#instance_id ⇒ String
The ID of the instance.
-
#instance_owning_service ⇒ String
The service principal of the Amazon Web Services service that owns the underlying resource to which the volume is attached.
-
#state ⇒ String
The attachment state of the volume.
-
#volume_id ⇒ String
The ID of the volume.
Instance Attribute Details
#associated_resource ⇒ String
The ARN of the Amazon Web Services-managed resource to which the volume is attached.
85700 85701 85702 85703 85704 85705 85706 85707 85708 85709 85710 85711 85712 |
# File 'lib/aws-sdk-ec2/types.rb', line 85700 class VolumeAttachment < Struct.new( :delete_on_termination, :associated_resource, :instance_owning_service, :ebs_card_index, :volume_id, :instance_id, :device, :state, :attach_time) SENSITIVE = [] include Aws::Structure end |
#attach_time ⇒ Time
The time stamp when the attachment initiated.
85700 85701 85702 85703 85704 85705 85706 85707 85708 85709 85710 85711 85712 |
# File 'lib/aws-sdk-ec2/types.rb', line 85700 class VolumeAttachment < Struct.new( :delete_on_termination, :associated_resource, :instance_owning_service, :ebs_card_index, :volume_id, :instance_id, :device, :state, :attach_time) SENSITIVE = [] include Aws::Structure end |
#delete_on_termination ⇒ Boolean
Indicates whether the EBS volume is deleted on instance termination.
85700 85701 85702 85703 85704 85705 85706 85707 85708 85709 85710 85711 85712 |
# File 'lib/aws-sdk-ec2/types.rb', line 85700 class VolumeAttachment < Struct.new( :delete_on_termination, :associated_resource, :instance_owning_service, :ebs_card_index, :volume_id, :instance_id, :device, :state, :attach_time) SENSITIVE = [] include Aws::Structure end |
#device ⇒ String
The device name.
If the volume is attached to an Amazon Web Services-managed resource, this parameter returns ‘null`.
85700 85701 85702 85703 85704 85705 85706 85707 85708 85709 85710 85711 85712 |
# File 'lib/aws-sdk-ec2/types.rb', line 85700 class VolumeAttachment < Struct.new( :delete_on_termination, :associated_resource, :instance_owning_service, :ebs_card_index, :volume_id, :instance_id, :device, :state, :attach_time) SENSITIVE = [] include Aws::Structure end |
#ebs_card_index ⇒ Integer
The index of the EBS card. Some instance types support multiple EBS cards. The default EBS card index is 0.
85700 85701 85702 85703 85704 85705 85706 85707 85708 85709 85710 85711 85712 |
# File 'lib/aws-sdk-ec2/types.rb', line 85700 class VolumeAttachment < Struct.new( :delete_on_termination, :associated_resource, :instance_owning_service, :ebs_card_index, :volume_id, :instance_id, :device, :state, :attach_time) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the instance.
If the volume is attached to an Amazon Web Services-managed resource, this parameter returns ‘null`.
85700 85701 85702 85703 85704 85705 85706 85707 85708 85709 85710 85711 85712 |
# File 'lib/aws-sdk-ec2/types.rb', line 85700 class VolumeAttachment < Struct.new( :delete_on_termination, :associated_resource, :instance_owning_service, :ebs_card_index, :volume_id, :instance_id, :device, :state, :attach_time) SENSITIVE = [] include Aws::Structure end |
#instance_owning_service ⇒ String
The service principal of the Amazon Web Services service that owns the underlying resource to which the volume is attached.
This parameter is returned only for volumes that are attached to Amazon Web Services-managed resources.
85700 85701 85702 85703 85704 85705 85706 85707 85708 85709 85710 85711 85712 |
# File 'lib/aws-sdk-ec2/types.rb', line 85700 class VolumeAttachment < Struct.new( :delete_on_termination, :associated_resource, :instance_owning_service, :ebs_card_index, :volume_id, :instance_id, :device, :state, :attach_time) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The attachment state of the volume.
85700 85701 85702 85703 85704 85705 85706 85707 85708 85709 85710 85711 85712 |
# File 'lib/aws-sdk-ec2/types.rb', line 85700 class VolumeAttachment < Struct.new( :delete_on_termination, :associated_resource, :instance_owning_service, :ebs_card_index, :volume_id, :instance_id, :device, :state, :attach_time) SENSITIVE = [] include Aws::Structure end |
#volume_id ⇒ String
The ID of the volume.
85700 85701 85702 85703 85704 85705 85706 85707 85708 85709 85710 85711 85712 |
# File 'lib/aws-sdk-ec2/types.rb', line 85700 class VolumeAttachment < Struct.new( :delete_on_termination, :associated_resource, :instance_owning_service, :ebs_card_index, :volume_id, :instance_id, :device, :state, :attach_time) SENSITIVE = [] include Aws::Structure end |