Class: Aws::EC2::Types::VolumeModification
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::VolumeModification
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes the modification status of an EBS volume.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_time ⇒ Time
The modification completion or failure time.
-
#modification_state ⇒ String
The current modification state.
-
#operator ⇒ Types::OperatorResponse
Describes whether the resource is managed by a service provider and, if so, describes the service provider that manages it.
-
#original_iops ⇒ Integer
The original IOPS rate of the volume.
-
#original_multi_attach_enabled ⇒ Boolean
The original setting for Amazon EBS Multi-Attach.
-
#original_size ⇒ Integer
The original size of the volume, in GiB.
-
#original_throughput ⇒ Integer
The original throughput of the volume, in MiB/s.
-
#original_volume_type ⇒ String
The original EBS volume type of the volume.
-
#progress ⇒ Integer
The modification progress, from 0 to 100 percent complete.
-
#start_time ⇒ Time
The modification start time.
-
#status_message ⇒ String
A status message about the modification progress or failure.
-
#target_iops ⇒ Integer
The target IOPS rate of the volume.
-
#target_multi_attach_enabled ⇒ Boolean
The target setting for Amazon EBS Multi-Attach.
-
#target_size ⇒ Integer
The target size of the volume, in GiB.
-
#target_throughput ⇒ Integer
The target throughput of the volume, in MiB/s.
-
#target_volume_type ⇒ String
The target EBS volume type of the volume.
-
#volume_id ⇒ String
The ID of the volume.
Instance Attribute Details
#end_time ⇒ Time
The modification completion or failure time.
85792 85793 85794 85795 85796 85797 85798 85799 85800 85801 85802 85803 85804 85805 85806 85807 85808 85809 85810 85811 85812 |
# File 'lib/aws-sdk-ec2/types.rb', line 85792 class VolumeModification < Struct.new( :volume_id, :modification_state, :status_message, :target_size, :target_iops, :target_volume_type, :target_throughput, :target_multi_attach_enabled, :original_size, :original_iops, :original_volume_type, :original_throughput, :original_multi_attach_enabled, :progress, :start_time, :end_time, :operator) SENSITIVE = [] include Aws::Structure end |
#modification_state ⇒ String
The current modification state.
85792 85793 85794 85795 85796 85797 85798 85799 85800 85801 85802 85803 85804 85805 85806 85807 85808 85809 85810 85811 85812 |
# File 'lib/aws-sdk-ec2/types.rb', line 85792 class VolumeModification < Struct.new( :volume_id, :modification_state, :status_message, :target_size, :target_iops, :target_volume_type, :target_throughput, :target_multi_attach_enabled, :original_size, :original_iops, :original_volume_type, :original_throughput, :original_multi_attach_enabled, :progress, :start_time, :end_time, :operator) SENSITIVE = [] include Aws::Structure end |
#operator ⇒ Types::OperatorResponse
Describes whether the resource is managed by a service provider and, if so, describes the service provider that manages it.
85792 85793 85794 85795 85796 85797 85798 85799 85800 85801 85802 85803 85804 85805 85806 85807 85808 85809 85810 85811 85812 |
# File 'lib/aws-sdk-ec2/types.rb', line 85792 class VolumeModification < Struct.new( :volume_id, :modification_state, :status_message, :target_size, :target_iops, :target_volume_type, :target_throughput, :target_multi_attach_enabled, :original_size, :original_iops, :original_volume_type, :original_throughput, :original_multi_attach_enabled, :progress, :start_time, :end_time, :operator) SENSITIVE = [] include Aws::Structure end |
#original_iops ⇒ Integer
The original IOPS rate of the volume.
85792 85793 85794 85795 85796 85797 85798 85799 85800 85801 85802 85803 85804 85805 85806 85807 85808 85809 85810 85811 85812 |
# File 'lib/aws-sdk-ec2/types.rb', line 85792 class VolumeModification < Struct.new( :volume_id, :modification_state, :status_message, :target_size, :target_iops, :target_volume_type, :target_throughput, :target_multi_attach_enabled, :original_size, :original_iops, :original_volume_type, :original_throughput, :original_multi_attach_enabled, :progress, :start_time, :end_time, :operator) SENSITIVE = [] include Aws::Structure end |
#original_multi_attach_enabled ⇒ Boolean
The original setting for Amazon EBS Multi-Attach.
85792 85793 85794 85795 85796 85797 85798 85799 85800 85801 85802 85803 85804 85805 85806 85807 85808 85809 85810 85811 85812 |
# File 'lib/aws-sdk-ec2/types.rb', line 85792 class VolumeModification < Struct.new( :volume_id, :modification_state, :status_message, :target_size, :target_iops, :target_volume_type, :target_throughput, :target_multi_attach_enabled, :original_size, :original_iops, :original_volume_type, :original_throughput, :original_multi_attach_enabled, :progress, :start_time, :end_time, :operator) SENSITIVE = [] include Aws::Structure end |
#original_size ⇒ Integer
The original size of the volume, in GiB.
85792 85793 85794 85795 85796 85797 85798 85799 85800 85801 85802 85803 85804 85805 85806 85807 85808 85809 85810 85811 85812 |
# File 'lib/aws-sdk-ec2/types.rb', line 85792 class VolumeModification < Struct.new( :volume_id, :modification_state, :status_message, :target_size, :target_iops, :target_volume_type, :target_throughput, :target_multi_attach_enabled, :original_size, :original_iops, :original_volume_type, :original_throughput, :original_multi_attach_enabled, :progress, :start_time, :end_time, :operator) SENSITIVE = [] include Aws::Structure end |
#original_throughput ⇒ Integer
The original throughput of the volume, in MiB/s.
85792 85793 85794 85795 85796 85797 85798 85799 85800 85801 85802 85803 85804 85805 85806 85807 85808 85809 85810 85811 85812 |
# File 'lib/aws-sdk-ec2/types.rb', line 85792 class VolumeModification < Struct.new( :volume_id, :modification_state, :status_message, :target_size, :target_iops, :target_volume_type, :target_throughput, :target_multi_attach_enabled, :original_size, :original_iops, :original_volume_type, :original_throughput, :original_multi_attach_enabled, :progress, :start_time, :end_time, :operator) SENSITIVE = [] include Aws::Structure end |
#original_volume_type ⇒ String
The original EBS volume type of the volume.
85792 85793 85794 85795 85796 85797 85798 85799 85800 85801 85802 85803 85804 85805 85806 85807 85808 85809 85810 85811 85812 |
# File 'lib/aws-sdk-ec2/types.rb', line 85792 class VolumeModification < Struct.new( :volume_id, :modification_state, :status_message, :target_size, :target_iops, :target_volume_type, :target_throughput, :target_multi_attach_enabled, :original_size, :original_iops, :original_volume_type, :original_throughput, :original_multi_attach_enabled, :progress, :start_time, :end_time, :operator) SENSITIVE = [] include Aws::Structure end |
#progress ⇒ Integer
The modification progress, from 0 to 100 percent complete.
85792 85793 85794 85795 85796 85797 85798 85799 85800 85801 85802 85803 85804 85805 85806 85807 85808 85809 85810 85811 85812 |
# File 'lib/aws-sdk-ec2/types.rb', line 85792 class VolumeModification < Struct.new( :volume_id, :modification_state, :status_message, :target_size, :target_iops, :target_volume_type, :target_throughput, :target_multi_attach_enabled, :original_size, :original_iops, :original_volume_type, :original_throughput, :original_multi_attach_enabled, :progress, :start_time, :end_time, :operator) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The modification start time.
85792 85793 85794 85795 85796 85797 85798 85799 85800 85801 85802 85803 85804 85805 85806 85807 85808 85809 85810 85811 85812 |
# File 'lib/aws-sdk-ec2/types.rb', line 85792 class VolumeModification < Struct.new( :volume_id, :modification_state, :status_message, :target_size, :target_iops, :target_volume_type, :target_throughput, :target_multi_attach_enabled, :original_size, :original_iops, :original_volume_type, :original_throughput, :original_multi_attach_enabled, :progress, :start_time, :end_time, :operator) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
A status message about the modification progress or failure.
85792 85793 85794 85795 85796 85797 85798 85799 85800 85801 85802 85803 85804 85805 85806 85807 85808 85809 85810 85811 85812 |
# File 'lib/aws-sdk-ec2/types.rb', line 85792 class VolumeModification < Struct.new( :volume_id, :modification_state, :status_message, :target_size, :target_iops, :target_volume_type, :target_throughput, :target_multi_attach_enabled, :original_size, :original_iops, :original_volume_type, :original_throughput, :original_multi_attach_enabled, :progress, :start_time, :end_time, :operator) SENSITIVE = [] include Aws::Structure end |
#target_iops ⇒ Integer
The target IOPS rate of the volume.
85792 85793 85794 85795 85796 85797 85798 85799 85800 85801 85802 85803 85804 85805 85806 85807 85808 85809 85810 85811 85812 |
# File 'lib/aws-sdk-ec2/types.rb', line 85792 class VolumeModification < Struct.new( :volume_id, :modification_state, :status_message, :target_size, :target_iops, :target_volume_type, :target_throughput, :target_multi_attach_enabled, :original_size, :original_iops, :original_volume_type, :original_throughput, :original_multi_attach_enabled, :progress, :start_time, :end_time, :operator) SENSITIVE = [] include Aws::Structure end |
#target_multi_attach_enabled ⇒ Boolean
The target setting for Amazon EBS Multi-Attach.
85792 85793 85794 85795 85796 85797 85798 85799 85800 85801 85802 85803 85804 85805 85806 85807 85808 85809 85810 85811 85812 |
# File 'lib/aws-sdk-ec2/types.rb', line 85792 class VolumeModification < Struct.new( :volume_id, :modification_state, :status_message, :target_size, :target_iops, :target_volume_type, :target_throughput, :target_multi_attach_enabled, :original_size, :original_iops, :original_volume_type, :original_throughput, :original_multi_attach_enabled, :progress, :start_time, :end_time, :operator) SENSITIVE = [] include Aws::Structure end |
#target_size ⇒ Integer
The target size of the volume, in GiB.
85792 85793 85794 85795 85796 85797 85798 85799 85800 85801 85802 85803 85804 85805 85806 85807 85808 85809 85810 85811 85812 |
# File 'lib/aws-sdk-ec2/types.rb', line 85792 class VolumeModification < Struct.new( :volume_id, :modification_state, :status_message, :target_size, :target_iops, :target_volume_type, :target_throughput, :target_multi_attach_enabled, :original_size, :original_iops, :original_volume_type, :original_throughput, :original_multi_attach_enabled, :progress, :start_time, :end_time, :operator) SENSITIVE = [] include Aws::Structure end |
#target_throughput ⇒ Integer
The target throughput of the volume, in MiB/s.
85792 85793 85794 85795 85796 85797 85798 85799 85800 85801 85802 85803 85804 85805 85806 85807 85808 85809 85810 85811 85812 |
# File 'lib/aws-sdk-ec2/types.rb', line 85792 class VolumeModification < Struct.new( :volume_id, :modification_state, :status_message, :target_size, :target_iops, :target_volume_type, :target_throughput, :target_multi_attach_enabled, :original_size, :original_iops, :original_volume_type, :original_throughput, :original_multi_attach_enabled, :progress, :start_time, :end_time, :operator) SENSITIVE = [] include Aws::Structure end |
#target_volume_type ⇒ String
The target EBS volume type of the volume.
85792 85793 85794 85795 85796 85797 85798 85799 85800 85801 85802 85803 85804 85805 85806 85807 85808 85809 85810 85811 85812 |
# File 'lib/aws-sdk-ec2/types.rb', line 85792 class VolumeModification < Struct.new( :volume_id, :modification_state, :status_message, :target_size, :target_iops, :target_volume_type, :target_throughput, :target_multi_attach_enabled, :original_size, :original_iops, :original_volume_type, :original_throughput, :original_multi_attach_enabled, :progress, :start_time, :end_time, :operator) SENSITIVE = [] include Aws::Structure end |
#volume_id ⇒ String
The ID of the volume.
85792 85793 85794 85795 85796 85797 85798 85799 85800 85801 85802 85803 85804 85805 85806 85807 85808 85809 85810 85811 85812 |
# File 'lib/aws-sdk-ec2/types.rb', line 85792 class VolumeModification < Struct.new( :volume_id, :modification_state, :status_message, :target_size, :target_iops, :target_volume_type, :target_throughput, :target_multi_attach_enabled, :original_size, :original_iops, :original_volume_type, :original_throughput, :original_multi_attach_enabled, :progress, :start_time, :end_time, :operator) SENSITIVE = [] include Aws::Structure end |