Class: Aws::EC2::Types::VolumeRecycleBinInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::VolumeRecycleBinInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Information about a volume that is currently in the Recycle Bin.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone ⇒ String
The Availability Zone for the volume.
-
#availability_zone_id ⇒ String
The ID of the Availability Zone for the volume.
-
#create_time ⇒ Time
The time stamp when volume creation was initiated.
-
#iops ⇒ Integer
The number of I/O operations per second (IOPS) for the volume.
-
#operator ⇒ Types::OperatorResponse
The service provider that manages the volume.
-
#outpost_arn ⇒ String
The ARN of the Outpost on which the volume is stored.
-
#recycle_bin_enter_time ⇒ Time
The date and time when the volume entered the Recycle Bin.
-
#recycle_bin_exit_time ⇒ Time
The date and time when the volume is to be permanently deleted from the Recycle Bin.
-
#size ⇒ Integer
The size of the volume, in GiB.
-
#snapshot_id ⇒ String
The snapshot from which the volume was created, if applicable.
-
#source_volume_id ⇒ String
The ID of the source volume.
-
#state ⇒ String
The state of the volume.
-
#throughput ⇒ Integer
The throughput that the volume supports, in MiB/s.
-
#volume_id ⇒ String
The ID of the volume.
-
#volume_type ⇒ String
The volume type.
Instance Attribute Details
#availability_zone ⇒ String
The Availability Zone for the volume.
85729 85730 85731 85732 85733 85734 85735 85736 85737 85738 85739 85740 85741 85742 85743 85744 85745 85746 85747 |
# File 'lib/aws-sdk-ec2/types.rb', line 85729 class VolumeRecycleBinInfo < Struct.new( :volume_id, :volume_type, :state, :size, :iops, :throughput, :outpost_arn, :availability_zone, :availability_zone_id, :source_volume_id, :snapshot_id, :operator, :create_time, :recycle_bin_enter_time, :recycle_bin_exit_time) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
The ID of the Availability Zone for the volume.
85729 85730 85731 85732 85733 85734 85735 85736 85737 85738 85739 85740 85741 85742 85743 85744 85745 85746 85747 |
# File 'lib/aws-sdk-ec2/types.rb', line 85729 class VolumeRecycleBinInfo < Struct.new( :volume_id, :volume_type, :state, :size, :iops, :throughput, :outpost_arn, :availability_zone, :availability_zone_id, :source_volume_id, :snapshot_id, :operator, :create_time, :recycle_bin_enter_time, :recycle_bin_exit_time) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time stamp when volume creation was initiated.
85729 85730 85731 85732 85733 85734 85735 85736 85737 85738 85739 85740 85741 85742 85743 85744 85745 85746 85747 |
# File 'lib/aws-sdk-ec2/types.rb', line 85729 class VolumeRecycleBinInfo < Struct.new( :volume_id, :volume_type, :state, :size, :iops, :throughput, :outpost_arn, :availability_zone, :availability_zone_id, :source_volume_id, :snapshot_id, :operator, :create_time, :recycle_bin_enter_time, :recycle_bin_exit_time) SENSITIVE = [] include Aws::Structure end |
#iops ⇒ Integer
The number of I/O operations per second (IOPS) for the volume.
85729 85730 85731 85732 85733 85734 85735 85736 85737 85738 85739 85740 85741 85742 85743 85744 85745 85746 85747 |
# File 'lib/aws-sdk-ec2/types.rb', line 85729 class VolumeRecycleBinInfo < Struct.new( :volume_id, :volume_type, :state, :size, :iops, :throughput, :outpost_arn, :availability_zone, :availability_zone_id, :source_volume_id, :snapshot_id, :operator, :create_time, :recycle_bin_enter_time, :recycle_bin_exit_time) SENSITIVE = [] include Aws::Structure end |
#operator ⇒ Types::OperatorResponse
The service provider that manages the volume.
85729 85730 85731 85732 85733 85734 85735 85736 85737 85738 85739 85740 85741 85742 85743 85744 85745 85746 85747 |
# File 'lib/aws-sdk-ec2/types.rb', line 85729 class VolumeRecycleBinInfo < Struct.new( :volume_id, :volume_type, :state, :size, :iops, :throughput, :outpost_arn, :availability_zone, :availability_zone_id, :source_volume_id, :snapshot_id, :operator, :create_time, :recycle_bin_enter_time, :recycle_bin_exit_time) SENSITIVE = [] include Aws::Structure end |
#outpost_arn ⇒ String
The ARN of the Outpost on which the volume is stored. For more information, see [Amazon EBS volumes on Outposts] in the *Amazon EBS User Guide*.
[1]: docs.aws.amazon.com/ebs/latest/userguide/ebs-volumes-outposts.html
85729 85730 85731 85732 85733 85734 85735 85736 85737 85738 85739 85740 85741 85742 85743 85744 85745 85746 85747 |
# File 'lib/aws-sdk-ec2/types.rb', line 85729 class VolumeRecycleBinInfo < Struct.new( :volume_id, :volume_type, :state, :size, :iops, :throughput, :outpost_arn, :availability_zone, :availability_zone_id, :source_volume_id, :snapshot_id, :operator, :create_time, :recycle_bin_enter_time, :recycle_bin_exit_time) SENSITIVE = [] include Aws::Structure end |
#recycle_bin_enter_time ⇒ Time
The date and time when the volume entered the Recycle Bin.
85729 85730 85731 85732 85733 85734 85735 85736 85737 85738 85739 85740 85741 85742 85743 85744 85745 85746 85747 |
# File 'lib/aws-sdk-ec2/types.rb', line 85729 class VolumeRecycleBinInfo < Struct.new( :volume_id, :volume_type, :state, :size, :iops, :throughput, :outpost_arn, :availability_zone, :availability_zone_id, :source_volume_id, :snapshot_id, :operator, :create_time, :recycle_bin_enter_time, :recycle_bin_exit_time) SENSITIVE = [] include Aws::Structure end |
#recycle_bin_exit_time ⇒ Time
The date and time when the volume is to be permanently deleted from the Recycle Bin.
85729 85730 85731 85732 85733 85734 85735 85736 85737 85738 85739 85740 85741 85742 85743 85744 85745 85746 85747 |
# File 'lib/aws-sdk-ec2/types.rb', line 85729 class VolumeRecycleBinInfo < Struct.new( :volume_id, :volume_type, :state, :size, :iops, :throughput, :outpost_arn, :availability_zone, :availability_zone_id, :source_volume_id, :snapshot_id, :operator, :create_time, :recycle_bin_enter_time, :recycle_bin_exit_time) SENSITIVE = [] include Aws::Structure end |
#size ⇒ Integer
The size of the volume, in GiB.
85729 85730 85731 85732 85733 85734 85735 85736 85737 85738 85739 85740 85741 85742 85743 85744 85745 85746 85747 |
# File 'lib/aws-sdk-ec2/types.rb', line 85729 class VolumeRecycleBinInfo < Struct.new( :volume_id, :volume_type, :state, :size, :iops, :throughput, :outpost_arn, :availability_zone, :availability_zone_id, :source_volume_id, :snapshot_id, :operator, :create_time, :recycle_bin_enter_time, :recycle_bin_exit_time) SENSITIVE = [] include Aws::Structure end |
#snapshot_id ⇒ String
The snapshot from which the volume was created, if applicable.
85729 85730 85731 85732 85733 85734 85735 85736 85737 85738 85739 85740 85741 85742 85743 85744 85745 85746 85747 |
# File 'lib/aws-sdk-ec2/types.rb', line 85729 class VolumeRecycleBinInfo < Struct.new( :volume_id, :volume_type, :state, :size, :iops, :throughput, :outpost_arn, :availability_zone, :availability_zone_id, :source_volume_id, :snapshot_id, :operator, :create_time, :recycle_bin_enter_time, :recycle_bin_exit_time) SENSITIVE = [] include Aws::Structure end |
#source_volume_id ⇒ String
The ID of the source volume.
85729 85730 85731 85732 85733 85734 85735 85736 85737 85738 85739 85740 85741 85742 85743 85744 85745 85746 85747 |
# File 'lib/aws-sdk-ec2/types.rb', line 85729 class VolumeRecycleBinInfo < Struct.new( :volume_id, :volume_type, :state, :size, :iops, :throughput, :outpost_arn, :availability_zone, :availability_zone_id, :source_volume_id, :snapshot_id, :operator, :create_time, :recycle_bin_enter_time, :recycle_bin_exit_time) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the volume.
85729 85730 85731 85732 85733 85734 85735 85736 85737 85738 85739 85740 85741 85742 85743 85744 85745 85746 85747 |
# File 'lib/aws-sdk-ec2/types.rb', line 85729 class VolumeRecycleBinInfo < Struct.new( :volume_id, :volume_type, :state, :size, :iops, :throughput, :outpost_arn, :availability_zone, :availability_zone_id, :source_volume_id, :snapshot_id, :operator, :create_time, :recycle_bin_enter_time, :recycle_bin_exit_time) SENSITIVE = [] include Aws::Structure end |
#throughput ⇒ Integer
The throughput that the volume supports, in MiB/s.
85729 85730 85731 85732 85733 85734 85735 85736 85737 85738 85739 85740 85741 85742 85743 85744 85745 85746 85747 |
# File 'lib/aws-sdk-ec2/types.rb', line 85729 class VolumeRecycleBinInfo < Struct.new( :volume_id, :volume_type, :state, :size, :iops, :throughput, :outpost_arn, :availability_zone, :availability_zone_id, :source_volume_id, :snapshot_id, :operator, :create_time, :recycle_bin_enter_time, :recycle_bin_exit_time) SENSITIVE = [] include Aws::Structure end |
#volume_id ⇒ String
The ID of the volume.
85729 85730 85731 85732 85733 85734 85735 85736 85737 85738 85739 85740 85741 85742 85743 85744 85745 85746 85747 |
# File 'lib/aws-sdk-ec2/types.rb', line 85729 class VolumeRecycleBinInfo < Struct.new( :volume_id, :volume_type, :state, :size, :iops, :throughput, :outpost_arn, :availability_zone, :availability_zone_id, :source_volume_id, :snapshot_id, :operator, :create_time, :recycle_bin_enter_time, :recycle_bin_exit_time) SENSITIVE = [] include Aws::Structure end |
#volume_type ⇒ String
The volume type.
85729 85730 85731 85732 85733 85734 85735 85736 85737 85738 85739 85740 85741 85742 85743 85744 85745 85746 85747 |
# File 'lib/aws-sdk-ec2/types.rb', line 85729 class VolumeRecycleBinInfo < Struct.new( :volume_id, :volume_type, :state, :size, :iops, :throughput, :outpost_arn, :availability_zone, :availability_zone_id, :source_volume_id, :snapshot_id, :operator, :create_time, :recycle_bin_enter_time, :recycle_bin_exit_time) SENSITIVE = [] include Aws::Structure end |