Class: Aws::EC2::Types::Vpc

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes a VPC.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#block_public_access_statesTypes::BlockPublicAccessStates

The state of VPC Block Public Access (BPA).



87320
87321
87322
87323
87324
87325
87326
87327
87328
87329
87330
87331
87332
87333
87334
87335
# File 'lib/aws-sdk-ec2/types.rb', line 87320

class Vpc < Struct.new(
  :owner_id,
  :instance_tenancy,
  :ipv_6_cidr_block_association_set,
  :cidr_block_association_set,
  :is_default,
  :encryption_control,
  :tags,
  :block_public_access_states,
  :vpc_id,
  :state,
  :cidr_block,
  :dhcp_options_id)
  SENSITIVE = []
  include Aws::Structure
end

#cidr_blockString

The primary IPv4 CIDR block for the VPC.

Returns:

  • (String)


87320
87321
87322
87323
87324
87325
87326
87327
87328
87329
87330
87331
87332
87333
87334
87335
# File 'lib/aws-sdk-ec2/types.rb', line 87320

class Vpc < Struct.new(
  :owner_id,
  :instance_tenancy,
  :ipv_6_cidr_block_association_set,
  :cidr_block_association_set,
  :is_default,
  :encryption_control,
  :tags,
  :block_public_access_states,
  :vpc_id,
  :state,
  :cidr_block,
  :dhcp_options_id)
  SENSITIVE = []
  include Aws::Structure
end

#cidr_block_association_setArray<Types::VpcCidrBlockAssociation>

Information about the IPv4 CIDR blocks associated with the VPC.

Returns:



87320
87321
87322
87323
87324
87325
87326
87327
87328
87329
87330
87331
87332
87333
87334
87335
# File 'lib/aws-sdk-ec2/types.rb', line 87320

class Vpc < Struct.new(
  :owner_id,
  :instance_tenancy,
  :ipv_6_cidr_block_association_set,
  :cidr_block_association_set,
  :is_default,
  :encryption_control,
  :tags,
  :block_public_access_states,
  :vpc_id,
  :state,
  :cidr_block,
  :dhcp_options_id)
  SENSITIVE = []
  include Aws::Structure
end

#dhcp_options_idString

The ID of the set of DHCP options you've associated with the VPC.

Returns:

  • (String)


87320
87321
87322
87323
87324
87325
87326
87327
87328
87329
87330
87331
87332
87333
87334
87335
# File 'lib/aws-sdk-ec2/types.rb', line 87320

class Vpc < Struct.new(
  :owner_id,
  :instance_tenancy,
  :ipv_6_cidr_block_association_set,
  :cidr_block_association_set,
  :is_default,
  :encryption_control,
  :tags,
  :block_public_access_states,
  :vpc_id,
  :state,
  :cidr_block,
  :dhcp_options_id)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_controlTypes::VpcEncryptionControl

Describes the configuration and state of VPC encryption controls.

For more information, see Enforce VPC encryption in transit in the Amazon VPC User Guide.



87320
87321
87322
87323
87324
87325
87326
87327
87328
87329
87330
87331
87332
87333
87334
87335
# File 'lib/aws-sdk-ec2/types.rb', line 87320

class Vpc < Struct.new(
  :owner_id,
  :instance_tenancy,
  :ipv_6_cidr_block_association_set,
  :cidr_block_association_set,
  :is_default,
  :encryption_control,
  :tags,
  :block_public_access_states,
  :vpc_id,
  :state,
  :cidr_block,
  :dhcp_options_id)
  SENSITIVE = []
  include Aws::Structure
end

#instance_tenancyString

The allowed tenancy of instances launched into the VPC.

Returns:

  • (String)


87320
87321
87322
87323
87324
87325
87326
87327
87328
87329
87330
87331
87332
87333
87334
87335
# File 'lib/aws-sdk-ec2/types.rb', line 87320

class Vpc < Struct.new(
  :owner_id,
  :instance_tenancy,
  :ipv_6_cidr_block_association_set,
  :cidr_block_association_set,
  :is_default,
  :encryption_control,
  :tags,
  :block_public_access_states,
  :vpc_id,
  :state,
  :cidr_block,
  :dhcp_options_id)
  SENSITIVE = []
  include Aws::Structure
end

#ipv_6_cidr_block_association_setArray<Types::VpcIpv6CidrBlockAssociation>

Information about the IPv6 CIDR blocks associated with the VPC.



87320
87321
87322
87323
87324
87325
87326
87327
87328
87329
87330
87331
87332
87333
87334
87335
# File 'lib/aws-sdk-ec2/types.rb', line 87320

class Vpc < Struct.new(
  :owner_id,
  :instance_tenancy,
  :ipv_6_cidr_block_association_set,
  :cidr_block_association_set,
  :is_default,
  :encryption_control,
  :tags,
  :block_public_access_states,
  :vpc_id,
  :state,
  :cidr_block,
  :dhcp_options_id)
  SENSITIVE = []
  include Aws::Structure
end

#is_defaultBoolean

Indicates whether the VPC is the default VPC.

Returns:

  • (Boolean)


87320
87321
87322
87323
87324
87325
87326
87327
87328
87329
87330
87331
87332
87333
87334
87335
# File 'lib/aws-sdk-ec2/types.rb', line 87320

class Vpc < Struct.new(
  :owner_id,
  :instance_tenancy,
  :ipv_6_cidr_block_association_set,
  :cidr_block_association_set,
  :is_default,
  :encryption_control,
  :tags,
  :block_public_access_states,
  :vpc_id,
  :state,
  :cidr_block,
  :dhcp_options_id)
  SENSITIVE = []
  include Aws::Structure
end

#owner_idString

The ID of the Amazon Web Services account that owns the VPC.

Returns:

  • (String)


87320
87321
87322
87323
87324
87325
87326
87327
87328
87329
87330
87331
87332
87333
87334
87335
# File 'lib/aws-sdk-ec2/types.rb', line 87320

class Vpc < Struct.new(
  :owner_id,
  :instance_tenancy,
  :ipv_6_cidr_block_association_set,
  :cidr_block_association_set,
  :is_default,
  :encryption_control,
  :tags,
  :block_public_access_states,
  :vpc_id,
  :state,
  :cidr_block,
  :dhcp_options_id)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The current state of the VPC.

Returns:

  • (String)


87320
87321
87322
87323
87324
87325
87326
87327
87328
87329
87330
87331
87332
87333
87334
87335
# File 'lib/aws-sdk-ec2/types.rb', line 87320

class Vpc < Struct.new(
  :owner_id,
  :instance_tenancy,
  :ipv_6_cidr_block_association_set,
  :cidr_block_association_set,
  :is_default,
  :encryption_control,
  :tags,
  :block_public_access_states,
  :vpc_id,
  :state,
  :cidr_block,
  :dhcp_options_id)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Any tags assigned to the VPC.

Returns:



87320
87321
87322
87323
87324
87325
87326
87327
87328
87329
87330
87331
87332
87333
87334
87335
# File 'lib/aws-sdk-ec2/types.rb', line 87320

class Vpc < Struct.new(
  :owner_id,
  :instance_tenancy,
  :ipv_6_cidr_block_association_set,
  :cidr_block_association_set,
  :is_default,
  :encryption_control,
  :tags,
  :block_public_access_states,
  :vpc_id,
  :state,
  :cidr_block,
  :dhcp_options_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC.

Returns:

  • (String)


87320
87321
87322
87323
87324
87325
87326
87327
87328
87329
87330
87331
87332
87333
87334
87335
# File 'lib/aws-sdk-ec2/types.rb', line 87320

class Vpc < Struct.new(
  :owner_id,
  :instance_tenancy,
  :ipv_6_cidr_block_association_set,
  :cidr_block_association_set,
  :is_default,
  :encryption_control,
  :tags,
  :block_public_access_states,
  :vpc_id,
  :state,
  :cidr_block,
  :dhcp_options_id)
  SENSITIVE = []
  include Aws::Structure
end