Class: Aws::EC2::Types::Vpc
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::Vpc
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a VPC.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#block_public_access_states ⇒ Types::BlockPublicAccessStates
The state of VPC Block Public Access (BPA).
-
#cidr_block ⇒ String
The primary IPv4 CIDR block for the VPC.
-
#cidr_block_association_set ⇒ Array<Types::VpcCidrBlockAssociation>
Information about the IPv4 CIDR blocks associated with the VPC.
-
#dhcp_options_id ⇒ String
The ID of the set of DHCP options you've associated with the VPC.
-
#encryption_control ⇒ Types::VpcEncryptionControl
Describes the configuration and state of VPC encryption controls.
-
#instance_tenancy ⇒ String
The allowed tenancy of instances launched into the VPC.
-
#ipv_6_cidr_block_association_set ⇒ Array<Types::VpcIpv6CidrBlockAssociation>
Information about the IPv6 CIDR blocks associated with the VPC.
-
#is_default ⇒ Boolean
Indicates whether the VPC is the default VPC.
-
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the VPC.
-
#state ⇒ String
The current state of the VPC.
-
#tags ⇒ Array<Types::Tag>
Any tags assigned to the VPC.
-
#vpc_id ⇒ String
The ID of the VPC.
Instance Attribute Details
#block_public_access_states ⇒ Types::BlockPublicAccessStates
The state of VPC Block Public Access (BPA).
86925 86926 86927 86928 86929 86930 86931 86932 86933 86934 86935 86936 86937 86938 86939 86940 |
# File 'lib/aws-sdk-ec2/types.rb', line 86925 class Vpc < Struct.new( :owner_id, :instance_tenancy, :ipv_6_cidr_block_association_set, :cidr_block_association_set, :is_default, :encryption_control, :tags, :block_public_access_states, :vpc_id, :state, :cidr_block, :dhcp_options_id) SENSITIVE = [] include Aws::Structure end |
#cidr_block ⇒ String
The primary IPv4 CIDR block for the VPC.
86925 86926 86927 86928 86929 86930 86931 86932 86933 86934 86935 86936 86937 86938 86939 86940 |
# File 'lib/aws-sdk-ec2/types.rb', line 86925 class Vpc < Struct.new( :owner_id, :instance_tenancy, :ipv_6_cidr_block_association_set, :cidr_block_association_set, :is_default, :encryption_control, :tags, :block_public_access_states, :vpc_id, :state, :cidr_block, :dhcp_options_id) SENSITIVE = [] include Aws::Structure end |
#cidr_block_association_set ⇒ Array<Types::VpcCidrBlockAssociation>
Information about the IPv4 CIDR blocks associated with the VPC.
86925 86926 86927 86928 86929 86930 86931 86932 86933 86934 86935 86936 86937 86938 86939 86940 |
# File 'lib/aws-sdk-ec2/types.rb', line 86925 class Vpc < Struct.new( :owner_id, :instance_tenancy, :ipv_6_cidr_block_association_set, :cidr_block_association_set, :is_default, :encryption_control, :tags, :block_public_access_states, :vpc_id, :state, :cidr_block, :dhcp_options_id) SENSITIVE = [] include Aws::Structure end |
#dhcp_options_id ⇒ String
The ID of the set of DHCP options you've associated with the VPC.
86925 86926 86927 86928 86929 86930 86931 86932 86933 86934 86935 86936 86937 86938 86939 86940 |
# File 'lib/aws-sdk-ec2/types.rb', line 86925 class Vpc < Struct.new( :owner_id, :instance_tenancy, :ipv_6_cidr_block_association_set, :cidr_block_association_set, :is_default, :encryption_control, :tags, :block_public_access_states, :vpc_id, :state, :cidr_block, :dhcp_options_id) SENSITIVE = [] include Aws::Structure end |
#encryption_control ⇒ Types::VpcEncryptionControl
Describes the configuration and state of VPC encryption controls.
For more information, see Enforce VPC encryption in transit in the Amazon VPC User Guide.
86925 86926 86927 86928 86929 86930 86931 86932 86933 86934 86935 86936 86937 86938 86939 86940 |
# File 'lib/aws-sdk-ec2/types.rb', line 86925 class Vpc < Struct.new( :owner_id, :instance_tenancy, :ipv_6_cidr_block_association_set, :cidr_block_association_set, :is_default, :encryption_control, :tags, :block_public_access_states, :vpc_id, :state, :cidr_block, :dhcp_options_id) SENSITIVE = [] include Aws::Structure end |
#instance_tenancy ⇒ String
The allowed tenancy of instances launched into the VPC.
86925 86926 86927 86928 86929 86930 86931 86932 86933 86934 86935 86936 86937 86938 86939 86940 |
# File 'lib/aws-sdk-ec2/types.rb', line 86925 class Vpc < Struct.new( :owner_id, :instance_tenancy, :ipv_6_cidr_block_association_set, :cidr_block_association_set, :is_default, :encryption_control, :tags, :block_public_access_states, :vpc_id, :state, :cidr_block, :dhcp_options_id) SENSITIVE = [] include Aws::Structure end |
#ipv_6_cidr_block_association_set ⇒ Array<Types::VpcIpv6CidrBlockAssociation>
Information about the IPv6 CIDR blocks associated with the VPC.
86925 86926 86927 86928 86929 86930 86931 86932 86933 86934 86935 86936 86937 86938 86939 86940 |
# File 'lib/aws-sdk-ec2/types.rb', line 86925 class Vpc < Struct.new( :owner_id, :instance_tenancy, :ipv_6_cidr_block_association_set, :cidr_block_association_set, :is_default, :encryption_control, :tags, :block_public_access_states, :vpc_id, :state, :cidr_block, :dhcp_options_id) SENSITIVE = [] include Aws::Structure end |
#is_default ⇒ Boolean
Indicates whether the VPC is the default VPC.
86925 86926 86927 86928 86929 86930 86931 86932 86933 86934 86935 86936 86937 86938 86939 86940 |
# File 'lib/aws-sdk-ec2/types.rb', line 86925 class Vpc < Struct.new( :owner_id, :instance_tenancy, :ipv_6_cidr_block_association_set, :cidr_block_association_set, :is_default, :encryption_control, :tags, :block_public_access_states, :vpc_id, :state, :cidr_block, :dhcp_options_id) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the VPC.
86925 86926 86927 86928 86929 86930 86931 86932 86933 86934 86935 86936 86937 86938 86939 86940 |
# File 'lib/aws-sdk-ec2/types.rb', line 86925 class Vpc < Struct.new( :owner_id, :instance_tenancy, :ipv_6_cidr_block_association_set, :cidr_block_association_set, :is_default, :encryption_control, :tags, :block_public_access_states, :vpc_id, :state, :cidr_block, :dhcp_options_id) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the VPC.
86925 86926 86927 86928 86929 86930 86931 86932 86933 86934 86935 86936 86937 86938 86939 86940 |
# File 'lib/aws-sdk-ec2/types.rb', line 86925 class Vpc < Struct.new( :owner_id, :instance_tenancy, :ipv_6_cidr_block_association_set, :cidr_block_association_set, :is_default, :encryption_control, :tags, :block_public_access_states, :vpc_id, :state, :cidr_block, :dhcp_options_id) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Any tags assigned to the VPC.
86925 86926 86927 86928 86929 86930 86931 86932 86933 86934 86935 86936 86937 86938 86939 86940 |
# File 'lib/aws-sdk-ec2/types.rb', line 86925 class Vpc < Struct.new( :owner_id, :instance_tenancy, :ipv_6_cidr_block_association_set, :cidr_block_association_set, :is_default, :encryption_control, :tags, :block_public_access_states, :vpc_id, :state, :cidr_block, :dhcp_options_id) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC.
86925 86926 86927 86928 86929 86930 86931 86932 86933 86934 86935 86936 86937 86938 86939 86940 |
# File 'lib/aws-sdk-ec2/types.rb', line 86925 class Vpc < Struct.new( :owner_id, :instance_tenancy, :ipv_6_cidr_block_association_set, :cidr_block_association_set, :is_default, :encryption_control, :tags, :block_public_access_states, :vpc_id, :state, :cidr_block, :dhcp_options_id) SENSITIVE = [] include Aws::Structure end |