Class: Aws::EC2::Types::VpcEncryptionNonCompliantResource
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::VpcEncryptionNonCompliantResource
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a resource that is not compliant with VPC encryption requirements.
For more information, see [Enforce VPC encryption in transit] in the *Amazon VPC User Guide*.
[1]: docs.aws.amazon.com/vpc/latest/userguide/vpc-encryption-controls.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the non-compliant resource.
-
#id ⇒ String
The ID of the non-compliant resource.
-
#is_excludable ⇒ Boolean
Indicates whether the resource can be excluded from encryption enforcement.
-
#type ⇒ String
The type of the non-compliant resource.
Instance Attribute Details
#description ⇒ String
A description of the non-compliant resource.
84458 84459 84460 84461 84462 84463 84464 84465 |
# File 'lib/aws-sdk-ec2/types.rb', line 84458 class VpcEncryptionNonCompliantResource < Struct.new( :id, :type, :description, :is_excludable) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the non-compliant resource.
84458 84459 84460 84461 84462 84463 84464 84465 |
# File 'lib/aws-sdk-ec2/types.rb', line 84458 class VpcEncryptionNonCompliantResource < Struct.new( :id, :type, :description, :is_excludable) SENSITIVE = [] include Aws::Structure end |
#is_excludable ⇒ Boolean
Indicates whether the resource can be excluded from encryption enforcement.
84458 84459 84460 84461 84462 84463 84464 84465 |
# File 'lib/aws-sdk-ec2/types.rb', line 84458 class VpcEncryptionNonCompliantResource < Struct.new( :id, :type, :description, :is_excludable) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the non-compliant resource.
84458 84459 84460 84461 84462 84463 84464 84465 |
# File 'lib/aws-sdk-ec2/types.rb', line 84458 class VpcEncryptionNonCompliantResource < Struct.new( :id, :type, :description, :is_excludable) SENSITIVE = [] include Aws::Structure end |