Class: Aws::EC2::Types::VpcEndpoint
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::VpcEndpoint
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a VPC endpoint.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ Time
The date and time that the endpoint was created.
-
#dns_entries ⇒ Array<Types::DnsEntry>
(Interface endpoint) The DNS entries for the endpoint.
-
#dns_options ⇒ Types::DnsOptions
The DNS options for the endpoint.
-
#failure_reason ⇒ String
Reason for the failure.
-
#groups ⇒ Array<Types::SecurityGroupIdentifier>
(Interface endpoint) Information about the security groups that are associated with the network interface.
-
#ip_address_type ⇒ String
The IP address type for the endpoint.
-
#ipv_4_prefixes ⇒ Array<Types::SubnetIpPrefixes>
Array of IPv4 prefixes.
-
#ipv_6_prefixes ⇒ Array<Types::SubnetIpPrefixes>
Array of IPv6 prefixes.
-
#last_error ⇒ Types::LastError
The last error that occurred for endpoint.
-
#network_interface_ids ⇒ Array<String>
(Interface endpoint) The network interfaces for the endpoint.
-
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the endpoint.
-
#payer_responsibilities ⇒ Array<Types::PayerResponsibilityEntry>
The payer responsibility settings for the endpoint.
-
#policy_document ⇒ String
The policy document associated with the endpoint, if applicable.
-
#private_dns_enabled ⇒ Boolean
(Interface endpoint) Indicates whether the VPC is associated with a private hosted zone.
-
#requester_managed ⇒ Boolean
Indicates whether the endpoint is being managed by its service.
-
#resource_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of the resource configuration.
-
#route_table_ids ⇒ Array<String>
(Gateway endpoint) The IDs of the route tables associated with the endpoint.
-
#service_name ⇒ String
The name of the service to which the endpoint is associated.
-
#service_network_arn ⇒ String
The Amazon Resource Name (ARN) of the service network.
-
#service_region ⇒ String
The Region where the service is hosted.
-
#state ⇒ String
The state of the endpoint.
-
#subnet_ids ⇒ Array<String>
(Interface endpoint) The subnets for the endpoint.
-
#tags ⇒ Array<Types::Tag>
The tags assigned to the endpoint.
-
#vpc_endpoint_id ⇒ String
The ID of the endpoint.
-
#vpc_endpoint_type ⇒ String
The type of endpoint.
-
#vpc_id ⇒ String
The ID of the VPC to which the endpoint is associated.
Instance Attribute Details
#creation_timestamp ⇒ Time
The date and time that the endpoint was created.
91384 91385 91386 91387 91388 91389 91390 91391 91392 91393 91394 91395 91396 91397 91398 91399 91400 91401 91402 91403 91404 91405 91406 91407 91408 91409 91410 91411 91412 91413 |
# File 'lib/aws-sdk-ec2/types.rb', line 91384 class VpcEndpoint < Struct.new( :vpc_endpoint_id, :vpc_endpoint_type, :vpc_id, :service_name, :state, :policy_document, :route_table_ids, :subnet_ids, :groups, :ip_address_type, :dns_options, :private_dns_enabled, :requester_managed, :network_interface_ids, :dns_entries, :creation_timestamp, :tags, :owner_id, :last_error, :ipv_4_prefixes, :ipv_6_prefixes, :failure_reason, :service_network_arn, :resource_configuration_arn, :service_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#dns_entries ⇒ Array<Types::DnsEntry>
(Interface endpoint) The DNS entries for the endpoint.
91384 91385 91386 91387 91388 91389 91390 91391 91392 91393 91394 91395 91396 91397 91398 91399 91400 91401 91402 91403 91404 91405 91406 91407 91408 91409 91410 91411 91412 91413 |
# File 'lib/aws-sdk-ec2/types.rb', line 91384 class VpcEndpoint < Struct.new( :vpc_endpoint_id, :vpc_endpoint_type, :vpc_id, :service_name, :state, :policy_document, :route_table_ids, :subnet_ids, :groups, :ip_address_type, :dns_options, :private_dns_enabled, :requester_managed, :network_interface_ids, :dns_entries, :creation_timestamp, :tags, :owner_id, :last_error, :ipv_4_prefixes, :ipv_6_prefixes, :failure_reason, :service_network_arn, :resource_configuration_arn, :service_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#dns_options ⇒ Types::DnsOptions
The DNS options for the endpoint.
91384 91385 91386 91387 91388 91389 91390 91391 91392 91393 91394 91395 91396 91397 91398 91399 91400 91401 91402 91403 91404 91405 91406 91407 91408 91409 91410 91411 91412 91413 |
# File 'lib/aws-sdk-ec2/types.rb', line 91384 class VpcEndpoint < Struct.new( :vpc_endpoint_id, :vpc_endpoint_type, :vpc_id, :service_name, :state, :policy_document, :route_table_ids, :subnet_ids, :groups, :ip_address_type, :dns_options, :private_dns_enabled, :requester_managed, :network_interface_ids, :dns_entries, :creation_timestamp, :tags, :owner_id, :last_error, :ipv_4_prefixes, :ipv_6_prefixes, :failure_reason, :service_network_arn, :resource_configuration_arn, :service_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
Reason for the failure.
91384 91385 91386 91387 91388 91389 91390 91391 91392 91393 91394 91395 91396 91397 91398 91399 91400 91401 91402 91403 91404 91405 91406 91407 91408 91409 91410 91411 91412 91413 |
# File 'lib/aws-sdk-ec2/types.rb', line 91384 class VpcEndpoint < Struct.new( :vpc_endpoint_id, :vpc_endpoint_type, :vpc_id, :service_name, :state, :policy_document, :route_table_ids, :subnet_ids, :groups, :ip_address_type, :dns_options, :private_dns_enabled, :requester_managed, :network_interface_ids, :dns_entries, :creation_timestamp, :tags, :owner_id, :last_error, :ipv_4_prefixes, :ipv_6_prefixes, :failure_reason, :service_network_arn, :resource_configuration_arn, :service_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#groups ⇒ Array<Types::SecurityGroupIdentifier>
(Interface endpoint) Information about the security groups that are associated with the network interface.
91384 91385 91386 91387 91388 91389 91390 91391 91392 91393 91394 91395 91396 91397 91398 91399 91400 91401 91402 91403 91404 91405 91406 91407 91408 91409 91410 91411 91412 91413 |
# File 'lib/aws-sdk-ec2/types.rb', line 91384 class VpcEndpoint < Struct.new( :vpc_endpoint_id, :vpc_endpoint_type, :vpc_id, :service_name, :state, :policy_document, :route_table_ids, :subnet_ids, :groups, :ip_address_type, :dns_options, :private_dns_enabled, :requester_managed, :network_interface_ids, :dns_entries, :creation_timestamp, :tags, :owner_id, :last_error, :ipv_4_prefixes, :ipv_6_prefixes, :failure_reason, :service_network_arn, :resource_configuration_arn, :service_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#ip_address_type ⇒ String
The IP address type for the endpoint.
91384 91385 91386 91387 91388 91389 91390 91391 91392 91393 91394 91395 91396 91397 91398 91399 91400 91401 91402 91403 91404 91405 91406 91407 91408 91409 91410 91411 91412 91413 |
# File 'lib/aws-sdk-ec2/types.rb', line 91384 class VpcEndpoint < Struct.new( :vpc_endpoint_id, :vpc_endpoint_type, :vpc_id, :service_name, :state, :policy_document, :route_table_ids, :subnet_ids, :groups, :ip_address_type, :dns_options, :private_dns_enabled, :requester_managed, :network_interface_ids, :dns_entries, :creation_timestamp, :tags, :owner_id, :last_error, :ipv_4_prefixes, :ipv_6_prefixes, :failure_reason, :service_network_arn, :resource_configuration_arn, :service_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#ipv_4_prefixes ⇒ Array<Types::SubnetIpPrefixes>
Array of IPv4 prefixes.
91384 91385 91386 91387 91388 91389 91390 91391 91392 91393 91394 91395 91396 91397 91398 91399 91400 91401 91402 91403 91404 91405 91406 91407 91408 91409 91410 91411 91412 91413 |
# File 'lib/aws-sdk-ec2/types.rb', line 91384 class VpcEndpoint < Struct.new( :vpc_endpoint_id, :vpc_endpoint_type, :vpc_id, :service_name, :state, :policy_document, :route_table_ids, :subnet_ids, :groups, :ip_address_type, :dns_options, :private_dns_enabled, :requester_managed, :network_interface_ids, :dns_entries, :creation_timestamp, :tags, :owner_id, :last_error, :ipv_4_prefixes, :ipv_6_prefixes, :failure_reason, :service_network_arn, :resource_configuration_arn, :service_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#ipv_6_prefixes ⇒ Array<Types::SubnetIpPrefixes>
Array of IPv6 prefixes.
91384 91385 91386 91387 91388 91389 91390 91391 91392 91393 91394 91395 91396 91397 91398 91399 91400 91401 91402 91403 91404 91405 91406 91407 91408 91409 91410 91411 91412 91413 |
# File 'lib/aws-sdk-ec2/types.rb', line 91384 class VpcEndpoint < Struct.new( :vpc_endpoint_id, :vpc_endpoint_type, :vpc_id, :service_name, :state, :policy_document, :route_table_ids, :subnet_ids, :groups, :ip_address_type, :dns_options, :private_dns_enabled, :requester_managed, :network_interface_ids, :dns_entries, :creation_timestamp, :tags, :owner_id, :last_error, :ipv_4_prefixes, :ipv_6_prefixes, :failure_reason, :service_network_arn, :resource_configuration_arn, :service_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#last_error ⇒ Types::LastError
The last error that occurred for endpoint.
91384 91385 91386 91387 91388 91389 91390 91391 91392 91393 91394 91395 91396 91397 91398 91399 91400 91401 91402 91403 91404 91405 91406 91407 91408 91409 91410 91411 91412 91413 |
# File 'lib/aws-sdk-ec2/types.rb', line 91384 class VpcEndpoint < Struct.new( :vpc_endpoint_id, :vpc_endpoint_type, :vpc_id, :service_name, :state, :policy_document, :route_table_ids, :subnet_ids, :groups, :ip_address_type, :dns_options, :private_dns_enabled, :requester_managed, :network_interface_ids, :dns_entries, :creation_timestamp, :tags, :owner_id, :last_error, :ipv_4_prefixes, :ipv_6_prefixes, :failure_reason, :service_network_arn, :resource_configuration_arn, :service_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#network_interface_ids ⇒ Array<String>
(Interface endpoint) The network interfaces for the endpoint.
91384 91385 91386 91387 91388 91389 91390 91391 91392 91393 91394 91395 91396 91397 91398 91399 91400 91401 91402 91403 91404 91405 91406 91407 91408 91409 91410 91411 91412 91413 |
# File 'lib/aws-sdk-ec2/types.rb', line 91384 class VpcEndpoint < Struct.new( :vpc_endpoint_id, :vpc_endpoint_type, :vpc_id, :service_name, :state, :policy_document, :route_table_ids, :subnet_ids, :groups, :ip_address_type, :dns_options, :private_dns_enabled, :requester_managed, :network_interface_ids, :dns_entries, :creation_timestamp, :tags, :owner_id, :last_error, :ipv_4_prefixes, :ipv_6_prefixes, :failure_reason, :service_network_arn, :resource_configuration_arn, :service_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
The ID of the Amazon Web Services account that owns the endpoint.
91384 91385 91386 91387 91388 91389 91390 91391 91392 91393 91394 91395 91396 91397 91398 91399 91400 91401 91402 91403 91404 91405 91406 91407 91408 91409 91410 91411 91412 91413 |
# File 'lib/aws-sdk-ec2/types.rb', line 91384 class VpcEndpoint < Struct.new( :vpc_endpoint_id, :vpc_endpoint_type, :vpc_id, :service_name, :state, :policy_document, :route_table_ids, :subnet_ids, :groups, :ip_address_type, :dns_options, :private_dns_enabled, :requester_managed, :network_interface_ids, :dns_entries, :creation_timestamp, :tags, :owner_id, :last_error, :ipv_4_prefixes, :ipv_6_prefixes, :failure_reason, :service_network_arn, :resource_configuration_arn, :service_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#payer_responsibilities ⇒ Array<Types::PayerResponsibilityEntry>
The payer responsibility settings for the endpoint.
91384 91385 91386 91387 91388 91389 91390 91391 91392 91393 91394 91395 91396 91397 91398 91399 91400 91401 91402 91403 91404 91405 91406 91407 91408 91409 91410 91411 91412 91413 |
# File 'lib/aws-sdk-ec2/types.rb', line 91384 class VpcEndpoint < Struct.new( :vpc_endpoint_id, :vpc_endpoint_type, :vpc_id, :service_name, :state, :policy_document, :route_table_ids, :subnet_ids, :groups, :ip_address_type, :dns_options, :private_dns_enabled, :requester_managed, :network_interface_ids, :dns_entries, :creation_timestamp, :tags, :owner_id, :last_error, :ipv_4_prefixes, :ipv_6_prefixes, :failure_reason, :service_network_arn, :resource_configuration_arn, :service_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#policy_document ⇒ String
The policy document associated with the endpoint, if applicable.
91384 91385 91386 91387 91388 91389 91390 91391 91392 91393 91394 91395 91396 91397 91398 91399 91400 91401 91402 91403 91404 91405 91406 91407 91408 91409 91410 91411 91412 91413 |
# File 'lib/aws-sdk-ec2/types.rb', line 91384 class VpcEndpoint < Struct.new( :vpc_endpoint_id, :vpc_endpoint_type, :vpc_id, :service_name, :state, :policy_document, :route_table_ids, :subnet_ids, :groups, :ip_address_type, :dns_options, :private_dns_enabled, :requester_managed, :network_interface_ids, :dns_entries, :creation_timestamp, :tags, :owner_id, :last_error, :ipv_4_prefixes, :ipv_6_prefixes, :failure_reason, :service_network_arn, :resource_configuration_arn, :service_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#private_dns_enabled ⇒ Boolean
(Interface endpoint) Indicates whether the VPC is associated with a private hosted zone.
91384 91385 91386 91387 91388 91389 91390 91391 91392 91393 91394 91395 91396 91397 91398 91399 91400 91401 91402 91403 91404 91405 91406 91407 91408 91409 91410 91411 91412 91413 |
# File 'lib/aws-sdk-ec2/types.rb', line 91384 class VpcEndpoint < Struct.new( :vpc_endpoint_id, :vpc_endpoint_type, :vpc_id, :service_name, :state, :policy_document, :route_table_ids, :subnet_ids, :groups, :ip_address_type, :dns_options, :private_dns_enabled, :requester_managed, :network_interface_ids, :dns_entries, :creation_timestamp, :tags, :owner_id, :last_error, :ipv_4_prefixes, :ipv_6_prefixes, :failure_reason, :service_network_arn, :resource_configuration_arn, :service_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#requester_managed ⇒ Boolean
Indicates whether the endpoint is being managed by its service.
91384 91385 91386 91387 91388 91389 91390 91391 91392 91393 91394 91395 91396 91397 91398 91399 91400 91401 91402 91403 91404 91405 91406 91407 91408 91409 91410 91411 91412 91413 |
# File 'lib/aws-sdk-ec2/types.rb', line 91384 class VpcEndpoint < Struct.new( :vpc_endpoint_id, :vpc_endpoint_type, :vpc_id, :service_name, :state, :policy_document, :route_table_ids, :subnet_ids, :groups, :ip_address_type, :dns_options, :private_dns_enabled, :requester_managed, :network_interface_ids, :dns_entries, :creation_timestamp, :tags, :owner_id, :last_error, :ipv_4_prefixes, :ipv_6_prefixes, :failure_reason, :service_network_arn, :resource_configuration_arn, :service_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#resource_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of the resource configuration.
91384 91385 91386 91387 91388 91389 91390 91391 91392 91393 91394 91395 91396 91397 91398 91399 91400 91401 91402 91403 91404 91405 91406 91407 91408 91409 91410 91411 91412 91413 |
# File 'lib/aws-sdk-ec2/types.rb', line 91384 class VpcEndpoint < Struct.new( :vpc_endpoint_id, :vpc_endpoint_type, :vpc_id, :service_name, :state, :policy_document, :route_table_ids, :subnet_ids, :groups, :ip_address_type, :dns_options, :private_dns_enabled, :requester_managed, :network_interface_ids, :dns_entries, :creation_timestamp, :tags, :owner_id, :last_error, :ipv_4_prefixes, :ipv_6_prefixes, :failure_reason, :service_network_arn, :resource_configuration_arn, :service_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#route_table_ids ⇒ Array<String>
(Gateway endpoint) The IDs of the route tables associated with the endpoint.
91384 91385 91386 91387 91388 91389 91390 91391 91392 91393 91394 91395 91396 91397 91398 91399 91400 91401 91402 91403 91404 91405 91406 91407 91408 91409 91410 91411 91412 91413 |
# File 'lib/aws-sdk-ec2/types.rb', line 91384 class VpcEndpoint < Struct.new( :vpc_endpoint_id, :vpc_endpoint_type, :vpc_id, :service_name, :state, :policy_document, :route_table_ids, :subnet_ids, :groups, :ip_address_type, :dns_options, :private_dns_enabled, :requester_managed, :network_interface_ids, :dns_entries, :creation_timestamp, :tags, :owner_id, :last_error, :ipv_4_prefixes, :ipv_6_prefixes, :failure_reason, :service_network_arn, :resource_configuration_arn, :service_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#service_name ⇒ String
The name of the service to which the endpoint is associated.
91384 91385 91386 91387 91388 91389 91390 91391 91392 91393 91394 91395 91396 91397 91398 91399 91400 91401 91402 91403 91404 91405 91406 91407 91408 91409 91410 91411 91412 91413 |
# File 'lib/aws-sdk-ec2/types.rb', line 91384 class VpcEndpoint < Struct.new( :vpc_endpoint_id, :vpc_endpoint_type, :vpc_id, :service_name, :state, :policy_document, :route_table_ids, :subnet_ids, :groups, :ip_address_type, :dns_options, :private_dns_enabled, :requester_managed, :network_interface_ids, :dns_entries, :creation_timestamp, :tags, :owner_id, :last_error, :ipv_4_prefixes, :ipv_6_prefixes, :failure_reason, :service_network_arn, :resource_configuration_arn, :service_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#service_network_arn ⇒ String
The Amazon Resource Name (ARN) of the service network.
91384 91385 91386 91387 91388 91389 91390 91391 91392 91393 91394 91395 91396 91397 91398 91399 91400 91401 91402 91403 91404 91405 91406 91407 91408 91409 91410 91411 91412 91413 |
# File 'lib/aws-sdk-ec2/types.rb', line 91384 class VpcEndpoint < Struct.new( :vpc_endpoint_id, :vpc_endpoint_type, :vpc_id, :service_name, :state, :policy_document, :route_table_ids, :subnet_ids, :groups, :ip_address_type, :dns_options, :private_dns_enabled, :requester_managed, :network_interface_ids, :dns_entries, :creation_timestamp, :tags, :owner_id, :last_error, :ipv_4_prefixes, :ipv_6_prefixes, :failure_reason, :service_network_arn, :resource_configuration_arn, :service_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#service_region ⇒ String
The Region where the service is hosted.
91384 91385 91386 91387 91388 91389 91390 91391 91392 91393 91394 91395 91396 91397 91398 91399 91400 91401 91402 91403 91404 91405 91406 91407 91408 91409 91410 91411 91412 91413 |
# File 'lib/aws-sdk-ec2/types.rb', line 91384 class VpcEndpoint < Struct.new( :vpc_endpoint_id, :vpc_endpoint_type, :vpc_id, :service_name, :state, :policy_document, :route_table_ids, :subnet_ids, :groups, :ip_address_type, :dns_options, :private_dns_enabled, :requester_managed, :network_interface_ids, :dns_entries, :creation_timestamp, :tags, :owner_id, :last_error, :ipv_4_prefixes, :ipv_6_prefixes, :failure_reason, :service_network_arn, :resource_configuration_arn, :service_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the endpoint.
91384 91385 91386 91387 91388 91389 91390 91391 91392 91393 91394 91395 91396 91397 91398 91399 91400 91401 91402 91403 91404 91405 91406 91407 91408 91409 91410 91411 91412 91413 |
# File 'lib/aws-sdk-ec2/types.rb', line 91384 class VpcEndpoint < Struct.new( :vpc_endpoint_id, :vpc_endpoint_type, :vpc_id, :service_name, :state, :policy_document, :route_table_ids, :subnet_ids, :groups, :ip_address_type, :dns_options, :private_dns_enabled, :requester_managed, :network_interface_ids, :dns_entries, :creation_timestamp, :tags, :owner_id, :last_error, :ipv_4_prefixes, :ipv_6_prefixes, :failure_reason, :service_network_arn, :resource_configuration_arn, :service_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#subnet_ids ⇒ Array<String>
(Interface endpoint) The subnets for the endpoint.
91384 91385 91386 91387 91388 91389 91390 91391 91392 91393 91394 91395 91396 91397 91398 91399 91400 91401 91402 91403 91404 91405 91406 91407 91408 91409 91410 91411 91412 91413 |
# File 'lib/aws-sdk-ec2/types.rb', line 91384 class VpcEndpoint < Struct.new( :vpc_endpoint_id, :vpc_endpoint_type, :vpc_id, :service_name, :state, :policy_document, :route_table_ids, :subnet_ids, :groups, :ip_address_type, :dns_options, :private_dns_enabled, :requester_managed, :network_interface_ids, :dns_entries, :creation_timestamp, :tags, :owner_id, :last_error, :ipv_4_prefixes, :ipv_6_prefixes, :failure_reason, :service_network_arn, :resource_configuration_arn, :service_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags assigned to the endpoint.
91384 91385 91386 91387 91388 91389 91390 91391 91392 91393 91394 91395 91396 91397 91398 91399 91400 91401 91402 91403 91404 91405 91406 91407 91408 91409 91410 91411 91412 91413 |
# File 'lib/aws-sdk-ec2/types.rb', line 91384 class VpcEndpoint < Struct.new( :vpc_endpoint_id, :vpc_endpoint_type, :vpc_id, :service_name, :state, :policy_document, :route_table_ids, :subnet_ids, :groups, :ip_address_type, :dns_options, :private_dns_enabled, :requester_managed, :network_interface_ids, :dns_entries, :creation_timestamp, :tags, :owner_id, :last_error, :ipv_4_prefixes, :ipv_6_prefixes, :failure_reason, :service_network_arn, :resource_configuration_arn, :service_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#vpc_endpoint_id ⇒ String
The ID of the endpoint.
91384 91385 91386 91387 91388 91389 91390 91391 91392 91393 91394 91395 91396 91397 91398 91399 91400 91401 91402 91403 91404 91405 91406 91407 91408 91409 91410 91411 91412 91413 |
# File 'lib/aws-sdk-ec2/types.rb', line 91384 class VpcEndpoint < Struct.new( :vpc_endpoint_id, :vpc_endpoint_type, :vpc_id, :service_name, :state, :policy_document, :route_table_ids, :subnet_ids, :groups, :ip_address_type, :dns_options, :private_dns_enabled, :requester_managed, :network_interface_ids, :dns_entries, :creation_timestamp, :tags, :owner_id, :last_error, :ipv_4_prefixes, :ipv_6_prefixes, :failure_reason, :service_network_arn, :resource_configuration_arn, :service_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#vpc_endpoint_type ⇒ String
The type of endpoint.
91384 91385 91386 91387 91388 91389 91390 91391 91392 91393 91394 91395 91396 91397 91398 91399 91400 91401 91402 91403 91404 91405 91406 91407 91408 91409 91410 91411 91412 91413 |
# File 'lib/aws-sdk-ec2/types.rb', line 91384 class VpcEndpoint < Struct.new( :vpc_endpoint_id, :vpc_endpoint_type, :vpc_id, :service_name, :state, :policy_document, :route_table_ids, :subnet_ids, :groups, :ip_address_type, :dns_options, :private_dns_enabled, :requester_managed, :network_interface_ids, :dns_entries, :creation_timestamp, :tags, :owner_id, :last_error, :ipv_4_prefixes, :ipv_6_prefixes, :failure_reason, :service_network_arn, :resource_configuration_arn, :service_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC to which the endpoint is associated.
91384 91385 91386 91387 91388 91389 91390 91391 91392 91393 91394 91395 91396 91397 91398 91399 91400 91401 91402 91403 91404 91405 91406 91407 91408 91409 91410 91411 91412 91413 |
# File 'lib/aws-sdk-ec2/types.rb', line 91384 class VpcEndpoint < Struct.new( :vpc_endpoint_id, :vpc_endpoint_type, :vpc_id, :service_name, :state, :policy_document, :route_table_ids, :subnet_ids, :groups, :ip_address_type, :dns_options, :private_dns_enabled, :requester_managed, :network_interface_ids, :dns_entries, :creation_timestamp, :tags, :owner_id, :last_error, :ipv_4_prefixes, :ipv_6_prefixes, :failure_reason, :service_network_arn, :resource_configuration_arn, :service_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |