Class: Aws::EC2::Types::VpcEndpoint

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes a VPC endpoint.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timestampTime

The date and time that the endpoint was created.

Returns:

  • (Time)


87943
87944
87945
87946
87947
87948
87949
87950
87951
87952
87953
87954
87955
87956
87957
87958
87959
87960
87961
87962
87963
87964
87965
87966
87967
87968
87969
87970
87971
87972
# File 'lib/aws-sdk-ec2/types.rb', line 87943

class VpcEndpoint < Struct.new(
  :vpc_endpoint_id,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :state,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :groups,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :requester_managed,
  :network_interface_ids,
  :dns_entries,
  :creation_timestamp,
  :tags,
  :owner_id,
  :last_error,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :failure_reason,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region,
  :payer_responsibilities)
  SENSITIVE = []
  include Aws::Structure
end

#dns_entriesArray<Types::DnsEntry>

(Interface endpoint) The DNS entries for the endpoint.

Returns:



87943
87944
87945
87946
87947
87948
87949
87950
87951
87952
87953
87954
87955
87956
87957
87958
87959
87960
87961
87962
87963
87964
87965
87966
87967
87968
87969
87970
87971
87972
# File 'lib/aws-sdk-ec2/types.rb', line 87943

class VpcEndpoint < Struct.new(
  :vpc_endpoint_id,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :state,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :groups,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :requester_managed,
  :network_interface_ids,
  :dns_entries,
  :creation_timestamp,
  :tags,
  :owner_id,
  :last_error,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :failure_reason,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region,
  :payer_responsibilities)
  SENSITIVE = []
  include Aws::Structure
end

#dns_optionsTypes::DnsOptions

The DNS options for the endpoint.

Returns:



87943
87944
87945
87946
87947
87948
87949
87950
87951
87952
87953
87954
87955
87956
87957
87958
87959
87960
87961
87962
87963
87964
87965
87966
87967
87968
87969
87970
87971
87972
# File 'lib/aws-sdk-ec2/types.rb', line 87943

class VpcEndpoint < Struct.new(
  :vpc_endpoint_id,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :state,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :groups,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :requester_managed,
  :network_interface_ids,
  :dns_entries,
  :creation_timestamp,
  :tags,
  :owner_id,
  :last_error,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :failure_reason,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region,
  :payer_responsibilities)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

Reason for the failure.

Returns:

  • (String)


87943
87944
87945
87946
87947
87948
87949
87950
87951
87952
87953
87954
87955
87956
87957
87958
87959
87960
87961
87962
87963
87964
87965
87966
87967
87968
87969
87970
87971
87972
# File 'lib/aws-sdk-ec2/types.rb', line 87943

class VpcEndpoint < Struct.new(
  :vpc_endpoint_id,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :state,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :groups,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :requester_managed,
  :network_interface_ids,
  :dns_entries,
  :creation_timestamp,
  :tags,
  :owner_id,
  :last_error,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :failure_reason,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region,
  :payer_responsibilities)
  SENSITIVE = []
  include Aws::Structure
end

#groupsArray<Types::SecurityGroupIdentifier>

(Interface endpoint) Information about the security groups that are associated with the network interface.

Returns:



87943
87944
87945
87946
87947
87948
87949
87950
87951
87952
87953
87954
87955
87956
87957
87958
87959
87960
87961
87962
87963
87964
87965
87966
87967
87968
87969
87970
87971
87972
# File 'lib/aws-sdk-ec2/types.rb', line 87943

class VpcEndpoint < Struct.new(
  :vpc_endpoint_id,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :state,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :groups,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :requester_managed,
  :network_interface_ids,
  :dns_entries,
  :creation_timestamp,
  :tags,
  :owner_id,
  :last_error,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :failure_reason,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region,
  :payer_responsibilities)
  SENSITIVE = []
  include Aws::Structure
end

#ip_address_typeString

The IP address type for the endpoint.

Returns:

  • (String)


87943
87944
87945
87946
87947
87948
87949
87950
87951
87952
87953
87954
87955
87956
87957
87958
87959
87960
87961
87962
87963
87964
87965
87966
87967
87968
87969
87970
87971
87972
# File 'lib/aws-sdk-ec2/types.rb', line 87943

class VpcEndpoint < Struct.new(
  :vpc_endpoint_id,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :state,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :groups,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :requester_managed,
  :network_interface_ids,
  :dns_entries,
  :creation_timestamp,
  :tags,
  :owner_id,
  :last_error,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :failure_reason,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region,
  :payer_responsibilities)
  SENSITIVE = []
  include Aws::Structure
end

#ipv_4_prefixesArray<Types::SubnetIpPrefixes>

Array of IPv4 prefixes.

Returns:



87943
87944
87945
87946
87947
87948
87949
87950
87951
87952
87953
87954
87955
87956
87957
87958
87959
87960
87961
87962
87963
87964
87965
87966
87967
87968
87969
87970
87971
87972
# File 'lib/aws-sdk-ec2/types.rb', line 87943

class VpcEndpoint < Struct.new(
  :vpc_endpoint_id,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :state,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :groups,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :requester_managed,
  :network_interface_ids,
  :dns_entries,
  :creation_timestamp,
  :tags,
  :owner_id,
  :last_error,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :failure_reason,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region,
  :payer_responsibilities)
  SENSITIVE = []
  include Aws::Structure
end

#ipv_6_prefixesArray<Types::SubnetIpPrefixes>

Array of IPv6 prefixes.

Returns:



87943
87944
87945
87946
87947
87948
87949
87950
87951
87952
87953
87954
87955
87956
87957
87958
87959
87960
87961
87962
87963
87964
87965
87966
87967
87968
87969
87970
87971
87972
# File 'lib/aws-sdk-ec2/types.rb', line 87943

class VpcEndpoint < Struct.new(
  :vpc_endpoint_id,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :state,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :groups,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :requester_managed,
  :network_interface_ids,
  :dns_entries,
  :creation_timestamp,
  :tags,
  :owner_id,
  :last_error,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :failure_reason,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region,
  :payer_responsibilities)
  SENSITIVE = []
  include Aws::Structure
end

#last_errorTypes::LastError

The last error that occurred for endpoint.

Returns:



87943
87944
87945
87946
87947
87948
87949
87950
87951
87952
87953
87954
87955
87956
87957
87958
87959
87960
87961
87962
87963
87964
87965
87966
87967
87968
87969
87970
87971
87972
# File 'lib/aws-sdk-ec2/types.rb', line 87943

class VpcEndpoint < Struct.new(
  :vpc_endpoint_id,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :state,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :groups,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :requester_managed,
  :network_interface_ids,
  :dns_entries,
  :creation_timestamp,
  :tags,
  :owner_id,
  :last_error,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :failure_reason,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region,
  :payer_responsibilities)
  SENSITIVE = []
  include Aws::Structure
end

#network_interface_idsArray<String>

(Interface endpoint) The network interfaces for the endpoint.

Returns:

  • (Array<String>)


87943
87944
87945
87946
87947
87948
87949
87950
87951
87952
87953
87954
87955
87956
87957
87958
87959
87960
87961
87962
87963
87964
87965
87966
87967
87968
87969
87970
87971
87972
# File 'lib/aws-sdk-ec2/types.rb', line 87943

class VpcEndpoint < Struct.new(
  :vpc_endpoint_id,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :state,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :groups,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :requester_managed,
  :network_interface_ids,
  :dns_entries,
  :creation_timestamp,
  :tags,
  :owner_id,
  :last_error,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :failure_reason,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region,
  :payer_responsibilities)
  SENSITIVE = []
  include Aws::Structure
end

#owner_idString

The ID of the Amazon Web Services account that owns the endpoint.

Returns:

  • (String)


87943
87944
87945
87946
87947
87948
87949
87950
87951
87952
87953
87954
87955
87956
87957
87958
87959
87960
87961
87962
87963
87964
87965
87966
87967
87968
87969
87970
87971
87972
# File 'lib/aws-sdk-ec2/types.rb', line 87943

class VpcEndpoint < Struct.new(
  :vpc_endpoint_id,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :state,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :groups,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :requester_managed,
  :network_interface_ids,
  :dns_entries,
  :creation_timestamp,
  :tags,
  :owner_id,
  :last_error,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :failure_reason,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region,
  :payer_responsibilities)
  SENSITIVE = []
  include Aws::Structure
end

#payer_responsibilitiesArray<Types::PayerResponsibilityEntry>

The payer responsibility settings for the endpoint.



87943
87944
87945
87946
87947
87948
87949
87950
87951
87952
87953
87954
87955
87956
87957
87958
87959
87960
87961
87962
87963
87964
87965
87966
87967
87968
87969
87970
87971
87972
# File 'lib/aws-sdk-ec2/types.rb', line 87943

class VpcEndpoint < Struct.new(
  :vpc_endpoint_id,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :state,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :groups,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :requester_managed,
  :network_interface_ids,
  :dns_entries,
  :creation_timestamp,
  :tags,
  :owner_id,
  :last_error,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :failure_reason,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region,
  :payer_responsibilities)
  SENSITIVE = []
  include Aws::Structure
end

#policy_documentString

The policy document associated with the endpoint, if applicable.

Returns:

  • (String)


87943
87944
87945
87946
87947
87948
87949
87950
87951
87952
87953
87954
87955
87956
87957
87958
87959
87960
87961
87962
87963
87964
87965
87966
87967
87968
87969
87970
87971
87972
# File 'lib/aws-sdk-ec2/types.rb', line 87943

class VpcEndpoint < Struct.new(
  :vpc_endpoint_id,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :state,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :groups,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :requester_managed,
  :network_interface_ids,
  :dns_entries,
  :creation_timestamp,
  :tags,
  :owner_id,
  :last_error,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :failure_reason,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region,
  :payer_responsibilities)
  SENSITIVE = []
  include Aws::Structure
end

#private_dns_enabledBoolean

(Interface endpoint) Indicates whether the VPC is associated with a private hosted zone.

Returns:

  • (Boolean)


87943
87944
87945
87946
87947
87948
87949
87950
87951
87952
87953
87954
87955
87956
87957
87958
87959
87960
87961
87962
87963
87964
87965
87966
87967
87968
87969
87970
87971
87972
# File 'lib/aws-sdk-ec2/types.rb', line 87943

class VpcEndpoint < Struct.new(
  :vpc_endpoint_id,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :state,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :groups,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :requester_managed,
  :network_interface_ids,
  :dns_entries,
  :creation_timestamp,
  :tags,
  :owner_id,
  :last_error,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :failure_reason,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region,
  :payer_responsibilities)
  SENSITIVE = []
  include Aws::Structure
end

#requester_managedBoolean

Indicates whether the endpoint is being managed by its service.

Returns:

  • (Boolean)


87943
87944
87945
87946
87947
87948
87949
87950
87951
87952
87953
87954
87955
87956
87957
87958
87959
87960
87961
87962
87963
87964
87965
87966
87967
87968
87969
87970
87971
87972
# File 'lib/aws-sdk-ec2/types.rb', line 87943

class VpcEndpoint < Struct.new(
  :vpc_endpoint_id,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :state,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :groups,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :requester_managed,
  :network_interface_ids,
  :dns_entries,
  :creation_timestamp,
  :tags,
  :owner_id,
  :last_error,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :failure_reason,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region,
  :payer_responsibilities)
  SENSITIVE = []
  include Aws::Structure
end

#resource_configuration_arnString

The Amazon Resource Name (ARN) of the resource configuration.

Returns:

  • (String)


87943
87944
87945
87946
87947
87948
87949
87950
87951
87952
87953
87954
87955
87956
87957
87958
87959
87960
87961
87962
87963
87964
87965
87966
87967
87968
87969
87970
87971
87972
# File 'lib/aws-sdk-ec2/types.rb', line 87943

class VpcEndpoint < Struct.new(
  :vpc_endpoint_id,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :state,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :groups,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :requester_managed,
  :network_interface_ids,
  :dns_entries,
  :creation_timestamp,
  :tags,
  :owner_id,
  :last_error,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :failure_reason,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region,
  :payer_responsibilities)
  SENSITIVE = []
  include Aws::Structure
end

#route_table_idsArray<String>

(Gateway endpoint) The IDs of the route tables associated with the endpoint.

Returns:

  • (Array<String>)


87943
87944
87945
87946
87947
87948
87949
87950
87951
87952
87953
87954
87955
87956
87957
87958
87959
87960
87961
87962
87963
87964
87965
87966
87967
87968
87969
87970
87971
87972
# File 'lib/aws-sdk-ec2/types.rb', line 87943

class VpcEndpoint < Struct.new(
  :vpc_endpoint_id,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :state,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :groups,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :requester_managed,
  :network_interface_ids,
  :dns_entries,
  :creation_timestamp,
  :tags,
  :owner_id,
  :last_error,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :failure_reason,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region,
  :payer_responsibilities)
  SENSITIVE = []
  include Aws::Structure
end

#service_nameString

The name of the service to which the endpoint is associated.

Returns:

  • (String)


87943
87944
87945
87946
87947
87948
87949
87950
87951
87952
87953
87954
87955
87956
87957
87958
87959
87960
87961
87962
87963
87964
87965
87966
87967
87968
87969
87970
87971
87972
# File 'lib/aws-sdk-ec2/types.rb', line 87943

class VpcEndpoint < Struct.new(
  :vpc_endpoint_id,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :state,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :groups,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :requester_managed,
  :network_interface_ids,
  :dns_entries,
  :creation_timestamp,
  :tags,
  :owner_id,
  :last_error,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :failure_reason,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region,
  :payer_responsibilities)
  SENSITIVE = []
  include Aws::Structure
end

#service_network_arnString

The Amazon Resource Name (ARN) of the service network.

Returns:

  • (String)


87943
87944
87945
87946
87947
87948
87949
87950
87951
87952
87953
87954
87955
87956
87957
87958
87959
87960
87961
87962
87963
87964
87965
87966
87967
87968
87969
87970
87971
87972
# File 'lib/aws-sdk-ec2/types.rb', line 87943

class VpcEndpoint < Struct.new(
  :vpc_endpoint_id,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :state,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :groups,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :requester_managed,
  :network_interface_ids,
  :dns_entries,
  :creation_timestamp,
  :tags,
  :owner_id,
  :last_error,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :failure_reason,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region,
  :payer_responsibilities)
  SENSITIVE = []
  include Aws::Structure
end

#service_regionString

The Region where the service is hosted.

Returns:

  • (String)


87943
87944
87945
87946
87947
87948
87949
87950
87951
87952
87953
87954
87955
87956
87957
87958
87959
87960
87961
87962
87963
87964
87965
87966
87967
87968
87969
87970
87971
87972
# File 'lib/aws-sdk-ec2/types.rb', line 87943

class VpcEndpoint < Struct.new(
  :vpc_endpoint_id,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :state,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :groups,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :requester_managed,
  :network_interface_ids,
  :dns_entries,
  :creation_timestamp,
  :tags,
  :owner_id,
  :last_error,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :failure_reason,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region,
  :payer_responsibilities)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of the endpoint.

Returns:

  • (String)


87943
87944
87945
87946
87947
87948
87949
87950
87951
87952
87953
87954
87955
87956
87957
87958
87959
87960
87961
87962
87963
87964
87965
87966
87967
87968
87969
87970
87971
87972
# File 'lib/aws-sdk-ec2/types.rb', line 87943

class VpcEndpoint < Struct.new(
  :vpc_endpoint_id,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :state,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :groups,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :requester_managed,
  :network_interface_ids,
  :dns_entries,
  :creation_timestamp,
  :tags,
  :owner_id,
  :last_error,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :failure_reason,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region,
  :payer_responsibilities)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idsArray<String>

(Interface endpoint) The subnets for the endpoint.

Returns:

  • (Array<String>)


87943
87944
87945
87946
87947
87948
87949
87950
87951
87952
87953
87954
87955
87956
87957
87958
87959
87960
87961
87962
87963
87964
87965
87966
87967
87968
87969
87970
87971
87972
# File 'lib/aws-sdk-ec2/types.rb', line 87943

class VpcEndpoint < Struct.new(
  :vpc_endpoint_id,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :state,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :groups,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :requester_managed,
  :network_interface_ids,
  :dns_entries,
  :creation_timestamp,
  :tags,
  :owner_id,
  :last_error,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :failure_reason,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region,
  :payer_responsibilities)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The tags assigned to the endpoint.

Returns:



87943
87944
87945
87946
87947
87948
87949
87950
87951
87952
87953
87954
87955
87956
87957
87958
87959
87960
87961
87962
87963
87964
87965
87966
87967
87968
87969
87970
87971
87972
# File 'lib/aws-sdk-ec2/types.rb', line 87943

class VpcEndpoint < Struct.new(
  :vpc_endpoint_id,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :state,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :groups,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :requester_managed,
  :network_interface_ids,
  :dns_entries,
  :creation_timestamp,
  :tags,
  :owner_id,
  :last_error,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :failure_reason,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region,
  :payer_responsibilities)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_endpoint_idString

The ID of the endpoint.

Returns:

  • (String)


87943
87944
87945
87946
87947
87948
87949
87950
87951
87952
87953
87954
87955
87956
87957
87958
87959
87960
87961
87962
87963
87964
87965
87966
87967
87968
87969
87970
87971
87972
# File 'lib/aws-sdk-ec2/types.rb', line 87943

class VpcEndpoint < Struct.new(
  :vpc_endpoint_id,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :state,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :groups,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :requester_managed,
  :network_interface_ids,
  :dns_entries,
  :creation_timestamp,
  :tags,
  :owner_id,
  :last_error,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :failure_reason,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region,
  :payer_responsibilities)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_endpoint_typeString

The type of endpoint.

Returns:

  • (String)


87943
87944
87945
87946
87947
87948
87949
87950
87951
87952
87953
87954
87955
87956
87957
87958
87959
87960
87961
87962
87963
87964
87965
87966
87967
87968
87969
87970
87971
87972
# File 'lib/aws-sdk-ec2/types.rb', line 87943

class VpcEndpoint < Struct.new(
  :vpc_endpoint_id,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :state,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :groups,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :requester_managed,
  :network_interface_ids,
  :dns_entries,
  :creation_timestamp,
  :tags,
  :owner_id,
  :last_error,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :failure_reason,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region,
  :payer_responsibilities)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC to which the endpoint is associated.

Returns:

  • (String)


87943
87944
87945
87946
87947
87948
87949
87950
87951
87952
87953
87954
87955
87956
87957
87958
87959
87960
87961
87962
87963
87964
87965
87966
87967
87968
87969
87970
87971
87972
# File 'lib/aws-sdk-ec2/types.rb', line 87943

class VpcEndpoint < Struct.new(
  :vpc_endpoint_id,
  :vpc_endpoint_type,
  :vpc_id,
  :service_name,
  :state,
  :policy_document,
  :route_table_ids,
  :subnet_ids,
  :groups,
  :ip_address_type,
  :dns_options,
  :private_dns_enabled,
  :requester_managed,
  :network_interface_ids,
  :dns_entries,
  :creation_timestamp,
  :tags,
  :owner_id,
  :last_error,
  :ipv_4_prefixes,
  :ipv_6_prefixes,
  :failure_reason,
  :service_network_arn,
  :resource_configuration_arn,
  :service_region,
  :payer_responsibilities)
  SENSITIVE = []
  include Aws::Structure
end