Class: Aws::EC2::Types::VpcEndpointConnection
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::VpcEndpointConnection
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a VPC endpoint connection to a service.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ Time
The date and time that the VPC endpoint was created.
-
#dns_entries ⇒ Array<Types::DnsEntry>
The DNS entries for the VPC endpoint.
-
#gateway_load_balancer_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the Gateway Load Balancers for the service.
-
#ip_address_type ⇒ String
The IP address type for the endpoint.
-
#network_load_balancer_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the network load balancers for the service.
-
#payer_responsibilities ⇒ Array<Types::PayerResponsibilityEntry>
The payer responsibility settings for the endpoint.
-
#service_id ⇒ String
The ID of the service to which the endpoint is connected.
-
#tags ⇒ Array<Types::Tag>
The tags.
-
#vpc_endpoint_connection_id ⇒ String
The ID of the VPC endpoint connection.
-
#vpc_endpoint_id ⇒ String
The ID of the VPC endpoint.
-
#vpc_endpoint_owner ⇒ String
The ID of the Amazon Web Services account that owns the VPC endpoint.
-
#vpc_endpoint_region ⇒ String
The Region of the endpoint.
-
#vpc_endpoint_state ⇒ String
The state of the VPC endpoint.
Instance Attribute Details
#creation_timestamp ⇒ Time
The date and time that the VPC endpoint was created.
91412 91413 91414 91415 91416 91417 91418 91419 91420 91421 91422 91423 91424 91425 91426 91427 91428 |
# File 'lib/aws-sdk-ec2/types.rb', line 91412 class VpcEndpointConnection < Struct.new( :service_id, :vpc_endpoint_id, :vpc_endpoint_owner, :vpc_endpoint_state, :creation_timestamp, :dns_entries, :network_load_balancer_arns, :gateway_load_balancer_arns, :ip_address_type, :vpc_endpoint_connection_id, :tags, :vpc_endpoint_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#dns_entries ⇒ Array<Types::DnsEntry>
The DNS entries for the VPC endpoint.
91412 91413 91414 91415 91416 91417 91418 91419 91420 91421 91422 91423 91424 91425 91426 91427 91428 |
# File 'lib/aws-sdk-ec2/types.rb', line 91412 class VpcEndpointConnection < Struct.new( :service_id, :vpc_endpoint_id, :vpc_endpoint_owner, :vpc_endpoint_state, :creation_timestamp, :dns_entries, :network_load_balancer_arns, :gateway_load_balancer_arns, :ip_address_type, :vpc_endpoint_connection_id, :tags, :vpc_endpoint_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#gateway_load_balancer_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the Gateway Load Balancers for the service.
91412 91413 91414 91415 91416 91417 91418 91419 91420 91421 91422 91423 91424 91425 91426 91427 91428 |
# File 'lib/aws-sdk-ec2/types.rb', line 91412 class VpcEndpointConnection < Struct.new( :service_id, :vpc_endpoint_id, :vpc_endpoint_owner, :vpc_endpoint_state, :creation_timestamp, :dns_entries, :network_load_balancer_arns, :gateway_load_balancer_arns, :ip_address_type, :vpc_endpoint_connection_id, :tags, :vpc_endpoint_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#ip_address_type ⇒ String
The IP address type for the endpoint.
91412 91413 91414 91415 91416 91417 91418 91419 91420 91421 91422 91423 91424 91425 91426 91427 91428 |
# File 'lib/aws-sdk-ec2/types.rb', line 91412 class VpcEndpointConnection < Struct.new( :service_id, :vpc_endpoint_id, :vpc_endpoint_owner, :vpc_endpoint_state, :creation_timestamp, :dns_entries, :network_load_balancer_arns, :gateway_load_balancer_arns, :ip_address_type, :vpc_endpoint_connection_id, :tags, :vpc_endpoint_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#network_load_balancer_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the network load balancers for the service.
91412 91413 91414 91415 91416 91417 91418 91419 91420 91421 91422 91423 91424 91425 91426 91427 91428 |
# File 'lib/aws-sdk-ec2/types.rb', line 91412 class VpcEndpointConnection < Struct.new( :service_id, :vpc_endpoint_id, :vpc_endpoint_owner, :vpc_endpoint_state, :creation_timestamp, :dns_entries, :network_load_balancer_arns, :gateway_load_balancer_arns, :ip_address_type, :vpc_endpoint_connection_id, :tags, :vpc_endpoint_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#payer_responsibilities ⇒ Array<Types::PayerResponsibilityEntry>
The payer responsibility settings for the endpoint.
91412 91413 91414 91415 91416 91417 91418 91419 91420 91421 91422 91423 91424 91425 91426 91427 91428 |
# File 'lib/aws-sdk-ec2/types.rb', line 91412 class VpcEndpointConnection < Struct.new( :service_id, :vpc_endpoint_id, :vpc_endpoint_owner, :vpc_endpoint_state, :creation_timestamp, :dns_entries, :network_load_balancer_arns, :gateway_load_balancer_arns, :ip_address_type, :vpc_endpoint_connection_id, :tags, :vpc_endpoint_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#service_id ⇒ String
The ID of the service to which the endpoint is connected.
91412 91413 91414 91415 91416 91417 91418 91419 91420 91421 91422 91423 91424 91425 91426 91427 91428 |
# File 'lib/aws-sdk-ec2/types.rb', line 91412 class VpcEndpointConnection < Struct.new( :service_id, :vpc_endpoint_id, :vpc_endpoint_owner, :vpc_endpoint_state, :creation_timestamp, :dns_entries, :network_load_balancer_arns, :gateway_load_balancer_arns, :ip_address_type, :vpc_endpoint_connection_id, :tags, :vpc_endpoint_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags.
91412 91413 91414 91415 91416 91417 91418 91419 91420 91421 91422 91423 91424 91425 91426 91427 91428 |
# File 'lib/aws-sdk-ec2/types.rb', line 91412 class VpcEndpointConnection < Struct.new( :service_id, :vpc_endpoint_id, :vpc_endpoint_owner, :vpc_endpoint_state, :creation_timestamp, :dns_entries, :network_load_balancer_arns, :gateway_load_balancer_arns, :ip_address_type, :vpc_endpoint_connection_id, :tags, :vpc_endpoint_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#vpc_endpoint_connection_id ⇒ String
The ID of the VPC endpoint connection.
91412 91413 91414 91415 91416 91417 91418 91419 91420 91421 91422 91423 91424 91425 91426 91427 91428 |
# File 'lib/aws-sdk-ec2/types.rb', line 91412 class VpcEndpointConnection < Struct.new( :service_id, :vpc_endpoint_id, :vpc_endpoint_owner, :vpc_endpoint_state, :creation_timestamp, :dns_entries, :network_load_balancer_arns, :gateway_load_balancer_arns, :ip_address_type, :vpc_endpoint_connection_id, :tags, :vpc_endpoint_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#vpc_endpoint_id ⇒ String
The ID of the VPC endpoint.
91412 91413 91414 91415 91416 91417 91418 91419 91420 91421 91422 91423 91424 91425 91426 91427 91428 |
# File 'lib/aws-sdk-ec2/types.rb', line 91412 class VpcEndpointConnection < Struct.new( :service_id, :vpc_endpoint_id, :vpc_endpoint_owner, :vpc_endpoint_state, :creation_timestamp, :dns_entries, :network_load_balancer_arns, :gateway_load_balancer_arns, :ip_address_type, :vpc_endpoint_connection_id, :tags, :vpc_endpoint_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#vpc_endpoint_owner ⇒ String
The ID of the Amazon Web Services account that owns the VPC endpoint.
91412 91413 91414 91415 91416 91417 91418 91419 91420 91421 91422 91423 91424 91425 91426 91427 91428 |
# File 'lib/aws-sdk-ec2/types.rb', line 91412 class VpcEndpointConnection < Struct.new( :service_id, :vpc_endpoint_id, :vpc_endpoint_owner, :vpc_endpoint_state, :creation_timestamp, :dns_entries, :network_load_balancer_arns, :gateway_load_balancer_arns, :ip_address_type, :vpc_endpoint_connection_id, :tags, :vpc_endpoint_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#vpc_endpoint_region ⇒ String
The Region of the endpoint.
91412 91413 91414 91415 91416 91417 91418 91419 91420 91421 91422 91423 91424 91425 91426 91427 91428 |
# File 'lib/aws-sdk-ec2/types.rb', line 91412 class VpcEndpointConnection < Struct.new( :service_id, :vpc_endpoint_id, :vpc_endpoint_owner, :vpc_endpoint_state, :creation_timestamp, :dns_entries, :network_load_balancer_arns, :gateway_load_balancer_arns, :ip_address_type, :vpc_endpoint_connection_id, :tags, :vpc_endpoint_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |
#vpc_endpoint_state ⇒ String
The state of the VPC endpoint.
91412 91413 91414 91415 91416 91417 91418 91419 91420 91421 91422 91423 91424 91425 91426 91427 91428 |
# File 'lib/aws-sdk-ec2/types.rb', line 91412 class VpcEndpointConnection < Struct.new( :service_id, :vpc_endpoint_id, :vpc_endpoint_owner, :vpc_endpoint_state, :creation_timestamp, :dns_entries, :network_load_balancer_arns, :gateway_load_balancer_arns, :ip_address_type, :vpc_endpoint_connection_id, :tags, :vpc_endpoint_region, :payer_responsibilities) SENSITIVE = [] include Aws::Structure end |