Class: Aws::EC2::Types::VpcIpv6CidrBlockAssociation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes an IPv6 CIDR block associated with a VPC.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#association_idString

The association ID for the IPv6 CIDR block.

Returns:

  • (String)


87016
87017
87018
87019
87020
87021
87022
87023
87024
87025
87026
# File 'lib/aws-sdk-ec2/types.rb', line 87016

class VpcIpv6CidrBlockAssociation < Struct.new(
  :association_id,
  :ipv_6_cidr_block,
  :ipv_6_cidr_block_state,
  :network_border_group,
  :ipv_6_pool,
  :ipv_6_address_attribute,
  :ip_source)
  SENSITIVE = []
  include Aws::Structure
end

#ip_sourceString

The source that allocated the IP address space. ‘byoip` or `amazon` indicates public IP address space allocated by Amazon or space that you have allocated with Bring your own IP (BYOIP). `none` indicates private space.

Returns:

  • (String)


87016
87017
87018
87019
87020
87021
87022
87023
87024
87025
87026
# File 'lib/aws-sdk-ec2/types.rb', line 87016

class VpcIpv6CidrBlockAssociation < Struct.new(
  :association_id,
  :ipv_6_cidr_block,
  :ipv_6_cidr_block_state,
  :network_border_group,
  :ipv_6_pool,
  :ipv_6_address_attribute,
  :ip_source)
  SENSITIVE = []
  include Aws::Structure
end

#ipv_6_address_attributeString

Public IPv6 addresses are those advertised on the internet from Amazon Web Services. Private IP addresses are not and cannot be advertised on the internet from Amazon Web Services.

Returns:

  • (String)


87016
87017
87018
87019
87020
87021
87022
87023
87024
87025
87026
# File 'lib/aws-sdk-ec2/types.rb', line 87016

class VpcIpv6CidrBlockAssociation < Struct.new(
  :association_id,
  :ipv_6_cidr_block,
  :ipv_6_cidr_block_state,
  :network_border_group,
  :ipv_6_pool,
  :ipv_6_address_attribute,
  :ip_source)
  SENSITIVE = []
  include Aws::Structure
end

#ipv_6_cidr_blockString

The IPv6 CIDR block.

Returns:

  • (String)


87016
87017
87018
87019
87020
87021
87022
87023
87024
87025
87026
# File 'lib/aws-sdk-ec2/types.rb', line 87016

class VpcIpv6CidrBlockAssociation < Struct.new(
  :association_id,
  :ipv_6_cidr_block,
  :ipv_6_cidr_block_state,
  :network_border_group,
  :ipv_6_pool,
  :ipv_6_address_attribute,
  :ip_source)
  SENSITIVE = []
  include Aws::Structure
end

#ipv_6_cidr_block_stateTypes::VpcCidrBlockState

Information about the state of the CIDR block.



87016
87017
87018
87019
87020
87021
87022
87023
87024
87025
87026
# File 'lib/aws-sdk-ec2/types.rb', line 87016

class VpcIpv6CidrBlockAssociation < Struct.new(
  :association_id,
  :ipv_6_cidr_block,
  :ipv_6_cidr_block_state,
  :network_border_group,
  :ipv_6_pool,
  :ipv_6_address_attribute,
  :ip_source)
  SENSITIVE = []
  include Aws::Structure
end

#ipv_6_poolString

The ID of the IPv6 address pool from which the IPv6 CIDR block is allocated.

Returns:

  • (String)


87016
87017
87018
87019
87020
87021
87022
87023
87024
87025
87026
# File 'lib/aws-sdk-ec2/types.rb', line 87016

class VpcIpv6CidrBlockAssociation < Struct.new(
  :association_id,
  :ipv_6_cidr_block,
  :ipv_6_cidr_block_state,
  :network_border_group,
  :ipv_6_pool,
  :ipv_6_address_attribute,
  :ip_source)
  SENSITIVE = []
  include Aws::Structure
end

#network_border_groupString

The name of the unique set of Availability Zones, Local Zones, or Wavelength Zones from which Amazon Web Services advertises IP addresses, for example, ‘us-east-1-wl1-bos-wlz-1`.

Returns:

  • (String)


87016
87017
87018
87019
87020
87021
87022
87023
87024
87025
87026
# File 'lib/aws-sdk-ec2/types.rb', line 87016

class VpcIpv6CidrBlockAssociation < Struct.new(
  :association_id,
  :ipv_6_cidr_block,
  :ipv_6_cidr_block_state,
  :network_border_group,
  :ipv_6_pool,
  :ipv_6_address_attribute,
  :ip_source)
  SENSITIVE = []
  include Aws::Structure
end