Class: Aws::EC2::Types::VpcIpv6CidrBlockAssociation
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::VpcIpv6CidrBlockAssociation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes an IPv6 CIDR block associated with a VPC.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#association_id ⇒ String
The association ID for the IPv6 CIDR block.
-
#ip_source ⇒ String
The source that allocated the IP address space.
-
#ipv_6_address_attribute ⇒ String
Public IPv6 addresses are those advertised on the internet from Amazon Web Services.
-
#ipv_6_cidr_block ⇒ String
The IPv6 CIDR block.
-
#ipv_6_cidr_block_state ⇒ Types::VpcCidrBlockState
Information about the state of the CIDR block.
-
#ipv_6_pool ⇒ String
The ID of the IPv6 address pool from which the IPv6 CIDR block is allocated.
-
#network_border_group ⇒ String
The name of the unique set of Availability Zones, Local Zones, or Wavelength Zones from which Amazon Web Services advertises IP addresses, for example, ‘us-east-1-wl1-bos-wlz-1`.
Instance Attribute Details
#association_id ⇒ String
The association ID for the IPv6 CIDR block.
86286 86287 86288 86289 86290 86291 86292 86293 86294 86295 86296 |
# File 'lib/aws-sdk-ec2/types.rb', line 86286 class VpcIpv6CidrBlockAssociation < Struct.new( :association_id, :ipv_6_cidr_block, :ipv_6_cidr_block_state, :network_border_group, :ipv_6_pool, :ipv_6_address_attribute, :ip_source) SENSITIVE = [] include Aws::Structure end |
#ip_source ⇒ String
The source that allocated the IP address space. ‘byoip` or `amazon` indicates public IP address space allocated by Amazon or space that you have allocated with Bring your own IP (BYOIP). `none` indicates private space.
86286 86287 86288 86289 86290 86291 86292 86293 86294 86295 86296 |
# File 'lib/aws-sdk-ec2/types.rb', line 86286 class VpcIpv6CidrBlockAssociation < Struct.new( :association_id, :ipv_6_cidr_block, :ipv_6_cidr_block_state, :network_border_group, :ipv_6_pool, :ipv_6_address_attribute, :ip_source) SENSITIVE = [] include Aws::Structure end |
#ipv_6_address_attribute ⇒ String
Public IPv6 addresses are those advertised on the internet from Amazon Web Services. Private IP addresses are not and cannot be advertised on the internet from Amazon Web Services.
86286 86287 86288 86289 86290 86291 86292 86293 86294 86295 86296 |
# File 'lib/aws-sdk-ec2/types.rb', line 86286 class VpcIpv6CidrBlockAssociation < Struct.new( :association_id, :ipv_6_cidr_block, :ipv_6_cidr_block_state, :network_border_group, :ipv_6_pool, :ipv_6_address_attribute, :ip_source) SENSITIVE = [] include Aws::Structure end |
#ipv_6_cidr_block ⇒ String
The IPv6 CIDR block.
86286 86287 86288 86289 86290 86291 86292 86293 86294 86295 86296 |
# File 'lib/aws-sdk-ec2/types.rb', line 86286 class VpcIpv6CidrBlockAssociation < Struct.new( :association_id, :ipv_6_cidr_block, :ipv_6_cidr_block_state, :network_border_group, :ipv_6_pool, :ipv_6_address_attribute, :ip_source) SENSITIVE = [] include Aws::Structure end |
#ipv_6_cidr_block_state ⇒ Types::VpcCidrBlockState
Information about the state of the CIDR block.
86286 86287 86288 86289 86290 86291 86292 86293 86294 86295 86296 |
# File 'lib/aws-sdk-ec2/types.rb', line 86286 class VpcIpv6CidrBlockAssociation < Struct.new( :association_id, :ipv_6_cidr_block, :ipv_6_cidr_block_state, :network_border_group, :ipv_6_pool, :ipv_6_address_attribute, :ip_source) SENSITIVE = [] include Aws::Structure end |
#ipv_6_pool ⇒ String
The ID of the IPv6 address pool from which the IPv6 CIDR block is allocated.
86286 86287 86288 86289 86290 86291 86292 86293 86294 86295 86296 |
# File 'lib/aws-sdk-ec2/types.rb', line 86286 class VpcIpv6CidrBlockAssociation < Struct.new( :association_id, :ipv_6_cidr_block, :ipv_6_cidr_block_state, :network_border_group, :ipv_6_pool, :ipv_6_address_attribute, :ip_source) SENSITIVE = [] include Aws::Structure end |
#network_border_group ⇒ String
The name of the unique set of Availability Zones, Local Zones, or Wavelength Zones from which Amazon Web Services advertises IP addresses, for example, ‘us-east-1-wl1-bos-wlz-1`.
86286 86287 86288 86289 86290 86291 86292 86293 86294 86295 86296 |
# File 'lib/aws-sdk-ec2/types.rb', line 86286 class VpcIpv6CidrBlockAssociation < Struct.new( :association_id, :ipv_6_cidr_block, :ipv_6_cidr_block_state, :network_border_group, :ipv_6_pool, :ipv_6_address_attribute, :ip_source) SENSITIVE = [] include Aws::Structure end |