Class: Aws::EC2::Types::VpnConcentrator

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes a VPN concentrator.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#stateString

The current state of the VPN concentrator.

Returns:

  • (String)


84960
84961
84962
84963
84964
84965
84966
84967
84968
84969
# File 'lib/aws-sdk-ec2/types.rb', line 84960

class VpnConcentrator < Struct.new(
  :vpn_concentrator_id,
  :state,
  :transit_gateway_id,
  :transit_gateway_attachment_id,
  :type,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Any tags assigned to the VPN concentrator.

Returns:



84960
84961
84962
84963
84964
84965
84966
84967
84968
84969
# File 'lib/aws-sdk-ec2/types.rb', line 84960

class VpnConcentrator < Struct.new(
  :vpn_concentrator_id,
  :state,
  :transit_gateway_id,
  :transit_gateway_attachment_id,
  :type,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_attachment_idString

The ID of the transit gateway attachment for the VPN concentrator.

Returns:

  • (String)


84960
84961
84962
84963
84964
84965
84966
84967
84968
84969
# File 'lib/aws-sdk-ec2/types.rb', line 84960

class VpnConcentrator < Struct.new(
  :vpn_concentrator_id,
  :state,
  :transit_gateway_id,
  :transit_gateway_attachment_id,
  :type,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_idString

The ID of the transit gateway associated with the VPN concentrator.

Returns:

  • (String)


84960
84961
84962
84963
84964
84965
84966
84967
84968
84969
# File 'lib/aws-sdk-ec2/types.rb', line 84960

class VpnConcentrator < Struct.new(
  :vpn_concentrator_id,
  :state,
  :transit_gateway_id,
  :transit_gateway_attachment_id,
  :type,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of VPN concentrator.

Returns:

  • (String)


84960
84961
84962
84963
84964
84965
84966
84967
84968
84969
# File 'lib/aws-sdk-ec2/types.rb', line 84960

class VpnConcentrator < Struct.new(
  :vpn_concentrator_id,
  :state,
  :transit_gateway_id,
  :transit_gateway_attachment_id,
  :type,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#vpn_concentrator_idString

The ID of the VPN concentrator.

Returns:

  • (String)


84960
84961
84962
84963
84964
84965
84966
84967
84968
84969
# File 'lib/aws-sdk-ec2/types.rb', line 84960

class VpnConcentrator < Struct.new(
  :vpn_concentrator_id,
  :state,
  :transit_gateway_id,
  :transit_gateway_attachment_id,
  :type,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end