Class: Aws::EC2::Types::VpnConcentrator
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::VpnConcentrator
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a VPN concentrator.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#state ⇒ String
The current state of the VPN concentrator.
-
#tags ⇒ Array<Types::Tag>
Any tags assigned to the VPN concentrator.
-
#transit_gateway_attachment_id ⇒ String
The ID of the transit gateway attachment for the VPN concentrator.
-
#transit_gateway_id ⇒ String
The ID of the transit gateway associated with the VPN concentrator.
-
#type ⇒ String
The type of VPN concentrator.
-
#vpn_concentrator_id ⇒ String
The ID of the VPN concentrator.
Instance Attribute Details
#state ⇒ String
The current state of the VPN concentrator.
84960 84961 84962 84963 84964 84965 84966 84967 84968 84969 |
# File 'lib/aws-sdk-ec2/types.rb', line 84960 class VpnConcentrator < Struct.new( :vpn_concentrator_id, :state, :transit_gateway_id, :transit_gateway_attachment_id, :type, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Any tags assigned to the VPN concentrator.
84960 84961 84962 84963 84964 84965 84966 84967 84968 84969 |
# File 'lib/aws-sdk-ec2/types.rb', line 84960 class VpnConcentrator < Struct.new( :vpn_concentrator_id, :state, :transit_gateway_id, :transit_gateway_attachment_id, :type, :tags) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_attachment_id ⇒ String
The ID of the transit gateway attachment for the VPN concentrator.
84960 84961 84962 84963 84964 84965 84966 84967 84968 84969 |
# File 'lib/aws-sdk-ec2/types.rb', line 84960 class VpnConcentrator < Struct.new( :vpn_concentrator_id, :state, :transit_gateway_id, :transit_gateway_attachment_id, :type, :tags) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_id ⇒ String
The ID of the transit gateway associated with the VPN concentrator.
84960 84961 84962 84963 84964 84965 84966 84967 84968 84969 |
# File 'lib/aws-sdk-ec2/types.rb', line 84960 class VpnConcentrator < Struct.new( :vpn_concentrator_id, :state, :transit_gateway_id, :transit_gateway_attachment_id, :type, :tags) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of VPN concentrator.
84960 84961 84962 84963 84964 84965 84966 84967 84968 84969 |
# File 'lib/aws-sdk-ec2/types.rb', line 84960 class VpnConcentrator < Struct.new( :vpn_concentrator_id, :state, :transit_gateway_id, :transit_gateway_attachment_id, :type, :tags) SENSITIVE = [] include Aws::Structure end |
#vpn_concentrator_id ⇒ String
The ID of the VPN concentrator.
84960 84961 84962 84963 84964 84965 84966 84967 84968 84969 |
# File 'lib/aws-sdk-ec2/types.rb', line 84960 class VpnConcentrator < Struct.new( :vpn_concentrator_id, :state, :transit_gateway_id, :transit_gateway_attachment_id, :type, :tags) SENSITIVE = [] include Aws::Structure end |