Class: Aws::EC2::Types::VpnConnection
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::VpnConnection
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a VPN connection.
Constant Summary collapse
- SENSITIVE =
[:customer_gateway_configuration]
Instance Attribute Summary collapse
-
#category ⇒ String
The category of the VPN connection.
-
#core_network_arn ⇒ String
The ARN of the core network.
-
#core_network_attachment_arn ⇒ String
The ARN of the core network attachment.
-
#customer_gateway_configuration ⇒ String
The configuration information for the VPN connection’s customer gateway (in the native XML format).
-
#customer_gateway_id ⇒ String
The ID of the customer gateway at your end of the VPN connection.
-
#gateway_association_state ⇒ String
The current state of the gateway association.
-
#options ⇒ Types::VpnConnectionOptions
The VPN connection options.
-
#pre_shared_key_arn ⇒ String
The Amazon Resource Name (ARN) of the Secrets Manager secret storing the pre-shared key(s) for the VPN connection.
-
#routes ⇒ Array<Types::VpnStaticRoute>
The static routes associated with the VPN connection.
-
#state ⇒ String
The current state of the VPN connection.
-
#tags ⇒ Array<Types::Tag>
Any tags assigned to the VPN connection.
-
#transit_gateway_id ⇒ String
The ID of the transit gateway associated with the VPN connection.
-
#type ⇒ String
The type of VPN connection.
-
#vgw_telemetry ⇒ Array<Types::VgwTelemetry>
Information about the VPN tunnel.
-
#vpn_concentrator_id ⇒ String
The ID of the VPN concentrator associated with the VPN connection.
-
#vpn_connection_id ⇒ String
The ID of the VPN connection.
-
#vpn_gateway_id ⇒ String
The ID of the virtual private gateway at the Amazon Web Services side of the VPN connection.
Instance Attribute Details
#category ⇒ String
The category of the VPN connection. A value of ‘VPN` indicates an Amazon Web Services VPN connection. A value of `VPN-Classic` indicates an Amazon Web Services Classic VPN connection.
87904 87905 87906 87907 87908 87909 87910 87911 87912 87913 87914 87915 87916 87917 87918 87919 87920 87921 87922 87923 87924 |
# File 'lib/aws-sdk-ec2/types.rb', line 87904 class VpnConnection < Struct.new( :category, :transit_gateway_id, :vpn_concentrator_id, :core_network_arn, :core_network_attachment_arn, :gateway_association_state, :options, :routes, :tags, :vgw_telemetry, :pre_shared_key_arn, :vpn_connection_id, :state, :customer_gateway_configuration, :type, :customer_gateway_id, :vpn_gateway_id) SENSITIVE = [:customer_gateway_configuration] include Aws::Structure end |
#core_network_arn ⇒ String
The ARN of the core network.
87904 87905 87906 87907 87908 87909 87910 87911 87912 87913 87914 87915 87916 87917 87918 87919 87920 87921 87922 87923 87924 |
# File 'lib/aws-sdk-ec2/types.rb', line 87904 class VpnConnection < Struct.new( :category, :transit_gateway_id, :vpn_concentrator_id, :core_network_arn, :core_network_attachment_arn, :gateway_association_state, :options, :routes, :tags, :vgw_telemetry, :pre_shared_key_arn, :vpn_connection_id, :state, :customer_gateway_configuration, :type, :customer_gateway_id, :vpn_gateway_id) SENSITIVE = [:customer_gateway_configuration] include Aws::Structure end |
#core_network_attachment_arn ⇒ String
The ARN of the core network attachment.
87904 87905 87906 87907 87908 87909 87910 87911 87912 87913 87914 87915 87916 87917 87918 87919 87920 87921 87922 87923 87924 |
# File 'lib/aws-sdk-ec2/types.rb', line 87904 class VpnConnection < Struct.new( :category, :transit_gateway_id, :vpn_concentrator_id, :core_network_arn, :core_network_attachment_arn, :gateway_association_state, :options, :routes, :tags, :vgw_telemetry, :pre_shared_key_arn, :vpn_connection_id, :state, :customer_gateway_configuration, :type, :customer_gateway_id, :vpn_gateway_id) SENSITIVE = [:customer_gateway_configuration] include Aws::Structure end |
#customer_gateway_configuration ⇒ String
The configuration information for the VPN connection’s customer gateway (in the native XML format). This element is always present in the CreateVpnConnection response; however, it’s present in the DescribeVpnConnections response only if the VPN connection is in the ‘pending` or `available` state.
87904 87905 87906 87907 87908 87909 87910 87911 87912 87913 87914 87915 87916 87917 87918 87919 87920 87921 87922 87923 87924 |
# File 'lib/aws-sdk-ec2/types.rb', line 87904 class VpnConnection < Struct.new( :category, :transit_gateway_id, :vpn_concentrator_id, :core_network_arn, :core_network_attachment_arn, :gateway_association_state, :options, :routes, :tags, :vgw_telemetry, :pre_shared_key_arn, :vpn_connection_id, :state, :customer_gateway_configuration, :type, :customer_gateway_id, :vpn_gateway_id) SENSITIVE = [:customer_gateway_configuration] include Aws::Structure end |
#customer_gateway_id ⇒ String
The ID of the customer gateway at your end of the VPN connection.
87904 87905 87906 87907 87908 87909 87910 87911 87912 87913 87914 87915 87916 87917 87918 87919 87920 87921 87922 87923 87924 |
# File 'lib/aws-sdk-ec2/types.rb', line 87904 class VpnConnection < Struct.new( :category, :transit_gateway_id, :vpn_concentrator_id, :core_network_arn, :core_network_attachment_arn, :gateway_association_state, :options, :routes, :tags, :vgw_telemetry, :pre_shared_key_arn, :vpn_connection_id, :state, :customer_gateway_configuration, :type, :customer_gateway_id, :vpn_gateway_id) SENSITIVE = [:customer_gateway_configuration] include Aws::Structure end |
#gateway_association_state ⇒ String
The current state of the gateway association.
87904 87905 87906 87907 87908 87909 87910 87911 87912 87913 87914 87915 87916 87917 87918 87919 87920 87921 87922 87923 87924 |
# File 'lib/aws-sdk-ec2/types.rb', line 87904 class VpnConnection < Struct.new( :category, :transit_gateway_id, :vpn_concentrator_id, :core_network_arn, :core_network_attachment_arn, :gateway_association_state, :options, :routes, :tags, :vgw_telemetry, :pre_shared_key_arn, :vpn_connection_id, :state, :customer_gateway_configuration, :type, :customer_gateway_id, :vpn_gateway_id) SENSITIVE = [:customer_gateway_configuration] include Aws::Structure end |
#options ⇒ Types::VpnConnectionOptions
The VPN connection options.
87904 87905 87906 87907 87908 87909 87910 87911 87912 87913 87914 87915 87916 87917 87918 87919 87920 87921 87922 87923 87924 |
# File 'lib/aws-sdk-ec2/types.rb', line 87904 class VpnConnection < Struct.new( :category, :transit_gateway_id, :vpn_concentrator_id, :core_network_arn, :core_network_attachment_arn, :gateway_association_state, :options, :routes, :tags, :vgw_telemetry, :pre_shared_key_arn, :vpn_connection_id, :state, :customer_gateway_configuration, :type, :customer_gateway_id, :vpn_gateway_id) SENSITIVE = [:customer_gateway_configuration] include Aws::Structure end |
#pre_shared_key_arn ⇒ String
The Amazon Resource Name (ARN) of the Secrets Manager secret storing the pre-shared key(s) for the VPN connection.
87904 87905 87906 87907 87908 87909 87910 87911 87912 87913 87914 87915 87916 87917 87918 87919 87920 87921 87922 87923 87924 |
# File 'lib/aws-sdk-ec2/types.rb', line 87904 class VpnConnection < Struct.new( :category, :transit_gateway_id, :vpn_concentrator_id, :core_network_arn, :core_network_attachment_arn, :gateway_association_state, :options, :routes, :tags, :vgw_telemetry, :pre_shared_key_arn, :vpn_connection_id, :state, :customer_gateway_configuration, :type, :customer_gateway_id, :vpn_gateway_id) SENSITIVE = [:customer_gateway_configuration] include Aws::Structure end |
#routes ⇒ Array<Types::VpnStaticRoute>
The static routes associated with the VPN connection.
87904 87905 87906 87907 87908 87909 87910 87911 87912 87913 87914 87915 87916 87917 87918 87919 87920 87921 87922 87923 87924 |
# File 'lib/aws-sdk-ec2/types.rb', line 87904 class VpnConnection < Struct.new( :category, :transit_gateway_id, :vpn_concentrator_id, :core_network_arn, :core_network_attachment_arn, :gateway_association_state, :options, :routes, :tags, :vgw_telemetry, :pre_shared_key_arn, :vpn_connection_id, :state, :customer_gateway_configuration, :type, :customer_gateway_id, :vpn_gateway_id) SENSITIVE = [:customer_gateway_configuration] include Aws::Structure end |
#state ⇒ String
The current state of the VPN connection.
87904 87905 87906 87907 87908 87909 87910 87911 87912 87913 87914 87915 87916 87917 87918 87919 87920 87921 87922 87923 87924 |
# File 'lib/aws-sdk-ec2/types.rb', line 87904 class VpnConnection < Struct.new( :category, :transit_gateway_id, :vpn_concentrator_id, :core_network_arn, :core_network_attachment_arn, :gateway_association_state, :options, :routes, :tags, :vgw_telemetry, :pre_shared_key_arn, :vpn_connection_id, :state, :customer_gateway_configuration, :type, :customer_gateway_id, :vpn_gateway_id) SENSITIVE = [:customer_gateway_configuration] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Any tags assigned to the VPN connection.
87904 87905 87906 87907 87908 87909 87910 87911 87912 87913 87914 87915 87916 87917 87918 87919 87920 87921 87922 87923 87924 |
# File 'lib/aws-sdk-ec2/types.rb', line 87904 class VpnConnection < Struct.new( :category, :transit_gateway_id, :vpn_concentrator_id, :core_network_arn, :core_network_attachment_arn, :gateway_association_state, :options, :routes, :tags, :vgw_telemetry, :pre_shared_key_arn, :vpn_connection_id, :state, :customer_gateway_configuration, :type, :customer_gateway_id, :vpn_gateway_id) SENSITIVE = [:customer_gateway_configuration] include Aws::Structure end |
#transit_gateway_id ⇒ String
The ID of the transit gateway associated with the VPN connection.
87904 87905 87906 87907 87908 87909 87910 87911 87912 87913 87914 87915 87916 87917 87918 87919 87920 87921 87922 87923 87924 |
# File 'lib/aws-sdk-ec2/types.rb', line 87904 class VpnConnection < Struct.new( :category, :transit_gateway_id, :vpn_concentrator_id, :core_network_arn, :core_network_attachment_arn, :gateway_association_state, :options, :routes, :tags, :vgw_telemetry, :pre_shared_key_arn, :vpn_connection_id, :state, :customer_gateway_configuration, :type, :customer_gateway_id, :vpn_gateway_id) SENSITIVE = [:customer_gateway_configuration] include Aws::Structure end |
#type ⇒ String
The type of VPN connection.
87904 87905 87906 87907 87908 87909 87910 87911 87912 87913 87914 87915 87916 87917 87918 87919 87920 87921 87922 87923 87924 |
# File 'lib/aws-sdk-ec2/types.rb', line 87904 class VpnConnection < Struct.new( :category, :transit_gateway_id, :vpn_concentrator_id, :core_network_arn, :core_network_attachment_arn, :gateway_association_state, :options, :routes, :tags, :vgw_telemetry, :pre_shared_key_arn, :vpn_connection_id, :state, :customer_gateway_configuration, :type, :customer_gateway_id, :vpn_gateway_id) SENSITIVE = [:customer_gateway_configuration] include Aws::Structure end |
#vgw_telemetry ⇒ Array<Types::VgwTelemetry>
Information about the VPN tunnel.
87904 87905 87906 87907 87908 87909 87910 87911 87912 87913 87914 87915 87916 87917 87918 87919 87920 87921 87922 87923 87924 |
# File 'lib/aws-sdk-ec2/types.rb', line 87904 class VpnConnection < Struct.new( :category, :transit_gateway_id, :vpn_concentrator_id, :core_network_arn, :core_network_attachment_arn, :gateway_association_state, :options, :routes, :tags, :vgw_telemetry, :pre_shared_key_arn, :vpn_connection_id, :state, :customer_gateway_configuration, :type, :customer_gateway_id, :vpn_gateway_id) SENSITIVE = [:customer_gateway_configuration] include Aws::Structure end |
#vpn_concentrator_id ⇒ String
The ID of the VPN concentrator associated with the VPN connection.
87904 87905 87906 87907 87908 87909 87910 87911 87912 87913 87914 87915 87916 87917 87918 87919 87920 87921 87922 87923 87924 |
# File 'lib/aws-sdk-ec2/types.rb', line 87904 class VpnConnection < Struct.new( :category, :transit_gateway_id, :vpn_concentrator_id, :core_network_arn, :core_network_attachment_arn, :gateway_association_state, :options, :routes, :tags, :vgw_telemetry, :pre_shared_key_arn, :vpn_connection_id, :state, :customer_gateway_configuration, :type, :customer_gateway_id, :vpn_gateway_id) SENSITIVE = [:customer_gateway_configuration] include Aws::Structure end |
#vpn_connection_id ⇒ String
The ID of the VPN connection.
87904 87905 87906 87907 87908 87909 87910 87911 87912 87913 87914 87915 87916 87917 87918 87919 87920 87921 87922 87923 87924 |
# File 'lib/aws-sdk-ec2/types.rb', line 87904 class VpnConnection < Struct.new( :category, :transit_gateway_id, :vpn_concentrator_id, :core_network_arn, :core_network_attachment_arn, :gateway_association_state, :options, :routes, :tags, :vgw_telemetry, :pre_shared_key_arn, :vpn_connection_id, :state, :customer_gateway_configuration, :type, :customer_gateway_id, :vpn_gateway_id) SENSITIVE = [:customer_gateway_configuration] include Aws::Structure end |
#vpn_gateway_id ⇒ String
The ID of the virtual private gateway at the Amazon Web Services side of the VPN connection.
87904 87905 87906 87907 87908 87909 87910 87911 87912 87913 87914 87915 87916 87917 87918 87919 87920 87921 87922 87923 87924 |
# File 'lib/aws-sdk-ec2/types.rb', line 87904 class VpnConnection < Struct.new( :category, :transit_gateway_id, :vpn_concentrator_id, :core_network_arn, :core_network_attachment_arn, :gateway_association_state, :options, :routes, :tags, :vgw_telemetry, :pre_shared_key_arn, :vpn_connection_id, :state, :customer_gateway_configuration, :type, :customer_gateway_id, :vpn_gateway_id) SENSITIVE = [:customer_gateway_configuration] include Aws::Structure end |