Class: Aws::EC2::Types::VpnConnectionDeviceType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

List of customer gateway devices that have a sample configuration file available for use. You can also see the list of device types with sample configuration files available under Your customer gateway device in the Amazon Web Services Site-to-Site VPN User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#platformString

Customer gateway device platform.

Returns:

  • (String)


90337
90338
90339
90340
90341
90342
90343
90344
# File 'lib/aws-sdk-ec2/types.rb', line 90337

class VpnConnectionDeviceType < Struct.new(
  :vpn_connection_device_type_id,
  :vendor,
  :platform,
  :software)
  SENSITIVE = []
  include Aws::Structure
end

#softwareString

Customer gateway device software version.

Returns:

  • (String)


90337
90338
90339
90340
90341
90342
90343
90344
# File 'lib/aws-sdk-ec2/types.rb', line 90337

class VpnConnectionDeviceType < Struct.new(
  :vpn_connection_device_type_id,
  :vendor,
  :platform,
  :software)
  SENSITIVE = []
  include Aws::Structure
end

#vendorString

Customer gateway device vendor.

Returns:

  • (String)


90337
90338
90339
90340
90341
90342
90343
90344
# File 'lib/aws-sdk-ec2/types.rb', line 90337

class VpnConnectionDeviceType < Struct.new(
  :vpn_connection_device_type_id,
  :vendor,
  :platform,
  :software)
  SENSITIVE = []
  include Aws::Structure
end

#vpn_connection_device_type_idString

Customer gateway device identifier.

Returns:

  • (String)


90337
90338
90339
90340
90341
90342
90343
90344
# File 'lib/aws-sdk-ec2/types.rb', line 90337

class VpnConnectionDeviceType < Struct.new(
  :vpn_connection_device_type_id,
  :vendor,
  :platform,
  :software)
  SENSITIVE = []
  include Aws::Structure
end