Class: Aws::EC2::Types::VpnConnectionDeviceType
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::VpnConnectionDeviceType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
List of customer gateway devices that have a sample configuration file available for use. You can also see the list of device types with sample configuration files available under Your customer gateway device in the Amazon Web Services Site-to-Site VPN User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#platform ⇒ String
Customer gateway device platform.
-
#software ⇒ String
Customer gateway device software version.
-
#vendor ⇒ String
Customer gateway device vendor.
-
#vpn_connection_device_type_id ⇒ String
Customer gateway device identifier.
Instance Attribute Details
#platform ⇒ String
Customer gateway device platform.
88070 88071 88072 88073 88074 88075 88076 88077 |
# File 'lib/aws-sdk-ec2/types.rb', line 88070 class VpnConnectionDeviceType < Struct.new( :vpn_connection_device_type_id, :vendor, :platform, :software) SENSITIVE = [] include Aws::Structure end |
#software ⇒ String
Customer gateway device software version.
88070 88071 88072 88073 88074 88075 88076 88077 |
# File 'lib/aws-sdk-ec2/types.rb', line 88070 class VpnConnectionDeviceType < Struct.new( :vpn_connection_device_type_id, :vendor, :platform, :software) SENSITIVE = [] include Aws::Structure end |
#vendor ⇒ String
Customer gateway device vendor.
88070 88071 88072 88073 88074 88075 88076 88077 |
# File 'lib/aws-sdk-ec2/types.rb', line 88070 class VpnConnectionDeviceType < Struct.new( :vpn_connection_device_type_id, :vendor, :platform, :software) SENSITIVE = [] include Aws::Structure end |
#vpn_connection_device_type_id ⇒ String
Customer gateway device identifier.
88070 88071 88072 88073 88074 88075 88076 88077 |
# File 'lib/aws-sdk-ec2/types.rb', line 88070 class VpnConnectionDeviceType < Struct.new( :vpn_connection_device_type_id, :vendor, :platform, :software) SENSITIVE = [] include Aws::Structure end |