Class: Aws::EC2::Types::VpnConnectionOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Describes VPN connection options.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enable_accelerationBoolean

Indicates whether acceleration is enabled for the VPN connection.

Returns:

  • (Boolean)


90407
90408
90409
90410
90411
90412
90413
90414
90415
90416
90417
90418
90419
90420
90421
# File 'lib/aws-sdk-ec2/types.rb', line 90407

class VpnConnectionOptions < Struct.new(
  :enable_acceleration,
  :static_routes_only,
  :local_ipv_4_network_cidr,
  :remote_ipv_4_network_cidr,
  :local_ipv_6_network_cidr,
  :remote_ipv_6_network_cidr,
  :outside_ip_address_type,
  :transport_transit_gateway_attachment_id,
  :tunnel_inside_ip_version,
  :tunnel_options,
  :tunnel_bandwidth)
  SENSITIVE = []
  include Aws::Structure
end

#local_ipv_4_network_cidrString

The IPv4 CIDR on the customer gateway (on-premises) side of the VPN connection.

Returns:

  • (String)


90407
90408
90409
90410
90411
90412
90413
90414
90415
90416
90417
90418
90419
90420
90421
# File 'lib/aws-sdk-ec2/types.rb', line 90407

class VpnConnectionOptions < Struct.new(
  :enable_acceleration,
  :static_routes_only,
  :local_ipv_4_network_cidr,
  :remote_ipv_4_network_cidr,
  :local_ipv_6_network_cidr,
  :remote_ipv_6_network_cidr,
  :outside_ip_address_type,
  :transport_transit_gateway_attachment_id,
  :tunnel_inside_ip_version,
  :tunnel_options,
  :tunnel_bandwidth)
  SENSITIVE = []
  include Aws::Structure
end

#local_ipv_6_network_cidrString

The IPv6 CIDR on the customer gateway (on-premises) side of the VPN connection.

Returns:

  • (String)


90407
90408
90409
90410
90411
90412
90413
90414
90415
90416
90417
90418
90419
90420
90421
# File 'lib/aws-sdk-ec2/types.rb', line 90407

class VpnConnectionOptions < Struct.new(
  :enable_acceleration,
  :static_routes_only,
  :local_ipv_4_network_cidr,
  :remote_ipv_4_network_cidr,
  :local_ipv_6_network_cidr,
  :remote_ipv_6_network_cidr,
  :outside_ip_address_type,
  :transport_transit_gateway_attachment_id,
  :tunnel_inside_ip_version,
  :tunnel_options,
  :tunnel_bandwidth)
  SENSITIVE = []
  include Aws::Structure
end

#outside_ip_address_typeString

The type of IPv4 address assigned to the outside interface of the customer gateway.

Valid values: PrivateIpv4 | PublicIpv4 | Ipv6

Default: PublicIpv4

Returns:

  • (String)


90407
90408
90409
90410
90411
90412
90413
90414
90415
90416
90417
90418
90419
90420
90421
# File 'lib/aws-sdk-ec2/types.rb', line 90407

class VpnConnectionOptions < Struct.new(
  :enable_acceleration,
  :static_routes_only,
  :local_ipv_4_network_cidr,
  :remote_ipv_4_network_cidr,
  :local_ipv_6_network_cidr,
  :remote_ipv_6_network_cidr,
  :outside_ip_address_type,
  :transport_transit_gateway_attachment_id,
  :tunnel_inside_ip_version,
  :tunnel_options,
  :tunnel_bandwidth)
  SENSITIVE = []
  include Aws::Structure
end

#remote_ipv_4_network_cidrString

The IPv4 CIDR on the Amazon Web Services side of the VPN connection.

Returns:

  • (String)


90407
90408
90409
90410
90411
90412
90413
90414
90415
90416
90417
90418
90419
90420
90421
# File 'lib/aws-sdk-ec2/types.rb', line 90407

class VpnConnectionOptions < Struct.new(
  :enable_acceleration,
  :static_routes_only,
  :local_ipv_4_network_cidr,
  :remote_ipv_4_network_cidr,
  :local_ipv_6_network_cidr,
  :remote_ipv_6_network_cidr,
  :outside_ip_address_type,
  :transport_transit_gateway_attachment_id,
  :tunnel_inside_ip_version,
  :tunnel_options,
  :tunnel_bandwidth)
  SENSITIVE = []
  include Aws::Structure
end

#remote_ipv_6_network_cidrString

The IPv6 CIDR on the Amazon Web Services side of the VPN connection.

Returns:

  • (String)


90407
90408
90409
90410
90411
90412
90413
90414
90415
90416
90417
90418
90419
90420
90421
# File 'lib/aws-sdk-ec2/types.rb', line 90407

class VpnConnectionOptions < Struct.new(
  :enable_acceleration,
  :static_routes_only,
  :local_ipv_4_network_cidr,
  :remote_ipv_4_network_cidr,
  :local_ipv_6_network_cidr,
  :remote_ipv_6_network_cidr,
  :outside_ip_address_type,
  :transport_transit_gateway_attachment_id,
  :tunnel_inside_ip_version,
  :tunnel_options,
  :tunnel_bandwidth)
  SENSITIVE = []
  include Aws::Structure
end

#static_routes_onlyBoolean

Indicates whether the VPN connection uses static routes only. Static routes must be used for devices that don't support BGP.

Returns:

  • (Boolean)


90407
90408
90409
90410
90411
90412
90413
90414
90415
90416
90417
90418
90419
90420
90421
# File 'lib/aws-sdk-ec2/types.rb', line 90407

class VpnConnectionOptions < Struct.new(
  :enable_acceleration,
  :static_routes_only,
  :local_ipv_4_network_cidr,
  :remote_ipv_4_network_cidr,
  :local_ipv_6_network_cidr,
  :remote_ipv_6_network_cidr,
  :outside_ip_address_type,
  :transport_transit_gateway_attachment_id,
  :tunnel_inside_ip_version,
  :tunnel_options,
  :tunnel_bandwidth)
  SENSITIVE = []
  include Aws::Structure
end

#transport_transit_gateway_attachment_idString

The transit gateway attachment ID in use for the VPN tunnel.

Returns:

  • (String)


90407
90408
90409
90410
90411
90412
90413
90414
90415
90416
90417
90418
90419
90420
90421
# File 'lib/aws-sdk-ec2/types.rb', line 90407

class VpnConnectionOptions < Struct.new(
  :enable_acceleration,
  :static_routes_only,
  :local_ipv_4_network_cidr,
  :remote_ipv_4_network_cidr,
  :local_ipv_6_network_cidr,
  :remote_ipv_6_network_cidr,
  :outside_ip_address_type,
  :transport_transit_gateway_attachment_id,
  :tunnel_inside_ip_version,
  :tunnel_options,
  :tunnel_bandwidth)
  SENSITIVE = []
  include Aws::Structure
end

#tunnel_bandwidthString

The configured bandwidth for the VPN tunnel. Represents the current throughput capacity setting for the tunnel connection. standard tunnel bandwidth supports up to 1.25 Gbps per tunnel while large supports up to 5 Gbps per tunnel. If no tunnel bandwidth was specified for the connection, standard is used as the default value.

Returns:

  • (String)


90407
90408
90409
90410
90411
90412
90413
90414
90415
90416
90417
90418
90419
90420
90421
# File 'lib/aws-sdk-ec2/types.rb', line 90407

class VpnConnectionOptions < Struct.new(
  :enable_acceleration,
  :static_routes_only,
  :local_ipv_4_network_cidr,
  :remote_ipv_4_network_cidr,
  :local_ipv_6_network_cidr,
  :remote_ipv_6_network_cidr,
  :outside_ip_address_type,
  :transport_transit_gateway_attachment_id,
  :tunnel_inside_ip_version,
  :tunnel_options,
  :tunnel_bandwidth)
  SENSITIVE = []
  include Aws::Structure
end

#tunnel_inside_ip_versionString

Indicates whether the VPN tunnels process IPv4 or IPv6 traffic.

Returns:

  • (String)


90407
90408
90409
90410
90411
90412
90413
90414
90415
90416
90417
90418
90419
90420
90421
# File 'lib/aws-sdk-ec2/types.rb', line 90407

class VpnConnectionOptions < Struct.new(
  :enable_acceleration,
  :static_routes_only,
  :local_ipv_4_network_cidr,
  :remote_ipv_4_network_cidr,
  :local_ipv_6_network_cidr,
  :remote_ipv_6_network_cidr,
  :outside_ip_address_type,
  :transport_transit_gateway_attachment_id,
  :tunnel_inside_ip_version,
  :tunnel_options,
  :tunnel_bandwidth)
  SENSITIVE = []
  include Aws::Structure
end

#tunnel_optionsArray<Types::TunnelOption>

Indicates the VPN tunnel options.

Returns:



90407
90408
90409
90410
90411
90412
90413
90414
90415
90416
90417
90418
90419
90420
90421
# File 'lib/aws-sdk-ec2/types.rb', line 90407

class VpnConnectionOptions < Struct.new(
  :enable_acceleration,
  :static_routes_only,
  :local_ipv_4_network_cidr,
  :remote_ipv_4_network_cidr,
  :local_ipv_6_network_cidr,
  :remote_ipv_6_network_cidr,
  :outside_ip_address_type,
  :transport_transit_gateway_attachment_id,
  :tunnel_inside_ip_version,
  :tunnel_options,
  :tunnel_bandwidth)
  SENSITIVE = []
  include Aws::Structure
end