Class: Aws::EC2::Types::VpnConnectionOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::VpnConnectionOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes VPN connection options.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enable_acceleration ⇒ Boolean
Indicates whether acceleration is enabled for the VPN connection.
-
#local_ipv_4_network_cidr ⇒ String
The IPv4 CIDR on the customer gateway (on-premises) side of the VPN connection.
-
#local_ipv_6_network_cidr ⇒ String
The IPv6 CIDR on the customer gateway (on-premises) side of the VPN connection.
-
#outside_ip_address_type ⇒ String
The type of IPv4 address assigned to the outside interface of the customer gateway.
-
#remote_ipv_4_network_cidr ⇒ String
The IPv4 CIDR on the Amazon Web Services side of the VPN connection.
-
#remote_ipv_6_network_cidr ⇒ String
The IPv6 CIDR on the Amazon Web Services side of the VPN connection.
-
#static_routes_only ⇒ Boolean
Indicates whether the VPN connection uses static routes only.
-
#transport_transit_gateway_attachment_id ⇒ String
The transit gateway attachment ID in use for the VPN tunnel.
-
#tunnel_bandwidth ⇒ String
The configured bandwidth for the VPN tunnel.
-
#tunnel_inside_ip_version ⇒ String
Indicates whether the VPN tunnels process IPv4 or IPv6 traffic.
-
#tunnel_options ⇒ Array<Types::TunnelOption>
Indicates the VPN tunnel options.
Instance Attribute Details
#enable_acceleration ⇒ Boolean
Indicates whether acceleration is enabled for the VPN connection.
88682 88683 88684 88685 88686 88687 88688 88689 88690 88691 88692 88693 88694 88695 88696 |
# File 'lib/aws-sdk-ec2/types.rb', line 88682 class VpnConnectionOptions < Struct.new( :enable_acceleration, :static_routes_only, :local_ipv_4_network_cidr, :remote_ipv_4_network_cidr, :local_ipv_6_network_cidr, :remote_ipv_6_network_cidr, :outside_ip_address_type, :transport_transit_gateway_attachment_id, :tunnel_inside_ip_version, :tunnel_options, :tunnel_bandwidth) SENSITIVE = [] include Aws::Structure end |
#local_ipv_4_network_cidr ⇒ String
The IPv4 CIDR on the customer gateway (on-premises) side of the VPN connection.
88682 88683 88684 88685 88686 88687 88688 88689 88690 88691 88692 88693 88694 88695 88696 |
# File 'lib/aws-sdk-ec2/types.rb', line 88682 class VpnConnectionOptions < Struct.new( :enable_acceleration, :static_routes_only, :local_ipv_4_network_cidr, :remote_ipv_4_network_cidr, :local_ipv_6_network_cidr, :remote_ipv_6_network_cidr, :outside_ip_address_type, :transport_transit_gateway_attachment_id, :tunnel_inside_ip_version, :tunnel_options, :tunnel_bandwidth) SENSITIVE = [] include Aws::Structure end |
#local_ipv_6_network_cidr ⇒ String
The IPv6 CIDR on the customer gateway (on-premises) side of the VPN connection.
88682 88683 88684 88685 88686 88687 88688 88689 88690 88691 88692 88693 88694 88695 88696 |
# File 'lib/aws-sdk-ec2/types.rb', line 88682 class VpnConnectionOptions < Struct.new( :enable_acceleration, :static_routes_only, :local_ipv_4_network_cidr, :remote_ipv_4_network_cidr, :local_ipv_6_network_cidr, :remote_ipv_6_network_cidr, :outside_ip_address_type, :transport_transit_gateway_attachment_id, :tunnel_inside_ip_version, :tunnel_options, :tunnel_bandwidth) SENSITIVE = [] include Aws::Structure end |
#outside_ip_address_type ⇒ String
The type of IPv4 address assigned to the outside interface of the customer gateway.
Valid values: PrivateIpv4 | PublicIpv4 | Ipv6
Default: PublicIpv4
88682 88683 88684 88685 88686 88687 88688 88689 88690 88691 88692 88693 88694 88695 88696 |
# File 'lib/aws-sdk-ec2/types.rb', line 88682 class VpnConnectionOptions < Struct.new( :enable_acceleration, :static_routes_only, :local_ipv_4_network_cidr, :remote_ipv_4_network_cidr, :local_ipv_6_network_cidr, :remote_ipv_6_network_cidr, :outside_ip_address_type, :transport_transit_gateway_attachment_id, :tunnel_inside_ip_version, :tunnel_options, :tunnel_bandwidth) SENSITIVE = [] include Aws::Structure end |
#remote_ipv_4_network_cidr ⇒ String
The IPv4 CIDR on the Amazon Web Services side of the VPN connection.
88682 88683 88684 88685 88686 88687 88688 88689 88690 88691 88692 88693 88694 88695 88696 |
# File 'lib/aws-sdk-ec2/types.rb', line 88682 class VpnConnectionOptions < Struct.new( :enable_acceleration, :static_routes_only, :local_ipv_4_network_cidr, :remote_ipv_4_network_cidr, :local_ipv_6_network_cidr, :remote_ipv_6_network_cidr, :outside_ip_address_type, :transport_transit_gateway_attachment_id, :tunnel_inside_ip_version, :tunnel_options, :tunnel_bandwidth) SENSITIVE = [] include Aws::Structure end |
#remote_ipv_6_network_cidr ⇒ String
The IPv6 CIDR on the Amazon Web Services side of the VPN connection.
88682 88683 88684 88685 88686 88687 88688 88689 88690 88691 88692 88693 88694 88695 88696 |
# File 'lib/aws-sdk-ec2/types.rb', line 88682 class VpnConnectionOptions < Struct.new( :enable_acceleration, :static_routes_only, :local_ipv_4_network_cidr, :remote_ipv_4_network_cidr, :local_ipv_6_network_cidr, :remote_ipv_6_network_cidr, :outside_ip_address_type, :transport_transit_gateway_attachment_id, :tunnel_inside_ip_version, :tunnel_options, :tunnel_bandwidth) SENSITIVE = [] include Aws::Structure end |
#static_routes_only ⇒ Boolean
Indicates whether the VPN connection uses static routes only. Static routes must be used for devices that don't support BGP.
88682 88683 88684 88685 88686 88687 88688 88689 88690 88691 88692 88693 88694 88695 88696 |
# File 'lib/aws-sdk-ec2/types.rb', line 88682 class VpnConnectionOptions < Struct.new( :enable_acceleration, :static_routes_only, :local_ipv_4_network_cidr, :remote_ipv_4_network_cidr, :local_ipv_6_network_cidr, :remote_ipv_6_network_cidr, :outside_ip_address_type, :transport_transit_gateway_attachment_id, :tunnel_inside_ip_version, :tunnel_options, :tunnel_bandwidth) SENSITIVE = [] include Aws::Structure end |
#transport_transit_gateway_attachment_id ⇒ String
The transit gateway attachment ID in use for the VPN tunnel.
88682 88683 88684 88685 88686 88687 88688 88689 88690 88691 88692 88693 88694 88695 88696 |
# File 'lib/aws-sdk-ec2/types.rb', line 88682 class VpnConnectionOptions < Struct.new( :enable_acceleration, :static_routes_only, :local_ipv_4_network_cidr, :remote_ipv_4_network_cidr, :local_ipv_6_network_cidr, :remote_ipv_6_network_cidr, :outside_ip_address_type, :transport_transit_gateway_attachment_id, :tunnel_inside_ip_version, :tunnel_options, :tunnel_bandwidth) SENSITIVE = [] include Aws::Structure end |
#tunnel_bandwidth ⇒ String
The configured bandwidth for the VPN tunnel. Represents the current
throughput capacity setting for the tunnel connection. standard
tunnel bandwidth supports up to 1.25 Gbps per tunnel while large
supports up to 5 Gbps per tunnel. If no tunnel bandwidth was
specified for the connection, standard is used as the default
value.
88682 88683 88684 88685 88686 88687 88688 88689 88690 88691 88692 88693 88694 88695 88696 |
# File 'lib/aws-sdk-ec2/types.rb', line 88682 class VpnConnectionOptions < Struct.new( :enable_acceleration, :static_routes_only, :local_ipv_4_network_cidr, :remote_ipv_4_network_cidr, :local_ipv_6_network_cidr, :remote_ipv_6_network_cidr, :outside_ip_address_type, :transport_transit_gateway_attachment_id, :tunnel_inside_ip_version, :tunnel_options, :tunnel_bandwidth) SENSITIVE = [] include Aws::Structure end |
#tunnel_inside_ip_version ⇒ String
Indicates whether the VPN tunnels process IPv4 or IPv6 traffic.
88682 88683 88684 88685 88686 88687 88688 88689 88690 88691 88692 88693 88694 88695 88696 |
# File 'lib/aws-sdk-ec2/types.rb', line 88682 class VpnConnectionOptions < Struct.new( :enable_acceleration, :static_routes_only, :local_ipv_4_network_cidr, :remote_ipv_4_network_cidr, :local_ipv_6_network_cidr, :remote_ipv_6_network_cidr, :outside_ip_address_type, :transport_transit_gateway_attachment_id, :tunnel_inside_ip_version, :tunnel_options, :tunnel_bandwidth) SENSITIVE = [] include Aws::Structure end |
#tunnel_options ⇒ Array<Types::TunnelOption>
Indicates the VPN tunnel options.
88682 88683 88684 88685 88686 88687 88688 88689 88690 88691 88692 88693 88694 88695 88696 |
# File 'lib/aws-sdk-ec2/types.rb', line 88682 class VpnConnectionOptions < Struct.new( :enable_acceleration, :static_routes_only, :local_ipv_4_network_cidr, :remote_ipv_4_network_cidr, :local_ipv_6_network_cidr, :remote_ipv_6_network_cidr, :outside_ip_address_type, :transport_transit_gateway_attachment_id, :tunnel_inside_ip_version, :tunnel_options, :tunnel_bandwidth) SENSITIVE = [] include Aws::Structure end |