Class: Aws::EC2::Types::VpnConnectionOptionsSpecification
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::VpnConnectionOptionsSpecification
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes VPN connection options.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enable_acceleration ⇒ Boolean
Indicate whether to enable acceleration for the VPN connection.
-
#local_ipv_4_network_cidr ⇒ String
The IPv4 CIDR on the customer gateway (on-premises) side of the VPN connection.
-
#local_ipv_6_network_cidr ⇒ String
The IPv6 CIDR on the customer gateway (on-premises) side of the VPN connection.
-
#outside_ip_address_type ⇒ String
The type of IP address assigned to the outside interface of the customer gateway device.
-
#remote_ipv_4_network_cidr ⇒ String
The IPv4 CIDR on the Amazon Web Services side of the VPN connection.
-
#remote_ipv_6_network_cidr ⇒ String
The IPv6 CIDR on the Amazon Web Services side of the VPN connection.
-
#static_routes_only ⇒ Boolean
Indicate whether the VPN connection uses static routes only.
-
#transport_transit_gateway_attachment_id ⇒ String
The transit gateway attachment ID to use for the VPN tunnel.
-
#tunnel_bandwidth ⇒ String
The desired bandwidth specification for the VPN tunnel, used when creating or modifying VPN connection options to set the tunnel’s throughput capacity.
-
#tunnel_inside_ip_version ⇒ String
Indicate whether the VPN tunnels process IPv4 or IPv6 traffic.
-
#tunnel_options ⇒ Array<Types::VpnTunnelOptionsSpecification>
The tunnel options for the VPN connection.
Instance Attribute Details
#enable_acceleration ⇒ Boolean
Indicate whether to enable acceleration for the VPN connection.
Default: ‘false`
85265 85266 85267 85268 85269 85270 85271 85272 85273 85274 85275 85276 85277 85278 85279 |
# File 'lib/aws-sdk-ec2/types.rb', line 85265 class VpnConnectionOptionsSpecification < Struct.new( :enable_acceleration, :tunnel_inside_ip_version, :tunnel_options, :local_ipv_4_network_cidr, :remote_ipv_4_network_cidr, :local_ipv_6_network_cidr, :remote_ipv_6_network_cidr, :outside_ip_address_type, :transport_transit_gateway_attachment_id, :tunnel_bandwidth, :static_routes_only) SENSITIVE = [] include Aws::Structure end |
#local_ipv_4_network_cidr ⇒ String
The IPv4 CIDR on the customer gateway (on-premises) side of the VPN connection.
Default: ‘0.0.0.0/0`
85265 85266 85267 85268 85269 85270 85271 85272 85273 85274 85275 85276 85277 85278 85279 |
# File 'lib/aws-sdk-ec2/types.rb', line 85265 class VpnConnectionOptionsSpecification < Struct.new( :enable_acceleration, :tunnel_inside_ip_version, :tunnel_options, :local_ipv_4_network_cidr, :remote_ipv_4_network_cidr, :local_ipv_6_network_cidr, :remote_ipv_6_network_cidr, :outside_ip_address_type, :transport_transit_gateway_attachment_id, :tunnel_bandwidth, :static_routes_only) SENSITIVE = [] include Aws::Structure end |
#local_ipv_6_network_cidr ⇒ String
The IPv6 CIDR on the customer gateway (on-premises) side of the VPN connection.
Default: ‘::/0`
85265 85266 85267 85268 85269 85270 85271 85272 85273 85274 85275 85276 85277 85278 85279 |
# File 'lib/aws-sdk-ec2/types.rb', line 85265 class VpnConnectionOptionsSpecification < Struct.new( :enable_acceleration, :tunnel_inside_ip_version, :tunnel_options, :local_ipv_4_network_cidr, :remote_ipv_4_network_cidr, :local_ipv_6_network_cidr, :remote_ipv_6_network_cidr, :outside_ip_address_type, :transport_transit_gateway_attachment_id, :tunnel_bandwidth, :static_routes_only) SENSITIVE = [] include Aws::Structure end |
#outside_ip_address_type ⇒ String
The type of IP address assigned to the outside interface of the customer gateway device.
Valid values: ‘PrivateIpv4` | `PublicIpv4` | `Ipv6`
Default: ‘PublicIpv4`
85265 85266 85267 85268 85269 85270 85271 85272 85273 85274 85275 85276 85277 85278 85279 |
# File 'lib/aws-sdk-ec2/types.rb', line 85265 class VpnConnectionOptionsSpecification < Struct.new( :enable_acceleration, :tunnel_inside_ip_version, :tunnel_options, :local_ipv_4_network_cidr, :remote_ipv_4_network_cidr, :local_ipv_6_network_cidr, :remote_ipv_6_network_cidr, :outside_ip_address_type, :transport_transit_gateway_attachment_id, :tunnel_bandwidth, :static_routes_only) SENSITIVE = [] include Aws::Structure end |
#remote_ipv_4_network_cidr ⇒ String
The IPv4 CIDR on the Amazon Web Services side of the VPN connection.
Default: ‘0.0.0.0/0`
85265 85266 85267 85268 85269 85270 85271 85272 85273 85274 85275 85276 85277 85278 85279 |
# File 'lib/aws-sdk-ec2/types.rb', line 85265 class VpnConnectionOptionsSpecification < Struct.new( :enable_acceleration, :tunnel_inside_ip_version, :tunnel_options, :local_ipv_4_network_cidr, :remote_ipv_4_network_cidr, :local_ipv_6_network_cidr, :remote_ipv_6_network_cidr, :outside_ip_address_type, :transport_transit_gateway_attachment_id, :tunnel_bandwidth, :static_routes_only) SENSITIVE = [] include Aws::Structure end |
#remote_ipv_6_network_cidr ⇒ String
The IPv6 CIDR on the Amazon Web Services side of the VPN connection.
Default: ‘::/0`
85265 85266 85267 85268 85269 85270 85271 85272 85273 85274 85275 85276 85277 85278 85279 |
# File 'lib/aws-sdk-ec2/types.rb', line 85265 class VpnConnectionOptionsSpecification < Struct.new( :enable_acceleration, :tunnel_inside_ip_version, :tunnel_options, :local_ipv_4_network_cidr, :remote_ipv_4_network_cidr, :local_ipv_6_network_cidr, :remote_ipv_6_network_cidr, :outside_ip_address_type, :transport_transit_gateway_attachment_id, :tunnel_bandwidth, :static_routes_only) SENSITIVE = [] include Aws::Structure end |
#static_routes_only ⇒ Boolean
Indicate whether the VPN connection uses static routes only. If you are creating a VPN connection for a device that does not support BGP, you must specify ‘true`. Use CreateVpnConnectionRoute to create a static route.
Default: ‘false`
85265 85266 85267 85268 85269 85270 85271 85272 85273 85274 85275 85276 85277 85278 85279 |
# File 'lib/aws-sdk-ec2/types.rb', line 85265 class VpnConnectionOptionsSpecification < Struct.new( :enable_acceleration, :tunnel_inside_ip_version, :tunnel_options, :local_ipv_4_network_cidr, :remote_ipv_4_network_cidr, :local_ipv_6_network_cidr, :remote_ipv_6_network_cidr, :outside_ip_address_type, :transport_transit_gateway_attachment_id, :tunnel_bandwidth, :static_routes_only) SENSITIVE = [] include Aws::Structure end |
#transport_transit_gateway_attachment_id ⇒ String
The transit gateway attachment ID to use for the VPN tunnel.
Required if ‘OutsideIpAddressType` is set to `PrivateIpv4`.
85265 85266 85267 85268 85269 85270 85271 85272 85273 85274 85275 85276 85277 85278 85279 |
# File 'lib/aws-sdk-ec2/types.rb', line 85265 class VpnConnectionOptionsSpecification < Struct.new( :enable_acceleration, :tunnel_inside_ip_version, :tunnel_options, :local_ipv_4_network_cidr, :remote_ipv_4_network_cidr, :local_ipv_6_network_cidr, :remote_ipv_6_network_cidr, :outside_ip_address_type, :transport_transit_gateway_attachment_id, :tunnel_bandwidth, :static_routes_only) SENSITIVE = [] include Aws::Structure end |
#tunnel_bandwidth ⇒ String
The desired bandwidth specification for the VPN tunnel, used when creating or modifying VPN connection options to set the tunnel’s throughput capacity. ‘standard` supports up to 1.25 Gbps per tunnel, while `large` supports up to 5 Gbps per tunnel. The default value is `standard`. Existing VPN connections without a bandwidth setting will automatically default to `standard`.
85265 85266 85267 85268 85269 85270 85271 85272 85273 85274 85275 85276 85277 85278 85279 |
# File 'lib/aws-sdk-ec2/types.rb', line 85265 class VpnConnectionOptionsSpecification < Struct.new( :enable_acceleration, :tunnel_inside_ip_version, :tunnel_options, :local_ipv_4_network_cidr, :remote_ipv_4_network_cidr, :local_ipv_6_network_cidr, :remote_ipv_6_network_cidr, :outside_ip_address_type, :transport_transit_gateway_attachment_id, :tunnel_bandwidth, :static_routes_only) SENSITIVE = [] include Aws::Structure end |
#tunnel_inside_ip_version ⇒ String
Indicate whether the VPN tunnels process IPv4 or IPv6 traffic.
Default: ‘ipv4`
85265 85266 85267 85268 85269 85270 85271 85272 85273 85274 85275 85276 85277 85278 85279 |
# File 'lib/aws-sdk-ec2/types.rb', line 85265 class VpnConnectionOptionsSpecification < Struct.new( :enable_acceleration, :tunnel_inside_ip_version, :tunnel_options, :local_ipv_4_network_cidr, :remote_ipv_4_network_cidr, :local_ipv_6_network_cidr, :remote_ipv_6_network_cidr, :outside_ip_address_type, :transport_transit_gateway_attachment_id, :tunnel_bandwidth, :static_routes_only) SENSITIVE = [] include Aws::Structure end |
#tunnel_options ⇒ Array<Types::VpnTunnelOptionsSpecification>
The tunnel options for the VPN connection.
85265 85266 85267 85268 85269 85270 85271 85272 85273 85274 85275 85276 85277 85278 85279 |
# File 'lib/aws-sdk-ec2/types.rb', line 85265 class VpnConnectionOptionsSpecification < Struct.new( :enable_acceleration, :tunnel_inside_ip_version, :tunnel_options, :local_ipv_4_network_cidr, :remote_ipv_4_network_cidr, :local_ipv_6_network_cidr, :remote_ipv_6_network_cidr, :outside_ip_address_type, :transport_transit_gateway_attachment_id, :tunnel_bandwidth, :static_routes_only) SENSITIVE = [] include Aws::Structure end |