Class: Aws::EC2::Types::VpnGateway
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::VpnGateway
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Describes a virtual private gateway.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#amazon_side_asn ⇒ Integer
The private Autonomous System Number (ASN) for the Amazon side of a BGP session.
-
#availability_zone ⇒ String
The Availability Zone where the virtual private gateway was created, if applicable.
-
#state ⇒ String
The current state of the virtual private gateway.
-
#tags ⇒ Array<Types::Tag>
Any tags assigned to the virtual private gateway.
-
#type ⇒ String
The type of VPN connection the virtual private gateway supports.
-
#vpc_attachments ⇒ Array<Types::VpcAttachment>
Any VPCs attached to the virtual private gateway.
-
#vpn_gateway_id ⇒ String
The ID of the virtual private gateway.
Instance Attribute Details
#amazon_side_asn ⇒ Integer
The private Autonomous System Number (ASN) for the Amazon side of a BGP session.
88676 88677 88678 88679 88680 88681 88682 88683 88684 88685 88686 |
# File 'lib/aws-sdk-ec2/types.rb', line 88676 class VpnGateway < Struct.new( :amazon_side_asn, :tags, :vpn_gateway_id, :state, :type, :availability_zone, :vpc_attachments) SENSITIVE = [] include Aws::Structure end |
#availability_zone ⇒ String
The Availability Zone where the virtual private gateway was created, if applicable. This field may be empty or not returned.
88676 88677 88678 88679 88680 88681 88682 88683 88684 88685 88686 |
# File 'lib/aws-sdk-ec2/types.rb', line 88676 class VpnGateway < Struct.new( :amazon_side_asn, :tags, :vpn_gateway_id, :state, :type, :availability_zone, :vpc_attachments) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the virtual private gateway.
88676 88677 88678 88679 88680 88681 88682 88683 88684 88685 88686 |
# File 'lib/aws-sdk-ec2/types.rb', line 88676 class VpnGateway < Struct.new( :amazon_side_asn, :tags, :vpn_gateway_id, :state, :type, :availability_zone, :vpc_attachments) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Any tags assigned to the virtual private gateway.
88676 88677 88678 88679 88680 88681 88682 88683 88684 88685 88686 |
# File 'lib/aws-sdk-ec2/types.rb', line 88676 class VpnGateway < Struct.new( :amazon_side_asn, :tags, :vpn_gateway_id, :state, :type, :availability_zone, :vpc_attachments) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of VPN connection the virtual private gateway supports.
88676 88677 88678 88679 88680 88681 88682 88683 88684 88685 88686 |
# File 'lib/aws-sdk-ec2/types.rb', line 88676 class VpnGateway < Struct.new( :amazon_side_asn, :tags, :vpn_gateway_id, :state, :type, :availability_zone, :vpc_attachments) SENSITIVE = [] include Aws::Structure end |
#vpc_attachments ⇒ Array<Types::VpcAttachment>
Any VPCs attached to the virtual private gateway.
88676 88677 88678 88679 88680 88681 88682 88683 88684 88685 88686 |
# File 'lib/aws-sdk-ec2/types.rb', line 88676 class VpnGateway < Struct.new( :amazon_side_asn, :tags, :vpn_gateway_id, :state, :type, :availability_zone, :vpc_attachments) SENSITIVE = [] include Aws::Structure end |
#vpn_gateway_id ⇒ String
The ID of the virtual private gateway.
88676 88677 88678 88679 88680 88681 88682 88683 88684 88685 88686 |
# File 'lib/aws-sdk-ec2/types.rb', line 88676 class VpnGateway < Struct.new( :amazon_side_asn, :tags, :vpn_gateway_id, :state, :type, :availability_zone, :vpc_attachments) SENSITIVE = [] include Aws::Structure end |