Class: Aws::EC2::Types::VpnTunnelOptionsSpecification

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

The tunnel options for a single VPN tunnel.

Constant Summary collapse

SENSITIVE =
[:pre_shared_key]

Instance Attribute Summary collapse

Instance Attribute Details

#dpd_timeout_actionString

The action to take after DPD timeout occurs. Specify ‘restart` to restart the IKE initiation. Specify `clear` to end the IKE session.

Valid Values: ‘clear` | `none` | `restart`

Default: ‘clear`

Returns:

  • (String)


88411
88412
88413
88414
88415
88416
88417
88418
88419
88420
88421
88422
88423
88424
88425
88426
88427
88428
88429
88430
88431
88432
88433
88434
# File 'lib/aws-sdk-ec2/types.rb', line 88411

class VpnTunnelOptionsSpecification < Struct.new(
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#dpd_timeout_secondsInteger

The number of seconds after which a DPD timeout occurs.

Constraints: A value greater than or equal to 30.

Default: ‘30`

Returns:

  • (Integer)


88411
88412
88413
88414
88415
88416
88417
88418
88419
88420
88421
88422
88423
88424
88425
88426
88427
88428
88429
88430
88431
88432
88433
88434
# File 'lib/aws-sdk-ec2/types.rb', line 88411

class VpnTunnelOptionsSpecification < Struct.new(
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#enable_tunnel_lifecycle_controlBoolean

Turn on or off tunnel endpoint lifecycle control feature.

Returns:

  • (Boolean)


88411
88412
88413
88414
88415
88416
88417
88418
88419
88420
88421
88422
88423
88424
88425
88426
88427
88428
88429
88430
88431
88432
88433
88434
# File 'lib/aws-sdk-ec2/types.rb', line 88411

class VpnTunnelOptionsSpecification < Struct.new(
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#ike_versionsArray<Types::IKEVersionsRequestListValue>

The IKE versions that are permitted for the VPN tunnel.

Valid values: ‘ikev1` | `ikev2`



88411
88412
88413
88414
88415
88416
88417
88418
88419
88420
88421
88422
88423
88424
88425
88426
88427
88428
88429
88430
88431
88432
88433
88434
# File 'lib/aws-sdk-ec2/types.rb', line 88411

class VpnTunnelOptionsSpecification < Struct.new(
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#log_optionsTypes::VpnTunnelLogOptionsSpecification

Options for logging VPN tunnel activity.



88411
88412
88413
88414
88415
88416
88417
88418
88419
88420
88421
88422
88423
88424
88425
88426
88427
88428
88429
88430
88431
88432
88433
88434
# File 'lib/aws-sdk-ec2/types.rb', line 88411

class VpnTunnelOptionsSpecification < Struct.new(
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#phase_1_dh_group_numbersArray<Types::Phase1DHGroupNumbersRequestListValue>

One or more Diffie-Hellman group numbers that are permitted for the VPN tunnel for phase 1 IKE negotiations.

Valid values: ‘2` | `14` | `15` | `16` | `17` | `18` | `19` | `20` | `21` | `22` | `23` | `24`



88411
88412
88413
88414
88415
88416
88417
88418
88419
88420
88421
88422
88423
88424
88425
88426
88427
88428
88429
88430
88431
88432
88433
88434
# File 'lib/aws-sdk-ec2/types.rb', line 88411

class VpnTunnelOptionsSpecification < Struct.new(
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#phase_1_encryption_algorithmsArray<Types::Phase1EncryptionAlgorithmsRequestListValue>

One or more encryption algorithms that are permitted for the VPN tunnel for phase 1 IKE negotiations.

Valid values: ‘AES128` | `AES256` | `AES128-GCM-16` | `AES256-GCM-16`



88411
88412
88413
88414
88415
88416
88417
88418
88419
88420
88421
88422
88423
88424
88425
88426
88427
88428
88429
88430
88431
88432
88433
88434
# File 'lib/aws-sdk-ec2/types.rb', line 88411

class VpnTunnelOptionsSpecification < Struct.new(
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#phase_1_integrity_algorithmsArray<Types::Phase1IntegrityAlgorithmsRequestListValue>

One or more integrity algorithms that are permitted for the VPN tunnel for phase 1 IKE negotiations.

Valid values: ‘SHA1` | `SHA2-256` | `SHA2-384` | `SHA2-512`



88411
88412
88413
88414
88415
88416
88417
88418
88419
88420
88421
88422
88423
88424
88425
88426
88427
88428
88429
88430
88431
88432
88433
88434
# File 'lib/aws-sdk-ec2/types.rb', line 88411

class VpnTunnelOptionsSpecification < Struct.new(
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#phase_1_lifetime_secondsInteger

The lifetime for phase 1 of the IKE negotiation, in seconds.

Constraints: A value between 900 and 28,800.

Default: ‘28800`

Returns:

  • (Integer)


88411
88412
88413
88414
88415
88416
88417
88418
88419
88420
88421
88422
88423
88424
88425
88426
88427
88428
88429
88430
88431
88432
88433
88434
# File 'lib/aws-sdk-ec2/types.rb', line 88411

class VpnTunnelOptionsSpecification < Struct.new(
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#phase_2_dh_group_numbersArray<Types::Phase2DHGroupNumbersRequestListValue>

One or more Diffie-Hellman group numbers that are permitted for the VPN tunnel for phase 2 IKE negotiations.

Valid values: ‘2` | `5` | `14` | `15` | `16` | `17` | `18` | `19` | `20` | `21` | `22` | `23` | `24`



88411
88412
88413
88414
88415
88416
88417
88418
88419
88420
88421
88422
88423
88424
88425
88426
88427
88428
88429
88430
88431
88432
88433
88434
# File 'lib/aws-sdk-ec2/types.rb', line 88411

class VpnTunnelOptionsSpecification < Struct.new(
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#phase_2_encryption_algorithmsArray<Types::Phase2EncryptionAlgorithmsRequestListValue>

One or more encryption algorithms that are permitted for the VPN tunnel for phase 2 IKE negotiations.

Valid values: ‘AES128` | `AES256` | `AES128-GCM-16` | `AES256-GCM-16`



88411
88412
88413
88414
88415
88416
88417
88418
88419
88420
88421
88422
88423
88424
88425
88426
88427
88428
88429
88430
88431
88432
88433
88434
# File 'lib/aws-sdk-ec2/types.rb', line 88411

class VpnTunnelOptionsSpecification < Struct.new(
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#phase_2_integrity_algorithmsArray<Types::Phase2IntegrityAlgorithmsRequestListValue>

One or more integrity algorithms that are permitted for the VPN tunnel for phase 2 IKE negotiations.

Valid values: ‘SHA1` | `SHA2-256` | `SHA2-384` | `SHA2-512`



88411
88412
88413
88414
88415
88416
88417
88418
88419
88420
88421
88422
88423
88424
88425
88426
88427
88428
88429
88430
88431
88432
88433
88434
# File 'lib/aws-sdk-ec2/types.rb', line 88411

class VpnTunnelOptionsSpecification < Struct.new(
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#phase_2_lifetime_secondsInteger

The lifetime for phase 2 of the IKE negotiation, in seconds.

Constraints: A value between 900 and 3,600. The value must be less than the value for ‘Phase1LifetimeSeconds`.

Default: ‘3600`

Returns:

  • (Integer)


88411
88412
88413
88414
88415
88416
88417
88418
88419
88420
88421
88422
88423
88424
88425
88426
88427
88428
88429
88430
88431
88432
88433
88434
# File 'lib/aws-sdk-ec2/types.rb', line 88411

class VpnTunnelOptionsSpecification < Struct.new(
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#pre_shared_keyString

The pre-shared key (PSK) to establish initial authentication between the virtual private gateway and customer gateway.

Constraints: Allowed characters are alphanumeric characters, periods (.), and underscores (_). Must be between 8 and 64 characters in length and cannot start with zero (0).

Returns:

  • (String)


88411
88412
88413
88414
88415
88416
88417
88418
88419
88420
88421
88422
88423
88424
88425
88426
88427
88428
88429
88430
88431
88432
88433
88434
# File 'lib/aws-sdk-ec2/types.rb', line 88411

class VpnTunnelOptionsSpecification < Struct.new(
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#rekey_fuzz_percentageInteger

The percentage of the rekey window (determined by ‘RekeyMarginTimeSeconds`) during which the rekey time is randomly selected.

Constraints: A value between 0 and 100.

Default: ‘100`

Returns:

  • (Integer)


88411
88412
88413
88414
88415
88416
88417
88418
88419
88420
88421
88422
88423
88424
88425
88426
88427
88428
88429
88430
88431
88432
88433
88434
# File 'lib/aws-sdk-ec2/types.rb', line 88411

class VpnTunnelOptionsSpecification < Struct.new(
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#rekey_margin_time_secondsInteger

The margin time, in seconds, before the phase 2 lifetime expires, during which the Amazon Web Services side of the VPN connection performs an IKE rekey. The exact time of the rekey is randomly selected based on the value for ‘RekeyFuzzPercentage`.

Constraints: A value between 60 and half of ‘Phase2LifetimeSeconds`.

Default: ‘270`

Returns:

  • (Integer)


88411
88412
88413
88414
88415
88416
88417
88418
88419
88420
88421
88422
88423
88424
88425
88426
88427
88428
88429
88430
88431
88432
88433
88434
# File 'lib/aws-sdk-ec2/types.rb', line 88411

class VpnTunnelOptionsSpecification < Struct.new(
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#replay_window_sizeInteger

The number of packets in an IKE replay window.

Constraints: A value between 64 and 2048.

Default: ‘1024`

Returns:

  • (Integer)


88411
88412
88413
88414
88415
88416
88417
88418
88419
88420
88421
88422
88423
88424
88425
88426
88427
88428
88429
88430
88431
88432
88433
88434
# File 'lib/aws-sdk-ec2/types.rb', line 88411

class VpnTunnelOptionsSpecification < Struct.new(
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#startup_actionString

The action to take when the establishing the tunnel for the VPN connection. By default, your customer gateway device must initiate the IKE negotiation and bring up the tunnel. Specify ‘start` for Amazon Web Services to initiate the IKE negotiation.

Valid Values: ‘add` | `start`

Default: ‘add`

Returns:

  • (String)


88411
88412
88413
88414
88415
88416
88417
88418
88419
88420
88421
88422
88423
88424
88425
88426
88427
88428
88429
88430
88431
88432
88433
88434
# File 'lib/aws-sdk-ec2/types.rb', line 88411

class VpnTunnelOptionsSpecification < Struct.new(
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#tunnel_inside_cidrString

The range of inside IPv4 addresses for the tunnel. Any specified CIDR blocks must be unique across all VPN connections that use the same virtual private gateway.

Constraints: A size /30 CIDR block from the ‘169.254.0.0/16` range. The following CIDR blocks are reserved and cannot be used:

  • ‘169.254.0.0/30`

  • ‘169.254.1.0/30`

  • ‘169.254.2.0/30`

  • ‘169.254.3.0/30`

  • ‘169.254.4.0/30`

  • ‘169.254.5.0/30`

  • ‘169.254.169.252/30`

Returns:

  • (String)


88411
88412
88413
88414
88415
88416
88417
88418
88419
88420
88421
88422
88423
88424
88425
88426
88427
88428
88429
88430
88431
88432
88433
88434
# File 'lib/aws-sdk-ec2/types.rb', line 88411

class VpnTunnelOptionsSpecification < Struct.new(
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end

#tunnel_inside_ipv_6_cidrString

The range of inside IPv6 addresses for the tunnel. Any specified CIDR blocks must be unique across all VPN connections that use the same transit gateway.

Constraints: A size /126 CIDR block from the local ‘fd00::/8` range.

Returns:

  • (String)


88411
88412
88413
88414
88415
88416
88417
88418
88419
88420
88421
88422
88423
88424
88425
88426
88427
88428
88429
88430
88431
88432
88433
88434
# File 'lib/aws-sdk-ec2/types.rb', line 88411

class VpnTunnelOptionsSpecification < Struct.new(
  :tunnel_inside_cidr,
  :tunnel_inside_ipv_6_cidr,
  :pre_shared_key,
  :phase_1_lifetime_seconds,
  :phase_2_lifetime_seconds,
  :rekey_margin_time_seconds,
  :rekey_fuzz_percentage,
  :replay_window_size,
  :dpd_timeout_seconds,
  :dpd_timeout_action,
  :phase_1_encryption_algorithms,
  :phase_2_encryption_algorithms,
  :phase_1_integrity_algorithms,
  :phase_2_integrity_algorithms,
  :phase_1_dh_group_numbers,
  :phase_2_dh_group_numbers,
  :ike_versions,
  :startup_action,
  :log_options,
  :enable_tunnel_lifecycle_control)
  SENSITIVE = [:pre_shared_key]
  include Aws::Structure
end