Class: Aws::EC2::Types::WithdrawByoipCidrRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::WithdrawByoipCidrRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cidr ⇒ String
The address range, in CIDR notation.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#cidr ⇒ String
The address range, in CIDR notation.
89108 89109 89110 89111 89112 89113 |
# File 'lib/aws-sdk-ec2/types.rb', line 89108 class WithdrawByoipCidrRequest < Struct.new( :cidr, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
89108 89109 89110 89111 89112 89113 |
# File 'lib/aws-sdk-ec2/types.rb', line 89108 class WithdrawByoipCidrRequest < Struct.new( :cidr, :dry_run) SENSITIVE = [] include Aws::Structure end |