Class: Aws::EC2::Types::WithdrawByoipCidrRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ec2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cidrString

The address range, in CIDR notation.

Returns:

  • (String)


88566
88567
88568
88569
88570
88571
# File 'lib/aws-sdk-ec2/types.rb', line 88566

class WithdrawByoipCidrRequest < Struct.new(
  :cidr,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

Returns:

  • (Boolean)


88566
88567
88568
88569
88570
88571
# File 'lib/aws-sdk-ec2/types.rb', line 88566

class WithdrawByoipCidrRequest < Struct.new(
  :cidr,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end