Class: Aws::EC2::Types::WithdrawByoipCidrRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EC2::Types::WithdrawByoipCidrRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ec2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cidr ⇒ String
The address range, in CIDR notation.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
Instance Attribute Details
#cidr ⇒ String
The address range, in CIDR notation.
87814 87815 87816 87817 87818 87819 |
# File 'lib/aws-sdk-ec2/types.rb', line 87814 class WithdrawByoipCidrRequest < Struct.new( :cidr, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.
87814 87815 87816 87817 87818 87819 |
# File 'lib/aws-sdk-ec2/types.rb', line 87814 class WithdrawByoipCidrRequest < Struct.new( :cidr, :dry_run) SENSITIVE = [] include Aws::Structure end |