Class: Aws::EC2::Waiters::ConversionTaskDeleted

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-ec2/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ ConversionTaskDeleted

Returns a new instance of ConversionTaskDeleted.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 40
  • :delay (Integer) — default: 15
  • :before_attempt (Proc)
  • :before_wait (Proc)


252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/aws-sdk-ec2/waiters.rb', line 252

def initialize(options)
  @client = options.fetch(:client)
  @waiter = Aws::Waiters::Waiter.new({
    max_attempts: 40,
    delay: 15,
    poller: Aws::Waiters::Poller.new(
      operation_name: :describe_conversion_tasks,
      acceptors: [{
        "expected" => "deleted",
        "matcher" => "pathAll",
        "state" => "success",
        "argument" => "conversion_tasks[].state"
      }]
    )
  }.merge(options))
end

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



276
277
278
# File 'lib/aws-sdk-ec2/waiters.rb', line 276

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeConversionTasksResult

Returns a response object which responds to the following methods:

Options Hash (params):

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

  • :conversion_task_ids (Array<String>)

    The conversion task IDs.

Returns:



271
272
273
# File 'lib/aws-sdk-ec2/waiters.rb', line 271

def wait(params = {})
  @waiter.wait(client: @client, params: params)
end