Class: Aws::EC2::Waiters::CustomerGatewayAvailable
- Inherits:
-
Object
- Object
- Aws::EC2::Waiters::CustomerGatewayAvailable
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-ec2/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ CustomerGatewayAvailable
constructor
A new instance of CustomerGatewayAvailable.
-
#wait(params = {}) ⇒ Types::DescribeCustomerGatewaysResult
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ CustomerGatewayAvailable
Returns a new instance of CustomerGatewayAvailable.
292 293 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 292
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
330 331 332 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 330 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeCustomerGatewaysResult
Returns a response object which responds to the following methods:
- #customer_gateways => Array<Types::CustomerGateway>
325 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 325
def wait: (
|