Class: Aws::EC2::Waiters::CustomerGatewayAvailable
- Inherits:
-
Object
- Object
- Aws::EC2::Waiters::CustomerGatewayAvailable
- Defined in:
- lib/aws-sdk-ec2/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ CustomerGatewayAvailable
constructor
A new instance of CustomerGatewayAvailable.
-
#wait(params = {}) ⇒ Types::DescribeCustomerGatewaysResult
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ CustomerGatewayAvailable
Returns a new instance of CustomerGatewayAvailable.
288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 288 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 40, delay: 15, poller: Aws::Waiters::Poller.new( operation_name: :describe_customer_gateways, acceptors: [ { "expected" => "available", "matcher" => "pathAll", "state" => "success", "argument" => "customer_gateways[].state" }, { "expected" => "deleted", "matcher" => "pathAny", "state" => "failure", "argument" => "customer_gateways[].state" }, { "expected" => "deleting", "matcher" => "pathAny", "state" => "failure", "argument" => "customer_gateways[].state" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
326 327 328 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 326 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeCustomerGatewaysResult
Returns a response object which responds to the following methods:
-
#customer_gateways => Array<Types::CustomerGateway>
321 322 323 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 321 def wait(params = {}) @waiter.wait(client: @client, params: params) end |