Class: Aws::EC2::Waiters::ImageUsageReportAvailable
- Inherits:
-
Object
- Object
- Aws::EC2::Waiters::ImageUsageReportAvailable
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-ec2/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ImageUsageReportAvailable
constructor
A new instance of ImageUsageReportAvailable.
-
#wait(params = {}) ⇒ Types::DescribeImageUsageReportsResult
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ImageUsageReportAvailable
Returns a new instance of ImageUsageReportAvailable.
501 502 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 501
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
533 534 535 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 533 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeImageUsageReportsResult
Returns a response object which responds to the following methods:
- #next_token => String
- #image_usage_reports => Array<Types::ImageUsageReport>
528 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 528
def wait: (
|