Class: Aws::EC2::Waiters::PasswordDataAvailable
- Inherits:
-
Object
- Object
- Aws::EC2::Waiters::PasswordDataAvailable
- Defined in:
- lib/aws-sdk-ec2/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ PasswordDataAvailable
constructor
A new instance of PasswordDataAvailable.
-
#wait(params = {}) ⇒ Types::GetPasswordDataResult
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ PasswordDataAvailable
Returns a new instance of PasswordDataAvailable.
1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1021 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 40, delay: 15, poller: Aws::Waiters::Poller.new( operation_name: :get_password_data, acceptors: [{ "state" => "success", "matcher" => "path", "argument" => "length(password_data) > `0`", "expected" => true }] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1045 1046 1047 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1045 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetPasswordDataResult
Returns a response object which responds to the following methods:
-
#instance_id => String
-
#timestamp => Time
-
#password_data => String
1040 1041 1042 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1040 def wait(params = {}) @waiter.wait(client: @client, params: params) end |