Class: Aws::EC2::Waiters::SecondaryNetworkCreateComplete
- Inherits:
-
Object
- Object
- Aws::EC2::Waiters::SecondaryNetworkCreateComplete
- Defined in:
- lib/aws-sdk-ec2/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ SecondaryNetworkCreateComplete
constructor
A new instance of SecondaryNetworkCreateComplete.
-
#wait(params = {}) ⇒ Types::DescribeSecondaryNetworksResult
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ SecondaryNetworkCreateComplete
Returns a new instance of SecondaryNetworkCreateComplete.
1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1061 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 30, delay: 10, poller: Aws::Waiters::Poller.new( operation_name: :describe_secondary_networks, acceptors: [ { "expected" => "create-complete", "matcher" => "pathAll", "state" => "success", "argument" => "secondary_networks[].state" }, { "expected" => "create-failed", "matcher" => "pathAny", "state" => "failure", "argument" => "secondary_networks[].state" }, { "matcher" => "error", "expected" => "InvalidSecondaryNetworkId.NotFound", "state" => "retry" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1098 1099 1100 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1098 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeSecondaryNetworksResult
Returns a response object which responds to the following methods:
-
#secondary_networks => Array<Types::SecondaryNetwork>
-
#next_token => String
1093 1094 1095 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1093 def wait(params = {}) @waiter.wait(client: @client, params: params) end |