Class: Aws::EC2::Waiters::SecondaryNetworkDeleteComplete
- Inherits:
-
Object
- Object
- Aws::EC2::Waiters::SecondaryNetworkDeleteComplete
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-ec2/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ SecondaryNetworkDeleteComplete
constructor
A new instance of SecondaryNetworkDeleteComplete.
-
#wait(params = {}) ⇒ Types::DescribeSecondaryNetworksResult
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ SecondaryNetworkDeleteComplete
Returns a new instance of SecondaryNetworkDeleteComplete.
1110 1111 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1110
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1142 1143 1144 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1142 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeSecondaryNetworksResult
Returns a response object which responds to the following methods:
- #secondary_networks => Array<Types::SecondaryNetwork>
- #next_token => String
1137 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1137
def wait: (
|