Class: Aws::EC2::Waiters::SecondaryNetworkDeleteComplete

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-ec2/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ SecondaryNetworkDeleteComplete

Returns a new instance of SecondaryNetworkDeleteComplete.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 30
  • :delay (Integer) — default: 10
  • :before_attempt (Proc)
  • :before_wait (Proc)


1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
# File 'lib/aws-sdk-ec2/waiters.rb', line 1110

def initialize(options)
  @client = options.fetch(:client)
  @waiter = Aws::Waiters::Waiter.new({
    max_attempts: 30,
    delay: 10,
    poller: Aws::Waiters::Poller.new(
      operation_name: :describe_secondary_networks,
      acceptors: [
        {
          "expected" => "delete-complete",
          "matcher" => "pathAll",
          "state" => "success",
          "argument" => "secondary_networks[].state"
        },
        {
          "expected" => "delete-failed",
          "matcher" => "pathAny",
          "state" => "failure",
          "argument" => "secondary_networks[].state"
        }
      ]
    )
  }.merge(options))
end

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



1142
1143
1144
# File 'lib/aws-sdk-ec2/waiters.rb', line 1142

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeSecondaryNetworksResult

Returns a response object which responds to the following methods:

Options Hash (params):

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

  • :filters (Array<Types::Filter>)

    The filters. The following are the possible values:

    • ‘ipv4-cidr-block-association.association-id` - The association ID for an IPv4 CIDR block associated with the secondary network.

    • ‘ipv4-cidr-block-association.cidr-block` - An IPv4 CIDR block associated with the secondary network.

    • ‘ipv4-cidr-block-association.state` - The state of an IPv4 CIDR block associated with the secondary network.

    • ‘owner-id` - The ID of the Amazon Web Services account that owns the secondary network.

    • ‘secondary-network-id` - The ID of the secondary network.

    • ‘secondary-network-arn` - The ARN of the secondary network.

    • ‘state` - The state of the secondary network (`create-in-progress` | `create-complete` | `create-failed` | `delete-in-progress` | `delete-complete` | `delete-failed`).

    • ‘tag`:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key `Owner` and the value `TeamA`, specify `tag:Owner` for the filter name and `TeamA` for the filter value.

    • ‘tag-key` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.

    • ‘type` - The type of the secondary network (`rdma`).

  • :max_results (Integer)

    The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned ‘nextToken` value.

  • :next_token (String)

    The token for the next page of results.

  • :secondary_network_ids (Array<String>)

    The IDs of the secondary networks.

Returns:



1137
1138
1139
# File 'lib/aws-sdk-ec2/waiters.rb', line 1137

def wait(params = {})
  @waiter.wait(client: @client, params: params)
end