Class: Aws::EC2::Waiters::SecondaryNetworkDeleteComplete
- Inherits:
-
Object
- Object
- Aws::EC2::Waiters::SecondaryNetworkDeleteComplete
- Defined in:
- lib/aws-sdk-ec2/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ SecondaryNetworkDeleteComplete
constructor
A new instance of SecondaryNetworkDeleteComplete.
-
#wait(params = {}) ⇒ Types::DescribeSecondaryNetworksResult
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ SecondaryNetworkDeleteComplete
Returns a new instance of SecondaryNetworkDeleteComplete.
1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1110 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 30, delay: 10, poller: Aws::Waiters::Poller.new( operation_name: :describe_secondary_networks, acceptors: [ { "expected" => "delete-complete", "matcher" => "pathAll", "state" => "success", "argument" => "secondary_networks[].state" }, { "expected" => "delete-failed", "matcher" => "pathAny", "state" => "failure", "argument" => "secondary_networks[].state" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1142 1143 1144 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1142 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeSecondaryNetworksResult
Returns a response object which responds to the following methods:
-
#secondary_networks => Array<Types::SecondaryNetwork>
-
#next_token => String
1137 1138 1139 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1137 def wait(params = {}) @waiter.wait(client: @client, params: params) end |