Class: Aws::EC2::Waiters::SecondarySubnetCreateComplete
- Inherits:
-
Object
- Object
- Aws::EC2::Waiters::SecondarySubnetCreateComplete
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-ec2/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ SecondarySubnetCreateComplete
constructor
A new instance of SecondarySubnetCreateComplete.
-
#wait(params = {}) ⇒ Types::DescribeSecondarySubnetsResult
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ SecondarySubnetCreateComplete
Returns a new instance of SecondarySubnetCreateComplete.
1154 1155 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1154
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1191 1192 1193 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1191 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeSecondarySubnetsResult
Returns a response object which responds to the following methods:
- #secondary_subnets => Array<Types::SecondarySubnet>
- #next_token => String
1186 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1186
def wait: (
|