Class: Aws::EC2::Waiters::SecurityGroupExists
- Inherits:
-
Object
- Object
- Aws::EC2::Waiters::SecurityGroupExists
- Defined in:
- lib/aws-sdk-ec2/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ SecurityGroupExists
constructor
A new instance of SecurityGroupExists.
-
#wait(params = {}) ⇒ Types::DescribeSecurityGroupsResult
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ SecurityGroupExists
Returns a new instance of SecurityGroupExists.
1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 1267 1268 1269 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1247 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 6, delay: 5, poller: Aws::Waiters::Poller.new( operation_name: :describe_security_groups, acceptors: [ { "expected" => true, "matcher" => "path", "state" => "success", "argument" => "length(security_groups[].group_id) > `0`" }, { "expected" => "InvalidGroup.NotFound", "matcher" => "error", "state" => "retry" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1278 1279 1280 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1278 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeSecurityGroupsResult
Returns a response object which responds to the following methods:
-
#next_token => String
-
#security_groups => Array<Types::SecurityGroup>
1273 1274 1275 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1273 def wait(params = {}) @waiter.wait(client: @client, params: params) end |