Class: Aws::EC2::Waiters::SecurityGroupVpcAssociationAssociated

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-ec2/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ SecurityGroupVpcAssociationAssociated

Returns a new instance of SecurityGroupVpcAssociationAssociated.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 7
  • :delay (Integer) — default: 10
  • :before_attempt (Proc)
  • :before_wait (Proc)


1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
# File 'lib/aws-sdk-ec2/waiters.rb', line 1100

def initialize(options)
  @client = options.fetch(:client)
  @waiter = Aws::Waiters::Waiter.new({
    max_attempts: 7,
    delay: 10,
    poller: Aws::Waiters::Poller.new(
      operation_name: :describe_security_group_vpc_associations,
      acceptors: [
        {
          "expected" => "associated",
          "matcher" => "pathAll",
          "state" => "success",
          "argument" => "security_group_vpc_associations[].state"
        },
        {
          "expected" => "associating",
          "matcher" => "pathAny",
          "state" => "retry",
          "argument" => "security_group_vpc_associations[].state"
        },
        {
          "expected" => "association-failed",
          "matcher" => "pathAny",
          "state" => "failure",
          "argument" => "security_group_vpc_associations[].state"
        }
      ]
    )
  }.merge(options))
end

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



1138
1139
1140
# File 'lib/aws-sdk-ec2/waiters.rb', line 1138

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeSecurityGroupVpcAssociationsResult

Returns a response object which responds to the following methods:

Options Hash (params):

  • :filters (Array<Types::Filter>)

    Security group VPC association filters.

    • ‘group-id`: The security group ID.

    • ‘group-owner-id`: The group owner ID.

    • ‘state`: The state of the association.

    • ‘vpc-id`: The ID of the associated VPC.

    • ‘vpc-owner-id`: The account ID of the VPC owner.

  • :next_token (String)

    The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

  • :max_results (Integer)

    The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].

    [1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:



1133
1134
1135
# File 'lib/aws-sdk-ec2/waiters.rb', line 1133

def wait(params = {})
  @waiter.wait(client: @client, params: params)
end