Class: Aws::EC2::Waiters::SnapshotCompleted
- Inherits:
-
Object
- Object
- Aws::EC2::Waiters::SnapshotCompleted
- Defined in:
- lib/aws-sdk-ec2/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ SnapshotCompleted
constructor
A new instance of SnapshotCompleted.
-
#wait(params = {}) ⇒ Types::DescribeSnapshotsResult
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ SnapshotCompleted
Returns a new instance of SnapshotCompleted.
1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1206 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 40, delay: 15, poller: Aws::Waiters::Poller.new( operation_name: :describe_snapshots, acceptors: [ { "expected" => "completed", "matcher" => "pathAll", "state" => "success", "argument" => "snapshots[].state" }, { "expected" => "error", "matcher" => "pathAny", "state" => "failure", "argument" => "snapshots[].state" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1238 1239 1240 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1238 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeSnapshotsResult
Returns a response object which responds to the following methods:
-
#next_token => String
-
#snapshots => Array<Types::Snapshot>
1233 1234 1235 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1233 def wait(params = {}) @waiter.wait(client: @client, params: params) end |