Class: Aws::EC2::Waiters::SnapshotImported
- Inherits:
-
Object
- Object
- Aws::EC2::Waiters::SnapshotImported
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-ec2/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ SnapshotImported
constructor
A new instance of SnapshotImported.
-
#wait(params = {}) ⇒ Types::DescribeImportSnapshotTasksResult
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ SnapshotImported
Returns a new instance of SnapshotImported.
1440 1441 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1440
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1472 1473 1474 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1472 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeImportSnapshotTasksResult
Returns a response object which responds to the following methods:
- #import_snapshot_tasks => Array<Types::ImportSnapshotTask>
- #next_token => String
1467 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1467
def wait: (
|