Class: Aws::EC2::Waiters::SnapshotImported

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-ec2/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ SnapshotImported

Returns a new instance of SnapshotImported.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 40
  • :delay (Integer) — default: 15
  • :before_attempt (Proc)
  • :before_wait (Proc)


1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
# File 'lib/aws-sdk-ec2/waiters.rb', line 1440

def initialize(options)
  @client = options.fetch(:client)
  @waiter = Aws::Waiters::Waiter.new({
    max_attempts: 40,
    delay: 15,
    poller: Aws::Waiters::Poller.new(
      operation_name: :describe_import_snapshot_tasks,
      acceptors: [
        {
          "expected" => "completed",
          "matcher" => "pathAll",
          "state" => "success",
          "argument" => "import_snapshot_tasks[].snapshot_task_detail.status"
        },
        {
          "expected" => "error",
          "matcher" => "pathAny",
          "state" => "failure",
          "argument" => "import_snapshot_tasks[].snapshot_task_detail.status"
        }
      ]
    )
  }.merge(options))
end

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



1472
1473
1474
# File 'lib/aws-sdk-ec2/waiters.rb', line 1472

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeImportSnapshotTasksResult

Returns a response object which responds to the following methods:

Options Hash (params):

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

  • :filters (Array<Types::Filter>)

    The filters.

  • :import_task_ids (Array<String>)

    A list of import snapshot task IDs.

  • :max_results (Integer)

    The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned ‘NextToken` value.

  • :next_token (String)

    A token that indicates the next page of results.

Returns:



1467
1468
1469
# File 'lib/aws-sdk-ec2/waiters.rb', line 1467

def wait(params = {})
  @waiter.wait(client: @client, params: params)
end