Class: Aws::EC2::Waiters::SpotInstanceRequestFulfilled
- Inherits:
-
Object
- Object
- Aws::EC2::Waiters::SpotInstanceRequestFulfilled
- Defined in:
- lib/aws-sdk-ec2/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ SpotInstanceRequestFulfilled
constructor
A new instance of SpotInstanceRequestFulfilled.
-
#wait(params = {}) ⇒ Types::DescribeSpotInstanceRequestsResult
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ SpotInstanceRequestFulfilled
Returns a new instance of SpotInstanceRequestFulfilled.
1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1294 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 40, delay: 15, poller: Aws::Waiters::Poller.new( operation_name: :describe_spot_instance_requests, acceptors: [ { "state" => "success", "matcher" => "pathAll", "argument" => "spot_instance_requests[].status.code", "expected" => "fulfilled" }, { "state" => "success", "matcher" => "pathAll", "argument" => "spot_instance_requests[].status.code", "expected" => "request-canceled-and-instance-running" }, { "state" => "failure", "matcher" => "pathAny", "argument" => "spot_instance_requests[].status.code", "expected" => "schedule-expired" }, { "state" => "failure", "matcher" => "pathAny", "argument" => "spot_instance_requests[].status.code", "expected" => "canceled-before-fulfillment" }, { "state" => "failure", "matcher" => "pathAny", "argument" => "spot_instance_requests[].status.code", "expected" => "bad-parameters" }, { "state" => "failure", "matcher" => "pathAny", "argument" => "spot_instance_requests[].status.code", "expected" => "system-error" }, { "state" => "retry", "matcher" => "error", "expected" => "InvalidSpotInstanceRequestID.NotFound" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1355 1356 1357 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1355 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeSpotInstanceRequestsResult
Returns a response object which responds to the following methods:
-
#spot_instance_requests => Array<Types::SpotInstanceRequest>
-
#next_token => String
1350 1351 1352 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1350 def wait(params = {}) @waiter.wait(client: @client, params: params) end |