Class: Aws::EC2::Waiters::StoreImageTaskComplete

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-ec2/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ StoreImageTaskComplete

Returns a new instance of StoreImageTaskComplete.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 40
  • :delay (Integer) — default: 5
  • :before_attempt (Proc)
  • :before_wait (Proc)


1367
1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
1394
1395
1396
# File 'lib/aws-sdk-ec2/waiters.rb', line 1367

def initialize(options)
  @client = options.fetch(:client)
  @waiter = Aws::Waiters::Waiter.new({
    max_attempts: 40,
    delay: 5,
    poller: Aws::Waiters::Poller.new(
      operation_name: :describe_store_image_tasks,
      acceptors: [
        {
          "expected" => "Completed",
          "matcher" => "pathAll",
          "state" => "success",
          "argument" => "store_image_task_results[].store_task_state"
        },
        {
          "expected" => "Failed",
          "matcher" => "pathAny",
          "state" => "failure",
          "argument" => "store_image_task_results[].store_task_state"
        },
        {
          "expected" => "InProgress",
          "matcher" => "pathAny",
          "state" => "retry",
          "argument" => "store_image_task_results[].store_task_state"
        }
      ]
    )
  }.merge(options))
end

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



1405
1406
1407
# File 'lib/aws-sdk-ec2/waiters.rb', line 1405

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeStoreImageTasksResult

Returns a response object which responds to the following methods:

Options Hash (params):

  • :image_ids (Array<String>)

    The AMI IDs for which to show progress. Up to 20 AMI IDs can be included in a request.

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

  • :filters (Array<Types::Filter>)

    The filters.

    • ‘task-state` - Returns tasks in a certain state (`InProgress` | `Completed` | `Failed`)

    • ‘bucket` - Returns task information for tasks that targeted a specific bucket. For the filter value, specify the bucket name.

    <note markdown=“1”> When you specify the ‘ImageIds` parameter, any filters that you specify are ignored. To use the filters, you must remove the `ImageIds` parameter.

    </note>
    
  • :next_token (String)

    The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

  • :max_results (Integer)

    The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].

    You cannot specify this parameter and the ‘ImageIds` parameter in the same call.

    [1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination

Returns:



1400
1401
1402
# File 'lib/aws-sdk-ec2/waiters.rb', line 1400

def wait(params = {})
  @waiter.wait(client: @client, params: params)
end