Class: Aws::EC2::Waiters::VpcAvailable

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-ec2/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ VpcAvailable

Returns a new instance of VpcAvailable.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 40
  • :delay (Integer) — default: 15
  • :before_attempt (Proc)
  • :before_wait (Proc)


1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
# File 'lib/aws-sdk-ec2/waiters.rb', line 1810

def initialize(options)
  @client = options.fetch(:client)
  @waiter = Aws::Waiters::Waiter.new({
    max_attempts: 40,
    delay: 15,
    poller: Aws::Waiters::Poller.new(
      operation_name: :describe_vpcs,
      acceptors: [{
        "expected" => "available",
        "matcher" => "pathAll",
        "state" => "success",
        "argument" => "vpcs[].state"
      }]
    )
  }.merge(options))
end

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



1834
1835
1836
# File 'lib/aws-sdk-ec2/waiters.rb', line 1834

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeVpcsResult

Returns a response object which responds to the following methods:

Options Hash (params):

  • :filters (Array<Types::Filter>)

    The filters.

    • ‘cidr` - The primary IPv4 CIDR block of the VPC. The CIDR block you specify must exactly match the VPC’s CIDR block for information to be returned for the VPC. Must contain the slash followed by one or two digits (for example, ‘/28`).

    • ‘cidr-block-association.cidr-block` - An IPv4 CIDR block associated with the VPC.

    • ‘cidr-block-association.association-id` - The association ID for an IPv4 CIDR block associated with the VPC.

    • ‘cidr-block-association.state` - The state of an IPv4 CIDR block associated with the VPC.

    • ‘dhcp-options-id` - The ID of a set of DHCP options.

    • ‘ipv6-cidr-block-association.ipv6-cidr-block` - An IPv6 CIDR block associated with the VPC.

    • ‘ipv6-cidr-block-association.ipv6-pool` - The ID of the IPv6 address pool from which the IPv6 CIDR block is allocated.

    • ‘ipv6-cidr-block-association.association-id` - The association ID for an IPv6 CIDR block associated with the VPC.

    • ‘ipv6-cidr-block-association.state` - The state of an IPv6 CIDR block associated with the VPC.

    • ‘is-default` - Indicates whether the VPC is the default VPC.

    • ‘owner-id` - The ID of the Amazon Web Services account that owns the VPC.

    • ‘state` - The state of the VPC (`pending` | `available`).

    • ‘tag` - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key `Owner` and the value `TeamA`, specify `tag:Owner` for the filter name and `TeamA` for the filter value.

    • ‘tag-key` - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.

    • ‘vpc-id` - The ID of the VPC.

  • :vpc_ids (Array<String>)

    The IDs of the VPCs.

  • :next_token (String)

    The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

  • :max_results (Integer)

    The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see [Pagination].

    [1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination

  • :dry_run (Boolean)

    Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is ‘DryRunOperation`. Otherwise, it is `UnauthorizedOperation`.

Returns:



1829
1830
1831
# File 'lib/aws-sdk-ec2/waiters.rb', line 1829

def wait(params = {})
  @waiter.wait(client: @client, params: params)
end