Class: Aws::EC2::Waiters::VpcAvailable
- Inherits:
-
Object
- Object
- Aws::EC2::Waiters::VpcAvailable
- Defined in:
- lib/aws-sdk-ec2/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ VpcAvailable
constructor
A new instance of VpcAvailable.
-
#wait(params = {}) ⇒ Types::DescribeVpcsResult
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ VpcAvailable
Returns a new instance of VpcAvailable.
1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1620 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 40, delay: 15, poller: Aws::Waiters::Poller.new( operation_name: :describe_vpcs, acceptors: [{ "expected" => "available", "matcher" => "pathAll", "state" => "success", "argument" => "vpcs[].state" }] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1644 1645 1646 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1644 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeVpcsResult
Returns a response object which responds to the following methods:
-
#next_token => String
-
#vpcs => Array<Types::Vpc>
1639 1640 1641 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1639 def wait(params = {}) @waiter.wait(client: @client, params: params) end |