Class: Aws::EC2::Waiters::VpnConnectionAvailable
- Inherits:
-
Object
- Object
- Aws::EC2::Waiters::VpnConnectionAvailable
- Defined in:
- lib/aws-sdk-ec2/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ VpnConnectionAvailable
constructor
A new instance of VpnConnectionAvailable.
-
#wait(params = {}) ⇒ Types::DescribeVpnConnectionsResult
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ VpnConnectionAvailable
Returns a new instance of VpnConnectionAvailable.
1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1973 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 40, delay: 15, poller: Aws::Waiters::Poller.new( operation_name: :describe_vpn_connections, acceptors: [ { "expected" => "available", "matcher" => "pathAll", "state" => "success", "argument" => "vpn_connections[].state" }, { "expected" => "deleting", "matcher" => "pathAny", "state" => "failure", "argument" => "vpn_connections[].state" }, { "expected" => "deleted", "matcher" => "pathAny", "state" => "failure", "argument" => "vpn_connections[].state" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2011 2012 2013 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 2011 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeVpnConnectionsResult
Returns a response object which responds to the following methods:
-
#vpn_connections => Array<Types::VpnConnection>
2006 2007 2008 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 2006 def wait(params = {}) @waiter.wait(client: @client, params: params) end |