Class: Aws::EC2::Waiters::VpnConnectionDeleted
- Inherits:
-
Object
- Object
- Aws::EC2::Waiters::VpnConnectionDeleted
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-ec2/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ VpnConnectionDeleted
constructor
A new instance of VpnConnectionDeleted.
-
#wait(params = {}) ⇒ Types::DescribeVpnConnectionsResult
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ VpnConnectionDeleted
Returns a new instance of VpnConnectionDeleted.
2023 2024 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 2023
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2055 2056 2057 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 2055 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeVpnConnectionsResult
Returns a response object which responds to the following methods:
- #vpn_connections => Array<Types::VpnConnection>
2050 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 2050
def wait: (
|