Class: Aws::EC2::Waiters::VpnConnectionDeleted
- Inherits:
-
Object
- Object
- Aws::EC2::Waiters::VpnConnectionDeleted
- Defined in:
- lib/aws-sdk-ec2/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ VpnConnectionDeleted
constructor
A new instance of VpnConnectionDeleted.
-
#wait(params = {}) ⇒ Types::DescribeVpnConnectionsResult
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ VpnConnectionDeleted
Returns a new instance of VpnConnectionDeleted.
1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1833 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 40, delay: 15, poller: Aws::Waiters::Poller.new( operation_name: :describe_vpn_connections, acceptors: [ { "expected" => "deleted", "matcher" => "pathAll", "state" => "success", "argument" => "vpn_connections[].state" }, { "expected" => "pending", "matcher" => "pathAny", "state" => "failure", "argument" => "vpn_connections[].state" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1865 1866 1867 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1865 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeVpnConnectionsResult
Returns a response object which responds to the following methods:
-
#vpn_connections => Array<Types::VpnConnection>
1860 1861 1862 |
# File 'lib/aws-sdk-ec2/waiters.rb', line 1860 def wait(params = {}) @waiter.wait(client: @client, params: params) end |